
#include "nir.h"
#include "nir_builder.h"
#include "nir_search.h"
#include "nir_search_helpers.h"

/* What follows is NIR algebraic transform code for the following 2067
 * transforms:
 *    ('imul', 'a', '#b(is_pos_power_of_two)') => ('ishl', 'a', ('find_lsb', 'b'))
 *    ('imul', 'a@8', 128) => ('ishl', 'a', 7)
 *    ('imul', 'a@16', 32768) => ('ishl', 'a', 15)
 *    ('imul', 'a@32', 2147483648) => ('ishl', 'a', 31)
 *    ('imul', 'a@64', 9223372036854775808) => ('ishl', 'a', 63)
 *    ('imul', 'a', '#b(is_neg_power_of_two)') => ('ineg', ('ishl', 'a', ('find_lsb', ('iabs', 'b'))))
 *    ('ishl', 'a', '#b') => ('imul', 'a', ('ishl', 1, 'b'))
 *    ('imul@64', 'a', '#b(is_bitcount2)') => ('iadd', ('ishl', 'a', ('ufind_msb', 'b')), ('ishl', 'a', ('find_lsb', 'b')))
 *    ('unpack_64_2x32_split_x', ('imul_2x32_64(is_used_once)', 'a', 'b')) => ('imul', 'a', 'b')
 *    ('unpack_64_2x32_split_x', ('umul_2x32_64(is_used_once)', 'a', 'b')) => ('imul', 'a', 'b')
 *    ('imul_2x32_64', 'a', 'b') => ('pack_64_2x32_split', ('imul', 'a', 'b'), ('imul_high', 'a', 'b'))
 *    ('umul_2x32_64', 'a', 'b') => ('pack_64_2x32_split', ('imul', 'a', 'b'), ('umul_high', 'a', 'b'))
 *    ('udiv', 'a', 1) => a
 *    ('idiv', 'a', 1) => a
 *    ('umod', 'a', 1) => 0
 *    ('imod', 'a', 1) => 0
 *    ('imod', 'a', -1) => 0
 *    ('irem', 'a', 1) => 0
 *    ('irem', 'a', -1) => 0
 *    ('udiv', 'a', '#b(is_pos_power_of_two)') => ('ushr', 'a', ('find_lsb', 'b'))
 *    ('idiv', 'a', '#b(is_pos_power_of_two)') => ('imul', ('isign', 'a'), ('ushr', ('iabs', 'a'), ('find_lsb', 'b')))
 *    ('idiv', 'a', '#b(is_neg_power_of_two)') => ('ineg', ('imul', ('isign', 'a'), ('ushr', ('iabs', 'a'), ('find_lsb', ('iabs', 'b')))))
 *    ('umod', 'a', '#b(is_pos_power_of_two)') => ('iand', 'a', ('isub', 'b', 1))
 *    ('imod', 'a', '#b(is_pos_power_of_two)') => ('iand', 'a', ('isub', 'b', 1))
 *    ('imod', 'a', '#b(is_neg_power_of_two)') => ('bcsel', ('ieq', ('ior', 'a', 'b'), 'b'), 0, ('ior', 'a', 'b'))
 *    ('irem', 'a', '#b(is_pos_power_of_two)') => ('isub', 'a', ('iand', ('bcsel', ('ilt', 'a', 0), ('iadd', 'a', ('isub', 'b', 1)), 'a'), ('ineg', 'b')))
 *    ('irem', 'a', '#b(is_neg_power_of_two)') => ('irem', 'a', ('iabs', 'b'))
 *    ('~fneg', ('fneg', 'a')) => a
 *    ('ineg', ('ineg', 'a')) => a
 *    ('fabs', ('fneg', 'a')) => ('fabs', 'a')
 *    ('fabs', ('u2f', 'a')) => ('u2f', 'a')
 *    ('iabs', ('iabs', 'a')) => ('iabs', 'a')
 *    ('iabs', ('ineg', 'a')) => ('iabs', 'a')
 *    ('f2b', ('fneg', 'a')) => ('f2b', 'a')
 *    ('~fadd', 'a', 0.0) => a
 *    ('fadd(is_only_used_as_float)', 'a@16', 0.0) => a
 *    ('fadd(is_only_used_as_float)', 'a@32', 0.0) => a
 *    ('iadd', 'a', 0) => a
 *    ('iadd_sat', 'a', 0) => a
 *    ('isub_sat', 'a', 0) => a
 *    ('uadd_sat', 'a', 0) => a
 *    ('usub_sat', 'a', 0) => a
 *    ('usadd_4x8_vc4', 'a', 0) => a
 *    ('usadd_4x8_vc4', 'a', -1) => -1
 *    ('~fadd', ('fmul', 'a', 'b'), ('fmul', 'a', 'c')) => ('fmul', 'a', ('fadd', 'b', 'c'))
 *    ('~fadd', ('fmulz', 'a', 'b'), ('fmulz', 'a', 'c')) => ('fmulz', 'a', ('fadd', 'b', 'c'))
 *    ('~ffma', 'a', 'b', ('ffma(is_used_once)', 'a', 'c', 'd')) => ('ffma', 'a', ('fadd', 'b', 'c'), 'd')
 *    ('~ffma', 'a', 'b', ('fmul(is_used_once)', 'a', 'c')) => ('fmul', 'a', ('fadd', 'b', 'c'))
 *    ('~fadd', ('fmul(is_used_once)', 'a', 'b'), ('ffma(is_used_once)', 'a', 'c', 'd')) => ('ffma', 'a', ('fadd', 'b', 'c'), 'd')
 *    ('~ffma', 'a', ('fmul(is_used_once)', 'b', 'c'), ('fmul(is_used_once)', 'b', 'd')) => ('fmul', 'b', ('ffma', 'a', 'c', 'd'))
 *    ('~ffmaz', 'a', 'b', ('ffmaz(is_used_once)', 'a', 'c', 'd')) => ('ffmaz', 'a', ('fadd', 'b', 'c'), 'd')
 *    ('~ffmaz', 'a', 'b', ('fmulz(is_used_once)', 'a', 'c')) => ('fmulz', 'a', ('fadd', 'b', 'c'))
 *    ('~fadd', ('fmulz(is_used_once)', 'a', 'b'), ('ffmaz(is_used_once)', 'a', 'c', 'd')) => ('ffmaz', 'a', ('fadd', 'b', 'c'), 'd')
 *    ('~ffmaz', 'a', ('fmulz(is_used_once)', 'b', 'c'), ('fmulz(is_used_once)', 'b', 'd')) => ('fmulz', 'b', ('ffmaz', 'a', 'c', 'd'))
 *    ('iadd', ('imul', 'a', 'b'), ('imul', 'a', 'c')) => ('imul', 'a', ('iadd', 'b', 'c'))
 *    ('iadd', ('ishl', 'b', 'a'), ('ishl', 'c', 'a')) => ('ishl', ('iadd', 'b', 'c'), 'a')
 *    ('iand', ('ior', 'a', 'b'), ('ior', 'a', 'c')) => ('ior', 'a', ('iand', 'b', 'c'))
 *    ('ior', ('iand', 'a', 'b'), ('iand', 'a', 'c')) => ('iand', 'a', ('ior', 'b', 'c'))
 *    ('ieq', ('iand', 'a', '#b(is_pos_power_of_two)'), 'b') => ('ine', ('iand', 'a', 'b'), 0)
 *    ('ine', ('iand', 'a', '#b(is_pos_power_of_two)'), 'b') => ('ieq', ('iand', 'a', 'b'), 0)
 *    ('~fadd', ('fneg', 'a'), 'a') => 0.0
 *    ('iadd', ('ineg', 'a'), 'a') => 0
 *    ('iadd', ('ineg', 'a'), ('iadd', 'a', 'b')) => b
 *    ('iadd', 'a', ('iadd', ('ineg', 'a'), 'b')) => b
 *    ('~fadd', ('fneg', 'a'), ('fadd', 'a', 'b')) => b
 *    ('~fadd', 'a', ('fadd', ('fneg', 'a'), 'b')) => b
 *    ('fadd', ('fsat', 'a'), ('fsat', ('fneg', 'a'))) => ('fsat', ('fabs', 'a'))
 *    ('~fmul', 'a', 0.0) => 0.0
 *    ('fmul', 'a@16', 0.0) => 0.0
 *    ('fmul', 'a@32', 0.0) => 0.0
 *    ('fmulz', 'a', 0.0) => 0.0
 *    ('fmulz', 'a', 'b(is_finite_not_zero)') => ('fmul', 'a', 'b')
 *    ('fmulz', 'a(is_finite)', 'b(is_finite)') => ('fmul', 'a', 'b')
 *    ('fmulz', 'a', 'a') => ('fmul', 'a', 'a')
 *    ('ffmaz', 'a', 'b(is_finite_not_zero)', 'c') => ('ffma', 'a', 'b', 'c')
 *    ('ffmaz', 'a(is_finite)', 'b(is_finite)', 'c') => ('ffma', 'a', 'b', 'c')
 *    ('ffmaz', 'a', 'a', 'b') => ('ffma', 'a', 'a', 'b')
 *    ('imul', 'a', 0) => 0
 *    ('umul_unorm_4x8_vc4', 'a', 0) => 0
 *    ('umul_unorm_4x8_vc4', 'a', -1) => a
 *    ('~fmul', 'a', 1.0) => a
 *    ('~fmulz', 'a', 1.0) => a
 *    ('fmul(is_only_used_as_float)', 'a', 1.0) => a
 *    ('imul', 'a', 1) => a
 *    ('fmul', 'a', -1.0) => ('fneg', 'a')
 *    ('imul', 'a', -1) => ('ineg', 'a')
 *    ('fmul', ('fsign', 'a'), ('fmul', 'a', 'a')) => ('fmul', ('fabs', 'a'), 'a')
 *    ('fmul', ('fmul', ('fsign', 'a'), 'a'), 'a') => ('fmul', ('fabs', 'a'), 'a')
 *    ('~ffma', 0.0, 'a', 'b') => b
 *    ('ffma@16(is_only_used_as_float)', 0.0, 'a', 'b') => b
 *    ('ffma@32(is_only_used_as_float)', 0.0, 'a', 'b') => b
 *    ('ffmaz', 0.0, 'a', 'b') => ('fadd', 0.0, 'b')
 *    ('~ffma', 'a', 'b', 0.0) => ('fmul', 'a', 'b')
 *    ('ffma@16', 'a', 'b', 0.0) => ('fmul', 'a', 'b')
 *    ('ffma@32', 'a', 'b', 0.0) => ('fmul', 'a', 'b')
 *    ('ffmaz', 'a', 'b', 0.0) => ('fmulz', 'a', 'b')
 *    ('ffma', 1.0, 'a', 'b') => ('fadd', 'a', 'b')
 *    ('ffmaz', 1.0, 'a', 'b') => ('fadd', 'a', 'b')
 *    ('ffma', -1.0, 'a', 'b') => ('fadd', ('fneg', 'a'), 'b')
 *    ('ffmaz', -1.0, 'a', 'b') => ('fadd', ('fneg', 'a'), 'b')
 *    ('~ffma', '#a', '#b', 'c') => ('fadd', ('fmul', 'a', 'b'), 'c')
 *    ('~ffmaz', '#a', '#b', 'c') => ('fadd', ('fmulz', 'a', 'b'), 'c')
 *    ('~flrp', 'a', 'b', 0.0) => a
 *    ('~flrp', 'a', 'b', 1.0) => b
 *    ('~flrp', 'a', 'a', 'b') => a
 *    ('~flrp', 0.0, 'a', 'b') => ('fmul', 'a', 'b')
 *    ('~flrp', 'a', ('fadd(is_used_once)', 'a', 'b'), 'c') => ('fadd', ('fmul', 'b', 'c'), 'a')
 *    ('sdot_4x8_iadd', 'a', 0, 'b') => b
 *    ('udot_4x8_uadd', 'a', 0, 'b') => b
 *    ('sdot_4x8_iadd_sat', 'a', 0, 'b') => b
 *    ('udot_4x8_uadd_sat', 'a', 0, 'b') => b
 *    ('sdot_2x16_iadd', 'a', 0, 'b') => b
 *    ('udot_2x16_uadd', 'a', 0, 'b') => b
 *    ('sdot_2x16_iadd_sat', 'a', 0, 'b') => b
 *    ('udot_2x16_uadd_sat', 'a', 0, 'b') => b
 *    ('sudot_4x8_iadd', 'a', 0, 'b') => b
 *    ('sudot_4x8_iadd', 0, 'a', 'b') => b
 *    ('sudot_4x8_iadd_sat', 'a', 0, 'b') => b
 *    ('sudot_4x8_iadd_sat', 0, 'a', 'b') => b
 *    ('iadd', ('sdot_4x8_iadd(is_used_once)', 'a', 'b', '#c'), '#d') => ('sdot_4x8_iadd', 'a', 'b', ('iadd', 'c', 'd'))
 *    ('iadd', ('udot_4x8_uadd(is_used_once)', 'a', 'b', '#c'), '#d') => ('udot_4x8_uadd', 'a', 'b', ('iadd', 'c', 'd'))
 *    ('iadd', ('sudot_4x8_iadd(is_used_once)', 'a', 'b', '#c'), '#d') => ('sudot_4x8_iadd', 'a', 'b', ('iadd', 'c', 'd'))
 *    ('iadd', ('sdot_2x16_iadd(is_used_once)', 'a', 'b', '#c'), '#d') => ('sdot_2x16_iadd', 'a', 'b', ('iadd', 'c', 'd'))
 *    ('iadd', ('udot_2x16_uadd(is_used_once)', 'a', 'b', '#c'), '#d') => ('udot_2x16_uadd', 'a', 'b', ('iadd', 'c', 'd'))
 *    ('iadd', ('sdot_4x8_iadd', 'a(is_not_const)', 'b', 0), 'c') => ('sdot_4x8_iadd', 'a', 'b', 'c')
 *    ('iadd', ('udot_4x8_uadd', 'a(is_not_const)', 'b', 0), 'c') => ('udot_4x8_uadd', 'a', 'b', 'c')
 *    ('iadd', ('sudot_4x8_iadd', 'a(is_not_const)', 'b', 0), 'c') => ('sudot_4x8_iadd', 'a', 'b', 'c')
 *    ('iadd', ('sudot_4x8_iadd', 'a', 'b(is_not_const)', 0), 'c') => ('sudot_4x8_iadd', 'a', 'b', 'c')
 *    ('iadd', ('sdot_2x16_iadd', 'a(is_not_const)', 'b', 0), 'c') => ('sdot_2x16_iadd', 'a', 'b', 'c')
 *    ('iadd', ('udot_2x16_uadd', 'a(is_not_const)', 'b', 0), 'c') => ('udot_2x16_uadd', 'a', 'b', 'c')
 *    ('sdot_4x8_iadd', '#a', '#b', 'c(is_not_const)') => ('iadd', ('sdot_4x8_iadd', 'a', 'b', 0), 'c')
 *    ('udot_4x8_uadd', '#a', '#b', 'c(is_not_const)') => ('iadd', ('udot_4x8_uadd', 'a', 'b', 0), 'c')
 *    ('sudot_4x8_iadd', '#a', '#b', 'c(is_not_const)') => ('iadd', ('sudot_4x8_iadd', 'a', 'b', 0), 'c')
 *    ('sdot_2x16_iadd', '#a', '#b', 'c(is_not_const)') => ('iadd', ('sdot_2x16_iadd', 'a', 'b', 0), 'c')
 *    ('udot_2x16_uadd', '#a', '#b', 'c(is_not_const)') => ('iadd', ('udot_2x16_uadd', 'a', 'b', 0), 'c')
 *    ('sdot_4x8_iadd_sat', '#a', '#b', 'c(is_not_const)') => ('iadd_sat', ('sdot_4x8_iadd', 'a', 'b', 0), 'c')
 *    ('udot_4x8_uadd_sat', '#a', '#b', 'c(is_not_const)') => ('uadd_sat', ('udot_4x8_uadd', 'a', 'b', 0), 'c')
 *    ('sudot_4x8_iadd_sat', '#a', '#b', 'c(is_not_const)') => ('iadd_sat', ('sudot_4x8_iadd', 'a', 'b', 0), 'c')
 *    ('sdot_2x16_iadd_sat', '#a', '#b', 'c(is_not_const)') => ('iadd_sat', ('sdot_2x16_iadd', 'a', 'b', 0), 'c')
 *    ('udot_2x16_uadd_sat', '#a', '#b', 'c(is_not_const)') => ('uadd_sat', ('udot_2x16_uadd', 'a', 'b', 0), 'c')
 *    ('fmul@32', ('bcsel', ('feq', 'b', 0.0, 'ignore_exact'), 0.0, 'a'), ('bcsel', ('feq', 'a', 0.0, 'ignore_exact'), 0.0, 'b')) => ('fmulz', 'a', 'b')
 *    ('fmul@32', 'a', ('bcsel', ('feq', 'a', 0.0, 'ignore_exact'), 0.0, '#b(is_not_const_zero)')) => ('fmulz', 'a', 'b')
 *    ('ffma@32', ('bcsel', ('feq', 'b', 0.0, 'ignore_exact'), 0.0, 'a'), ('bcsel', ('feq', 'a', 0.0, 'ignore_exact'), 0.0, 'b'), 'c') => ('ffmaz', 'a', 'b', 'c')
 *    ('ffma@32', 'a', ('bcsel', ('feq', 'a', 0.0, 'ignore_exact'), 0.0, '#b(is_not_const_zero)'), 'c') => ('ffmaz', 'a', 'b', 'c')
 *    ('bcsel', ('feq', 'b', 0.0, 'ignore_exact'), 1.0, ('fexp2', ('fmul@32', 'a', 'b'))) => ('fexp2', ('fmulz', 'a', 'b'))
 *    ('sdot_4x8_iadd', 'a', 'b', 'c') => ('iadd', ('iadd', ('iadd', ('imul', ('extract_i8', 'a', 0), ('extract_i8', 'b', 0)), ('imul', ('extract_i8', 'a', 1), ('extract_i8', 'b', 1))), ('iadd', ('imul', ('extract_i8', 'a', 2), ('extract_i8', 'b', 2)), ('imul', ('extract_i8', 'a', 3), ('extract_i8', 'b', 3)))), 'c')
 *    ('udot_4x8_uadd', 'a', 'b', 'c') => ('iadd', ('iadd', ('iadd', ('imul', ('extract_u8', 'a', 0), ('extract_u8', 'b', 0)), ('imul', ('extract_u8', 'a', 1), ('extract_u8', 'b', 1))), ('iadd', ('imul', ('extract_u8', 'a', 2), ('extract_u8', 'b', 2)), ('imul', ('extract_u8', 'a', 3), ('extract_u8', 'b', 3)))), 'c')
 *    ('sudot_4x8_iadd', 'a', 'b', 'c') => ('iadd', ('iadd', ('iadd', ('imul', ('extract_i8', 'a', 0), ('extract_u8', 'b', 0)), ('imul', ('extract_i8', 'a', 1), ('extract_u8', 'b', 1))), ('iadd', ('imul', ('extract_i8', 'a', 2), ('extract_u8', 'b', 2)), ('imul', ('extract_i8', 'a', 3), ('extract_u8', 'b', 3)))), 'c')
 *    ('sdot_2x16_iadd', 'a', 'b', 'c') => ('iadd', ('iadd', ('imul', ('extract_i16', 'a', 0), ('extract_i16', 'b', 0)), ('imul', ('extract_i16', 'a', 1), ('extract_i16', 'b', 1))), 'c')
 *    ('udot_2x16_uadd', 'a', 'b', 'c') => ('iadd', ('iadd', ('imul', ('extract_u16', 'a', 0), ('extract_u16', 'b', 0)), ('imul', ('extract_u16', 'a', 1), ('extract_u16', 'b', 1))), 'c')
 *    ('udot_4x8_uadd_sat', 'a', 'b', '#c(is_ult_0xfffc07fc)') => ('udot_4x8_uadd', 'a', 'b', 'c')
 *    ('udot_4x8_uadd_sat', 'a', 'b', 'c') => ('uadd_sat', ('iadd', ('iadd', ('imul', ('extract_u8', 'a', 0), ('extract_u8', 'b', 0)), ('imul', ('extract_u8', 'a', 1), ('extract_u8', 'b', 1))), ('iadd', ('imul', ('extract_u8', 'a', 2), ('extract_u8', 'b', 2)), ('imul', ('extract_u8', 'a', 3), ('extract_u8', 'b', 3)))), 'c')
 *    ('sdot_4x8_iadd_sat', 'a', 'b', 'c') => ('iadd_sat', ('iadd', ('iadd', ('imul', ('extract_i8', 'a', 0), ('extract_i8', 'b', 0)), ('imul', ('extract_i8', 'a', 1), ('extract_i8', 'b', 1))), ('iadd', ('imul', ('extract_i8', 'a', 2), ('extract_i8', 'b', 2)), ('imul', ('extract_i8', 'a', 3), ('extract_i8', 'b', 3)))), 'c')
 *    ('sudot_4x8_iadd_sat', 'a', 'b', 'c') => ('iadd_sat', ('iadd', ('iadd', ('imul', ('extract_i8', 'a', 0), ('extract_u8', 'b', 0)), ('imul', ('extract_i8', 'a', 1), ('extract_u8', 'b', 1))), ('iadd', ('imul', ('extract_i8', 'a', 2), ('extract_u8', 'b', 2)), ('imul', ('extract_i8', 'a', 3), ('extract_u8', 'b', 3)))), 'c')
 *    ('udot_2x16_uadd_sat', 'a', 'b', 'c') => ('uadd_sat', ('iadd', ('imul', ('extract_u16', 'a', 0), ('extract_u16', 'b', 0)), ('imul', ('extract_u16', 'a', 1), ('extract_u16', 'b', 1))), 'c')
 *    ('sdot_2x16_iadd_sat', 'a', 'b', 'c') => ('iadd_sat', ('iadd', ('imul', ('extract_i16', 'a', 0), ('extract_i16', 'b', 0)), ('imul', ('extract_i16', 'a', 1), ('extract_i16', 'b', 1))), 'c')
 *    ('~flrp@16', 'a', 'b', ('b2f', 'c@1')) => ('bcsel', 'c', 'b', 'a')
 *    ('~flrp@16', 'a', ('fadd', 'a', 'b'), 'c') => ('fadd', ('fmul', 'b', 'c'), 'a')
 *    ('~flrp@16', ('fadd(is_used_once)', 'a', 'b'), ('fadd(is_used_once)', 'a', 'c'), 'd') => ('fadd', ('flrp', 'b', 'c', 'd'), 'a')
 *    ('~flrp@16', 'a', ('fmul(is_used_once)', 'a', 'b'), 'c') => ('fmul', ('flrp', 1.0, 'b', 'c'), 'a')
 *    ('~fadd@16', ('fmul', 'a', ('fadd', 1.0, ('fneg', 'c'))), ('fmul', 'b', 'c')) => ('flrp', 'a', 'b', 'c')
 *    ('~fadd@16', ('fmul', 'a', ('fsat', ('fadd', 1.0, ('fneg', 'c')))), ('fmul', 'b', ('fsat', 'c'))) => ('flrp', 'a', 'b', ('fsat', 'c'))
 *    ('~fadd@16', 'a', ('fmul', 'c', ('fadd', 'b', ('fneg', 'a')))) => ('flrp', 'a', 'b', 'c')
 *    ('~fadd@16', ('fmul', 'a', ('fadd', 1.0, ('fneg', ('b2f', 'c@1')))), ('fmul', 'b', ('b2f', 'c'))) => ('bcsel', 'c', 'b', 'a')
 *    ('~fadd@16', 'a', ('fmul', ('b2f', 'c@1'), ('fadd', 'b', ('fneg', 'a')))) => ('bcsel', 'c', 'b', 'a')
 *    ('~ffma@16', 'a', ('fadd', 1.0, ('fneg', ('b2f', 'c@1'))), ('fmul', 'b', ('b2f', 'c@1'))) => ('bcsel', 'c', 'b', 'a')
 *    ('~ffma@16', 'b', ('b2f', 'c@1'), ('ffma', ('fneg', 'a'), ('b2f', 'c@1'), 'a')) => ('bcsel', 'c', 'b', 'a')
 *    ('~ffma@16', ('b2f', 'c@1'), ('fadd', 'b', ('fneg', 'a')), 'a') => ('bcsel', 'c', 'b', 'a')
 *    ('~ffma@16', ('b2f', 'c@1'), ('ffma', ('fneg', 'a'), 'b', 'd'), ('fmul', 'a', 'b')) => ('bcsel', 'c', 'd', ('fmul', 'a', 'b'))
 *    ('~fadd@16', 1.0, ('fneg', ('fmul', ('fadd', 1.0, ('fneg', 'a')), ('fadd', 1.0, ('fneg', 'b'))))) => ('flrp', 'b', 1.0, 'a')
 *    ('~flrp@32', 'a', 'b', ('b2f', 'c@1')) => ('bcsel', 'c', 'b', 'a')
 *    ('~flrp@32', 'a', ('fadd', 'a', 'b'), 'c') => ('fadd', ('fmul', 'b', 'c'), 'a')
 *    ('~flrp@32', ('fadd(is_used_once)', 'a', 'b'), ('fadd(is_used_once)', 'a', 'c'), 'd') => ('fadd', ('flrp', 'b', 'c', 'd'), 'a')
 *    ('~flrp@32', 'a', ('fmul(is_used_once)', 'a', 'b'), 'c') => ('fmul', ('flrp', 1.0, 'b', 'c'), 'a')
 *    ('~fadd@32', ('fmul', 'a', ('fadd', 1.0, ('fneg', 'c'))), ('fmul', 'b', 'c')) => ('flrp', 'a', 'b', 'c')
 *    ('~fadd@32', ('fmul', 'a', ('fsat', ('fadd', 1.0, ('fneg', 'c')))), ('fmul', 'b', ('fsat', 'c'))) => ('flrp', 'a', 'b', ('fsat', 'c'))
 *    ('~fadd@32', 'a', ('fmul', 'c', ('fadd', 'b', ('fneg', 'a')))) => ('flrp', 'a', 'b', 'c')
 *    ('~fadd@32', ('fmul', 'a', ('fadd', 1.0, ('fneg', ('b2f', 'c@1')))), ('fmul', 'b', ('b2f', 'c'))) => ('bcsel', 'c', 'b', 'a')
 *    ('~fadd@32', 'a', ('fmul', ('b2f', 'c@1'), ('fadd', 'b', ('fneg', 'a')))) => ('bcsel', 'c', 'b', 'a')
 *    ('~ffma@32', 'a', ('fadd', 1.0, ('fneg', ('b2f', 'c@1'))), ('fmul', 'b', ('b2f', 'c@1'))) => ('bcsel', 'c', 'b', 'a')
 *    ('~ffma@32', 'b', ('b2f', 'c@1'), ('ffma', ('fneg', 'a'), ('b2f', 'c@1'), 'a')) => ('bcsel', 'c', 'b', 'a')
 *    ('~ffma@32', ('b2f', 'c@1'), ('fadd', 'b', ('fneg', 'a')), 'a') => ('bcsel', 'c', 'b', 'a')
 *    ('~ffma@32', ('b2f', 'c@1'), ('ffma', ('fneg', 'a'), 'b', 'd'), ('fmul', 'a', 'b')) => ('bcsel', 'c', 'd', ('fmul', 'a', 'b'))
 *    ('~fadd@32', 1.0, ('fneg', ('fmul', ('fadd', 1.0, ('fneg', 'a')), ('fadd', 1.0, ('fneg', 'b'))))) => ('flrp', 'b', 1.0, 'a')
 *    ('~flrp@64', 'a', 'b', ('b2f', 'c@1')) => ('bcsel', 'c', 'b', 'a')
 *    ('~flrp@64', 'a', ('fadd', 'a', 'b'), 'c') => ('fadd', ('fmul', 'b', 'c'), 'a')
 *    ('~flrp@64', ('fadd(is_used_once)', 'a', 'b'), ('fadd(is_used_once)', 'a', 'c'), 'd') => ('fadd', ('flrp', 'b', 'c', 'd'), 'a')
 *    ('~flrp@64', 'a', ('fmul(is_used_once)', 'a', 'b'), 'c') => ('fmul', ('flrp', 1.0, 'b', 'c'), 'a')
 *    ('~fadd@64', ('fmul', 'a', ('fadd', 1.0, ('fneg', 'c'))), ('fmul', 'b', 'c')) => ('flrp', 'a', 'b', 'c')
 *    ('~fadd@64', ('fmul', 'a', ('fsat', ('fadd', 1.0, ('fneg', 'c')))), ('fmul', 'b', ('fsat', 'c'))) => ('flrp', 'a', 'b', ('fsat', 'c'))
 *    ('~fadd@64', 'a', ('fmul', 'c', ('fadd', 'b', ('fneg', 'a')))) => ('flrp', 'a', 'b', 'c')
 *    ('~fadd@64', ('fmul', 'a', ('fadd', 1.0, ('fneg', ('b2f', 'c@1')))), ('fmul', 'b', ('b2f', 'c'))) => ('bcsel', 'c', 'b', 'a')
 *    ('~fadd@64', 'a', ('fmul', ('b2f', 'c@1'), ('fadd', 'b', ('fneg', 'a')))) => ('bcsel', 'c', 'b', 'a')
 *    ('~ffma@64', 'a', ('fadd', 1.0, ('fneg', ('b2f', 'c@1'))), ('fmul', 'b', ('b2f', 'c@1'))) => ('bcsel', 'c', 'b', 'a')
 *    ('~ffma@64', 'b', ('b2f', 'c@1'), ('ffma', ('fneg', 'a'), ('b2f', 'c@1'), 'a')) => ('bcsel', 'c', 'b', 'a')
 *    ('~ffma@64', ('b2f', 'c@1'), ('fadd', 'b', ('fneg', 'a')), 'a') => ('bcsel', 'c', 'b', 'a')
 *    ('~ffma@64', ('b2f', 'c@1'), ('ffma', ('fneg', 'a'), 'b', 'd'), ('fmul', 'a', 'b')) => ('bcsel', 'c', 'd', ('fmul', 'a', 'b'))
 *    ('~fadd@64', 1.0, ('fneg', ('fmul', ('fadd', 1.0, ('fneg', 'a')), ('fadd', 1.0, ('fneg', 'b'))))) => ('flrp', 'b', 1.0, 'a')
 *    ('~flrp', ('fmul(is_used_once)', 'a', 'b'), ('fmul(is_used_once)', 'a', 'c'), 'd') => ('fmul', ('flrp', 'b', 'c', 'd'), 'a')
 *    ('~flrp', 'a', 0.0, 'c') => ('fadd', ('fmul', ('fneg', 'a'), 'c'), 'a')
 *    ('ftrunc@16', 'a') => ('bcsel', ('flt', 'a', 0.0), ('fneg', ('ffloor', ('fabs', 'a'))), ('ffloor', ('fabs', 'a')))
 *    ('ftrunc@32', 'a') => ('bcsel', ('flt', 'a', 0.0), ('fneg', ('ffloor', ('fabs', 'a'))), ('ffloor', ('fabs', 'a')))
 *    ('ftrunc@64', 'a') => ('bcsel', ('flt', 'a', 0.0), ('fneg', ('ffloor', ('fabs', 'a'))), ('ffloor', ('fabs', 'a')))
 *    ('ffloor@16', 'a') => ('fsub', 'a', ('ffract', 'a'))
 *    ('ffloor@32', 'a') => ('fsub', 'a', ('ffract', 'a'))
 *    ('ffloor@64', 'a') => ('fsub', 'a', ('ffract', 'a'))
 *    ('fadd@16', 'a', ('fadd@16', 'b', ('fneg', ('ffract', 'a')))) => ('fadd@16', 'b', ('ffloor', 'a'))
 *    ('fadd@32', 'a', ('fadd@32', 'b', ('fneg', ('ffract', 'a')))) => ('fadd@32', 'b', ('ffloor', 'a'))
 *    ('fadd@64', 'a', ('fadd@64', 'b', ('fneg', ('ffract', 'a')))) => ('fadd@64', 'b', ('ffloor', 'a'))
 *    ('fadd@16', 'a', ('fneg', ('ffract', 'a'))) => ('ffloor', 'a')
 *    ('fadd@32', 'a', ('fneg', ('ffract', 'a'))) => ('ffloor', 'a')
 *    ('fadd@64', 'a', ('fneg', ('ffract', 'a'))) => ('ffloor', 'a')
 *    ('ffract@16', 'a') => ('fsub', 'a', ('ffloor', 'a'))
 *    ('ffract@32', 'a') => ('fsub', 'a', ('ffloor', 'a'))
 *    ('ffract@64', 'a') => ('fsub', 'a', ('ffloor', 'a'))
 *    ('fceil', 'a') => ('fneg', ('ffloor', ('fneg', 'a')))
 *    ('ffma@16', 'a', 'b', 'c') => ('fadd', ('fmul', 'a', 'b'), 'c')
 *    ('ffma@32', 'a', 'b', 'c') => ('fadd', ('fmul', 'a', 'b'), 'c')
 *    ('ffma@64', 'a', 'b', 'c') => ('fadd', ('fmul', 'a', 'b'), 'c')
 *    ('ffmaz', 'a', 'b', 'c') => ('fadd', ('fmulz', 'a', 'b'), 'c')
 *    ('~ffma@16', 'a', 'b', 'c') => ('fadd', ('fmul', 'a', 'b'), 'c')
 *    ('~ffma@32', 'a', 'b', 'c') => ('fadd', ('fmul', 'a', 'b'), 'c')
 *    ('~ffma@64', 'a', 'b', 'c') => ('fadd', ('fmul', 'a', 'b'), 'c')
 *    ('~ffmaz', 'a', 'b', 'c') => ('fadd', ('fmulz', 'a', 'b'), 'c')
 *    ('~fmul', ('fadd', ('iand', ('ineg', ('b2i', 'a@bool')), ('fmul', 'b', 'c')), '#d'), '#e') => ('bcsel', 'a', ('fmul', ('fadd', ('fmul', 'b', 'c'), 'd'), 'e'), ('fmul', 'd', 'e'))
 *    ('fdph', 'a', 'b') => ('fdot4', ('vec4', 'a.x', 'a.y', 'a.z', 1.0), 'b')
 *    ('fdot4', ('vec4', 'a', 'b', 'c', 1.0), 'd') => ('fdph', ('vec3', 'a', 'b', 'c'), 'd')
 *    ('fdot4', ('vec4', 'a', 0.0, 0.0, 0.0), 'b') => ('fmul', 'a', 'b')
 *    ('fdot4', ('vec4', 'a', 'b', 0.0, 0.0), 'c') => ('fdot2', ('vec2', 'a', 'b'), 'c')
 *    ('fdot4', ('vec4', 'a', 'b', 'c', 0.0), 'd') => ('fdot3', ('vec3', 'a', 'b', 'c'), 'd')
 *    ('fdot3', ('vec3', 'a', 0.0, 0.0), 'b') => ('fmul', 'a', 'b')
 *    ('fdot3', ('vec3', 'a', 'b', 0.0), 'c') => ('fdot2', ('vec2', 'a', 'b'), 'c')
 *    ('fdot2', ('vec2', 'a', 0.0), 'b') => ('fmul', 'a', 'b')
 *    ('fdot2', 'a', 1.0) => ('fadd', 'a.x', 'a.y')
 *    ('fdot2', 'a', 'b') => ('fsum2', ('fmul', 'a', 'b'))
 *    ('fdot3', 'a', 'b') => ('fsum3', ('fmul', 'a', 'b'))
 *    ('fdot4', 'a', 'b') => ('fsum4', ('fmul', 'a', 'b'))
 *    ('fsum2', 'a') => ('fadd', 'a.x', 'a.y')
 *    ('~fadd', ('fneg(is_used_once)', ('fsat(is_used_once)', 'a(is_not_fmul)')), 1.0) => ('fsat', ('fadd', 1.0, ('fneg', 'a')))
 *    ('ishl', ('iadd', ('imul', 'a', '#b'), '#c'), '#d') => ('iadd', ('imul', 'a', ('ishl', 'b', 'd')), ('ishl', 'c', 'd'))
 *    ('ishl', ('imul', 'a', '#b'), '#c') => ('imul', 'a', ('ishl', 'b', 'c'))
 *    ('ishl@8', ('ishl@8', 'a', '#b'), '#c') => ('bcsel', ('ult', ('iadd', ('iand', 'b', 7), ('iand', 'c', 7)), 8), ('ishl@8', 'a', ('iadd', 'b', 'c')), 0)
 *    ('ushr@8', ('ushr@8', 'a', '#b'), '#c') => ('bcsel', ('ult', ('iadd', ('iand', 'b', 7), ('iand', 'c', 7)), 8), ('ushr@8', 'a', ('iadd', 'b', 'c')), 0)
 *    ('ishr@8', ('ishr@8', 'a', '#b'), '#c') => ('ishr@8', 'a', ('imin', ('iadd', ('iand', 'b', 7), ('iand', 'c', 7)), 7))
 *    ('ishl@16', ('ishl@16', 'a', '#b'), '#c') => ('bcsel', ('ult', ('iadd', ('iand', 'b', 15), ('iand', 'c', 15)), 16), ('ishl@16', 'a', ('iadd', 'b', 'c')), 0)
 *    ('ushr@16', ('ushr@16', 'a', '#b'), '#c') => ('bcsel', ('ult', ('iadd', ('iand', 'b', 15), ('iand', 'c', 15)), 16), ('ushr@16', 'a', ('iadd', 'b', 'c')), 0)
 *    ('ishr@16', ('ishr@16', 'a', '#b'), '#c') => ('ishr@16', 'a', ('imin', ('iadd', ('iand', 'b', 15), ('iand', 'c', 15)), 15))
 *    ('ishl@32', ('ishl@32', 'a', '#b'), '#c') => ('bcsel', ('ult', ('iadd', ('iand', 'b', 31), ('iand', 'c', 31)), 32), ('ishl@32', 'a', ('iadd', 'b', 'c')), 0)
 *    ('ushr@32', ('ushr@32', 'a', '#b'), '#c') => ('bcsel', ('ult', ('iadd', ('iand', 'b', 31), ('iand', 'c', 31)), 32), ('ushr@32', 'a', ('iadd', 'b', 'c')), 0)
 *    ('ishr@32', ('ishr@32', 'a', '#b'), '#c') => ('ishr@32', 'a', ('imin', ('iadd', ('iand', 'b', 31), ('iand', 'c', 31)), 31))
 *    ('ishl@64', ('ishl@64', 'a', '#b'), '#c') => ('bcsel', ('ult', ('iadd', ('iand', 'b', 63), ('iand', 'c', 63)), 64), ('ishl@64', 'a', ('iadd', 'b', 'c')), 0)
 *    ('ushr@64', ('ushr@64', 'a', '#b'), '#c') => ('bcsel', ('ult', ('iadd', ('iand', 'b', 63), ('iand', 'c', 63)), 64), ('ushr@64', 'a', ('iadd', 'b', 'c')), 0)
 *    ('ishr@64', ('ishr@64', 'a', '#b'), '#c') => ('ishr@64', 'a', ('imin', ('iadd', ('iand', 'b', 63), ('iand', 'c', 63)), 63))
 *    ('ishl', ('ushr', 'a@8', '#b'), 'b') => ('iand', 'a', ('ishl', 255, 'b'))
 *    ('ishl', ('ishr', 'a@8', '#b'), 'b') => ('iand', 'a', ('ishl', 255, 'b'))
 *    ('ushr', ('ishl', 'a@8', '#b'), 'b') => ('iand', 'a', ('ushr', 255, 'b'))
 *    ('ishl', ('ushr', 'a@16', '#b'), 'b') => ('iand', 'a', ('ishl', 65535, 'b'))
 *    ('ishl', ('ishr', 'a@16', '#b'), 'b') => ('iand', 'a', ('ishl', 65535, 'b'))
 *    ('ushr', ('ishl', 'a@16', '#b'), 'b') => ('iand', 'a', ('ushr', 65535, 'b'))
 *    ('ishl', ('ushr', 'a@32', '#b'), 'b') => ('iand', 'a', ('ishl', 4294967295, 'b'))
 *    ('ishl', ('ishr', 'a@32', '#b'), 'b') => ('iand', 'a', ('ishl', 4294967295, 'b'))
 *    ('ushr', ('ishl', 'a@32', '#b'), 'b') => ('iand', 'a', ('ushr', 4294967295, 'b'))
 *    ('ishl', ('ushr', 'a@64', '#b'), 'b') => ('iand', 'a', ('ishl', 18446744073709551615, 'b'))
 *    ('ishl', ('ishr', 'a@64', '#b'), 'b') => ('iand', 'a', ('ishl', 18446744073709551615, 'b'))
 *    ('ushr', ('ishl', 'a@64', '#b'), 'b') => ('iand', 'a', ('ushr', 18446744073709551615, 'b'))
 *    ('iand', ('ishl', 'a@32', '#b(is_first_5_bits_uge_2)'), -4) => ('ishl', 'a', 'b')
 *    ('iand', ('imul', 'a', '#b(is_unsigned_multiple_of_4)'), -4) => ('imul', 'a', 'b')
 *    ('iand@32', ('iadd@32', 'a', '#b(is_unsigned_multiple_of_2)'), 4294967294) => ('iadd', ('iand', 'a', 4294967294), 'b')
 *    ('iand@32', ('iadd@32', 'a', '#b(is_unsigned_multiple_of_4)'), 4294967292) => ('iadd', ('iand', 'a', 4294967292), 'b')
 *    ('iand@32', ('iadd@32', 'a', '#b(is_unsigned_multiple_of_8)'), 4294967288) => ('iadd', ('iand', 'a', 4294967288), 'b')
 *    ('iand@32', ('iadd@32', 'a', '#b(is_unsigned_multiple_of_16)'), 4294967280) => ('iadd', ('iand', 'a', 4294967280), 'b')
 *    ('iand@32', ('iadd@32', 'a', '#b(is_unsigned_multiple_of_32)'), 4294967264) => ('iadd', ('iand', 'a', 4294967264), 'b')
 *    ('iand@32', ('iadd@32', 'a', '#b(is_unsigned_multiple_of_64)'), 4294967232) => ('iadd', ('iand', 'a', 4294967232), 'b')
 *    ('ishl@32', ('iand', 'a@32', 2147483647), 1) => ('ishl', 'a', 1)
 *    ('iand', ('ishl', 'a@32', 1), 4294967294) => ('ishl', 'a', 1)
 *    ('iand', ('ushr', 'a@32', 1), 2147483647) => ('ushr', 'a', 1)
 *    ('ishl@32', ('iand', 'a@32', 1073741823), 2) => ('ishl', 'a', 2)
 *    ('iand', ('ishl', 'a@32', 2), 4294967292) => ('ishl', 'a', 2)
 *    ('iand', ('ushr', 'a@32', 2), 1073741823) => ('ushr', 'a', 2)
 *    ('ishl@32', ('iand', 'a@32', 65535), 16) => ('ishl', 'a', 16)
 *    ('iand', ('ishl', 'a@32', 16), 4294901760) => ('ishl', 'a', 16)
 *    ('iand', ('ushr', 'a@32', 16), 65535) => ('ushr', 'a', 16)
 *    ('ishl@32', ('iand', 'a@32', 255), 24) => ('ishl', 'a', 24)
 *    ('iand', ('ishl', 'a@32', 24), 4278190080) => ('ishl', 'a', 24)
 *    ('iand', ('ushr', 'a@32', 24), 255) => ('ushr', 'a', 24)
 *    ('ishl', ('iadd', 'a', '#b'), '#c') => ('iadd', ('ishl', 'a', 'c'), ('ishl', 'b', 'c'))
 *    ('imul', ('iadd(is_used_once)', 'a', '#b'), '#c') => ('iadd', ('imul', 'a', 'c'), ('imul', 'b', 'c'))
 *    ('imul', ('iadd(is_used_once)', ('iadd(is_used_once)', 'a', '#b'), 'c'), '#d') => ('iadd', ('imul', ('iadd', 'a', 'c'), 'd'), ('imul', 'b', 'd'))
 *    ('ishl', ('iadd(is_used_once)', ('iadd(is_used_once)', 'a', '#b'), 'c'), '#d') => ('iadd', ('ishl', ('iadd', 'a', 'c'), 'd'), ('ishl', 'b', 'd'))
 *    ('inot', ('flt(is_used_once)', 'a(is_a_number)', 'b(is_a_number)')) => ('fge', 'a', 'b')
 *    ('inot', ('fge(is_used_once)', 'a(is_a_number)', 'b(is_a_number)')) => ('flt', 'a', 'b')
 *    ('inot', ('feq(is_used_once)', 'a', 'b')) => ('fneu', 'a', 'b')
 *    ('inot', ('fneu(is_used_once)', 'a', 'b')) => ('feq', 'a', 'b')
 *    ('inot', ('ilt(is_used_once)', 'a', 'b')) => ('ige', 'a', 'b')
 *    ('inot', ('ult(is_used_once)', 'a', 'b')) => ('uge', 'a', 'b')
 *    ('inot', ('ige(is_used_once)', 'a', 'b')) => ('ilt', 'a', 'b')
 *    ('inot', ('uge(is_used_once)', 'a', 'b')) => ('ult', 'a', 'b')
 *    ('inot', ('ieq(is_used_once)', 'a', 'b')) => ('ine', 'a', 'b')
 *    ('inot', ('ine(is_used_once)', 'a', 'b')) => ('ieq', 'a', 'b')
 *    ('iand', ('feq', 'a', 'b'), ('fneu', 'a', 'b')) => False
 *    ('iand', ('flt', 'a', 'b'), ('flt', 'b', 'a')) => False
 *    ('iand', ('ieq', 'a', 'b'), ('ine', 'a', 'b')) => False
 *    ('iand', ('ilt', 'a', 'b'), ('ilt', 'b', 'a')) => False
 *    ('iand', ('ult', 'a', 'b'), ('ult', 'b', 'a')) => False
 *    ('flt', ('fneg', 'a'), ('fneg', 'b')) => ('flt', 'b', 'a')
 *    ('fge', ('fneg', 'a'), ('fneg', 'b')) => ('fge', 'b', 'a')
 *    ('feq', ('fneg', 'a'), ('fneg', 'b')) => ('feq', 'b', 'a')
 *    ('fneu', ('fneg', 'a'), ('fneg', 'b')) => ('fneu', 'b', 'a')
 *    ('flt', ('fneg', 'a'), -1.0) => ('flt', 1.0, 'a')
 *    ('flt', -1.0, ('fneg', 'a')) => ('flt', 'a', 1.0)
 *    ('fge', ('fneg', 'a'), -1.0) => ('fge', 1.0, 'a')
 *    ('fge', -1.0, ('fneg', 'a')) => ('fge', 'a', 1.0)
 *    ('fneu', ('fneg', 'a'), -1.0) => ('fneu', 1.0, 'a')
 *    ('feq', -1.0, ('fneg', 'a')) => ('feq', 'a', 1.0)
 *    ('ieq', ('ineg', 'a'), 0) => ('ieq', 'a', 0)
 *    ('ine', ('ineg', 'a'), 0) => ('ine', 'a', 0)
 *    ('ieq', ('iabs', 'a'), 0) => ('ieq', 'a', 0)
 *    ('ine', ('iabs', 'a'), 0) => ('ine', 'a', 0)
 *    ('flt', '#b(is_gt_0_and_lt_1)', ('fsat(is_used_once)', 'a')) => ('flt', 'b', 'a')
 *    ('fge', ('fsat(is_used_once)', 'a'), '#b(is_gt_0_and_lt_1)') => ('fge', 'a', 'b')
 *    ('feq', ('fsat(is_used_once)', 'a'), '#b(is_gt_0_and_lt_1)') => ('feq', 'a', 'b')
 *    ('fneu', ('fsat(is_used_once)', 'a'), '#b(is_gt_0_and_lt_1)') => ('fneu', 'a', 'b')
 *    ('fge', ('fsat(is_used_once)', 'a'), 1.0) => ('fge', 'a', 1.0)
 *    ('flt', 0.0, ('fsat(is_used_once)', 'a')) => ('flt', 0.0, 'a')
 *    ('fge', 0.0, ('b2f', 'a@1')) => ('inot', 'a')
 *    ('fge', ('fneg', ('b2f', 'a@1')), 0.0) => ('inot', 'a')
 *    ('fneu', ('fadd', ('b2f', 'a@1'), ('b2f', 'b@1')), 0.0) => ('ior', 'a', 'b')
 *    ('fneu', ('bcsel', 'a', 1.0, ('b2f', 'b@1')), 0.0) => ('ior', 'a', 'b')
 *    ('fneu', ('b2f', 'a@1'), ('fneg', ('b2f', 'b@1'))) => ('ior', 'a', 'b')
 *    ('fneu', ('fmul', ('b2f', 'a@1'), ('b2f', 'b@1')), 0.0) => ('iand', 'a', 'b')
 *    ('fneu', ('bcsel', 'a', ('b2f', 'b@1'), 0.0), 0.0) => ('iand', 'a', 'b')
 *    ('fneu', ('fadd', ('b2f', 'a@1'), ('fneg', ('b2f', 'b@1'))), 0.0) => ('ixor', 'a', 'b')
 *    ('fneu', ('b2f', 'a@1'), ('b2f', 'b@1')) => ('ixor', 'a', 'b')
 *    ('fneu', ('fneg', ('b2f', 'a@1')), ('fneg', ('b2f', 'b@1'))) => ('ixor', 'a', 'b')
 *    ('feq', ('fadd', ('b2f', 'a@1'), ('b2f', 'b@1')), 0.0) => ('inot', ('ior', 'a', 'b'))
 *    ('feq', ('bcsel', 'a', 1.0, ('b2f', 'b@1')), 0.0) => ('inot', ('ior', 'a', 'b'))
 *    ('feq', ('b2f', 'a@1'), ('fneg', ('b2f', 'b@1'))) => ('inot', ('ior', 'a', 'b'))
 *    ('feq', ('fmul', ('b2f', 'a@1'), ('b2f', 'b@1')), 0.0) => ('inot', ('iand', 'a', 'b'))
 *    ('feq', ('bcsel', 'a', ('b2f', 'b@1'), 0.0), 0.0) => ('inot', ('iand', 'a', 'b'))
 *    ('feq', ('fadd', ('b2f', 'a@1'), ('fneg', ('b2f', 'b@1'))), 0.0) => ('ieq', 'a', 'b')
 *    ('feq', ('b2f', 'a@1'), ('b2f', 'b@1')) => ('ieq', 'a', 'b')
 *    ('feq', ('fneg', ('b2f', 'a@1')), ('fneg', ('b2f', 'b@1'))) => ('ieq', 'a', 'b')
 *    ('flt', ('fneg', ('fadd', ('b2f', 'a@1'), ('b2f', 'b@1'))), 0.0) => ('ior', 'a', 'b')
 *    ('flt', 0.0, ('fadd', ('b2f', 'a@1'), ('b2f', 'b@1'))) => ('ior', 'a', 'b')
 *    ('fge', ('fneg', ('fadd', ('b2f', 'a@1'), ('b2f', 'b@1'))), 0.0) => ('inot', ('ior', 'a', 'b'))
 *    ('fge', 0.0, ('fadd', ('b2f', 'a@1'), ('b2f', 'b@1'))) => ('inot', ('ior', 'a', 'b'))
 *    ('flt', 'a', ('fneg', 'a')) => ('flt', 'a', 0.0)
 *    ('fge', 'a', ('fneg', 'a')) => ('fge', 'a', 0.0)
 *    ('flt', ('fmin', 'c', ('fneg', ('fadd', ('b2f', 'a@1'), ('b2f', 'b@1')))), 0.0) => ('ior', ('flt', 'c', 0.0), ('ior', 'a', 'b'))
 *    ('~flt', ('fadd', 'a', 'b'), 'a') => ('flt', 'b', 0.0)
 *    ('~fge', ('fadd', 'a', 'b'), 'a') => ('fge', 'b', 0.0)
 *    ('~feq', ('fadd', 'a', 'b'), 'a') => ('feq', 'b', 0.0)
 *    ('~fneu', ('fadd', 'a', 'b'), 'a') => ('fneu', 'b', 0.0)
 *    ('~flt', ('fadd(is_used_once)', 'a', '#b'), '#c') => ('flt', 'a', ('fadd', 'c', ('fneg', 'b')))
 *    ('~flt', ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', '#b')), '#c') => ('flt', ('fneg', ('fadd', 'c', 'b')), 'a')
 *    ('~fge', ('fadd(is_used_once)', 'a', '#b'), '#c') => ('fge', 'a', ('fadd', 'c', ('fneg', 'b')))
 *    ('~fge', ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', '#b')), '#c') => ('fge', ('fneg', ('fadd', 'c', 'b')), 'a')
 *    ('~feq', ('fadd(is_used_once)', 'a', '#b'), '#c') => ('feq', 'a', ('fadd', 'c', ('fneg', 'b')))
 *    ('~feq', ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', '#b')), '#c') => ('feq', ('fneg', ('fadd', 'c', 'b')), 'a')
 *    ('~fneu', ('fadd(is_used_once)', 'a', '#b'), '#c') => ('fneu', 'a', ('fadd', 'c', ('fneg', 'b')))
 *    ('~fneu', ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', '#b')), '#c') => ('fneu', ('fneg', ('fadd', 'c', 'b')), 'a')
 *    ('ieq', ('iadd', 'a', 'b'), 'a') => ('ieq', 'b', 0)
 *    ('ine', ('iadd', 'a', 'b'), 'a') => ('ine', 'b', 0)
 *    ('feq', ('b2f', 'a@1'), 0.0) => ('inot', 'a')
 *    ('fneu', ('b2f', 'a@1'), 0.0) => a
 *    ('ieq', ('b2i', 'a@1'), 0) => ('inot', 'a')
 *    ('ine', ('b2i', 'a@1'), 0) => a
 *    ('fneu', ('u2f', 'a'), 0.0) => ('ine', 'a', 0)
 *    ('feq', ('u2f', 'a'), 0.0) => ('ieq', 'a', 0)
 *    ('fge', ('u2f', 'a'), 0.0) => True
 *    ('fge', 0.0, ('u2f', 'a')) => ('uge', 0, 'a')
 *    ('flt', ('u2f', 'a'), 0.0) => False
 *    ('flt', 0.0, ('u2f', 'a')) => ('ult', 0, 'a')
 *    ('fneu', ('i2f', 'a'), 0.0) => ('ine', 'a', 0)
 *    ('feq', ('i2f', 'a'), 0.0) => ('ieq', 'a', 0)
 *    ('fge', ('i2f', 'a'), 0.0) => ('ige', 'a', 0)
 *    ('fge', 0.0, ('i2f', 'a')) => ('ige', 0, 'a')
 *    ('flt', ('i2f', 'a'), 0.0) => ('ilt', 'a', 0)
 *    ('flt', 0.0, ('i2f', 'a')) => ('ilt', 0, 'a')
 *    ('~flt', 0.0, ('fabs', 'a')) => ('fneu', 'a', 0.0)
 *    ('~flt', ('fneg', ('fabs', 'a')), 0.0) => ('fneu', 'a', 0.0)
 *    ('fge', 0.0, ('fabs', 'a')) => ('feq', 'a', 0.0)
 *    ('fge', ('fneg', ('fabs', 'a')), 0.0) => ('feq', 'a', 0.0)
 *    ('iand', ('fge', 'a', 0.0), ('fge', 1.0, 'a')) => ('feq', 'a', ('fsat', 'a'))
 *    ('fmax', ('b2f(is_used_once)', 'a@1'), ('b2f', 'b@1')) => ('b2f', ('ior', 'a', 'b'))
 *    ('fmax', ('fneg(is_used_once)', ('b2f(is_used_once)', 'a@1')), ('fneg', ('b2f', 'b@1'))) => ('fneg', ('b2f', ('iand', 'a', 'b')))
 *    ('fmin', ('b2f(is_used_once)', 'a@1'), ('b2f', 'b@1')) => ('b2f', ('iand', 'a', 'b'))
 *    ('fmin', ('fneg(is_used_once)', ('b2f(is_used_once)', 'a@1')), ('fneg', ('b2f', 'b@1'))) => ('fneg', ('b2f', ('ior', 'a', 'b')))
 *    ('fmin', ('b2f', 'a@1'), '#b') => ('bcsel', 'a', ('fmin', 'b', 1.0), ('fmin', 'b', 0.0))
 *    ('flt', ('fadd(is_used_once)', 'a', ('fneg', 'b')), 0.0) => ('flt', 'a', 'b')
 *    ('fge', ('fneg', ('fabs', 'a')), 0.0) => ('feq', 'a', 0.0)
 *    ('~bcsel', ('flt', 'b', 'a'), 'b', 'a') => ('fmin', 'a', 'b')
 *    ('~bcsel', ('flt', 'a', 'b'), 'b', 'a') => ('fmax', 'a', 'b')
 *    ('~bcsel', ('fge', 'a', 'b'), 'b', 'a') => ('fmin', 'a', 'b')
 *    ('~bcsel', ('fge', 'b', 'a'), 'b', 'a') => ('fmax', 'a', 'b')
 *    ('bcsel', ('ult', 'b', 'a'), 'b', 'a') => ('umin', 'a', 'b')
 *    ('bcsel', ('ult', 'a', 'b'), 'b', 'a') => ('umax', 'a', 'b')
 *    ('bcsel', ('uge', 'a', 'b'), 'b', 'a') => ('umin', 'a', 'b')
 *    ('bcsel', ('uge', 'b', 'a'), 'b', 'a') => ('umax', 'a', 'b')
 *    ('bcsel', ('ilt', 'b', 'a'), 'b', 'a') => ('imin', 'a', 'b')
 *    ('bcsel', ('ilt', 'a', 'b'), 'b', 'a') => ('imax', 'a', 'b')
 *    ('bcsel', ('ige', 'a', 'b'), 'b', 'a') => ('imin', 'a', 'b')
 *    ('bcsel', ('ige', 'b', 'a'), 'b', 'a') => ('imax', 'a', 'b')
 *    ('bcsel', ('inot', 'a'), 'b', 'c') => ('bcsel', 'a', 'c', 'b')
 *    ('bcsel', 'a', ('bcsel', 'a', 'b', 'c'), 'd') => ('bcsel', 'a', 'b', 'd')
 *    ('bcsel', 'a', 'b', ('bcsel', 'a', 'c', 'd')) => ('bcsel', 'a', 'b', 'd')
 *    ('bcsel', 'a', ('bcsel', 'b', 'c', 'd'), ('bcsel(is_used_once)', 'b', 'c', 'e')) => ('bcsel', 'b', 'c', ('bcsel', 'a', 'd', 'e'))
 *    ('bcsel', 'a', ('bcsel(is_used_once)', 'b', 'c', 'd'), ('bcsel', 'b', 'c', 'e')) => ('bcsel', 'b', 'c', ('bcsel', 'a', 'd', 'e'))
 *    ('bcsel', 'a', ('bcsel', 'b', 'c', 'd'), ('bcsel(is_used_once)', 'b', 'e', 'd')) => ('bcsel', 'b', ('bcsel', 'a', 'c', 'e'), 'd')
 *    ('bcsel', 'a', ('bcsel(is_used_once)', 'b', 'c', 'd'), ('bcsel', 'b', 'e', 'd')) => ('bcsel', 'b', ('bcsel', 'a', 'c', 'e'), 'd')
 *    ('bcsel', 'a', True, 'b') => ('ior', 'a', 'b')
 *    ('bcsel', 'a', 'a', 'b') => ('ior', 'a', 'b')
 *    ('bcsel', 'a', 'b', False) => ('iand', 'a', 'b')
 *    ('bcsel', 'a', 'b', 'a') => ('iand', 'a', 'b')
 *    ('~fmin', 'a', 'a') => a
 *    ('~fmax', 'a', 'a') => a
 *    ('imin', 'a', 'a') => a
 *    ('imax', 'a', 'a') => a
 *    ('umin', 'a', 'a') => a
 *    ('umin', 'a', 0) => 0
 *    ('umin', 'a', -1) => a
 *    ('umax', 'a', 'a') => a
 *    ('umax', 'a', 0) => a
 *    ('umax', 'a', -1) => -1
 *    ('fmax', ('fmax', 'a', 'b'), 'b') => ('fmax', 'a', 'b')
 *    ('umax', ('umax', 'a', 'b'), 'b') => ('umax', 'a', 'b')
 *    ('imax', ('imax', 'a', 'b'), 'b') => ('imax', 'a', 'b')
 *    ('fmin', ('fmin', 'a', 'b'), 'b') => ('fmin', 'a', 'b')
 *    ('umin', ('umin', 'a', 'b'), 'b') => ('umin', 'a', 'b')
 *    ('imin', ('imin', 'a', 'b'), 'b') => ('imin', 'a', 'b')
 *    ('fmax', ('fmax', ('fmax', 'a', 'b'), 'c'), 'a') => ('fmax', ('fmax', 'a', 'b'), 'c')
 *    ('umax', ('umax', ('umax', 'a', 'b'), 'c'), 'a') => ('umax', ('umax', 'a', 'b'), 'c')
 *    ('imax', ('imax', ('imax', 'a', 'b'), 'c'), 'a') => ('imax', ('imax', 'a', 'b'), 'c')
 *    ('fmin', ('fmin', ('fmin', 'a', 'b'), 'c'), 'a') => ('fmin', ('fmin', 'a', 'b'), 'c')
 *    ('umin', ('umin', ('umin', 'a', 'b'), 'c'), 'a') => ('umin', ('umin', 'a', 'b'), 'c')
 *    ('imin', ('imin', ('imin', 'a', 'b'), 'c'), 'a') => ('imin', ('imin', 'a', 'b'), 'c')
 *    ('ieq', ('b2i8', 'a@1'), ('b2i8', 'b@1')) => ('ieq', 'a', 'b')
 *    ('ine', ('b2i8', 'a@1'), ('b2i8', 'b@1')) => ('ine', 'a', 'b')
 *    ('ieq', ('b2i16', 'a@1'), ('b2i16', 'b@1')) => ('ieq', 'a', 'b')
 *    ('ine', ('b2i16', 'a@1'), ('b2i16', 'b@1')) => ('ine', 'a', 'b')
 *    ('ieq', ('b2i32', 'a@1'), ('b2i32', 'b@1')) => ('ieq', 'a', 'b')
 *    ('ine', ('b2i32', 'a@1'), ('b2i32', 'b@1')) => ('ine', 'a', 'b')
 *    ('ieq', ('b2i64', 'a@1'), ('b2i64', 'b@1')) => ('ieq', 'a', 'b')
 *    ('ine', ('b2i64', 'a@1'), ('b2i64', 'b@1')) => ('ine', 'a', 'b')
 *    ('feq', ('b2f16', 'a@1'), ('b2f16', 'b@1')) => ('ieq', 'a', 'b')
 *    ('fneu', ('b2f16', 'a@1'), ('b2f16', 'b@1')) => ('ine', 'a', 'b')
 *    ('feq', ('b2f32', 'a@1'), ('b2f32', 'b@1')) => ('ieq', 'a', 'b')
 *    ('fneu', ('b2f32', 'a@1'), ('b2f32', 'b@1')) => ('ine', 'a', 'b')
 *    ('feq', ('b2f64', 'a@1'), ('b2f64', 'b@1')) => ('ieq', 'a', 'b')
 *    ('fneu', ('b2f64', 'a@1'), ('b2f64', 'b@1')) => ('ine', 'a', 'b')
 *    ('iand@8', 'a', ('inot', ('ishr', 'a', 7))) => ('imax', 'a', 0)
 *    ('ieq', ('iand', 'a@8', 128), 0) => ('ige', 'a', 0)
 *    ('ine', ('iand', 'a@8', 128), 128) => ('ige', 'a', 0)
 *    ('ine', ('iand', 'a@8', 128), 0) => ('ilt', 'a', 0)
 *    ('ieq', ('iand', 'a@8', 128), 128) => ('ilt', 'a', 0)
 *    ('ine', ('ushr', 'a@8', 7), 0) => ('ilt', 'a', 0)
 *    ('ieq', ('ushr', 'a@8', 7), 0) => ('ige', 'a', 0)
 *    ('ieq', ('ushr', 'a@8', 7), 1) => ('ilt', 'a', 0)
 *    ('ine', ('ushr', 'a@8', 7), 1) => ('ige', 'a', 0)
 *    ('ine', ('ishr', 'a@8', 7), 0) => ('ilt', 'a', 0)
 *    ('ieq', ('ishr', 'a@8', 7), 0) => ('ige', 'a', 0)
 *    ('ieq', ('ishr', 'a@8', 7), -1) => ('ilt', 'a', 0)
 *    ('ine', ('ishr', 'a@8', 7), -1) => ('ige', 'a', 0)
 *    ('iand@16', 'a', ('inot', ('ishr', 'a', 15))) => ('imax', 'a', 0)
 *    ('ieq', ('iand', 'a@16', 32768), 0) => ('ige', 'a', 0)
 *    ('ine', ('iand', 'a@16', 32768), 32768) => ('ige', 'a', 0)
 *    ('ine', ('iand', 'a@16', 32768), 0) => ('ilt', 'a', 0)
 *    ('ieq', ('iand', 'a@16', 32768), 32768) => ('ilt', 'a', 0)
 *    ('ine', ('ushr', 'a@16', 15), 0) => ('ilt', 'a', 0)
 *    ('ieq', ('ushr', 'a@16', 15), 0) => ('ige', 'a', 0)
 *    ('ieq', ('ushr', 'a@16', 15), 1) => ('ilt', 'a', 0)
 *    ('ine', ('ushr', 'a@16', 15), 1) => ('ige', 'a', 0)
 *    ('ine', ('ishr', 'a@16', 15), 0) => ('ilt', 'a', 0)
 *    ('ieq', ('ishr', 'a@16', 15), 0) => ('ige', 'a', 0)
 *    ('ieq', ('ishr', 'a@16', 15), -1) => ('ilt', 'a', 0)
 *    ('ine', ('ishr', 'a@16', 15), -1) => ('ige', 'a', 0)
 *    ('iand@32', 'a', ('inot', ('ishr', 'a', 31))) => ('imax', 'a', 0)
 *    ('ieq', ('iand', 'a@32', 2147483648), 0) => ('ige', 'a', 0)
 *    ('ine', ('iand', 'a@32', 2147483648), 2147483648) => ('ige', 'a', 0)
 *    ('ine', ('iand', 'a@32', 2147483648), 0) => ('ilt', 'a', 0)
 *    ('ieq', ('iand', 'a@32', 2147483648), 2147483648) => ('ilt', 'a', 0)
 *    ('ine', ('ushr', 'a@32', 31), 0) => ('ilt', 'a', 0)
 *    ('ieq', ('ushr', 'a@32', 31), 0) => ('ige', 'a', 0)
 *    ('ieq', ('ushr', 'a@32', 31), 1) => ('ilt', 'a', 0)
 *    ('ine', ('ushr', 'a@32', 31), 1) => ('ige', 'a', 0)
 *    ('ine', ('ishr', 'a@32', 31), 0) => ('ilt', 'a', 0)
 *    ('ieq', ('ishr', 'a@32', 31), 0) => ('ige', 'a', 0)
 *    ('ieq', ('ishr', 'a@32', 31), -1) => ('ilt', 'a', 0)
 *    ('ine', ('ishr', 'a@32', 31), -1) => ('ige', 'a', 0)
 *    ('iand@64', 'a', ('inot', ('ishr', 'a', 63))) => ('imax', 'a', 0)
 *    ('ieq', ('iand', 'a@64', 9223372036854775808), 0) => ('ige', 'a', 0)
 *    ('ine', ('iand', 'a@64', 9223372036854775808), 9223372036854775808) => ('ige', 'a', 0)
 *    ('ine', ('iand', 'a@64', 9223372036854775808), 0) => ('ilt', 'a', 0)
 *    ('ieq', ('iand', 'a@64', 9223372036854775808), 9223372036854775808) => ('ilt', 'a', 0)
 *    ('ine', ('ushr', 'a@64', 63), 0) => ('ilt', 'a', 0)
 *    ('ieq', ('ushr', 'a@64', 63), 0) => ('ige', 'a', 0)
 *    ('ieq', ('ushr', 'a@64', 63), 1) => ('ilt', 'a', 0)
 *    ('ine', ('ushr', 'a@64', 63), 1) => ('ige', 'a', 0)
 *    ('ine', ('ishr', 'a@64', 63), 0) => ('ilt', 'a', 0)
 *    ('ieq', ('ishr', 'a@64', 63), 0) => ('ige', 'a', 0)
 *    ('ieq', ('ishr', 'a@64', 63), -1) => ('ilt', 'a', 0)
 *    ('ine', ('ishr', 'a@64', 63), -1) => ('ige', 'a', 0)
 *    ('fmin', 'a', ('fneg', 'a')) => ('fneg', ('fabs', 'a'))
 *    ('imin', 'a', ('ineg', 'a')) => ('ineg', ('iabs', 'a'))
 *    ('fmin', 'a', ('fneg', ('fabs', 'a'))) => ('fneg', ('fabs', 'a'))
 *    ('imin', 'a', ('ineg', ('iabs', 'a'))) => ('ineg', ('iabs', 'a'))
 *    ('~fmin', 'a', ('fabs', 'a')) => a
 *    ('imin', 'a', ('iabs', 'a')) => a
 *    ('~fmax', 'a', ('fneg', ('fabs', 'a'))) => a
 *    ('imax', 'a', ('ineg', ('iabs', 'a'))) => a
 *    ('fmax', 'a', ('fabs', 'a')) => ('fabs', 'a')
 *    ('imax', 'a', ('iabs', 'a')) => ('iabs', 'a')
 *    ('fmax', 'a', ('fneg', 'a')) => ('fabs', 'a')
 *    ('imax', 'a', ('ineg', 'a')) => ('iabs', 'a')
 *    ('~fmax', ('fabs', 'a'), 0.0) => ('fabs', 'a')
 *    ('fmin', ('fmax', 'a', 0.0), 1.0) => ('fsat', 'a')
 *    ('~fmax', ('fmin', 'a', 1.0), 0.0) => ('fsat', 'a')
 *    ('~fmin', ('fmax', 'a', -1.0), 0.0) => ('fneg', ('fsat', ('fneg', 'a')))
 *    ('~fmax', ('fmin', 'a', 0.0), -1.0) => ('fneg', ('fsat', ('fneg', 'a')))
 *    ('fsat', ('fsign', 'a')) => ('b2f', ('!flt', 0.0, 'a'))
 *    ('fsat', ('b2f', 'a')) => ('b2f', 'a')
 *    ('fsat', 'a') => ('fmin', ('fmax', 'a', 0.0), 1.0)
 *    ('fsat', ('fsat', 'a')) => ('fsat', 'a')
 *    ('fsat', ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', 'b'))) => ('fsat', ('fadd', ('fneg', 'a'), ('fneg', 'b')))
 *    ('fsat', ('fneg(is_used_once)', ('fmul(is_used_once)', 'a', 'b'))) => ('fsat', ('fmul', ('fneg', 'a'), 'b'))
 *    ('fsat', ('fneg(is_used_once)', ('fmulz(is_used_once)', 'a', 'b'))) => ('fsat', ('fmulz', ('fneg', 'a'), 'b'))
 *    ('fsat', ('fabs(is_used_once)', ('fmul(is_used_once)', 'a', 'b'))) => ('fsat', ('fmul', ('fabs', 'a'), ('fabs', 'b')))
 *    ('fmin', ('fmax', ('fmin', ('fmax', 'a', 'b'), 'c'), 'b'), 'c') => ('fmin', ('fmax', 'a', 'b'), 'c')
 *    ('imin', ('imax', ('imin', ('imax', 'a', 'b'), 'c'), 'b'), 'c') => ('imin', ('imax', 'a', 'b'), 'c')
 *    ('umin', ('umax', ('umin', ('umax', 'a', 'b'), 'c'), 'b'), 'c') => ('umin', ('umax', 'a', 'b'), 'c')
 *    ('fmax', ('fsat', 'a'), '#b(is_zero_to_one)') => ('fsat', ('fmax', 'a', 'b'))
 *    ('~fmin', ('fsat', 'a'), '#b(is_zero_to_one)') => ('fsat', ('fmin', 'a', 'b'))
 *    ('fmax', ('fneg', ('fmin', 'b', 'a')), 'b') => ('fmax', ('fabs', 'b'), ('fneg', 'a'))
 *    ('fmin', ('fneg', ('fmax', 'b', 'a')), 'b') => ('fmin', ('fneg', ('fabs', 'b')), ('fneg', 'a'))
 *    ('fmax', ('fadd(is_used_once)', ('fneg', 'a(is_not_negative)'), '#b(is_zero_to_one)'), 0.0) => ('fsat', ('fadd', ('fneg', 'a'), 'b'))
 *    ('extract_u8', ('imin', ('imax', 'a', 0), 255), 0) => ('imin', ('imax', 'a', 0), 255)
 *    ('ior', ('flt(is_used_once)', 'a', 'b'), ('flt', 'a', 'c')) => ('flt', 'a', ('!fmax', 'b', 'c'))
 *    ('ior', ('flt(is_used_once)', 'a', 'c'), ('flt', 'b', 'c')) => ('flt', ('!fmin', 'a', 'b'), 'c')
 *    ('ior', ('fge(is_used_once)', 'a', 'b'), ('fge', 'a', 'c')) => ('fge', 'a', ('!fmin', 'b', 'c'))
 *    ('ior', ('fge(is_used_once)', 'a', 'c'), ('fge', 'b', 'c')) => ('fge', ('!fmax', 'a', 'b'), 'c')
 *    ('ior', ('flt', 'a', '#b'), ('flt', 'a', '#c')) => ('flt', 'a', ('!fmax', 'b', 'c'))
 *    ('ior', ('flt', '#a', 'c'), ('flt', '#b', 'c')) => ('flt', ('!fmin', 'a', 'b'), 'c')
 *    ('ior', ('fge', 'a', '#b'), ('fge', 'a', '#c')) => ('fge', 'a', ('!fmin', 'b', 'c'))
 *    ('ior', ('fge', '#a', 'c'), ('fge', '#b', 'c')) => ('fge', ('!fmax', 'a', 'b'), 'c')
 *    ('~iand', ('flt(is_used_once)', 'a', 'b'), ('flt', 'a', 'c')) => ('flt', 'a', ('fmin', 'b', 'c'))
 *    ('~iand', ('flt(is_used_once)', 'a', 'c'), ('flt', 'b', 'c')) => ('flt', ('fmax', 'a', 'b'), 'c')
 *    ('~iand', ('fge(is_used_once)', 'a', 'b'), ('fge', 'a', 'c')) => ('fge', 'a', ('fmax', 'b', 'c'))
 *    ('~iand', ('fge(is_used_once)', 'a', 'c'), ('fge', 'b', 'c')) => ('fge', ('fmin', 'a', 'b'), 'c')
 *    ('iand', ('flt', 'a', '#b(is_a_number)'), ('flt', 'a', '#c(is_a_number)')) => ('flt', 'a', ('fmin', 'b', 'c'))
 *    ('iand', ('flt', '#a(is_a_number)', 'c'), ('flt', '#b(is_a_number)', 'c')) => ('flt', ('fmax', 'a', 'b'), 'c')
 *    ('iand', ('fge', 'a', '#b(is_a_number)'), ('fge', 'a', '#c(is_a_number)')) => ('fge', 'a', ('fmax', 'b', 'c'))
 *    ('iand', ('fge', '#a(is_a_number)', 'c'), ('fge', '#b(is_a_number)', 'c')) => ('fge', ('fmin', 'a', 'b'), 'c')
 *    ('ior', ('ilt(is_used_once)', 'a', 'b'), ('ilt', 'a', 'c')) => ('ilt', 'a', ('imax', 'b', 'c'))
 *    ('ior', ('ilt(is_used_once)', 'a', 'c'), ('ilt', 'b', 'c')) => ('ilt', ('imin', 'a', 'b'), 'c')
 *    ('ior', ('ige(is_used_once)', 'a', 'b'), ('ige', 'a', 'c')) => ('ige', 'a', ('imin', 'b', 'c'))
 *    ('ior', ('ige(is_used_once)', 'a', 'c'), ('ige', 'b', 'c')) => ('ige', ('imax', 'a', 'b'), 'c')
 *    ('ior', ('ult(is_used_once)', 'a', 'b'), ('ult', 'a', 'c')) => ('ult', 'a', ('umax', 'b', 'c'))
 *    ('ior', ('ult(is_used_once)', 'a', 'c'), ('ult', 'b', 'c')) => ('ult', ('umin', 'a', 'b'), 'c')
 *    ('ior', ('uge(is_used_once)', 'a', 'b'), ('uge', 'a', 'c')) => ('uge', 'a', ('umin', 'b', 'c'))
 *    ('ior', ('uge(is_used_once)', 'a', 'c'), ('uge', 'b', 'c')) => ('uge', ('umax', 'a', 'b'), 'c')
 *    ('iand', ('ilt(is_used_once)', 'a', 'b'), ('ilt', 'a', 'c')) => ('ilt', 'a', ('imin', 'b', 'c'))
 *    ('iand', ('ilt(is_used_once)', 'a', 'c'), ('ilt', 'b', 'c')) => ('ilt', ('imax', 'a', 'b'), 'c')
 *    ('iand', ('ige(is_used_once)', 'a', 'b'), ('ige', 'a', 'c')) => ('ige', 'a', ('imax', 'b', 'c'))
 *    ('iand', ('ige(is_used_once)', 'a', 'c'), ('ige', 'b', 'c')) => ('ige', ('imin', 'a', 'b'), 'c')
 *    ('iand', ('ult(is_used_once)', 'a', 'b'), ('ult', 'a', 'c')) => ('ult', 'a', ('umin', 'b', 'c'))
 *    ('iand', ('ult(is_used_once)', 'a', 'c'), ('ult', 'b', 'c')) => ('ult', ('umax', 'a', 'b'), 'c')
 *    ('iand', ('uge(is_used_once)', 'a', 'b'), ('uge', 'a', 'c')) => ('uge', 'a', ('umax', 'b', 'c'))
 *    ('iand', ('uge(is_used_once)', 'a', 'c'), ('uge', 'b', 'c')) => ('uge', ('umin', 'a', 'b'), 'c')
 *    ('ior', ('ior(is_used_once)', ('flt(is_used_once)', 'a', 'c'), 'd'), ('flt', 'b', 'c')) => ('ior', ('flt', ('!fmin', 'a', 'b'), 'c'), 'd')
 *    ('ior', ('ior(is_used_once)', ('flt', 'a', 'c'), 'd'), ('flt(is_used_once)', 'b', 'c')) => ('ior', ('flt', ('!fmin', 'a', 'b'), 'c'), 'd')
 *    ('ior', ('ior(is_used_once)', ('flt(is_used_once)', 'a', 'b'), 'd'), ('flt', 'a', 'c')) => ('ior', ('flt', 'a', ('!fmax', 'b', 'c')), 'd')
 *    ('ior', ('ior(is_used_once)', ('flt', 'a', 'b'), 'd'), ('flt(is_used_once)', 'a', 'c')) => ('ior', ('flt', 'a', ('!fmax', 'b', 'c')), 'd')
 *    ('ior', ('flt', 'a(is_a_number)', 'b(is_a_number)'), ('flt', 'b', 'a')) => ('fneu', 'a', 'b')
 *    ('umin', ('iand', 'a', '#b(is_pos_power_of_two)'), ('iand', 'c', 'b')) => ('iand', ('iand', 'a', 'b'), ('iand', 'c', 'b'))
 *    ('ior', ('flt(is_used_once)', 0.0, 'a@16'), ('flt', 'b@16', 0.0)) => ('flt', 0.0, ('fmax', 'a', ('fneg', 'b')))
 *    ('ior', ('flt', 0.0, 'a@16'), ('flt(is_used_once)', 'b@16', 0.0)) => ('flt', 0.0, ('fmax', 'a', ('fneg', 'b')))
 *    ('ior', ('fge(is_used_once)', 0.0, 'a@16'), ('fge', 'b@16', 0.0)) => ('fge', 0.0, ('fmin', 'a', ('fneg', 'b')))
 *    ('ior', ('fge', 0.0, 'a@16'), ('fge(is_used_once)', 'b@16', 0.0)) => ('fge', 0.0, ('fmin', 'a', ('fneg', 'b')))
 *    ('~iand', ('flt(is_used_once)', 0.0, 'a@16'), ('flt', 'b@16', 0.0)) => ('flt', 0.0, ('fmin', 'a', ('fneg', 'b')))
 *    ('~iand', ('flt', 0.0, 'a@16'), ('flt(is_used_once)', 'b@16', 0.0)) => ('flt', 0.0, ('fmin', 'a', ('fneg', 'b')))
 *    ('~iand', ('fge(is_used_once)', 0.0, 'a@16'), ('fge', 'b@16', 0.0)) => ('fge', 0.0, ('fmax', 'a', ('fneg', 'b')))
 *    ('~iand', ('fge', 0.0, 'a@16'), ('fge(is_used_once)', 'b@16', 0.0)) => ('fge', 0.0, ('fmax', 'a', ('fneg', 'b')))
 *    ('bcsel@16', ('feq', 'a', 0.0), 1.0, ('i2f16', ('iadd', ('b2i16', ('flt', 0.0, 'a@16')), ('ineg', ('b2i16', ('flt', 'a@16', 0.0)))))) => ('i2f16', ('iadd', ('b2i32', ('!fge', 'a', 0.0)), ('ineg', ('b2i32', ('!flt', 'a', 0.0)))))
 *    ('bcsel', 'a', ('b2f(is_used_once)', 'b@16'), ('b2f', 'c@16')) => ('b2f', ('bcsel', 'a', 'b', 'c'))
 *    ('~i2f16', ('f2i', 'a@16')) => ('ftrunc', 'a')
 *    ('~f2i16', ('i2f', 'a@16')) => a
 *    ('~f2i16', ('u2f', 'a@16')) => a
 *    ('~f2u16', ('i2f', 'a@16')) => a
 *    ('~f2u16', ('u2f', 'a@16')) => a
 *    ('fadd', ('b2f16', ('flt', 0.0, 'a@16')), ('fneg', ('b2f16', ('flt', 'a@16', 0.0)))) => ('fsign', 'a')
 *    ('iadd', ('b2i16', ('flt', 0, 'a@16')), ('ineg', ('b2i16', ('flt', 'a@16', 0)))) => ('f2i16', ('fsign', 'a'))
 *    ('~f2f16', ('f2f', 'a')) => ('f2f16', 'a')
 *    ('~f2f16', ('u2f', 'a')) => ('u2f16', 'a')
 *    ('~f2f16', ('i2f', 'a')) => ('i2f16', 'a')
 *    ('~f2u16', ('f2f', 'a')) => ('f2u16', 'a')
 *    ('~f2i16', ('f2f', 'a')) => ('f2i16', 'a')
 *    ('f2f16', ('f2f32', 'a@16')) => a
 *    ('i2i16', ('i2i32', 'a@16')) => a
 *    ('u2u16', ('u2u32', 'a@16')) => a
 *    ('f2u32', ('f2f32', 'a@16')) => ('f2u32', 'a')
 *    ('f2i32', ('f2f32', 'a@16')) => ('f2i32', 'a')
 *    ('f2f16', ('u2f32', 'a')) => ('u2f16', 'a')
 *    ('f2f16', ('i2f32', 'a')) => ('i2f16', 'a')
 *    ('u2f32', ('u2u32', 'a@16')) => ('u2f32', 'a')
 *    ('i2f32', ('i2i32', 'a@16')) => ('i2f32', 'a')
 *    ('f2f16', ('f2f64', 'a@16')) => a
 *    ('i2i16', ('i2i64', 'a@16')) => a
 *    ('u2u16', ('u2u64', 'a@16')) => a
 *    ('f2u64', ('f2f64', 'a@16')) => ('f2u64', 'a')
 *    ('f2i64', ('f2f64', 'a@16')) => ('f2i64', 'a')
 *    ('f2f16', ('u2f64', 'a')) => ('u2f16', 'a')
 *    ('f2f16', ('i2f64', 'a')) => ('i2f16', 'a')
 *    ('u2f64', ('u2u64', 'a@16')) => ('u2f64', 'a')
 *    ('i2f64', ('i2i64', 'a@16')) => ('i2f64', 'a')
 *    ('ior', ('flt(is_used_once)', 0.0, 'a@32'), ('flt', 'b@32', 0.0)) => ('flt', 0.0, ('fmax', 'a', ('fneg', 'b')))
 *    ('ior', ('flt', 0.0, 'a@32'), ('flt(is_used_once)', 'b@32', 0.0)) => ('flt', 0.0, ('fmax', 'a', ('fneg', 'b')))
 *    ('ior', ('fge(is_used_once)', 0.0, 'a@32'), ('fge', 'b@32', 0.0)) => ('fge', 0.0, ('fmin', 'a', ('fneg', 'b')))
 *    ('ior', ('fge', 0.0, 'a@32'), ('fge(is_used_once)', 'b@32', 0.0)) => ('fge', 0.0, ('fmin', 'a', ('fneg', 'b')))
 *    ('~iand', ('flt(is_used_once)', 0.0, 'a@32'), ('flt', 'b@32', 0.0)) => ('flt', 0.0, ('fmin', 'a', ('fneg', 'b')))
 *    ('~iand', ('flt', 0.0, 'a@32'), ('flt(is_used_once)', 'b@32', 0.0)) => ('flt', 0.0, ('fmin', 'a', ('fneg', 'b')))
 *    ('~iand', ('fge(is_used_once)', 0.0, 'a@32'), ('fge', 'b@32', 0.0)) => ('fge', 0.0, ('fmax', 'a', ('fneg', 'b')))
 *    ('~iand', ('fge', 0.0, 'a@32'), ('fge(is_used_once)', 'b@32', 0.0)) => ('fge', 0.0, ('fmax', 'a', ('fneg', 'b')))
 *    ('bcsel@32', ('feq', 'a', 0.0), 1.0, ('i2f32', ('iadd', ('b2i32', ('flt', 0.0, 'a@32')), ('ineg', ('b2i32', ('flt', 'a@32', 0.0)))))) => ('i2f32', ('iadd', ('b2i32', ('!fge', 'a', 0.0)), ('ineg', ('b2i32', ('!flt', 'a', 0.0)))))
 *    ('bcsel', 'a', ('b2f(is_used_once)', 'b@32'), ('b2f', 'c@32')) => ('b2f', ('bcsel', 'a', 'b', 'c'))
 *    ('~i2f32', ('f2i', 'a@32')) => ('ftrunc', 'a')
 *    ('~f2i32', ('i2f', 'a@32')) => a
 *    ('~f2i32', ('u2f', 'a@32')) => a
 *    ('~f2u32', ('i2f', 'a@32')) => a
 *    ('~f2u32', ('u2f', 'a@32')) => a
 *    ('fadd', ('b2f32', ('flt', 0.0, 'a@32')), ('fneg', ('b2f32', ('flt', 'a@32', 0.0)))) => ('fsign', 'a')
 *    ('iadd', ('b2i32', ('flt', 0, 'a@32')), ('ineg', ('b2i32', ('flt', 'a@32', 0)))) => ('f2i32', ('fsign', 'a'))
 *    ('~f2f32', ('f2f', 'a')) => ('f2f32', 'a')
 *    ('~f2f32', ('u2f', 'a')) => ('u2f32', 'a')
 *    ('~f2f32', ('i2f', 'a')) => ('i2f32', 'a')
 *    ('~f2u32', ('f2f', 'a')) => ('f2u32', 'a')
 *    ('~f2i32', ('f2f', 'a')) => ('f2i32', 'a')
 *    ('f2f32', ('f2f64', 'a@32')) => a
 *    ('i2i32', ('i2i64', 'a@32')) => a
 *    ('u2u32', ('u2u64', 'a@32')) => a
 *    ('f2u64', ('f2f64', 'a@32')) => ('f2u64', 'a')
 *    ('f2i64', ('f2f64', 'a@32')) => ('f2i64', 'a')
 *    ('f2f32', ('u2f64', 'a')) => ('u2f32', 'a')
 *    ('f2f32', ('i2f64', 'a')) => ('i2f32', 'a')
 *    ('u2f64', ('u2u64', 'a@32')) => ('u2f64', 'a')
 *    ('i2f64', ('i2i64', 'a@32')) => ('i2f64', 'a')
 *    ('ior', ('flt(is_used_once)', 0.0, 'a@64'), ('flt', 'b@64', 0.0)) => ('flt', 0.0, ('fmax', 'a', ('fneg', 'b')))
 *    ('ior', ('flt', 0.0, 'a@64'), ('flt(is_used_once)', 'b@64', 0.0)) => ('flt', 0.0, ('fmax', 'a', ('fneg', 'b')))
 *    ('ior', ('fge(is_used_once)', 0.0, 'a@64'), ('fge', 'b@64', 0.0)) => ('fge', 0.0, ('fmin', 'a', ('fneg', 'b')))
 *    ('ior', ('fge', 0.0, 'a@64'), ('fge(is_used_once)', 'b@64', 0.0)) => ('fge', 0.0, ('fmin', 'a', ('fneg', 'b')))
 *    ('~iand', ('flt(is_used_once)', 0.0, 'a@64'), ('flt', 'b@64', 0.0)) => ('flt', 0.0, ('fmin', 'a', ('fneg', 'b')))
 *    ('~iand', ('flt', 0.0, 'a@64'), ('flt(is_used_once)', 'b@64', 0.0)) => ('flt', 0.0, ('fmin', 'a', ('fneg', 'b')))
 *    ('~iand', ('fge(is_used_once)', 0.0, 'a@64'), ('fge', 'b@64', 0.0)) => ('fge', 0.0, ('fmax', 'a', ('fneg', 'b')))
 *    ('~iand', ('fge', 0.0, 'a@64'), ('fge(is_used_once)', 'b@64', 0.0)) => ('fge', 0.0, ('fmax', 'a', ('fneg', 'b')))
 *    ('bcsel@64', ('feq', 'a', 0.0), 1.0, ('i2f64', ('iadd', ('b2i64', ('flt', 0.0, 'a@64')), ('ineg', ('b2i64', ('flt', 'a@64', 0.0)))))) => ('i2f64', ('iadd', ('b2i32', ('!fge', 'a', 0.0)), ('ineg', ('b2i32', ('!flt', 'a', 0.0)))))
 *    ('bcsel', 'a', ('b2f(is_used_once)', 'b@64'), ('b2f', 'c@64')) => ('b2f', ('bcsel', 'a', 'b', 'c'))
 *    ('~i2f64', ('f2i', 'a@64')) => ('ftrunc', 'a')
 *    ('~f2i64', ('i2f', 'a@64')) => a
 *    ('~f2i64', ('u2f', 'a@64')) => a
 *    ('~f2u64', ('i2f', 'a@64')) => a
 *    ('~f2u64', ('u2f', 'a@64')) => a
 *    ('fadd', ('b2f64', ('flt', 0.0, 'a@64')), ('fneg', ('b2f64', ('flt', 'a@64', 0.0)))) => ('fsign', 'a')
 *    ('iadd', ('b2i64', ('flt', 0, 'a@64')), ('ineg', ('b2i64', ('flt', 'a@64', 0)))) => ('f2i64', ('fsign', 'a'))
 *    ('~f2f64', ('f2f', 'a')) => ('f2f64', 'a')
 *    ('~f2f64', ('u2f', 'a')) => ('u2f64', 'a')
 *    ('~f2f64', ('i2f', 'a')) => ('i2f64', 'a')
 *    ('~f2u64', ('f2f', 'a')) => ('f2u64', 'a')
 *    ('~f2i64', ('f2f', 'a')) => ('f2i64', 'a')
 *    ('f2fmp', ('u2f32', 'a@32')) => ('u2fmp', 'a')
 *    ('f2fmp', ('i2f32', 'a@32')) => ('i2fmp', 'a')
 *    ('f2u16', ('f2fmp', 'a@32')) => ('f2u16', 'a')
 *    ('f2i16', ('f2fmp', 'a@32')) => ('f2i16', 'a')
 *    ('i2imp', ('f2u32', 'a@32')) => ('f2ump', 'a')
 *    ('i2imp', ('f2i32', 'a@32')) => ('f2imp', 'a')
 *    ('u2f16', ('i2imp', 'a@32')) => ('u2f16', 'a')
 *    ('i2f16', ('i2imp', 'a@32')) => ('i2f16', 'a')
 *    ('iand', ('u2u16', ('u2u8', 'a@16')), '#b') => ('iand', 'a', ('iand', 'b', 255))
 *    ('u2u16', ('u2u8(is_used_once)', ('iand', 'a@16', '#b'))) => ('iand', 'a', ('iand', 'b', 255))
 *    ('u2u8', ('iand', ('u2u16', ('u2u8', 'a@16')), ('u2u16', ('u2u8', 'b@16')))) => ('u2u8', ('iand', 'a', 'b'))
 *    ('u2u8', ('iand', ('u2u16', ('u2u8', 'a@32')), ('u2u16', ('u2u8', 'b@32')))) => ('u2u8', ('iand', 'a', 'b'))
 *    ('iand', ('extract_i8', 'a', '#b'), ('extract_i8', 'c', 'b')) => ('extract_i8', ('iand', 'a', 'c'), 'b')
 *    ('iand', ('extract_u8', 'a', '#b'), ('extract_u8', 'c', 'b')) => ('extract_u8', ('iand', 'a', 'c'), 'b')
 *    ('iand', ('extract_i16', 'a', '#b'), ('extract_i16', 'c', 'b')) => ('extract_i16', ('iand', 'a', 'c'), 'b')
 *    ('iand', ('extract_u16', 'a', '#b'), ('extract_u16', 'c', 'b')) => ('extract_u16', ('iand', 'a', 'c'), 'b')
 *    ('iand', ('ushr(is_used_once)', 'a', '#b'), ('ushr', 'c', 'b')) => ('ushr', ('iand', 'a', 'c'), 'b')
 *    ('iand', ('ishr(is_used_once)', 'a', '#b'), ('ishr', 'c', 'b')) => ('ishr', ('iand', 'a', 'c'), 'b')
 *    ('iand', ('ishl(is_used_once)', 'a', '#b'), ('ishl', 'c', 'b')) => ('ishl', ('iand', 'a', 'c'), 'b')
 *    ('u2u8', ('ior', ('u2u16', ('u2u8', 'a@16')), ('u2u16', ('u2u8', 'b@16')))) => ('u2u8', ('ior', 'a', 'b'))
 *    ('u2u8', ('ior', ('u2u16', ('u2u8', 'a@32')), ('u2u16', ('u2u8', 'b@32')))) => ('u2u8', ('ior', 'a', 'b'))
 *    ('ior', ('extract_i8', 'a', '#b'), ('extract_i8', 'c', 'b')) => ('extract_i8', ('ior', 'a', 'c'), 'b')
 *    ('ior', ('extract_u8', 'a', '#b'), ('extract_u8', 'c', 'b')) => ('extract_u8', ('ior', 'a', 'c'), 'b')
 *    ('ior', ('extract_i16', 'a', '#b'), ('extract_i16', 'c', 'b')) => ('extract_i16', ('ior', 'a', 'c'), 'b')
 *    ('ior', ('extract_u16', 'a', '#b'), ('extract_u16', 'c', 'b')) => ('extract_u16', ('ior', 'a', 'c'), 'b')
 *    ('ior', ('ushr(is_used_once)', 'a', '#b'), ('ushr', 'c', 'b')) => ('ushr', ('ior', 'a', 'c'), 'b')
 *    ('ior', ('ishr(is_used_once)', 'a', '#b'), ('ishr', 'c', 'b')) => ('ishr', ('ior', 'a', 'c'), 'b')
 *    ('ior', ('ishl(is_used_once)', 'a', '#b'), ('ishl', 'c', 'b')) => ('ishl', ('ior', 'a', 'c'), 'b')
 *    ('u2u8', ('ixor', ('u2u16', ('u2u8', 'a@16')), ('u2u16', ('u2u8', 'b@16')))) => ('u2u8', ('ixor', 'a', 'b'))
 *    ('u2u8', ('ixor', ('u2u16', ('u2u8', 'a@32')), ('u2u16', ('u2u8', 'b@32')))) => ('u2u8', ('ixor', 'a', 'b'))
 *    ('ixor', ('extract_i8', 'a', '#b'), ('extract_i8', 'c', 'b')) => ('extract_i8', ('ixor', 'a', 'c'), 'b')
 *    ('ixor', ('extract_u8', 'a', '#b'), ('extract_u8', 'c', 'b')) => ('extract_u8', ('ixor', 'a', 'c'), 'b')
 *    ('ixor', ('extract_i16', 'a', '#b'), ('extract_i16', 'c', 'b')) => ('extract_i16', ('ixor', 'a', 'c'), 'b')
 *    ('ixor', ('extract_u16', 'a', '#b'), ('extract_u16', 'c', 'b')) => ('extract_u16', ('ixor', 'a', 'c'), 'b')
 *    ('ixor', ('ushr(is_used_once)', 'a', '#b'), ('ushr', 'c', 'b')) => ('ushr', ('ixor', 'a', 'c'), 'b')
 *    ('ixor', ('ishr(is_used_once)', 'a', '#b'), ('ishr', 'c', 'b')) => ('ishr', ('ixor', 'a', 'c'), 'b')
 *    ('ixor', ('ishl(is_used_once)', 'a', '#b'), ('ishl', 'c', 'b')) => ('ishl', ('ixor', 'a', 'c'), 'b')
 *    ('iand', ('ieq', 'a@8', 0), ('ieq', 'b@8', 0)) => ('ieq', ('ior', 'a', 'b'), 0)
 *    ('ior', ('ine', 'a@8', 0), ('ine', 'b@8', 0)) => ('ine', ('ior', 'a', 'b'), 0)
 *    ('iand', ('ieq', 'a@8', 0), ('ieq', 'b@8', 0)) => ('ieq', ('umax', 'a', 'b'), 0)
 *    ('ior', ('ieq', 'a@8', 0), ('ieq', 'b@8', 0)) => ('ieq', ('umin', 'a', 'b'), 0)
 *    ('iand', ('ine', 'a@8', 0), ('ine', 'b@8', 0)) => ('ine', ('umin', 'a', 'b'), 0)
 *    ('ior', ('ine', 'a@8', 0), ('ine', 'b@8', 0)) => ('ine', ('umax', 'a', 'b'), 0)
 *    ('ineg', ('b2i8', 'a@8')) => a
 *    ('ishl', 'a@8', ('iand', 7, 'b')) => ('ishl', 'a', 'b')
 *    ('ishr', 'a@8', ('iand', 7, 'b')) => ('ishr', 'a', 'b')
 *    ('ushr', 'a@8', ('iand', 7, 'b')) => ('ushr', 'a', 'b')
 *    ('ushr', 'a@8', ('ishl(is_used_once)', ('iand', 'b', 1), 2)) => ('ushr', 'a', ('ishl', 'b', 2))
 *    ('iand', ('ieq', 'a@16', 0), ('ieq', 'b@16', 0)) => ('ieq', ('ior', 'a', 'b'), 0)
 *    ('ior', ('ine', 'a@16', 0), ('ine', 'b@16', 0)) => ('ine', ('ior', 'a', 'b'), 0)
 *    ('iand', ('ieq', 'a@16', 0), ('ieq', 'b@16', 0)) => ('ieq', ('umax', 'a', 'b'), 0)
 *    ('ior', ('ieq', 'a@16', 0), ('ieq', 'b@16', 0)) => ('ieq', ('umin', 'a', 'b'), 0)
 *    ('iand', ('ine', 'a@16', 0), ('ine', 'b@16', 0)) => ('ine', ('umin', 'a', 'b'), 0)
 *    ('ior', ('ine', 'a@16', 0), ('ine', 'b@16', 0)) => ('ine', ('umax', 'a', 'b'), 0)
 *    ('ineg', ('b2i16', 'a@16')) => a
 *    ('ishl', 'a@16', ('iand', 15, 'b')) => ('ishl', 'a', 'b')
 *    ('ishr', 'a@16', ('iand', 15, 'b')) => ('ishr', 'a', 'b')
 *    ('ushr', 'a@16', ('iand', 15, 'b')) => ('ushr', 'a', 'b')
 *    ('ushr', 'a@16', ('ishl(is_used_once)', ('iand', 'b', 1), 3)) => ('ushr', 'a', ('ishl', 'b', 3))
 *    ('iand', ('ieq', 'a@32', 0), ('ieq', 'b@32', 0)) => ('ieq', ('ior', 'a', 'b'), 0)
 *    ('ior', ('ine', 'a@32', 0), ('ine', 'b@32', 0)) => ('ine', ('ior', 'a', 'b'), 0)
 *    ('iand', ('ieq', 'a@32', 0), ('ieq', 'b@32', 0)) => ('ieq', ('umax', 'a', 'b'), 0)
 *    ('ior', ('ieq', 'a@32', 0), ('ieq', 'b@32', 0)) => ('ieq', ('umin', 'a', 'b'), 0)
 *    ('iand', ('ine', 'a@32', 0), ('ine', 'b@32', 0)) => ('ine', ('umin', 'a', 'b'), 0)
 *    ('ior', ('ine', 'a@32', 0), ('ine', 'b@32', 0)) => ('ine', ('umax', 'a', 'b'), 0)
 *    ('ineg', ('b2i32', 'a@32')) => a
 *    ('ishl', 'a@32', ('iand', 31, 'b')) => ('ishl', 'a', 'b')
 *    ('ishr', 'a@32', ('iand', 31, 'b')) => ('ishr', 'a', 'b')
 *    ('ushr', 'a@32', ('iand', 31, 'b')) => ('ushr', 'a', 'b')
 *    ('ushr', 'a@32', ('ishl(is_used_once)', ('iand', 'b', 1), 4)) => ('ushr', 'a', ('ishl', 'b', 4))
 *    ('iand', ('ieq', 'a@64', 0), ('ieq', 'b@64', 0)) => ('ieq', ('ior', 'a', 'b'), 0)
 *    ('ior', ('ine', 'a@64', 0), ('ine', 'b@64', 0)) => ('ine', ('ior', 'a', 'b'), 0)
 *    ('iand', ('ieq', 'a@64', 0), ('ieq', 'b@64', 0)) => ('ieq', ('umax', 'a', 'b'), 0)
 *    ('ior', ('ieq', 'a@64', 0), ('ieq', 'b@64', 0)) => ('ieq', ('umin', 'a', 'b'), 0)
 *    ('iand', ('ine', 'a@64', 0), ('ine', 'b@64', 0)) => ('ine', ('umin', 'a', 'b'), 0)
 *    ('ior', ('ine', 'a@64', 0), ('ine', 'b@64', 0)) => ('ine', ('umax', 'a', 'b'), 0)
 *    ('ineg', ('b2i64', 'a@64')) => a
 *    ('ishl', 'a@64', ('iand', 63, 'b')) => ('ishl', 'a', 'b')
 *    ('ishr', 'a@64', ('iand', 63, 'b')) => ('ishr', 'a', 'b')
 *    ('ushr', 'a@64', ('iand', 63, 'b')) => ('ushr', 'a', 'b')
 *    ('ushr', 'a@64', ('ishl(is_used_once)', ('iand', 'b', 1), 5)) => ('ushr', 'a', ('ishl', 'b', 5))
 *    ('ior', ('ieq', 'a', 0), ('ieq', 'a', 1)) => ('uge', 1, 'a')
 *    ('ior', ('uge', 1, 'a'), ('ieq', 'a', 2)) => ('uge', 2, 'a')
 *    ('ior', ('uge', 2, 'a'), ('ieq', 'a', 3)) => ('uge', 3, 'a')
 *    ('ior', 'a', ('ieq', 'a', False)) => True
 *    ('ine', ('ineg', ('b2i', 'a@1')), ('ineg', ('b2i', 'b@1'))) => ('ine', 'a', 'b')
 *    ('b2i', ('ine', 'a@1', 'b@1')) => ('b2i', ('ixor', 'a', 'b'))
 *    ('ishl', ('b2i32', ('ine', ('iand', 'a@32', '#b(is_pos_power_of_two)'), 0)), '#c') => ('bcsel', ('ige', ('iand', 'c', 31), ('find_lsb', 'b')), ('ishl', ('iand', 'a', 'b'), ('iadd', ('iand', 'c', 31), ('ineg', ('find_lsb', 'b')))), ('ushr', ('iand', 'a', 'b'), ('iadd', ('ineg', ('iand', 'c', 31)), ('find_lsb', 'b'))))
 *    ('b2i32', ('ine', ('iand', 'a@32', '#b(is_pos_power_of_two)'), 0)) => ('ushr', ('iand', 'a', 'b'), ('find_lsb', 'b'))
 *    ('ior', ('b2i', 'a'), ('iand', 'b', 1)) => ('iand', ('ior', ('b2i', 'a'), 'b'), 1)
 *    ('iand', ('b2i', 'a'), ('iand', 'b', 1)) => ('iand', ('b2i', 'a'), 'b')
 *    ('iand', ('inot', ('iand', ('ior', ('ieq', 'a', 0), 'b'), 'c')), ('ilt', 'a', 0)) => ('iand', ('inot', ('iand', 'b', 'c')), ('ilt', 'a', 0))
 *    ('iand', ('inot', ('iand', ('ieq', ('umin', 'a', 'b'), 0), 'c')), ('ilt', 'a', 0)) => ('iand', ('inot', ('iand', ('ieq', 'b', 0), 'c')), ('ilt', 'a', 0))
 *    ('flt', 'a', ('fmax', 'b', 'a')) => ('flt', 'a', 'b')
 *    ('flt', ('fmin', 'a', 'b'), 'a') => ('flt', 'b', 'a')
 *    ('~fge', 'a', ('fmin', 'b', 'a')) => True
 *    ('~fge', ('fmax', 'a', 'b'), 'a') => True
 *    ('flt', 'a', ('fmin', 'b', 'a')) => False
 *    ('flt', ('fmax', 'a', 'b'), 'a') => False
 *    ('~fge', 'a', ('fmax', 'b', 'a')) => ('fge', 'a', 'b')
 *    ('~fge', ('fmin', 'a', 'b'), 'a') => ('fge', 'b', 'a')
 *    ('ilt', 'a', ('imax', 'b', 'a')) => ('ilt', 'a', 'b')
 *    ('ilt', ('imin', 'a', 'b'), 'a') => ('ilt', 'b', 'a')
 *    ('ige', 'a', ('imin', 'b', 'a')) => True
 *    ('ige', ('imax', 'a', 'b'), 'a') => True
 *    ('ult', 'a', ('umax', 'b', 'a')) => ('ult', 'a', 'b')
 *    ('ult', ('umin', 'a', 'b'), 'a') => ('ult', 'b', 'a')
 *    ('uge', 'a', ('umin', 'b', 'a')) => True
 *    ('uge', ('umax', 'a', 'b'), 'a') => True
 *    ('ilt', 'a', ('imin', 'b', 'a')) => False
 *    ('ilt', ('imax', 'a', 'b'), 'a') => False
 *    ('ige', 'a', ('imax', 'b', 'a')) => ('ige', 'a', 'b')
 *    ('ige', ('imin', 'a', 'b'), 'a') => ('ige', 'b', 'a')
 *    ('ult', 'a', ('umin', 'b', 'a')) => False
 *    ('ult', ('umax', 'a', 'b'), 'a') => False
 *    ('uge', 'a', ('umax', 'b', 'a')) => ('uge', 'a', 'b')
 *    ('uge', ('umin', 'a', 'b'), 'a') => ('uge', 'b', 'a')
 *    ('ult', 'a', ('iand', 'b', 'a')) => False
 *    ('ult', ('ior', 'a', 'b'), 'a') => False
 *    ('uge', 'a', ('iand', 'b', 'a')) => True
 *    ('uge', ('ior', 'a', 'b'), 'a') => True
 *    ('ilt', '#a', ('imax', '#b', 'c')) => ('ior', ('ilt', 'a', 'b'), ('ilt', 'a', 'c'))
 *    ('ilt', ('imin', '#a', 'b'), '#c') => ('ior', ('ilt', 'a', 'c'), ('ilt', 'b', 'c'))
 *    ('ige', '#a', ('imin', '#b', 'c')) => ('ior', ('ige', 'a', 'b'), ('ige', 'a', 'c'))
 *    ('ige', ('imax', '#a', 'b'), '#c') => ('ior', ('ige', 'a', 'c'), ('ige', 'b', 'c'))
 *    ('ult', '#a', ('umax', '#b', 'c')) => ('ior', ('ult', 'a', 'b'), ('ult', 'a', 'c'))
 *    ('ult', ('umin', '#a', 'b'), '#c') => ('ior', ('ult', 'a', 'c'), ('ult', 'b', 'c'))
 *    ('uge', '#a', ('umin', '#b', 'c')) => ('ior', ('uge', 'a', 'b'), ('uge', 'a', 'c'))
 *    ('uge', ('umax', '#a', 'b'), '#c') => ('ior', ('uge', 'a', 'c'), ('uge', 'b', 'c'))
 *    ('ilt', '#a', ('imin', '#b', 'c')) => ('iand', ('ilt', 'a', 'b'), ('ilt', 'a', 'c'))
 *    ('ilt', ('imax', '#a', 'b'), '#c') => ('iand', ('ilt', 'a', 'c'), ('ilt', 'b', 'c'))
 *    ('ige', '#a', ('imax', '#b', 'c')) => ('iand', ('ige', 'a', 'b'), ('ige', 'a', 'c'))
 *    ('ige', ('imin', '#a', 'b'), '#c') => ('iand', ('ige', 'a', 'c'), ('ige', 'b', 'c'))
 *    ('ult', '#a', ('umin', '#b', 'c')) => ('iand', ('ult', 'a', 'b'), ('ult', 'a', 'c'))
 *    ('ult', ('umax', '#a', 'b'), '#c') => ('iand', ('ult', 'a', 'c'), ('ult', 'b', 'c'))
 *    ('uge', '#a', ('umax', '#b', 'c')) => ('iand', ('uge', 'a', 'b'), ('uge', 'a', 'c'))
 *    ('uge', ('umin', '#a', 'b'), '#c') => ('iand', ('uge', 'a', 'c'), ('uge', 'b', 'c'))
 *    ('bcsel', ('ilt', 'a', 0), ('ineg', ('ishr', 'a', 'b')), ('ishr', 'a', 'b')) => ('iabs', ('ishr', 'a', 'b'))
 *    ('iabs', ('ishr', ('iabs', 'a'), 'b')) => ('ishr', ('iabs', 'a'), 'b')
 *    ('fabs', ('slt', 'a', 'b')) => ('slt', 'a', 'b')
 *    ('fabs', ('sge', 'a', 'b')) => ('sge', 'a', 'b')
 *    ('fabs', ('seq', 'a', 'b')) => ('seq', 'a', 'b')
 *    ('fabs', ('sne', 'a', 'b')) => ('sne', 'a', 'b')
 *    ('slt', 'a', 'b') => ('b2f', ('flt', 'a', 'b'))
 *    ('sge', 'a', 'b') => ('b2f', ('fge', 'a', 'b'))
 *    ('seq', 'a', 'b') => ('b2f', ('feq', 'a', 'b'))
 *    ('sne', 'a', 'b') => ('b2f', ('fneu', 'a', 'b'))
 *    ('seq', ('seq', 'a', 'b'), 1.0) => ('seq', 'a', 'b')
 *    ('seq', ('sne', 'a', 'b'), 1.0) => ('sne', 'a', 'b')
 *    ('seq', ('slt', 'a', 'b'), 1.0) => ('slt', 'a', 'b')
 *    ('seq', ('sge', 'a', 'b'), 1.0) => ('sge', 'a', 'b')
 *    ('sne', ('seq', 'a', 'b'), 0.0) => ('seq', 'a', 'b')
 *    ('sne', ('sne', 'a', 'b'), 0.0) => ('sne', 'a', 'b')
 *    ('sne', ('slt', 'a', 'b'), 0.0) => ('slt', 'a', 'b')
 *    ('sne', ('sge', 'a', 'b'), 0.0) => ('sge', 'a', 'b')
 *    ('seq', ('seq', 'a', 'b'), 0.0) => ('sne', 'a', 'b')
 *    ('seq', ('sne', 'a', 'b'), 0.0) => ('seq', 'a', 'b')
 *    ('seq', ('slt', 'a', 'b'), 0.0) => ('sge', 'a', 'b')
 *    ('seq', ('sge', 'a', 'b'), 0.0) => ('slt', 'a', 'b')
 *    ('sne', ('seq', 'a', 'b'), 1.0) => ('sne', 'a', 'b')
 *    ('sne', ('sne', 'a', 'b'), 1.0) => ('seq', 'a', 'b')
 *    ('sne', ('slt', 'a', 'b'), 1.0) => ('sge', 'a', 'b')
 *    ('sne', ('sge', 'a', 'b'), 1.0) => ('slt', 'a', 'b')
 *    ('fall_equal2', 'a', 'b') => ('fmin', ('seq', 'a.x', 'b.x'), ('seq', 'a.y', 'b.y'))
 *    ('fall_equal3', 'a', 'b') => ('seq', ('fany_nequal3', 'a', 'b'), 0.0)
 *    ('fall_equal4', 'a', 'b') => ('seq', ('fany_nequal4', 'a', 'b'), 0.0)
 *    ('fall_equal8', 'a', 'b') => ('seq', ('fany_nequal8', 'a', 'b'), 0.0)
 *    ('fall_equal16', 'a', 'b') => ('seq', ('fany_nequal16', 'a', 'b'), 0.0)
 *    ('fany_nequal2', 'a', 'b') => ('fmax', ('sne', 'a.x', 'b.x'), ('sne', 'a.y', 'b.y'))
 *    ('fany_nequal3', 'a', 'b') => ('fsat', ('fdot3', ('sne', 'a', 'b'), ('sne', 'a', 'b')))
 *    ('fany_nequal4', 'a', 'b') => ('fsat', ('fdot4', ('sne', 'a', 'b'), ('sne', 'a', 'b')))
 *    ('fany_nequal8', 'a', 'b') => ('fsat', ('fdot8', ('sne', 'a', 'b'), ('sne', 'a', 'b')))
 *    ('fany_nequal16', 'a', 'b') => ('fsat', ('fdot16', ('sne', 'a', 'b'), ('sne', 'a', 'b')))
 *    ('ball_iequal2', 'a', 'b') => ('iand', ('ieq', 'a.x', 'b.x'), ('ieq', 'a.y', 'b.y'))
 *    ('ball_iequal3', 'a', 'b') => ('iand', ('ieq', 'a.x', 'b.x'), ('iand', ('ieq', 'a.y', 'b.y'), ('ieq', 'a.z', 'b.z')))
 *    ('ball_iequal4', 'a', 'b') => ('iand', ('iand', ('ieq', 'a.x', 'b.x'), ('ieq', 'a.y', 'b.y')), ('iand', ('ieq', 'a.z', 'b.z'), ('ieq', 'a.w', 'b.w')))
 *    ('ball_iequal8', 'a', 'b') => ('iand', ('iand', ('iand', ('ieq', 'a.a', 'b.a'), ('ieq', 'a.b', 'b.b')), ('iand', ('ieq', 'a.c', 'b.c'), ('ieq', 'a.d', 'b.d'))), ('iand', ('iand', ('ieq', 'a.e', 'b.e'), ('ieq', 'a.f', 'b.f')), ('iand', ('ieq', 'a.g', 'b.g'), ('ieq', 'a.h', 'b.h'))))
 *    ('ball_iequal16', 'a', 'b') => ('iand', ('iand', ('iand', ('iand', ('ieq', 'a.a', 'b.a'), ('ieq', 'a.b', 'b.b')), ('iand', ('ieq', 'a.c', 'b.c'), ('ieq', 'a.d', 'b.d'))), ('iand', ('iand', ('ieq', 'a.e', 'b.e'), ('ieq', 'a.f', 'b.f')), ('iand', ('ieq', 'a.g', 'b.g'), ('ieq', 'a.h', 'b.h')))), ('iand', ('iand', ('iand', ('ieq', 'a.i', 'b.i'), ('ieq', 'a.j', 'b.j')), ('iand', ('ieq', 'a.k', 'b.k'), ('ieq', 'a.l', 'b.l'))), ('iand', ('iand', ('ieq', 'a.m', 'b.m'), ('ieq', 'a.n', 'b.n')), ('iand', ('ieq', 'a.o', 'b.o'), ('ieq', 'a.p', 'b.p')))))
 *    ('ball_fequal2', 'a', 'b') => ('iand', ('feq', 'a.x', 'b.x'), ('feq', 'a.y', 'b.y'))
 *    ('ball_fequal3', 'a', 'b') => ('iand', ('feq', 'a.x', 'b.x'), ('iand', ('feq', 'a.y', 'b.y'), ('feq', 'a.z', 'b.z')))
 *    ('ball_fequal4', 'a', 'b') => ('iand', ('iand', ('feq', 'a.x', 'b.x'), ('feq', 'a.y', 'b.y')), ('iand', ('feq', 'a.z', 'b.z'), ('feq', 'a.w', 'b.w')))
 *    ('ball_fequal8', 'a', 'b') => ('iand', ('iand', ('iand', ('feq', 'a.a', 'b.a'), ('feq', 'a.b', 'b.b')), ('iand', ('feq', 'a.c', 'b.c'), ('feq', 'a.d', 'b.d'))), ('iand', ('iand', ('feq', 'a.e', 'b.e'), ('feq', 'a.f', 'b.f')), ('iand', ('feq', 'a.g', 'b.g'), ('feq', 'a.h', 'b.h'))))
 *    ('ball_fequal16', 'a', 'b') => ('iand', ('iand', ('iand', ('iand', ('feq', 'a.a', 'b.a'), ('feq', 'a.b', 'b.b')), ('iand', ('feq', 'a.c', 'b.c'), ('feq', 'a.d', 'b.d'))), ('iand', ('iand', ('feq', 'a.e', 'b.e'), ('feq', 'a.f', 'b.f')), ('iand', ('feq', 'a.g', 'b.g'), ('feq', 'a.h', 'b.h')))), ('iand', ('iand', ('iand', ('feq', 'a.i', 'b.i'), ('feq', 'a.j', 'b.j')), ('iand', ('feq', 'a.k', 'b.k'), ('feq', 'a.l', 'b.l'))), ('iand', ('iand', ('feq', 'a.m', 'b.m'), ('feq', 'a.n', 'b.n')), ('iand', ('feq', 'a.o', 'b.o'), ('feq', 'a.p', 'b.p')))))
 *    ('bany_inequal2', 'a', 'b') => ('ior', ('ine', 'a.x', 'b.x'), ('ine', 'a.y', 'b.y'))
 *    ('bany_inequal3', 'a', 'b') => ('ior', ('ine', 'a.x', 'b.x'), ('ior', ('ine', 'a.y', 'b.y'), ('ine', 'a.z', 'b.z')))
 *    ('bany_inequal4', 'a', 'b') => ('ior', ('ior', ('ine', 'a.x', 'b.x'), ('ine', 'a.y', 'b.y')), ('ior', ('ine', 'a.z', 'b.z'), ('ine', 'a.w', 'b.w')))
 *    ('bany_inequal8', 'a', 'b') => ('ior', ('ior', ('ior', ('ine', 'a.a', 'b.a'), ('ine', 'a.b', 'b.b')), ('ior', ('ine', 'a.c', 'b.c'), ('ine', 'a.d', 'b.d'))), ('ior', ('ior', ('ine', 'a.e', 'b.e'), ('ine', 'a.f', 'b.f')), ('ior', ('ine', 'a.g', 'b.g'), ('ine', 'a.h', 'b.h'))))
 *    ('bany_inequal16', 'a', 'b') => ('ior', ('ior', ('ior', ('ior', ('ine', 'a.a', 'b.a'), ('ine', 'a.b', 'b.b')), ('ior', ('ine', 'a.c', 'b.c'), ('ine', 'a.d', 'b.d'))), ('ior', ('ior', ('ine', 'a.e', 'b.e'), ('ine', 'a.f', 'b.f')), ('ior', ('ine', 'a.g', 'b.g'), ('ine', 'a.h', 'b.h')))), ('ior', ('ior', ('ior', ('ine', 'a.i', 'b.i'), ('ine', 'a.j', 'b.j')), ('ior', ('ine', 'a.k', 'b.k'), ('ine', 'a.l', 'b.l'))), ('ior', ('ior', ('ine', 'a.m', 'b.m'), ('ine', 'a.n', 'b.n')), ('ior', ('ine', 'a.o', 'b.o'), ('ine', 'a.p', 'b.p')))))
 *    ('bany_fnequal2', 'a', 'b') => ('ior', ('fneu', 'a.x', 'b.x'), ('fneu', 'a.y', 'b.y'))
 *    ('bany_fnequal3', 'a', 'b') => ('ior', ('fneu', 'a.x', 'b.x'), ('ior', ('fneu', 'a.y', 'b.y'), ('fneu', 'a.z', 'b.z')))
 *    ('bany_fnequal4', 'a', 'b') => ('ior', ('ior', ('fneu', 'a.x', 'b.x'), ('fneu', 'a.y', 'b.y')), ('ior', ('fneu', 'a.z', 'b.z'), ('fneu', 'a.w', 'b.w')))
 *    ('bany_fnequal8', 'a', 'b') => ('ior', ('ior', ('ior', ('fneu', 'a.a', 'b.a'), ('fneu', 'a.b', 'b.b')), ('ior', ('fneu', 'a.c', 'b.c'), ('fneu', 'a.d', 'b.d'))), ('ior', ('ior', ('fneu', 'a.e', 'b.e'), ('fneu', 'a.f', 'b.f')), ('ior', ('fneu', 'a.g', 'b.g'), ('fneu', 'a.h', 'b.h'))))
 *    ('bany_fnequal16', 'a', 'b') => ('ior', ('ior', ('ior', ('ior', ('fneu', 'a.a', 'b.a'), ('fneu', 'a.b', 'b.b')), ('ior', ('fneu', 'a.c', 'b.c'), ('fneu', 'a.d', 'b.d'))), ('ior', ('ior', ('fneu', 'a.e', 'b.e'), ('fneu', 'a.f', 'b.f')), ('ior', ('fneu', 'a.g', 'b.g'), ('fneu', 'a.h', 'b.h')))), ('ior', ('ior', ('ior', ('fneu', 'a.i', 'b.i'), ('fneu', 'a.j', 'b.j')), ('ior', ('fneu', 'a.k', 'b.k'), ('fneu', 'a.l', 'b.l'))), ('ior', ('ior', ('fneu', 'a.m', 'b.m'), ('fneu', 'a.n', 'b.n')), ('ior', ('fneu', 'a.o', 'b.o'), ('fneu', 'a.p', 'b.p')))))
 *    ('feq', ('seq', 'a', 'b'), 1.0) => ('feq', 'a', 'b')
 *    ('feq', ('sne', 'a', 'b'), 1.0) => ('fneu', 'a', 'b')
 *    ('feq', ('slt', 'a', 'b'), 1.0) => ('flt', 'a', 'b')
 *    ('feq', ('sge', 'a', 'b'), 1.0) => ('fge', 'a', 'b')
 *    ('fneu', ('seq', 'a', 'b'), 0.0) => ('feq', 'a', 'b')
 *    ('fneu', ('sne', 'a', 'b'), 0.0) => ('fneu', 'a', 'b')
 *    ('fneu', ('slt', 'a', 'b'), 0.0) => ('flt', 'a', 'b')
 *    ('fneu', ('sge', 'a', 'b'), 0.0) => ('fge', 'a', 'b')
 *    ('feq', ('seq', 'a', 'b'), 0.0) => ('fneu', 'a', 'b')
 *    ('feq', ('sne', 'a', 'b'), 0.0) => ('feq', 'a', 'b')
 *    ('feq', ('slt', 'a', 'b'), 0.0) => ('fge', 'a', 'b')
 *    ('feq', ('sge', 'a', 'b'), 0.0) => ('flt', 'a', 'b')
 *    ('fneu', ('seq', 'a', 'b'), 1.0) => ('fneu', 'a', 'b')
 *    ('fneu', ('sne', 'a', 'b'), 1.0) => ('feq', 'a', 'b')
 *    ('fneu', ('slt', 'a', 'b'), 1.0) => ('fge', 'a', 'b')
 *    ('fneu', ('sge', 'a', 'b'), 1.0) => ('flt', 'a', 'b')
 *    ('fneu', ('fneg', 'a'), 'a') => ('fneu', 'a', 0.0)
 *    ('feq', ('fneg', 'a'), 'a') => ('feq', 'a', 0.0)
 *    ('imul', ('b2i', 'a@1'), ('b2i', 'b@1')) => ('b2i', ('iand', 'a', 'b'))
 *    ('iand', ('b2i', 'a@1'), ('b2i', 'b@1')) => ('b2i', ('iand', 'a', 'b'))
 *    ('ior', ('b2i', 'a@1'), ('b2i', 'b@1')) => ('b2i', ('ior', 'a', 'b'))
 *    ('fmul', ('b2f', 'a@1'), ('b2f', 'b@1')) => ('b2f', ('iand', 'a', 'b'))
 *    ('fsat', ('fadd', ('b2f', 'a@1'), ('b2f', 'b@1'))) => ('b2f', ('ior', 'a', 'b'))
 *    ('iand', 'a@bool16', 1.0) => ('b2f', 'a')
 *    ('iand', 'a@bool32', 1.0) => ('b2f', 'a')
 *    ('flt', ('fneg', ('b2f', 'a@1')), 0) => a
 *    ('ilt', 'a', 'a') => False
 *    ('ige', 'a', 'a') => True
 *    ('ieq', 'a', 'a') => True
 *    ('ine', 'a', 'a') => False
 *    ('ult', 'a', 'a') => False
 *    ('uge', 'a', 'a') => True
 *    ('flt', 'a', 'a') => False
 *    ('fge', 'a(is_a_number)', 'a') => True
 *    ('feq', 'a(is_a_number)', 'a') => True
 *    ('fneu', 'a(is_a_number)', 'a') => False
 *    ('iand', 'a', 'a') => a
 *    ('iand', 'a', 0) => 0
 *    ('iand', 'a', -1) => a
 *    ('iand', 'a', ('inot', 'a')) => 0
 *    ('ior', 'a', 'a') => a
 *    ('ior', 'a', 0) => a
 *    ('ior', 'a', -1) => -1
 *    ('ior', 'a', ('inot', 'a')) => -1
 *    ('ixor', 'a', 'a') => 0
 *    ('ixor', 'a', 0) => a
 *    ('ixor', 'a', ('ixor', 'a', 'b')) => b
 *    ('ixor', 'a', -1) => ('inot', 'a')
 *    ('inot', ('inot', 'a')) => a
 *    ('ior', ('iand', 'a', 'b'), 'b') => b
 *    ('ior', ('ior', 'a', 'b'), 'b') => ('ior', 'a', 'b')
 *    ('iand', ('ior', 'a', 'b'), 'b') => b
 *    ('iand', ('iand', 'a', 'b'), 'b') => ('iand', 'a', 'b')
 *    ('iand', ('iand(is_used_once)', 'a', 'b'), ('iand(is_used_once)', 'a', 'c')) => ('iand', 'a', ('iand', 'b', 'c'))
 *    ('iand@64', 'a', '#b(is_lower_half_zero)') => ('pack_64_2x32_split', 0, ('iand', ('unpack_64_2x32_split_y', 'a'), ('unpack_64_2x32_split_y', 'b')))
 *    ('iand@64', 'a', '#b(is_upper_half_zero)') => ('pack_64_2x32_split', ('iand', ('unpack_64_2x32_split_x', 'a'), ('unpack_64_2x32_split_x', 'b')), 0)
 *    ('iand@64', 'a', '#b(is_lower_half_negative_one)') => ('pack_64_2x32_split', ('unpack_64_2x32_split_x', 'a'), ('iand', ('unpack_64_2x32_split_y', 'a'), ('unpack_64_2x32_split_y', 'b')))
 *    ('iand@64', 'a', '#b(is_upper_half_negative_one)') => ('pack_64_2x32_split', ('iand', ('unpack_64_2x32_split_x', 'a'), ('unpack_64_2x32_split_x', 'b')), ('unpack_64_2x32_split_y', 'a'))
 *    ('ior@64', 'a', '#b(is_lower_half_zero)') => ('pack_64_2x32_split', ('unpack_64_2x32_split_x', 'a'), ('ior', ('unpack_64_2x32_split_y', 'a'), ('unpack_64_2x32_split_y', 'b')))
 *    ('ior@64', 'a', '#b(is_upper_half_zero)') => ('pack_64_2x32_split', ('ior', ('unpack_64_2x32_split_x', 'a'), ('unpack_64_2x32_split_x', 'b')), ('unpack_64_2x32_split_y', 'a'))
 *    ('ior@64', 'a', '#b(is_lower_half_negative_one)') => ('pack_64_2x32_split', -1, ('ior', ('unpack_64_2x32_split_y', 'a'), ('unpack_64_2x32_split_y', 'b')))
 *    ('ior@64', 'a', '#b(is_upper_half_negative_one)') => ('pack_64_2x32_split', ('ior', ('unpack_64_2x32_split_x', 'a'), ('unpack_64_2x32_split_x', 'b')), -1)
 *    ('ixor@64', 'a', '#b(is_lower_half_zero)') => ('pack_64_2x32_split', ('unpack_64_2x32_split_x', 'a'), ('ixor', ('unpack_64_2x32_split_y', 'a'), ('unpack_64_2x32_split_y', 'b')))
 *    ('ixor@64', 'a', '#b(is_upper_half_zero)') => ('pack_64_2x32_split', ('ixor', ('unpack_64_2x32_split_x', 'a'), ('unpack_64_2x32_split_x', 'b')), ('unpack_64_2x32_split_y', 'a'))
 *    ('iand', ('inot', 'a'), ('inot', 'b')) => ('inot', ('ior', 'a', 'b'))
 *    ('ior', ('inot', 'a'), ('inot', 'b')) => ('inot', ('iand', 'a', 'b'))
 *    ('ishl', 0, 'a') => 0
 *    ('ishl', 'a', 0) => a
 *    ('ishr', 0, 'a') => 0
 *    ('ishr', -1, 'a') => -1
 *    ('ishr', 'a', 0) => a
 *    ('ushr', 0, 'a') => 0
 *    ('ushr', 'a', 0) => a
 *    ('ior', ('ishl@16', 'a', 'b'), ('ushr@16', 'a', ('iadd', 16, ('ineg', 'b')))) => ('urol', 'a', 'b')
 *    ('ior', ('ishl@16', 'a', 'b'), ('ushr@16', 'a', ('isub', 16, 'b'))) => ('urol', 'a', 'b')
 *    ('ior', ('ishl@32', 'a', 'b'), ('ushr@32', 'a', ('iadd', 32, ('ineg', 'b')))) => ('urol', 'a', 'b')
 *    ('ior', ('ishl@32', 'a', 'b'), ('ushr@32', 'a', ('isub', 32, 'b'))) => ('urol', 'a', 'b')
 *    ('ior', ('ushr@16', 'a', 'b'), ('ishl@16', 'a', ('iadd', 16, ('ineg', 'b')))) => ('uror', 'a', 'b')
 *    ('ior', ('ushr@16', 'a', 'b'), ('ishl@16', 'a', ('isub', 16, 'b'))) => ('uror', 'a', 'b')
 *    ('ior', ('ushr@32', 'a', 'b'), ('ishl@32', 'a', ('iadd', 32, ('ineg', 'b')))) => ('uror', 'a', 'b')
 *    ('ior', ('ushr@32', 'a', 'b'), ('ishl@32', 'a', ('isub', 32, 'b'))) => ('uror', 'a', 'b')
 *    ('urol@8', 'a', 'b') => ('ior', ('ishl', 'a', 'b'), ('ushr', 'a', ('isub', 8, 'b')))
 *    ('urol@16', 'a', 'b') => ('ior', ('ishl', 'a', 'b'), ('ushr', 'a', ('isub', 16, 'b')))
 *    ('urol@32', 'a', 'b') => ('ior', ('ishl', 'a', 'b'), ('ushr', 'a', ('isub', 32, 'b')))
 *    ('urol@64', 'a', 'b') => ('ior', ('ishl', 'a', 'b'), ('ushr', 'a', ('isub', 64, 'b')))
 *    ('uror@8', 'a', 'b') => ('ior', ('ushr', 'a', 'b'), ('ishl', 'a', ('isub', 8, 'b')))
 *    ('uror@16', 'a', 'b') => ('ior', ('ushr', 'a', 'b'), ('ishl', 'a', ('isub', 16, 'b')))
 *    ('uror@32', 'a', 'b') => ('ior', ('ushr', 'a', 'b'), ('ishl', 'a', ('isub', 32, 'b')))
 *    ('uror@64', 'a', 'b') => ('ior', ('ushr', 'a', 'b'), ('ishl', 'a', ('isub', 64, 'b')))
 *    ('~fexp2', ('flog2', 'a')) => a
 *    ('~flog2', ('fexp2', 'a')) => a
 *    ('fpow', 'a', 'b') => ('fexp2', ('fmul', ('flog2', 'a'), 'b'))
 *    ('~fexp2', ('fmul', ('flog2', 'a'), 'b')) => ('fpow', 'a', 'b')
 *    ('~fexp2', ('fadd', ('fmul', ('flog2', 'a'), 'b'), ('fmul', ('flog2', 'c'), 'd'))) => ('~fmul', ('fpow', 'a', 'b'), ('fpow', 'c', 'd'))
 *    ('~fexp2', ('fmul', ('flog2', 'a'), 0.5)) => ('fsqrt', 'a')
 *    ('~fexp2', ('fmul', ('flog2', 'a'), 2.0)) => ('fmul', 'a', 'a')
 *    ('~fexp2', ('fmul', ('flog2', 'a'), 4.0)) => ('fmul', ('fmul', 'a', 'a'), ('fmul', 'a', 'a'))
 *    ('~fpow', 'a', 1.0) => a
 *    ('~fpow', 'a', 2.0) => ('fmul', 'a', 'a')
 *    ('~fpow', 'a', 4.0) => ('fmul', ('fmul', 'a', 'a'), ('fmul', 'a', 'a'))
 *    ('~fpow', 2.0, 'a') => ('fexp2', 'a')
 *    ('~fpow', ('fpow', 'a', 2.2), 0.454545) => a
 *    ('~fpow', ('fabs', ('fpow', 'a', 2.2)), 0.454545) => ('fabs', 'a')
 *    ('~fsqrt', ('fexp2', 'a')) => ('fexp2', ('fmul', 0.5, 'a'))
 *    ('~frcp', ('fexp2', 'a')) => ('fexp2', ('fneg', 'a'))
 *    ('~frsq', ('fexp2', 'a')) => ('fexp2', ('fmul', -0.5, 'a'))
 *    ('~flog2', ('fsqrt', 'a')) => ('fmul', 0.5, ('flog2', 'a'))
 *    ('~flog2', ('frcp', 'a')) => ('fneg', ('flog2', 'a'))
 *    ('~flog2', ('frsq', 'a')) => ('fmul', -0.5, ('flog2', 'a'))
 *    ('~flog2', ('fpow', 'a', 'b')) => ('fmul', 'b', ('flog2', 'a'))
 *    ('~fmul', ('fexp2(is_used_once)', 'a'), ('fexp2(is_used_once)', 'b')) => ('fexp2', ('fadd', 'a', 'b'))
 *    ('bcsel', ('flt', 'a', 0.0), 0.0, ('fsqrt', 'a')) => ('fsqrt', ('fmax', 'a', 0.0))
 *    ('~fmul', ('fsqrt', 'a'), ('fsqrt', 'a')) => ('fabs', 'a')
 *    ('~fmulz', ('fsqrt', 'a'), ('fsqrt', 'a')) => ('fabs', 'a')
 *    ('~fdiv', 1.0, 'a') => ('frcp', 'a')
 *    ('fdiv', 'a', 'b') => ('fmul', 'a', ('frcp', 'b'))
 *    ('~frcp', ('frcp', 'a')) => a
 *    ('~frcp', ('fsqrt', 'a')) => ('frsq', 'a')
 *    ('fsqrt', 'a') => ('frcp', ('frsq', 'a'))
 *    ('~frcp', ('frsq', 'a')) => ('fsqrt', 'a')
 *    ('fsin', 'a') => ('ffma', ('ffma', ('fmul', ('fsub', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0), ('fmul', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0), ('fabs', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0)))), 4.0), ('fabs', ('fmul', ('fsub', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0), ('fmul', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0), ('fabs', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0)))), 4.0)), ('fneg', ('fmul', ('fsub', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0), ('fmul', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0), ('fabs', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0)))), 4.0))), 0.225, ('fmul', ('fsub', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0), ('fmul', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0), ('fabs', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0)))), 4.0))
 *    ('fcos', 'a') => ('ffma', ('ffma', ('fmul', ('fsub', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0), ('fmul', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0), ('fabs', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0)))), 4.0), ('fabs', ('fmul', ('fsub', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0), ('fmul', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0), ('fabs', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0)))), 4.0)), ('fneg', ('fmul', ('fsub', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0), ('fmul', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0), ('fabs', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0)))), 4.0))), 0.225, ('fmul', ('fsub', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0), ('fmul', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0), ('fabs', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0)))), 4.0))
 *    ('ieq', 'a', True) => a
 *    ('ine(is_not_used_by_if)', 'a', True) => ('inot', 'a')
 *    ('ine', 'a', False) => a
 *    ('ieq(is_not_used_by_if)', 'a', False) => ('inot', 'a')
 *    ('bcsel', 'a', True, False) => a
 *    ('bcsel', 'a', False, True) => ('inot', 'a')
 *    ('bcsel', True, 'b', 'c') => b
 *    ('bcsel', False, 'b', 'c') => c
 *    ('bcsel@16', 'a', 1.0, 0.0) => ('b2f', 'a')
 *    ('bcsel@16', 'a', 0.0, 1.0) => ('b2f', ('inot', 'a'))
 *    ('bcsel@16', 'a', -1.0, -0.0) => ('fneg', ('b2f', 'a'))
 *    ('bcsel@16', 'a', -0.0, -1.0) => ('fneg', ('b2f', ('inot', 'a')))
 *    ('bcsel@32', 'a', 1.0, 0.0) => ('b2f', 'a')
 *    ('bcsel@32', 'a', 0.0, 1.0) => ('b2f', ('inot', 'a'))
 *    ('bcsel@32', 'a', -1.0, -0.0) => ('fneg', ('b2f', 'a'))
 *    ('bcsel@32', 'a', -0.0, -1.0) => ('fneg', ('b2f', ('inot', 'a')))
 *    ('bcsel@64', 'a', 1.0, 0.0) => ('b2f', 'a')
 *    ('bcsel@64', 'a', 0.0, 1.0) => ('b2f', ('inot', 'a'))
 *    ('bcsel@64', 'a', -1.0, -0.0) => ('fneg', ('b2f', 'a'))
 *    ('bcsel@64', 'a', -0.0, -1.0) => ('fneg', ('b2f', ('inot', 'a')))
 *    ('bcsel', 'a', 'b', 'b') => b
 *    ('~fcsel', 'a', 'b', 'b') => b
 *    ('bcsel', 'a', -1, 0) => ('ineg', ('b2i', 'a@1'))
 *    ('bcsel', 'a', 0, -1) => ('ineg', ('b2i', ('inot', 'a')))
 *    ('bcsel', 'a', 1, 0) => ('b2i', 'a@1')
 *    ('bcsel', 'a', 0, 1) => ('b2i', ('inot', 'a'))
 *    ('iand', ('ineg', ('b2i', 'a@1')), ('ineg', ('b2i', 'b@1'))) => ('ineg', ('b2i', ('iand', 'a', 'b')))
 *    ('ior', ('ineg', ('b2i', 'a@1')), ('ineg', ('b2i', 'b@1'))) => ('ineg', ('b2i', ('ior', 'a', 'b')))
 *    ('ieq', ('ineg', ('b2i', 'a@1')), -1) => a
 *    ('ine', ('ineg', ('b2i', 'a@1')), -1) => ('inot', 'a')
 *    ('ige', ('ineg', ('b2i', 'a@1')), 0) => ('inot', 'a')
 *    ('ilt', ('ineg', ('b2i', 'a@1')), 0) => a
 *    ('ult', 0, ('ineg', ('b2i', 'a@1'))) => a
 *    ('iand', ('ineg', ('b2i', 'a')), 1.0) => ('b2f', 'a')
 *    ('iand', ('ineg', ('b2i', 'a')), 1) => ('b2i', 'a')
 *    ('imax', ('ineg', ('b2i', 'a@1')), ('ineg', ('b2i', 'b@1'))) => ('ineg', ('b2i', ('iand', 'a', 'b')))
 *    ('imin', ('ineg', ('b2i', 'a@1')), ('ineg', ('b2i', 'b@1'))) => ('ineg', ('b2i', ('ior', 'a', 'b')))
 *    ('umax', ('ineg', ('b2i', 'a@1')), ('ineg', ('b2i', 'b@1'))) => ('ineg', ('b2i', ('ior', 'a', 'b')))
 *    ('umin', ('ineg', ('b2i', 'a@1')), ('ineg', ('b2i', 'b@1'))) => ('ineg', ('b2i', ('iand', 'a', 'b')))
 *    ('umax', ('b2i', 'a@1'), ('b2i', 'b@1')) => ('b2i', ('ior', 'a', 'b'))
 *    ('umin', ('b2i', 'a@1'), ('b2i', 'b@1')) => ('b2i', ('iand', 'a', 'b'))
 *    ('ine', ('umin', ('ineg', ('b2i', 'a@1')), 'b'), 0) => ('iand', 'a', ('ine', 'b', 0))
 *    ('ine', ('umax', ('ineg', ('b2i', 'a@1')), 'b'), 0) => ('ior', 'a', ('ine', 'b', 0))
 *    ('f2i', ('ftrunc', 'a')) => ('f2i', 'a')
 *    ('f2u', ('ftrunc', 'a')) => ('f2u', 'a')
 *    ('inot', ('f2b1', 'a')) => ('feq', 'a', 0.0)
 *    ('f2fmp', ('f2f32', 'a@16')) => a
 *    ('i2imp', ('i2i32', 'a@16')) => a
 *    ('i2imp', ('u2u32', 'a@16')) => a
 *    ('f2imp', ('f2f32', 'a@16')) => ('f2i16', 'a')
 *    ('f2ump', ('f2f32', 'a@16')) => ('f2u16', 'a')
 *    ('i2fmp', ('i2i32', 'a@16')) => ('i2f16', 'a')
 *    ('u2fmp', ('u2u32', 'a@16')) => ('u2f16', 'a')
 *    ('f2fmp', ('b2f32', 'a@1')) => ('b2f16', 'a')
 *    ('i2imp', ('b2i32', 'a@1')) => ('b2i16', 'a')
 *    ('i2imp', ('b2i32', 'a@1')) => ('b2i16', 'a')
 *    ('f2imp', ('b2f32', 'a@1')) => ('b2i16', 'a')
 *    ('f2ump', ('b2f32', 'a@1')) => ('b2i16', 'a')
 *    ('i2fmp', ('b2i32', 'a@1')) => ('b2f16', 'a')
 *    ('u2fmp', ('b2i32', 'a@1')) => ('b2f16', 'a')
 *    ('f2f32', ('f2fmp', 'a@32')) => a
 *    ('i2i32', ('i2imp', 'a@32')) => a
 *    ('u2u32', ('i2imp', 'a@32')) => a
 *    ('i2i32', ('f2imp', 'a@32')) => ('f2i32', 'a')
 *    ('u2u32', ('f2ump', 'a@32')) => ('f2u32', 'a')
 *    ('f2f32', ('i2fmp', 'a@32')) => ('i2f32', 'a')
 *    ('f2f32', ('u2fmp', 'a@32')) => ('u2f32', 'a')
 *    ('~f2f32', ('f2f64', 'a@32')) => a
 *    ('ffloor', 'a(is_integral)') => a
 *    ('fceil', 'a(is_integral)') => a
 *    ('ftrunc', 'a(is_integral)') => a
 *    ('fround_even', 'a(is_integral)') => a
 *    ('~ffract', 'a(is_integral)') => 0.0
 *    ('fabs', 'a(is_not_negative)') => a
 *    ('iabs', 'a(is_not_negative)') => a
 *    ('fsat', 'a(is_not_positive)') => 0.0
 *    ('~fmin', 'a(is_not_negative)', 1.0) => ('fsat', 'a')
 *    ('flt', ('fadd', ('fmul', ('fsat', 'a'), ('fneg', ('fsat', 'a'))), 1.0), 0.0) => False
 *    ('flt', ('fadd', ('fneg', ('fmul', ('fsat', 'a'), ('fsat', 'a'))), 1.0), 0.0) => False
 *    ('fmax', ('fadd', ('fmul', ('fsat', 'a'), ('fneg', ('fsat', 'a'))), 1.0), 0.0) => ('fadd', ('fmul', ('fsat', 'a'), ('fneg', ('fsat', 'a'))), 1.0)
 *    ('fmax', ('fadd', ('fneg', ('fmul', ('fsat', 'a'), ('fsat', 'a'))), 1.0), 0.0) => ('fadd', ('fneg', ('fmul', ('fsat', 'a'), ('fsat', 'a'))), 1.0)
 *    ('fneu', 'a(is_not_zero)', 0.0) => True
 *    ('feq', 'a(is_not_zero)', 0.0) => False
 *    ('fge', 'a(is_a_number_not_negative)', 'b(is_a_number_not_positive)') => True
 *    ('fge', 'a(is_not_positive)', 'b(is_gt_zero)') => False
 *    ('fge', 'a(is_lt_zero)', 'b(is_not_negative)') => False
 *    ('flt', 'a(is_not_negative)', 'b(is_not_positive)') => False
 *    ('flt', 'a(is_a_number_not_positive)', 'b(is_a_number_gt_zero)') => True
 *    ('flt', 'a(is_a_number_lt_zero)', 'b(is_a_number_not_negative)') => True
 *    ('ine', 'a(is_not_zero)', 0) => True
 *    ('ieq', 'a(is_not_zero)', 0) => False
 *    ('ige', 'a(is_not_negative)', 'b(is_not_positive)') => True
 *    ('ige', 'a(is_not_positive)', 'b(is_gt_zero)') => False
 *    ('ige', 'a(is_lt_zero)', 'b(is_not_negative)') => False
 *    ('ilt', 'a(is_not_negative)', 'b(is_not_positive)') => False
 *    ('ilt', 'a(is_not_positive)', 'b(is_gt_zero)') => True
 *    ('ilt', 'a(is_lt_zero)', 'b(is_not_negative)') => True
 *    ('ult', 0, 'a(is_gt_zero)') => True
 *    ('ult', 'a', 0) => False
 *    ('unpack_64_2x32_split_x', ('pack_64_2x32_split', 'a', 'b')) => a
 *    ('unpack_64_2x32_split_y', ('pack_64_2x32_split', 'a', 'b')) => b
 *    ('unpack_64_2x32_split_x', ('pack_64_2x32', 'a')) => a.x
 *    ('unpack_64_2x32_split_y', ('pack_64_2x32', 'a')) => a.y
 *    ('unpack_64_2x32_split_x', ('u2u64', 'a@32')) => a
 *    ('unpack_64_2x32_split_y', ('u2u64', 'a')) => 0
 *    ('unpack_64_2x32_split_x', ('i2i64', 'a@32')) => a
 *    ('unpack_64_2x32_split_y', ('i2i64(is_used_once)', 'a@32')) => ('ishr', 'a', 31)
 *    ('unpack_64_2x32', ('pack_64_2x32_split', 'a', 'b')) => ('vec2', 'a', 'b')
 *    ('unpack_64_2x32', ('pack_64_2x32', 'a')) => a
 *    ('unpack_double_2x32_dxil', ('pack_double_2x32_dxil', 'a')) => a
 *    ('pack_64_2x32_split', ('unpack_64_2x32_split_x', 'a'), ('unpack_64_2x32_split_y', 'a')) => a
 *    ('pack_64_2x32', ('vec2', ('unpack_64_2x32_split_x', 'a'), ('unpack_64_2x32_split_y', 'a'))) => a
 *    ('pack_64_2x32', ('unpack_64_2x32', 'a')) => a
 *    ('pack_double_2x32_dxil', ('unpack_double_2x32_dxil', 'a')) => a
 *    ('iand', ('ieq', ('unpack_32_2x16_split_x', 'a'), '#b'), ('ieq', ('unpack_32_2x16_split_y', 'a'), '#c')) => ('ieq', 'a', ('pack_32_2x16_split', 'b', 'c'))
 *    ('ushr', 'a@16', 8) => ('extract_u8', 'a', 1)
 *    ('ushr', 'a@32', 24) => ('extract_u8', 'a', 3)
 *    ('ushr', 'a@64', 56) => ('extract_u8', 'a', 7)
 *    ('ishr', 'a@16', 8) => ('extract_i8', 'a', 1)
 *    ('ishr', 'a@32', 24) => ('extract_i8', 'a', 3)
 *    ('ishr', 'a@64', 56) => ('extract_i8', 'a', 7)
 *    ('iand', 255, 'a') => ('extract_u8', 'a', 0)
 *    ('u2u8', ('extract_u16', 'a', 1)) => ('u2u8', ('extract_u8', 'a', 2))
 *    ('u2u8', ('ushr', 'a', 8)) => ('u2u8', ('extract_u8', 'a', 1))
 *    ('i2i16', ('u2u8', ('extract_u8', 'a', 'b'))) => ('i2i16', ('extract_i8', 'a', 'b'))
 *    ('u2u16', ('u2u8', ('extract_u8', 'a', 'b'))) => ('u2u16', ('extract_u8', 'a', 'b'))
 *    ('ubfe', 'a', 0, 8) => ('extract_u8', 'a', 0)
 *    ('ubfe', 'a', 8, 8) => ('extract_u8', 'a', 1)
 *    ('ubfe', 'a', 16, 8) => ('extract_u8', 'a', 2)
 *    ('ubfe', 'a', 24, 8) => ('extract_u8', 'a', 3)
 *    ('ibfe', 'a', 0, 8) => ('extract_i8', 'a', 0)
 *    ('ibfe', 'a', 8, 8) => ('extract_i8', 'a', 1)
 *    ('ibfe', 'a', 16, 8) => ('extract_i8', 'a', 2)
 *    ('ibfe', 'a', 24, 8) => ('extract_i8', 'a', 3)
 *    ('extract_u8', ('extract_i8', 'a', 'b'), 0) => ('extract_u8', 'a', 'b')
 *    ('extract_u8', ('extract_u8', 'a', 'b'), 0) => ('extract_u8', 'a', 'b')
 *    ('ushr', ('ishl', 'a@32', 16), 16) => ('extract_u16', 'a', 0)
 *    ('ushr', 'a@32', 16) => ('extract_u16', 'a', 1)
 *    ('ishr', ('ishl', 'a@32', 16), 16) => ('extract_i16', 'a', 0)
 *    ('ishr', 'a@32', 16) => ('extract_i16', 'a', 1)
 *    ('iand', 65535, 'a') => ('extract_u16', 'a', 0)
 *    ('ubfe', 'a', 0, 16) => ('extract_u16', 'a', 0)
 *    ('ubfe', 'a', 16, 16) => ('extract_u16', 'a', 1)
 *    ('ibfe', 'a', 0, 16) => ('extract_i16', 'a', 0)
 *    ('ibfe', 'a', 16, 16) => ('extract_i16', 'a', 1)
 *    ('ior', ('ishl', ('u2u32', 'a@8'), 24), ('ior', ('ishl', ('u2u32', 'b@8'), 16), ('ior', ('ishl', ('u2u32', 'c@8'), 8), ('u2u32', 'd@8')))) => ('pack_32_4x8', ('vec4', 'd', 'c', 'b', 'a'))
 *    ('extract_u16', ('extract_i16', 'a', 'b'), 0) => ('extract_u16', 'a', 'b')
 *    ('extract_u16', ('extract_u16', 'a', 'b'), 0) => ('extract_u16', 'a', 'b')
 *    ('pack_64_2x32_split', 'a', 'b') => ('ior', ('u2u64', 'a'), ('ishl', ('u2u64', 'b'), 32))
 *    ('pack_32_2x16_split', 'a', 'b') => ('ior', ('u2u32', 'a'), ('ishl', ('u2u32', 'b'), 16))
 *    ('unpack_64_2x32_split_x', 'a') => ('u2u32', 'a')
 *    ('unpack_64_2x32_split_y', 'a') => ('u2u32', ('ushr', 'a', 32))
 *    ('unpack_32_2x16_split_x', 'a') => ('u2u16', 'a')
 *    ('unpack_32_2x16_split_y', 'a') => ('u2u16', ('ushr', 'a', 16))
 *    ('unpack_half_2x16_split_x', ('iand', 'a', 65535)) => ('unpack_half_2x16_split_x', 'a')
 *    ('unpack_32_2x16_split_x', ('iand', 'a', 65535)) => ('unpack_32_2x16_split_x', 'a')
 *    ('unpack_64_2x32_split_x', ('iand', 'a', 4294967295)) => ('unpack_64_2x32_split_x', 'a')
 *    ('unpack_half_2x16_split_y', ('iand', 'a', 4294901760)) => ('unpack_half_2x16_split_y', 'a')
 *    ('unpack_32_2x16_split_y', ('iand', 'a', 4294901760)) => ('unpack_32_2x16_split_y', 'a')
 *    ('unpack_64_2x32_split_y', ('iand', 'a', 18446744069414584320)) => ('unpack_64_2x32_split_y', 'a')
 *    ('unpack_half_2x16_split_x', ('extract_u16', 'a', 0)) => ('unpack_half_2x16_split_x', 'a')
 *    ('unpack_half_2x16_split_x', ('extract_u16', 'a', 1)) => ('unpack_half_2x16_split_y', 'a')
 *    ('unpack_half_2x16_split_x', ('ushr', 'a', 16)) => ('unpack_half_2x16_split_y', 'a')
 *    ('unpack_32_2x16_split_x', ('extract_u16', 'a', 0)) => ('unpack_32_2x16_split_x', 'a')
 *    ('unpack_32_2x16_split_x', ('extract_u16', 'a', 1)) => ('unpack_32_2x16_split_y', 'a')
 *    ('ishl', ('pack_half_2x16', ('vec2', 'a', 0)), 16) => ('pack_half_2x16', ('vec2', 0, 'a'))
 *    ('ushr', ('pack_half_2x16', ('vec2', 0, 'a')), 16) => ('pack_half_2x16', ('vec2', 'a', 0))
 *    ('iadd', ('pack_half_2x16', ('vec2', 'a', 0)), ('pack_half_2x16', ('vec2', 0, 'b'))) => ('pack_half_2x16', ('vec2', 'a', 'b'))
 *    ('ior', ('pack_half_2x16', ('vec2', 'a', 0)), ('pack_half_2x16', ('vec2', 0, 'b'))) => ('pack_half_2x16', ('vec2', 'a', 'b'))
 *    ('ishl', ('pack_half_2x16_split', 'a', 0), 16) => ('pack_half_2x16_split', 0, 'a')
 *    ('ushr', ('pack_half_2x16_split', 0, 'a'), 16) => ('pack_half_2x16_split', 'a', 0)
 *    ('extract_u16', ('pack_half_2x16_split', 0, 'a'), 1) => ('pack_half_2x16_split', 'a', 0)
 *    ('iadd', ('pack_half_2x16_split', 'a', 0), ('pack_half_2x16_split', 0, 'b')) => ('pack_half_2x16_split', 'a', 'b')
 *    ('ior', ('pack_half_2x16_split', 'a', 0), ('pack_half_2x16_split', 0, 'b')) => ('pack_half_2x16_split', 'a', 'b')
 *    ('extract_i8', ('pack_32_4x8_split', 'a', 'b', 'c', 'd'), 0) => ('i2i', 'a')
 *    ('extract_i8', ('pack_32_4x8_split', 'a', 'b', 'c', 'd'), 1) => ('i2i', 'b')
 *    ('extract_i8', ('pack_32_4x8_split', 'a', 'b', 'c', 'd'), 2) => ('i2i', 'c')
 *    ('extract_i8', ('pack_32_4x8_split', 'a', 'b', 'c', 'd'), 3) => ('i2i', 'd')
 *    ('extract_u8', ('pack_32_4x8_split', 'a', 'b', 'c', 'd'), 0) => ('u2u', 'a')
 *    ('extract_u8', ('pack_32_4x8_split', 'a', 'b', 'c', 'd'), 1) => ('u2u', 'b')
 *    ('extract_u8', ('pack_32_4x8_split', 'a', 'b', 'c', 'd'), 2) => ('u2u', 'c')
 *    ('extract_u8', ('pack_32_4x8_split', 'a', 'b', 'c', 'd'), 3) => ('u2u', 'd')
 *    ('extract_u8', ('ushr', 'a@16', 8), 0) => ('extract_u8', 'a', 1)
 *    ('extract_u8', ('ushr', 'a@32', 8), 0) => ('extract_u8', 'a', 1)
 *    ('extract_u8', ('ushr', 'a@32', 16), 0) => ('extract_u8', 'a', 2)
 *    ('extract_u8', ('ushr', 'a@32', 24), 0) => ('extract_u8', 'a', 3)
 *    ('extract_u8', ('ushr', 'a@64', 8), 0) => ('extract_u8', 'a', 1)
 *    ('extract_u8', ('ushr', 'a@64', 16), 0) => ('extract_u8', 'a', 2)
 *    ('extract_u8', ('ushr', 'a@64', 24), 0) => ('extract_u8', 'a', 3)
 *    ('extract_u8', ('ushr', 'a@64', 32), 0) => ('extract_u8', 'a', 4)
 *    ('extract_u8', ('ushr', 'a@64', 40), 0) => ('extract_u8', 'a', 5)
 *    ('extract_u8', ('ushr', 'a@64', 48), 0) => ('extract_u8', 'a', 6)
 *    ('extract_u8', ('ushr', 'a@64', 56), 0) => ('extract_u8', 'a', 7)
 *    ('extract_u8', ('ishr', 'a@16', 8), 0) => ('extract_u8', 'a', 1)
 *    ('extract_u8', ('ishr', 'a@32', 8), 0) => ('extract_u8', 'a', 1)
 *    ('extract_u8', ('ishr', 'a@32', 16), 0) => ('extract_u8', 'a', 2)
 *    ('extract_u8', ('ishr', 'a@32', 24), 0) => ('extract_u8', 'a', 3)
 *    ('extract_u8', ('ishr', 'a@64', 8), 0) => ('extract_u8', 'a', 1)
 *    ('extract_u8', ('ishr', 'a@64', 16), 0) => ('extract_u8', 'a', 2)
 *    ('extract_u8', ('ishr', 'a@64', 24), 0) => ('extract_u8', 'a', 3)
 *    ('extract_u8', ('ishr', 'a@64', 32), 0) => ('extract_u8', 'a', 4)
 *    ('extract_u8', ('ishr', 'a@64', 40), 0) => ('extract_u8', 'a', 5)
 *    ('extract_u8', ('ishr', 'a@64', 48), 0) => ('extract_u8', 'a', 6)
 *    ('extract_u8', ('ishr', 'a@64', 56), 0) => ('extract_u8', 'a', 7)
 *    ('extract_u8', ('extract_u16', 'a', 1), 0) => ('extract_u8', 'a', 2)
 *    ('extract_u8', ('ishl', 'a@16', 8), 1) => ('extract_u8', 'a', 0)
 *    ('extract_u8', ('ishl', 'a@32', 8), 3) => ('extract_u8', 'a', 2)
 *    ('extract_u8', ('ishl', 'a@32', 16), 3) => ('extract_u8', 'a', 1)
 *    ('extract_u8', ('ishl', 'a@32', 24), 3) => ('extract_u8', 'a', 0)
 *    ('extract_u8', ('ishl', 'a@64', 8), 7) => ('extract_u8', 'a', 6)
 *    ('extract_u8', ('ishl', 'a@64', 16), 7) => ('extract_u8', 'a', 5)
 *    ('extract_u8', ('ishl', 'a@64', 24), 7) => ('extract_u8', 'a', 4)
 *    ('extract_u8', ('ishl', 'a@64', 32), 7) => ('extract_u8', 'a', 3)
 *    ('extract_u8', ('ishl', 'a@64', 40), 7) => ('extract_u8', 'a', 2)
 *    ('extract_u8', ('ishl', 'a@64', 48), 7) => ('extract_u8', 'a', 1)
 *    ('extract_u8', ('ishl', 'a@64', 56), 7) => ('extract_u8', 'a', 0)
 *    ('extract_i8', ('ishl', 'a@16', 8), 1) => ('extract_i8', 'a', 0)
 *    ('extract_i8', ('ishl', 'a@32', 8), 3) => ('extract_i8', 'a', 2)
 *    ('extract_i8', ('ishl', 'a@32', 16), 3) => ('extract_i8', 'a', 1)
 *    ('extract_i8', ('ishl', 'a@32', 24), 3) => ('extract_i8', 'a', 0)
 *    ('extract_i8', ('ishl', 'a@64', 8), 7) => ('extract_i8', 'a', 6)
 *    ('extract_i8', ('ishl', 'a@64', 16), 7) => ('extract_i8', 'a', 5)
 *    ('extract_i8', ('ishl', 'a@64', 24), 7) => ('extract_i8', 'a', 4)
 *    ('extract_i8', ('ishl', 'a@64', 32), 7) => ('extract_i8', 'a', 3)
 *    ('extract_i8', ('ishl', 'a@64', 40), 7) => ('extract_i8', 'a', 2)
 *    ('extract_i8', ('ishl', 'a@64', 48), 7) => ('extract_i8', 'a', 1)
 *    ('extract_i8', ('ishl', 'a@64', 56), 7) => ('extract_i8', 'a', 0)
 *    ('ussub_4x8_vc4', 'a', 0) => a
 *    ('ussub_4x8_vc4', 'a', -1) => 0
 *    ('fsub', 'a', 'b') => ('fadd', 'a', ('fneg', 'b'))
 *    ('isub', 'a', 'b') => ('iadd', 'a', ('ineg', 'b'))
 *    ('uabs_usub', 'a', 'b') => ('bcsel', ('ult', 'a', 'b'), ('ineg', ('isub', 'a', 'b')), ('isub', 'a', 'b'))
 *    ('uabs_isub', 'a', 'b') => ('bcsel', ('ilt', 'a', 'b'), ('ineg', ('isub', 'a', 'b')), ('isub', 'a', 'b'))
 *    ('fmul(is_used_by_non_fsat)', ('fneg', 'a'), 'b') => ('fneg', ('fmul', 'a', 'b'))
 *    ('fmulz(is_used_by_non_fsat)', ('fneg', 'a'), 'b') => ('fneg', ('fmulz', 'a', 'b'))
 *    ('ffma', ('fneg', 'a'), ('fneg', 'b'), 'c') => ('ffma', 'a', 'b', 'c')
 *    ('ffmaz', ('fneg', 'a'), ('fneg', 'b'), 'c') => ('ffmaz', 'a', 'b', 'c')
 *    ('imul', ('ineg', 'a'), 'b') => ('ineg', ('imul', 'a', 'b'))
 *    ('~fmul(is_used_once)', ('fmul(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c') => ('fmul', ('fmul', 'a', 'c'), 'b')
 *    ('~fmulz(is_used_once)', ('fmulz(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c') => ('fmulz', ('fmulz', 'a', 'c'), 'b')
 *    ('~fmul(is_used_once)', ('fmulz(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c(is_finite_not_zero)') => ('fmulz', ('fmul', 'a', 'c'), 'b')
 *    ('imul(is_used_once)', ('imul(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c') => ('imul', ('imul', 'a', 'c'), 'b')
 *    ('~ffma', ('fmul(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c', 'd') => ('ffma', ('fmul', 'a', 'c'), 'b', 'd')
 *    ('~ffmaz', ('fmulz(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c', 'd') => ('ffmaz', ('fmulz', 'a', 'c'), 'b', 'd')
 *    ('~ffma', ('fmulz(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c(is_finite_not_zero)', 'd') => ('ffmaz', ('fmul', 'a', 'c'), 'b', 'd')
 *    ('~fadd(is_used_once)', ('fadd(is_used_once)', 'a(is_not_const)', 'b(is_fmul)'), '#c') => ('fadd', ('fadd', 'a', 'c'), 'b')
 *    ('~fadd(is_used_once)', ('fadd(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c') => ('fadd', ('fadd', 'a', 'c'), 'b')
 *    ('~fadd(is_used_once)', ('ffma(is_used_once)', 'a(is_not_const)', 'b', 'c(is_not_const)'), '#d') => ('fadd', ('ffma', 'a', 'b', 'd'), 'c')
 *    ('~fadd(is_used_once)', ('ffmaz(is_used_once)', 'a(is_not_const)', 'b', 'c(is_not_const)'), '#d') => ('fadd', ('ffmaz', 'a', 'b', 'd'), 'c')
 *    ('iadd(is_used_once)', ('iadd(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c') => ('iadd', ('iadd', 'a', 'c'), 'b')
 *    ('~fmul', '#a', ('fmul', 'b(is_not_const)', '#c')) => ('fmul', ('fmul', 'a', 'c'), 'b')
 *    ('~fmulz', '#a', ('fmulz', 'b(is_not_const)', '#c')) => ('fmulz', ('fmulz', 'a', 'c'), 'b')
 *    ('~fmul', '#a(is_finite_not_zero)', ('fmulz', 'b(is_not_const)', '#c')) => ('fmulz', ('fmul', 'a', 'c'), 'b')
 *    ('~ffma', '#a', ('fmul', 'b(is_not_const)', '#c'), 'd') => ('ffma', ('fmul', 'a', 'c'), 'b', 'd')
 *    ('~ffmaz', '#a', ('fmulz', 'b(is_not_const)', '#c'), 'd') => ('ffmaz', ('fmulz', 'a', 'c'), 'b', 'd')
 *    ('~ffmaz', '#a(is_finite_not_zero)', ('fmulz', 'b(is_not_const)', '#c'), 'd') => ('ffmaz', ('fmul', 'a', 'c'), 'b', 'd')
 *    ('imul', '#a', ('imul', 'b(is_not_const)', '#c')) => ('imul', ('imul', 'a', 'c'), 'b')
 *    ('~fadd', '#a', ('fadd', 'b(is_not_const)', '#c')) => ('fadd', ('fadd', 'a', 'c'), 'b')
 *    ('~fadd', '#a', ('fneg', ('fadd', 'b(is_not_const)', '#c'))) => ('fadd', ('fadd', 'a', ('fneg', 'c')), ('fneg', 'b'))
 *    ('~fadd', '#a', ('ffma', 'b(is_not_const)', 'c(is_not_const)', '#d')) => ('ffma', 'b', 'c', ('fadd', 'a', 'd'))
 *    ('~fadd', '#a', ('fneg', ('ffma', 'b(is_not_const)', 'c(is_not_const)', '#d'))) => ('ffma', ('fneg', 'b'), 'c', ('fadd', 'a', ('fneg', 'd')))
 *    ('~fadd', '#a', ('ffmaz', 'b(is_not_const)', 'c(is_not_const)', '#d')) => ('ffmaz', 'b', 'c', ('fadd', 'a', 'd'))
 *    ('~fadd', '#a', ('fneg', ('ffmaz', 'b(is_not_const)', 'c(is_not_const)', '#d'))) => ('ffmaz', ('fneg', 'b'), 'c', ('fadd', 'a', ('fneg', 'd')))
 *    ('iadd', '#a', ('iadd', 'b(is_not_const)', '#c')) => ('iadd', ('iadd', 'a', 'c'), 'b')
 *    ('iand', '#a', ('iand', 'b(is_not_const)', '#c')) => ('iand', ('iand', 'a', 'c'), 'b')
 *    ('ior', '#a', ('ior', 'b(is_not_const)', '#c')) => ('ior', ('ior', 'a', 'c'), 'b')
 *    ('ixor', '#a', ('ixor', 'b(is_not_const)', '#c')) => ('ixor', ('ixor', 'a', 'c'), 'b')
 *    ('~fadd', ('fadd(is_used_once)', 'a(is_fmul)', 'b(is_fmul)'), 'c(is_not_fmul)') => ('fadd', ('fadd', 'a', 'c'), 'b')
 *    ('idiv', ('imul(no_signed_wrap)', 'a', 'b'), 'b') => a
 *    ('bcsel', ('ige', ('find_lsb', 'a'), 0), ('find_lsb', 'a'), -1) => ('find_lsb', 'a')
 *    ('bcsel', ('ige', ('ifind_msb', 'a'), 0), ('ifind_msb', 'a'), -1) => ('ifind_msb', 'a')
 *    ('bcsel', ('ige', ('ufind_msb', 'a'), 0), ('ufind_msb', 'a'), -1) => ('ufind_msb', 'a')
 *    ('bcsel', ('ige', ('ifind_msb_rev', 'a'), 0), ('ifind_msb_rev', 'a'), -1) => ('ifind_msb_rev', 'a')
 *    ('bcsel', ('ige', ('ufind_msb_rev', 'a'), 0), ('ufind_msb_rev', 'a'), -1) => ('ufind_msb_rev', 'a')
 *    ('bcsel', ('ine', 'a', 0), ('find_lsb', 'a'), -1) => ('find_lsb', 'a')
 *    ('bcsel', ('ine', 'a', 0), ('ifind_msb', 'a'), -1) => ('ifind_msb', 'a')
 *    ('bcsel', ('ine', 'a', 0), ('ufind_msb', 'a'), -1) => ('ufind_msb', 'a')
 *    ('bcsel', ('ine', 'a', 0), ('ifind_msb_rev', 'a'), -1) => ('ifind_msb_rev', 'a')
 *    ('bcsel', ('ine', 'a', 0), ('ufind_msb_rev', 'a'), -1) => ('ufind_msb_rev', 'a')
 *    ('bcsel', ('ine', 'a', -1), ('ifind_msb', 'a'), -1) => ('ifind_msb', 'a')
 *    ('bcsel', ('ine', 'a', -1), ('ifind_msb_rev', 'a'), -1) => ('ifind_msb_rev', 'a')
 *    ('bcsel', ('ine', ('ifind_msb', 'a@32'), -1), ('iadd', 31, ('ineg', ('ifind_msb', 'a'))), -1) => ('ifind_msb_rev', 'a')
 *    ('bcsel', ('ine', ('ufind_msb', 'a@32'), -1), ('iadd', 31, ('ineg', ('ufind_msb', 'a'))), -1) => ('ufind_msb_rev', 'a')
 *    ('bcsel', ('ieq', ('ifind_msb', 'a@32'), -1), -1, ('iadd', 31, ('ineg', ('ifind_msb', 'a')))) => ('ifind_msb_rev', 'a')
 *    ('bcsel', ('ieq', ('ufind_msb', 'a@32'), -1), -1, ('iadd', 31, ('ineg', ('ufind_msb', 'a')))) => ('ufind_msb_rev', 'a')
 *    ('bcsel', ('ine', ('ifind_msb', 'a@32'), -1), ('iadd', 31, ('ineg', ('ifind_msb', 'a'))), ('ifind_msb', 'a')) => ('ifind_msb_rev', 'a')
 *    ('bcsel', ('ine', ('ufind_msb', 'a@32'), -1), ('iadd', 31, ('ineg', ('ufind_msb', 'a'))), ('ufind_msb', 'a')) => ('ufind_msb_rev', 'a')
 *    ('bcsel', ('ieq', ('ifind_msb', 'a@32'), -1), ('ifind_msb', 'a'), ('iadd', 31, ('ineg', ('ifind_msb', 'a')))) => ('ifind_msb_rev', 'a')
 *    ('bcsel', ('ieq', ('ufind_msb', 'a@32'), -1), ('ufind_msb', 'a'), ('iadd', 31, ('ineg', ('ufind_msb', 'a')))) => ('ufind_msb_rev', 'a')
 *    ('bcsel', ('ine', 'a@32', 0), ('iadd', 31, ('ineg', ('ufind_msb', 'a'))), -1) => ('ufind_msb_rev', 'a')
 *    ('bcsel', ('ieq', 'a@32', 0), -1, ('iadd', 31, ('ineg', ('ufind_msb', 'a')))) => ('ufind_msb_rev', 'a')
 *    ('bcsel', ('ine', 'a@32', 0), ('iadd', 31, ('ineg', ('ufind_msb', 'a'))), ('ufind_msb', 'a')) => ('ufind_msb_rev', 'a')
 *    ('bcsel', ('ieq', 'a@32', 0), ('ufind_msb', 'a'), ('iadd', 31, ('ineg', ('ufind_msb', 'a')))) => ('ufind_msb_rev', 'a')
 *    ('bcsel', ('ine', ('ifind_msb_rev', 'a@32'), -1), ('iadd', 31, ('ineg', ('ifind_msb_rev', 'a'))), -1) => ('ifind_msb', 'a')
 *    ('bcsel', ('ine', ('ufind_msb_rev', 'a@32'), -1), ('iadd', 31, ('ineg', ('ufind_msb_rev', 'a'))), -1) => ('ufind_msb', 'a')
 *    ('bcsel', ('ieq', ('ifind_msb_rev', 'a@32'), -1), -1, ('iadd', 31, ('ineg', ('ifind_msb_rev', 'a')))) => ('ifind_msb', 'a')
 *    ('bcsel', ('ieq', ('ufind_msb_rev', 'a@32'), -1), -1, ('iadd', 31, ('ineg', ('ufind_msb_rev', 'a')))) => ('ufind_msb', 'a')
 *    ('bcsel', ('ine', ('ifind_msb_rev', 'a@32'), -1), ('iadd', 31, ('ineg', ('ifind_msb_rev', 'a'))), ('ifind_msb_rev', 'a')) => ('ifind_msb', 'a')
 *    ('bcsel', ('ine', ('ufind_msb_rev', 'a@32'), -1), ('iadd', 31, ('ineg', ('ufind_msb_rev', 'a'))), ('ufind_msb_rev', 'a')) => ('ufind_msb', 'a')
 *    ('bcsel', ('ieq', ('ifind_msb_rev', 'a@32'), -1), ('ifind_msb_rev', 'a'), ('iadd', 31, ('ineg', ('ifind_msb_rev', 'a')))) => ('ifind_msb', 'a')
 *    ('bcsel', ('ieq', ('ufind_msb_rev', 'a@32'), -1), ('ufind_msb_rev', 'a'), ('iadd', 31, ('ineg', ('ufind_msb_rev', 'a')))) => ('ufind_msb', 'a')
 *    ('bcsel', ('ine', 'a@32', 0), ('iadd', 31, ('ineg', ('ufind_msb_rev', 'a'))), -1) => ('ufind_msb', 'a')
 *    ('bcsel', ('ieq', 'a@32', 0), -1, ('iadd', 31, ('ineg', ('ufind_msb_rev', 'a')))) => ('ufind_msb', 'a')
 *    ('bcsel', ('ine', 'a@32', 0), ('iadd', 31, ('ineg', ('ufind_msb_rev', 'a'))), ('ufind_msb_rev', 'a')) => ('ufind_msb', 'a')
 *    ('bcsel', ('ieq', 'a@32', 0), ('ufind_msb_rev', 'a'), ('iadd', 31, ('ineg', ('ufind_msb_rev', 'a')))) => ('ufind_msb', 'a')
 *    ('find_lsb', ('bitfield_reverse', 'a')) => ('ufind_msb_rev', 'a')
 *    ('ufind_msb_rev', ('bitfield_reverse', 'a')) => ('find_lsb', 'a')
 *    ('~fmul', ('bcsel(is_used_once)', 'c', -1.0, 1.0), 'b') => ('bcsel', 'c', ('fneg', 'b'), 'b')
 *    ('~fmul', ('bcsel(is_used_once)', 'c', 1.0, -1.0), 'b') => ('bcsel', 'c', 'b', ('fneg', 'b'))
 *    ('~fmulz', ('bcsel(is_used_once)', 'c', -1.0, 1.0), 'b') => ('bcsel', 'c', ('fneg', 'b'), 'b')
 *    ('~fmulz', ('bcsel(is_used_once)', 'c', 1.0, -1.0), 'b') => ('bcsel', 'c', 'b', ('fneg', 'b'))
 *    ('fabs', ('bcsel(is_used_once)', 'b', ('fneg', 'a'), 'a')) => ('fabs', 'a')
 *    ('fabs', ('bcsel(is_used_once)', 'b', 'a', ('fneg', 'a'))) => ('fabs', 'a')
 *    ('~bcsel', ('flt', 'a', 0.0), ('fneg', 'a'), 'a') => ('fabs', 'a')
 *    ('bcsel', 'a', ('bcsel', 'b', 'c', 'd'), 'd') => ('bcsel', ('iand', 'a', 'b'), 'c', 'd')
 *    ('bcsel', 'a', 'b', ('bcsel', 'c', 'b', 'd')) => ('bcsel', ('ior', 'a', 'c'), 'b', 'd')
 *    ('fmod', 'a', 'b') => ('fsub', 'a', ('fmul', 'b', ('ffloor', ('fdiv', 'a', 'b'))))
 *    ('frem', 'a', 'b') => ('fsub', 'a', ('fmul', 'b', ('ftrunc', ('fdiv', 'a', 'b'))))
 *    ('uadd_carry', 'a', 'b') => ('b2i', ('ult', ('iadd', 'a', 'b'), 'a'))
 *    ('usub_borrow', 'a', 'b') => ('b2i', ('ult', 'a', 'b'))
 *    ('bitfield_insert', 'base', 'insert', 'offset', 'bits') => ('bcsel', ('ult', 31, 'bits'), 'insert', ('bfi', ('bfm', 'bits', 'offset'), 'insert', 'base'))
 *    ('ihadd', 'a', 'b') => ('iadd', ('iand', 'a', 'b'), ('ishr', ('ixor', 'a', 'b'), 1))
 *    ('uhadd', 'a', 'b') => ('iadd', ('iand', 'a', 'b'), ('ushr', ('ixor', 'a', 'b'), 1))
 *    ('irhadd', 'a', 'b') => ('isub', ('ior', 'a', 'b'), ('ishr', ('ixor', 'a', 'b'), 1))
 *    ('urhadd', 'a', 'b') => ('isub', ('ior', 'a', 'b'), ('ushr', ('ixor', 'a', 'b'), 1))
 *    ('ihadd@64', 'a', 'b') => ('iadd', ('iand', 'a', 'b'), ('ishr', ('ixor', 'a', 'b'), 1))
 *    ('uhadd@64', 'a', 'b') => ('iadd', ('iand', 'a', 'b'), ('ushr', ('ixor', 'a', 'b'), 1))
 *    ('irhadd@64', 'a', 'b') => ('isub', ('ior', 'a', 'b'), ('ishr', ('ixor', 'a', 'b'), 1))
 *    ('urhadd@64', 'a', 'b') => ('isub', ('ior', 'a', 'b'), ('ushr', ('ixor', 'a', 'b'), 1))
 *    ('imul_32x16', 'a', 'b') => ('imul', 'a', ('extract_i16', 'b', 0))
 *    ('umul_32x16', 'a', 'b') => ('imul', 'a', ('extract_u16', 'b', 0))
 *    ('uadd_sat@64', 'a', 'b') => ('bcsel', ('ult', ('iadd', 'a', 'b'), 'a'), -1, ('iadd', 'a', 'b'))
 *    ('uadd_sat', 'a', 'b') => ('bcsel', ('ult', ('iadd', 'a', 'b'), 'a'), -1, ('iadd', 'a', 'b'))
 *    ('usub_sat', 'a', 'b') => ('bcsel', ('ult', 'a', 'b'), 0, ('isub', 'a', 'b'))
 *    ('usub_sat@64', 'a', 'b') => ('bcsel', ('ult', 'a', 'b'), 0, ('isub', 'a', 'b'))
 *    ('iadd_sat@64', 'a', 'b') => ('bcsel', ('iand', ('iand', ('ilt', 'a', 0), ('ilt', 'b', 0)), ('ige', ('iadd', 'a', 'b'), 0)), 9223372036854775808, ('bcsel', ('ior', ('ior', ('ilt', 'a', 0), ('ilt', 'b', 0)), ('ige', ('iadd', 'a', 'b'), 0)), ('iadd', 'a', 'b'), 9223372036854775807))
 *    ('isub_sat@64', 'a', 'b') => ('bcsel', ('iand', ('iand', ('ilt', 'a', 0), ('ige', 'b', 0)), ('ige', ('isub', 'a', 'b'), 0)), 9223372036854775808, ('bcsel', ('ior', ('ior', ('ilt', 'a', 0), ('ige', 'b', 0)), ('ige', ('isub', 'a', 'b'), 0)), ('isub', 'a', 'b'), 9223372036854775807))
 *    ('ilt', ('imax(is_used_once)', 'a@64', 'b@64'), 0) => ('ilt', ('imax', ('unpack_64_2x32_split_y', 'a'), ('unpack_64_2x32_split_y', 'b')), 0)
 *    ('ilt', ('imin(is_used_once)', 'a@64', 'b@64'), 0) => ('ilt', ('imin', ('unpack_64_2x32_split_y', 'a'), ('unpack_64_2x32_split_y', 'b')), 0)
 *    ('ige', ('imax(is_used_once)', 'a@64', 'b@64'), 0) => ('ige', ('imax', ('unpack_64_2x32_split_y', 'a'), ('unpack_64_2x32_split_y', 'b')), 0)
 *    ('ige', ('imin(is_used_once)', 'a@64', 'b@64'), 0) => ('ige', ('imin', ('unpack_64_2x32_split_y', 'a'), ('unpack_64_2x32_split_y', 'b')), 0)
 *    ('ilt', 'a@64', 0) => ('ilt', ('unpack_64_2x32_split_y', 'a'), 0)
 *    ('ige', 'a@64', 0) => ('ige', ('unpack_64_2x32_split_y', 'a'), 0)
 *    ('ine', 'a@64', 0) => ('ine', ('ior', ('unpack_64_2x32_split_x', 'a'), ('unpack_64_2x32_split_y', 'a')), 0)
 *    ('ieq', 'a@64', 0) => ('ieq', ('ior', ('unpack_64_2x32_split_x', 'a'), ('unpack_64_2x32_split_y', 'a')), 0)
 *    ('ult', 0, 'a@64') => ('ine', ('ior', ('unpack_64_2x32_split_x', 'a'), ('unpack_64_2x32_split_y', 'a')), 0)
 *    ('bitfield_insert', 'base', 'insert', 'offset', 'bits') => ('bcsel', ('ult', 31, 'bits'), 'insert', ('ior', ('iand', 'base', ('inot', ('ishl', ('isub', ('ishl', 1, 'bits'), 1), 'offset'))), ('iand', ('ishl', 'insert', 'offset'), ('ishl', ('isub', ('ishl', 1, 'bits'), 1), 'offset'))))
 *    ('bitfield_insert', 'base', 'insert', 'offset', 'bits') => ('bcsel', ('ult', 31, 'bits'), 'insert', ('bitfield_select', ('bfm', 'bits', 'offset'), ('ishl', 'insert', 'offset'), 'base'))
 *    ('ibitfield_extract', 'value', 'offset', 'bits') => ('bcsel', ('ult', 31, 'bits'), 'value', ('ibfe', 'value', 'offset', 'bits'))
 *    ('ubitfield_extract', 'value', 'offset', 'bits') => ('bcsel', ('ult', 31, 'bits'), 'value', ('ubfe', 'value', 'offset', 'bits'))
 *    ('bitfield_select', 'a', 'b', 0) => ('iand', 'a', 'b')
 *    ('bitfield_select', 'a', ('iand', 'a', 'b'), 'c') => ('bitfield_select', 'a', 'b', 'c')
 *    ('ubfe', 'value', 'offset', ('iand', 31, 'bits')) => ('ubfe', 'value', 'offset', 'bits')
 *    ('ubfe', 'value', ('iand', 31, 'offset'), 'bits') => ('ubfe', 'value', 'offset', 'bits')
 *    ('ibfe', 'value', 'offset', ('iand', 31, 'bits')) => ('ibfe', 'value', 'offset', 'bits')
 *    ('ibfe', 'value', ('iand', 31, 'offset'), 'bits') => ('ibfe', 'value', 'offset', 'bits')
 *    ('bfm', 'bits', ('iand', 31, 'offset')) => ('bfm', 'bits', 'offset')
 *    ('bfm', ('iand', 31, 'bits'), 'offset') => ('bfm', 'bits', 'offset')
 *    ('ult', 'a', ('umin', ('iand', 'a', 'b'), 'c')) => False
 *    ('ult', 31, ('umin', '#bits(is_ult_32)', 'a')) => False
 *    ('ubfe', 'value', 'offset', ('umin', 'width', ('iadd', 32, ('ineg', ('iand', 31, 'offset'))))) => ('ubfe', 'value', 'offset', 'width')
 *    ('ibfe', 'value', 'offset', ('umin', 'width', ('iadd', 32, ('ineg', ('iand', 31, 'offset'))))) => ('ibfe', 'value', 'offset', 'width')
 *    ('bfm', ('umin', 'width', ('iadd', 32, ('ineg', ('iand', 31, 'offset')))), 'offset') => ('bfm', 'width', 'offset')
 *    ('iadd@32', ('ishl', 1, 'a'), -1) => ('bfm', 'a', 0)
 *    ('ishl', ('bfm', 'a', 0), 'b') => ('bfm', 'a', 'b')
 *    ('ubfe', 'a', 'b', 0) => 0
 *    ('ibfe', 'a', 'b', 0) => 0
 *    ('ubfe', 'a', 0, '#b') => ('iand', 'a', ('ushr', 4294967295, ('ineg', 'b')))
 *    ('b2i32', ('ine', ('ubfe', 'a', 'b', 1), 0)) => ('ubfe', 'a', 'b', 1)
 *    ('b2i32', ('ine', ('ibfe', 'a', 'b', 1), 0)) => ('ubfe', 'a', 'b', 1)
 *    ('ine', ('ibfe(is_used_once)', 'a', '#b', '#c'), 0) => ('ine', ('iand', 'a', ('ishl', ('ushr', 4294967295, ('ineg', 'c')), 'b')), 0)
 *    ('ieq', ('ibfe(is_used_once)', 'a', '#b', '#c'), 0) => ('ieq', ('iand', 'a', ('ishl', ('ushr', 4294967295, ('ineg', 'c')), 'b')), 0)
 *    ('ine', ('ubfe(is_used_once)', 'a', '#b', '#c'), 0) => ('ine', ('iand', 'a', ('ishl', ('ushr', 4294967295, ('ineg', 'c')), 'b')), 0)
 *    ('ieq', ('ubfe(is_used_once)', 'a', '#b', '#c'), 0) => ('ieq', ('iand', 'a', ('ishl', ('ushr', 4294967295, ('ineg', 'c')), 'b')), 0)
 *    ('ibitfield_extract', 'value', 'offset', 'bits') => ('bcsel', ('ieq', 0, 'bits'), 0, ('ishr', ('ishl', 'value', ('isub', ('isub', 32, 'bits'), 'offset')), ('isub', 32, 'bits')))
 *    ('ubitfield_extract', 'value', 'offset', 'bits') => ('iand', ('ushr', 'value', 'offset'), ('bcsel', ('ieq', 'bits', 32), 4294967295, ('isub', ('ishl', 1, 'bits'), 1)))
 *    ('ifind_msb', 'value') => ('ufind_msb', ('bcsel', ('ilt', 'value', 0), ('inot', 'value'), 'value'))
 *    ('ifind_msb', 'value') => ('bcsel', ('ige', ('ifind_msb_rev', 'value'), 0), ('isub', 31, ('ifind_msb_rev', 'value')), ('ifind_msb_rev', 'value'))
 *    ('ufind_msb', 'value') => ('bcsel', ('ige', ('ufind_msb_rev', 'value'), 0), ('isub', 31, ('ufind_msb_rev', 'value')), ('ufind_msb_rev', 'value'))
 *    ('uclz', 'a') => ('umin', 32, ('ufind_msb_rev', 'a'))
 *    ('find_lsb', 'value') => ('ufind_msb', ('iand', 'value', ('ineg', 'value')))
 *    ('extract_i8', 'a', 'b@32') => ('ishr', ('ishl', 'a', ('imul', ('isub', 3, 'b'), 8)), 24)
 *    ('extract_u8', 'a', 'b@32') => ('iand', ('ushr', 'a', ('imul', 'b', 8)), 255)
 *    ('extract_i16', 'a', 'b@32') => ('ishr', ('ishl', 'a', ('imul', ('isub', 1, 'b'), 16)), 16)
 *    ('extract_u16', 'a', 'b@32') => ('iand', ('ushr', 'a', ('imul', 'b', 16)), 65535)
 *    ('pack_unorm_2x16', 'v') => ('pack_uvec2_to_uint', ('f2u32', ('fround_even', ('fmul', ('fsat', 'v'), 65535.0))))
 *    ('pack_unorm_4x8', 'v') => ('pack_uvec4_to_uint', ('f2u32', ('fround_even', ('fmul', ('fsat', 'v'), 255.0))))
 *    ('pack_snorm_2x16', 'v') => ('pack_uvec2_to_uint', ('f2i32', ('fround_even', ('fmul', ('fmin', 1.0, ('fmax', -1.0, 'v')), 32767.0))))
 *    ('pack_snorm_4x8', 'v') => ('pack_uvec4_to_uint', ('f2i32', ('fround_even', ('fmul', ('fmin', 1.0, ('fmax', -1.0, 'v')), 127.0))))
 *    ('unpack_unorm_2x16', 'v') => ('fdiv', ('u2f32', ('vec2', ('extract_u16', 'v', 0), ('extract_u16', 'v', 1))), 65535.0)
 *    ('unpack_unorm_4x8', 'v') => ('fdiv', ('u2f32', ('vec4', ('extract_u8', 'v', 0), ('extract_u8', 'v', 1), ('extract_u8', 'v', 2), ('extract_u8', 'v', 3))), 255.0)
 *    ('unpack_snorm_2x16', 'v') => ('fmin', 1.0, ('fmax', -1.0, ('fdiv', ('i2f', ('vec2', ('extract_i16', 'v', 0), ('extract_i16', 'v', 1))), 32767.0)))
 *    ('unpack_snorm_4x8', 'v') => ('fmin', 1.0, ('fmax', -1.0, ('fdiv', ('i2f', ('vec4', ('extract_i8', 'v', 0), ('extract_i8', 'v', 1), ('extract_i8', 'v', 2), ('extract_i8', 'v', 3))), 127.0)))
 *    ('pack_half_2x16_split', 'a@32', 'b@32') => ('ior', ('ishl', ('u2u32', ('f2f16', 'b')), 16), ('u2u32', ('f2f16', 'a')))
 *    ('unpack_half_2x16_split_x', 'a@32') => ('f2f32', ('u2u16', 'a'))
 *    ('unpack_half_2x16_split_y', 'a@32') => ('f2f32', ('u2u16', ('ushr', 'a', 16)))
 *    ('pack_32_2x16_split', 'a@16', 'b@16') => ('ior', ('ishl', ('u2u32', 'b'), 16), ('u2u32', 'a'))
 *    ('unpack_32_2x16_split_x', 'a@32') => ('u2u16', 'a')
 *    ('unpack_32_2x16_split_y', 'a@32') => ('u2u16', ('ushr', 'a', 16))
 *    ('isign', 'a') => ('imin', ('imax', 'a', -1), 1)
 *    ('imin', ('imax', 'a', -1), 1) => ('isign', 'a')
 *    ('imax', ('imin', 'a', 1), -1) => ('isign', 'a')
 *    ('fsign', 'a') => ('fsub', ('b2f', ('!flt', 0.0, 'a')), ('b2f', ('!flt', 'a', 0.0)))
 *    ('amul', 'a', 'b') => ('imul', 'a', 'b')
 *    ('umul24', 'a', 'b') => ('imul', ('iand', 'a', 16777215), ('iand', 'b', 16777215))
 *    ('umad24', 'a', 'b', 'c') => ('iadd', ('imul', ('iand', 'a', 16777215), ('iand', 'b', 16777215)), 'c')
 *    ('imul24_relaxed', 'a', 'b') => ('imul24', 'a', 'b')
 *    ('imul24_relaxed', 'a', 'b') => ('imul', 'a', 'b')
 *    ('umad24_relaxed', 'a', 'b', 'c') => ('umad24', 'a', 'b', 'c')
 *    ('umad24_relaxed', 'a', 'b', 'c') => ('iadd', ('umul24_relaxed', 'a', 'b'), 'c')
 *    ('umul24_relaxed', 'a', 'b') => ('umul24', 'a', 'b')
 *    ('umul24_relaxed', 'a', 'b') => ('imul', 'a', 'b')
 *    ('imad24_ir3', 'a', 'b', 0) => ('imul24', 'a', 'b')
 *    ('imad24_ir3', 'a', 0, 'c') => c
 *    ('imad24_ir3', 'a', 1, 'c') => ('iadd', 'a', 'c')
 *    ('imad24_ir3', '#a', '#b', 'c') => ('iadd', ('imul', 'a', 'b'), 'c')
 *    ('imul24', 'a', '#b@32(is_pos_power_of_two)') => ('ishl', 'a', ('find_lsb', 'b'))
 *    ('imul24', 'a', '#b@32(is_neg_power_of_two)') => ('ineg', ('ishl', 'a', ('find_lsb', ('iabs', 'b'))))
 *    ('imul24', 'a', 0) => 0
 *    ('bcsel', ('ult', ('iadd', 'a', 'b'), 'a'), -1, ('iadd@8', 'a', 'b')) => ('uadd_sat', 'a', 'b')
 *    ('bcsel', ('uge', ('iadd', 'a', 'b'), 'a'), ('iadd@8', 'a', 'b'), -1) => ('uadd_sat', 'a', 'b')
 *    ('bcsel', ('ieq', ('uadd_carry', 'a', 'b'), 0), ('iadd@8', 'a', 'b'), -1) => ('uadd_sat', 'a', 'b')
 *    ('bcsel', ('ine', ('uadd_carry', 'a', 'b'), 0), -1, ('iadd@8', 'a', 'b')) => ('uadd_sat', 'a', 'b')
 *    ('bcsel', ('ult', ('iadd', 'a', 'b'), 'a'), -1, ('iadd@16', 'a', 'b')) => ('uadd_sat', 'a', 'b')
 *    ('bcsel', ('uge', ('iadd', 'a', 'b'), 'a'), ('iadd@16', 'a', 'b'), -1) => ('uadd_sat', 'a', 'b')
 *    ('bcsel', ('ieq', ('uadd_carry', 'a', 'b'), 0), ('iadd@16', 'a', 'b'), -1) => ('uadd_sat', 'a', 'b')
 *    ('bcsel', ('ine', ('uadd_carry', 'a', 'b'), 0), -1, ('iadd@16', 'a', 'b')) => ('uadd_sat', 'a', 'b')
 *    ('bcsel', ('ult', ('iadd', 'a', 'b'), 'a'), -1, ('iadd@32', 'a', 'b')) => ('uadd_sat', 'a', 'b')
 *    ('bcsel', ('uge', ('iadd', 'a', 'b'), 'a'), ('iadd@32', 'a', 'b'), -1) => ('uadd_sat', 'a', 'b')
 *    ('bcsel', ('ieq', ('uadd_carry', 'a', 'b'), 0), ('iadd@32', 'a', 'b'), -1) => ('uadd_sat', 'a', 'b')
 *    ('bcsel', ('ine', ('uadd_carry', 'a', 'b'), 0), -1, ('iadd@32', 'a', 'b')) => ('uadd_sat', 'a', 'b')
 *    ('bcsel', ('ult', ('iadd', 'a', 'b'), 'a'), -1, ('iadd@64', 'a', 'b')) => ('uadd_sat', 'a', 'b')
 *    ('bcsel', ('uge', ('iadd', 'a', 'b'), 'a'), ('iadd@64', 'a', 'b'), -1) => ('uadd_sat', 'a', 'b')
 *    ('bcsel', ('ieq', ('uadd_carry', 'a', 'b'), 0), ('iadd@64', 'a', 'b'), -1) => ('uadd_sat', 'a', 'b')
 *    ('bcsel', ('ine', ('uadd_carry', 'a', 'b'), 0), -1, ('iadd@64', 'a', 'b')) => ('uadd_sat', 'a', 'b')
 *    ('bcsel', ('ult', 'a', 'b'), 0, ('iadd@8', 'a', ('ineg', 'b'))) => ('usub_sat', 'a', 'b')
 *    ('bcsel', ('uge', 'a', 'b'), ('iadd@8', 'a', ('ineg', 'b')), 0) => ('usub_sat', 'a', 'b')
 *    ('bcsel', ('ieq', ('usub_borrow', 'a', 'b'), 0), ('iadd@8', 'a', ('ineg', 'b')), 0) => ('usub_sat', 'a', 'b')
 *    ('bcsel', ('ine', ('usub_borrow', 'a', 'b'), 0), 0, ('iadd@8', 'a', ('ineg', 'b'))) => ('usub_sat', 'a', 'b')
 *    ('bcsel', ('ult', 'a', 'b'), 0, ('iadd@16', 'a', ('ineg', 'b'))) => ('usub_sat', 'a', 'b')
 *    ('bcsel', ('uge', 'a', 'b'), ('iadd@16', 'a', ('ineg', 'b')), 0) => ('usub_sat', 'a', 'b')
 *    ('bcsel', ('ieq', ('usub_borrow', 'a', 'b'), 0), ('iadd@16', 'a', ('ineg', 'b')), 0) => ('usub_sat', 'a', 'b')
 *    ('bcsel', ('ine', ('usub_borrow', 'a', 'b'), 0), 0, ('iadd@16', 'a', ('ineg', 'b'))) => ('usub_sat', 'a', 'b')
 *    ('bcsel', ('ult', 'a', 'b'), 0, ('iadd@32', 'a', ('ineg', 'b'))) => ('usub_sat', 'a', 'b')
 *    ('bcsel', ('uge', 'a', 'b'), ('iadd@32', 'a', ('ineg', 'b')), 0) => ('usub_sat', 'a', 'b')
 *    ('bcsel', ('ieq', ('usub_borrow', 'a', 'b'), 0), ('iadd@32', 'a', ('ineg', 'b')), 0) => ('usub_sat', 'a', 'b')
 *    ('bcsel', ('ine', ('usub_borrow', 'a', 'b'), 0), 0, ('iadd@32', 'a', ('ineg', 'b'))) => ('usub_sat', 'a', 'b')
 *    ('bcsel', ('ult', 'a', 'b'), 0, ('iadd@64', 'a', ('ineg', 'b'))) => ('usub_sat', 'a', 'b')
 *    ('bcsel', ('uge', 'a', 'b'), ('iadd@64', 'a', ('ineg', 'b')), 0) => ('usub_sat', 'a', 'b')
 *    ('bcsel', ('ieq', ('usub_borrow', 'a', 'b'), 0), ('iadd@64', 'a', ('ineg', 'b')), 0) => ('usub_sat', 'a', 'b')
 *    ('bcsel', ('ine', ('usub_borrow', 'a', 'b'), 0), 0, ('iadd@64', 'a', ('ineg', 'b'))) => ('usub_sat', 'a', 'b')
 *    ('iadd_sat@8', 'a', 'b') => ('bcsel', ('ige', 'b', 1), ('bcsel', ('ilt', ('iadd', 'a', 'b'), 'a'), 127, ('iadd', 'a', 'b')), ('bcsel', ('ilt', 'a', ('iadd', 'a', 'b')), 128, ('iadd', 'a', 'b')))
 *    ('isub_sat@8', 'a', 'b') => ('bcsel', ('ilt', 'b', 0), ('bcsel', ('ilt', ('isub', 'a', 'b'), 'a'), 127, ('isub', 'a', 'b')), ('bcsel', ('ilt', 'a', ('isub', 'a', 'b')), 128, ('isub', 'a', 'b')))
 *    ('iadd_sat@16', 'a', 'b') => ('bcsel', ('ige', 'b', 1), ('bcsel', ('ilt', ('iadd', 'a', 'b'), 'a'), 32767, ('iadd', 'a', 'b')), ('bcsel', ('ilt', 'a', ('iadd', 'a', 'b')), 32768, ('iadd', 'a', 'b')))
 *    ('isub_sat@16', 'a', 'b') => ('bcsel', ('ilt', 'b', 0), ('bcsel', ('ilt', ('isub', 'a', 'b'), 'a'), 32767, ('isub', 'a', 'b')), ('bcsel', ('ilt', 'a', ('isub', 'a', 'b')), 32768, ('isub', 'a', 'b')))
 *    ('iadd_sat@32', 'a', 'b') => ('bcsel', ('ige', 'b', 1), ('bcsel', ('ilt', ('iadd', 'a', 'b'), 'a'), 2147483647, ('iadd', 'a', 'b')), ('bcsel', ('ilt', 'a', ('iadd', 'a', 'b')), 2147483648, ('iadd', 'a', 'b')))
 *    ('isub_sat@32', 'a', 'b') => ('bcsel', ('ilt', 'b', 0), ('bcsel', ('ilt', ('isub', 'a', 'b'), 'a'), 2147483647, ('isub', 'a', 'b')), ('bcsel', ('ilt', 'a', ('isub', 'a', 'b')), 2147483648, ('isub', 'a', 'b')))
 *    ('iadd_sat@64', 'a', 'b') => ('bcsel', ('ige', 'b', 1), ('bcsel', ('ilt', ('iadd', 'a', 'b'), 'a'), 9223372036854775807, ('iadd', 'a', 'b')), ('bcsel', ('ilt', 'a', ('iadd', 'a', 'b')), 9223372036854775808, ('iadd', 'a', 'b')))
 *    ('isub_sat@64', 'a', 'b') => ('bcsel', ('ilt', 'b', 0), ('bcsel', ('ilt', ('isub', 'a', 'b'), 'a'), 9223372036854775807, ('isub', 'a', 'b')), ('bcsel', ('ilt', 'a', ('isub', 'a', 'b')), 9223372036854775808, ('isub', 'a', 'b')))
 *    ('inot', ('ior(is_used_once)', ('feq', 'a', 'b'), ('feq', 'c', 'd'))) => ('iand', ('fneu', 'a', 'b'), ('fneu', 'c', 'd'))
 *    ('inot', ('iand(is_used_once)', ('feq', 'a', 'b'), ('feq', 'c', 'd'))) => ('ior', ('fneu', 'a', 'b'), ('fneu', 'c', 'd'))
 *    ('inot', ('ior(is_used_once)', ('feq', 'a', 'b'), ('fneu', 'c', 'd'))) => ('iand', ('fneu', 'a', 'b'), ('feq', 'c', 'd'))
 *    ('inot', ('iand(is_used_once)', ('feq', 'a', 'b'), ('fneu', 'c', 'd'))) => ('ior', ('fneu', 'a', 'b'), ('feq', 'c', 'd'))
 *    ('inot', ('ior(is_used_once)', ('fneu', 'a', 'b'), ('fneu', 'c', 'd'))) => ('iand', ('feq', 'a', 'b'), ('feq', 'c', 'd'))
 *    ('inot', ('iand(is_used_once)', ('fneu', 'a', 'b'), ('fneu', 'c', 'd'))) => ('ior', ('feq', 'a', 'b'), ('feq', 'c', 'd'))
 *    ('f2b1', ('b2f', 'a@1')) => a
 *    ('f2b8', ('b2f', 'a@8')) => a
 *    ('f2b16', ('b2f', 'a@16')) => a
 *    ('f2b32', ('b2f', 'a@32')) => a
 *    ('f2f', ('b2f', 'a')) => ('b2f', 'a')
 *    ('f2u', ('b2f', 'a')) => ('b2i', 'a')
 *    ('f2i', ('b2f', 'a')) => ('b2i', 'a')
 *    ('u2f', ('b2i', 'a')) => ('b2f', 'a')
 *    ('u2u', ('b2i', 'a')) => ('b2i', 'a')
 *    ('i2f', ('b2i', 'a')) => ('b2f', 'a')
 *    ('i2i', ('b2i', 'a')) => ('b2i', 'a')
 *    ('i2i1', 'a@1') => a
 *    ('i2i8', 'a@8') => a
 *    ('i2i16', 'a@16') => a
 *    ('i2i32', 'a@32') => a
 *    ('i2i64', 'a@64') => a
 *    ('u2u1', 'a@1') => a
 *    ('u2u8', 'a@8') => a
 *    ('u2u16', 'a@16') => a
 *    ('u2u32', 'a@32') => a
 *    ('u2u64', 'a@64') => a
 *    ('f2f16', 'a@16') => a
 *    ('f2f32', 'a@32') => a
 *    ('f2f64', 'a@64') => a
 *    ('b2b1', 'a@1') => a
 *    ('b2b8', 'a@8') => a
 *    ('b2b16', 'a@16') => a
 *    ('b2b32', 'a@32') => a
 *    ('i2i1', ('i2i8', 'a')) => ('i2i1', 'a')
 *    ('i2i1', ('u2u8', 'a')) => ('u2u1', 'a')
 *    ('u2u1', ('i2i8', 'a')) => ('i2i1', 'a')
 *    ('u2u1', ('u2u8', 'a')) => ('u2u1', 'a')
 *    ('i2i1', ('i2i16', 'a')) => ('i2i1', 'a')
 *    ('i2i1', ('u2u16', 'a')) => ('u2u1', 'a')
 *    ('u2u1', ('i2i16', 'a')) => ('i2i1', 'a')
 *    ('u2u1', ('u2u16', 'a')) => ('u2u1', 'a')
 *    ('i2i1', ('i2i32', 'a')) => ('i2i1', 'a')
 *    ('i2i1', ('u2u32', 'a')) => ('u2u1', 'a')
 *    ('u2u1', ('i2i32', 'a')) => ('i2i1', 'a')
 *    ('u2u1', ('u2u32', 'a')) => ('u2u1', 'a')
 *    ('i2i1', ('i2i64', 'a')) => ('i2i1', 'a')
 *    ('i2i1', ('u2u64', 'a')) => ('u2u1', 'a')
 *    ('u2u1', ('i2i64', 'a')) => ('i2i1', 'a')
 *    ('u2u1', ('u2u64', 'a')) => ('u2u1', 'a')
 *    ('i2i8', ('i2i1', 'a@1')) => ('i2i8', 'a')
 *    ('u2u8', ('u2u1', 'a@1')) => ('u2u8', 'a')
 *    ('i2i8', ('i2i16', 'a')) => ('i2i8', 'a')
 *    ('i2i8', ('u2u16', 'a')) => ('u2u8', 'a')
 *    ('u2u8', ('i2i16', 'a')) => ('i2i8', 'a')
 *    ('u2u8', ('u2u16', 'a')) => ('u2u8', 'a')
 *    ('i2i8', ('i2i32', 'a')) => ('i2i8', 'a')
 *    ('i2i8', ('u2u32', 'a')) => ('u2u8', 'a')
 *    ('u2u8', ('i2i32', 'a')) => ('i2i8', 'a')
 *    ('u2u8', ('u2u32', 'a')) => ('u2u8', 'a')
 *    ('i2i8', ('i2i64', 'a')) => ('i2i8', 'a')
 *    ('i2i8', ('u2u64', 'a')) => ('u2u8', 'a')
 *    ('u2u8', ('i2i64', 'a')) => ('i2i8', 'a')
 *    ('u2u8', ('u2u64', 'a')) => ('u2u8', 'a')
 *    ('i2i16', ('i2i1', 'a@1')) => ('i2i16', 'a')
 *    ('u2u16', ('u2u1', 'a@1')) => ('u2u16', 'a')
 *    ('i2i16', ('i2i8', 'a@1')) => ('i2i16', 'a')
 *    ('u2u16', ('u2u8', 'a@1')) => ('u2u16', 'a')
 *    ('i2i16', ('i2i8', 'a@8')) => ('i2i16', 'a')
 *    ('u2u16', ('u2u8', 'a@8')) => ('u2u16', 'a')
 *    ('i2i16', ('i2i32', 'a')) => ('i2i16', 'a')
 *    ('i2i16', ('u2u32', 'a')) => ('u2u16', 'a')
 *    ('u2u16', ('i2i32', 'a')) => ('i2i16', 'a')
 *    ('u2u16', ('u2u32', 'a')) => ('u2u16', 'a')
 *    ('i2i16', ('i2i64', 'a')) => ('i2i16', 'a')
 *    ('i2i16', ('u2u64', 'a')) => ('u2u16', 'a')
 *    ('u2u16', ('i2i64', 'a')) => ('i2i16', 'a')
 *    ('u2u16', ('u2u64', 'a')) => ('u2u16', 'a')
 *    ('i2i32', ('i2i1', 'a@1')) => ('i2i32', 'a')
 *    ('u2u32', ('u2u1', 'a@1')) => ('u2u32', 'a')
 *    ('i2i32', ('i2i8', 'a@1')) => ('i2i32', 'a')
 *    ('u2u32', ('u2u8', 'a@1')) => ('u2u32', 'a')
 *    ('i2i32', ('i2i8', 'a@8')) => ('i2i32', 'a')
 *    ('u2u32', ('u2u8', 'a@8')) => ('u2u32', 'a')
 *    ('i2i32', ('i2i16', 'a@1')) => ('i2i32', 'a')
 *    ('u2u32', ('u2u16', 'a@1')) => ('u2u32', 'a')
 *    ('i2i32', ('i2i16', 'a@8')) => ('i2i32', 'a')
 *    ('u2u32', ('u2u16', 'a@8')) => ('u2u32', 'a')
 *    ('i2i32', ('i2i16', 'a@16')) => ('i2i32', 'a')
 *    ('u2u32', ('u2u16', 'a@16')) => ('u2u32', 'a')
 *    ('i2i32', ('i2i64', 'a')) => ('i2i32', 'a')
 *    ('i2i32', ('u2u64', 'a')) => ('u2u32', 'a')
 *    ('u2u32', ('i2i64', 'a')) => ('i2i32', 'a')
 *    ('u2u32', ('u2u64', 'a')) => ('u2u32', 'a')
 *    ('i2i64', ('i2i1', 'a@1')) => ('i2i64', 'a')
 *    ('u2u64', ('u2u1', 'a@1')) => ('u2u64', 'a')
 *    ('i2i64', ('i2i8', 'a@1')) => ('i2i64', 'a')
 *    ('u2u64', ('u2u8', 'a@1')) => ('u2u64', 'a')
 *    ('i2i64', ('i2i8', 'a@8')) => ('i2i64', 'a')
 *    ('u2u64', ('u2u8', 'a@8')) => ('u2u64', 'a')
 *    ('i2i64', ('i2i16', 'a@1')) => ('i2i64', 'a')
 *    ('u2u64', ('u2u16', 'a@1')) => ('u2u64', 'a')
 *    ('i2i64', ('i2i16', 'a@8')) => ('i2i64', 'a')
 *    ('u2u64', ('u2u16', 'a@8')) => ('u2u64', 'a')
 *    ('i2i64', ('i2i16', 'a@16')) => ('i2i64', 'a')
 *    ('u2u64', ('u2u16', 'a@16')) => ('u2u64', 'a')
 *    ('i2i64', ('i2i32', 'a@1')) => ('i2i64', 'a')
 *    ('u2u64', ('u2u32', 'a@1')) => ('u2u64', 'a')
 *    ('i2i64', ('i2i32', 'a@8')) => ('i2i64', 'a')
 *    ('u2u64', ('u2u32', 'a@8')) => ('u2u64', 'a')
 *    ('i2i64', ('i2i32', 'a@16')) => ('i2i64', 'a')
 *    ('u2u64', ('u2u32', 'a@16')) => ('u2u64', 'a')
 *    ('i2i64', ('i2i32', 'a@32')) => ('i2i64', 'a')
 *    ('u2u64', ('u2u32', 'a@32')) => ('u2u64', 'a')
 *    ('i2i8', ('pack_64_2x32_split', 'a', 'b')) => ('i2i8', 'a')
 *    ('i2i8', ('pack_64_2x32_split', 'a', 'b')) => ('i2i8', 'a')
 *    ('i2i16', ('pack_64_2x32_split', 'a', 'b')) => ('i2i16', 'a')
 *    ('i2i16', ('pack_64_2x32_split', 'a', 'b')) => ('i2i16', 'a')
 *    ('i2i32', ('pack_64_2x32_split', 'a', 'b')) => ('i2i32', 'a')
 *    ('i2i32', ('pack_64_2x32_split', 'a', 'b')) => ('i2i32', 'a')
 *    ('u2u8', ('pack_64_2x32_split', 'a', 'b')) => ('u2u8', 'a')
 *    ('u2u8', ('pack_64_2x32_split', 'a', 'b')) => ('u2u8', 'a')
 *    ('u2u16', ('pack_64_2x32_split', 'a', 'b')) => ('u2u16', 'a')
 *    ('u2u16', ('pack_64_2x32_split', 'a', 'b')) => ('u2u16', 'a')
 *    ('u2u32', ('pack_64_2x32_split', 'a', 'b')) => ('u2u32', 'a')
 *    ('u2u32', ('pack_64_2x32_split', 'a', 'b')) => ('u2u32', 'a')
 *    ('ieq', ('i2i16', 'a@8'), ('i2i16', 'b@8')) => ('ieq', 'a', ('i2i8', 'b'))
 *    ('ine', ('i2i16', 'a@8'), ('i2i16', 'b@8')) => ('ine', 'a', ('i2i8', 'b'))
 *    ('ige', ('i2i16', 'a@8'), ('i2i16', 'b@8')) => ('ige', 'a', ('i2i8', 'b'))
 *    ('ilt', ('i2i16', 'a@8'), ('i2i16', 'b@8')) => ('ilt', 'a', ('i2i8', 'b'))
 *    ('ige', ('i2i16', 'b@8'), ('i2i16', 'a@8')) => ('ige', ('i2i8', 'b'), 'a')
 *    ('ilt', ('i2i16', 'b@8'), ('i2i16', 'a@8')) => ('ilt', ('i2i8', 'b'), 'a')
 *    ('ieq', ('i2i16', 'a@8'), '#b') => ('iand', ('ieq', 'a', ('i2i8', 'b')), ('ieq', ('i2i16', ('i2i8', 'b')), 'b'))
 *    ('ine', ('i2i16', 'a@8'), '#b') => ('ior', ('ine', 'a', ('i2i8', 'b')), ('ine', ('i2i16', ('i2i8', 'b')), 'b'))
 *    ('ilt', ('i2i16', 'a@8'), '#b') => ('iand', ('ilt', -128, 'b'), ('ior', ('ilt', 127, 'b'), ('ilt', 'a', ('i2i8', 'b'))))
 *    ('ilt', '#a', ('i2i16', 'b@8')) => ('iand', ('ilt', 'a', 127), ('ior', ('ilt', 'a', -128), ('ilt', ('i2i8', 'a'), 'b')))
 *    ('ige', ('i2i16', 'a@8'), '#b') => ('iand', ('ige', 127, 'b'), ('ior', ('ige', -128, 'b'), ('ige', 'a', ('i2i8', 'b'))))
 *    ('ige', '#a', ('i2i16', 'b@8')) => ('iand', ('ige', 'a', -128), ('ior', ('ige', 'a', 127), ('ige', ('i2i8', 'a'), 'b')))
 *    ('ieq', ('i2i32', 'a@8'), ('i2i32', 'b@8')) => ('ieq', 'a', ('i2i8', 'b'))
 *    ('ine', ('i2i32', 'a@8'), ('i2i32', 'b@8')) => ('ine', 'a', ('i2i8', 'b'))
 *    ('ige', ('i2i32', 'a@8'), ('i2i32', 'b@8')) => ('ige', 'a', ('i2i8', 'b'))
 *    ('ilt', ('i2i32', 'a@8'), ('i2i32', 'b@8')) => ('ilt', 'a', ('i2i8', 'b'))
 *    ('ige', ('i2i32', 'b@8'), ('i2i32', 'a@8')) => ('ige', ('i2i8', 'b'), 'a')
 *    ('ilt', ('i2i32', 'b@8'), ('i2i32', 'a@8')) => ('ilt', ('i2i8', 'b'), 'a')
 *    ('ieq', ('i2i32', 'a@8'), '#b') => ('iand', ('ieq', 'a', ('i2i8', 'b')), ('ieq', ('i2i32', ('i2i8', 'b')), 'b'))
 *    ('ine', ('i2i32', 'a@8'), '#b') => ('ior', ('ine', 'a', ('i2i8', 'b')), ('ine', ('i2i32', ('i2i8', 'b')), 'b'))
 *    ('ilt', ('i2i32', 'a@8'), '#b') => ('iand', ('ilt', -128, 'b'), ('ior', ('ilt', 127, 'b'), ('ilt', 'a', ('i2i8', 'b'))))
 *    ('ilt', '#a', ('i2i32', 'b@8')) => ('iand', ('ilt', 'a', 127), ('ior', ('ilt', 'a', -128), ('ilt', ('i2i8', 'a'), 'b')))
 *    ('ige', ('i2i32', 'a@8'), '#b') => ('iand', ('ige', 127, 'b'), ('ior', ('ige', -128, 'b'), ('ige', 'a', ('i2i8', 'b'))))
 *    ('ige', '#a', ('i2i32', 'b@8')) => ('iand', ('ige', 'a', -128), ('ior', ('ige', 'a', 127), ('ige', ('i2i8', 'a'), 'b')))
 *    ('ieq', ('i2i64', 'a@8'), ('i2i64', 'b@8')) => ('ieq', 'a', ('i2i8', 'b'))
 *    ('ine', ('i2i64', 'a@8'), ('i2i64', 'b@8')) => ('ine', 'a', ('i2i8', 'b'))
 *    ('ige', ('i2i64', 'a@8'), ('i2i64', 'b@8')) => ('ige', 'a', ('i2i8', 'b'))
 *    ('ilt', ('i2i64', 'a@8'), ('i2i64', 'b@8')) => ('ilt', 'a', ('i2i8', 'b'))
 *    ('ige', ('i2i64', 'b@8'), ('i2i64', 'a@8')) => ('ige', ('i2i8', 'b'), 'a')
 *    ('ilt', ('i2i64', 'b@8'), ('i2i64', 'a@8')) => ('ilt', ('i2i8', 'b'), 'a')
 *    ('ieq', ('i2i64', 'a@8'), '#b') => ('iand', ('ieq', 'a', ('i2i8', 'b')), ('ieq', ('i2i64', ('i2i8', 'b')), 'b'))
 *    ('ine', ('i2i64', 'a@8'), '#b') => ('ior', ('ine', 'a', ('i2i8', 'b')), ('ine', ('i2i64', ('i2i8', 'b')), 'b'))
 *    ('ilt', ('i2i64', 'a@8'), '#b') => ('iand', ('ilt', -128, 'b'), ('ior', ('ilt', 127, 'b'), ('ilt', 'a', ('i2i8', 'b'))))
 *    ('ilt', '#a', ('i2i64', 'b@8')) => ('iand', ('ilt', 'a', 127), ('ior', ('ilt', 'a', -128), ('ilt', ('i2i8', 'a'), 'b')))
 *    ('ige', ('i2i64', 'a@8'), '#b') => ('iand', ('ige', 127, 'b'), ('ior', ('ige', -128, 'b'), ('ige', 'a', ('i2i8', 'b'))))
 *    ('ige', '#a', ('i2i64', 'b@8')) => ('iand', ('ige', 'a', -128), ('ior', ('ige', 'a', 127), ('ige', ('i2i8', 'a'), 'b')))
 *    ('ieq', ('i2i32', 'a@16'), ('i2i32', 'b@8')) => ('ieq', 'a', ('i2i16', 'b'))
 *    ('ine', ('i2i32', 'a@16'), ('i2i32', 'b@8')) => ('ine', 'a', ('i2i16', 'b'))
 *    ('ige', ('i2i32', 'a@16'), ('i2i32', 'b@8')) => ('ige', 'a', ('i2i16', 'b'))
 *    ('ilt', ('i2i32', 'a@16'), ('i2i32', 'b@8')) => ('ilt', 'a', ('i2i16', 'b'))
 *    ('ige', ('i2i32', 'b@8'), ('i2i32', 'a@16')) => ('ige', ('i2i16', 'b'), 'a')
 *    ('ilt', ('i2i32', 'b@8'), ('i2i32', 'a@16')) => ('ilt', ('i2i16', 'b'), 'a')
 *    ('ieq', ('i2i32', 'a@16'), ('i2i32', 'b@16')) => ('ieq', 'a', ('i2i16', 'b'))
 *    ('ine', ('i2i32', 'a@16'), ('i2i32', 'b@16')) => ('ine', 'a', ('i2i16', 'b'))
 *    ('ige', ('i2i32', 'a@16'), ('i2i32', 'b@16')) => ('ige', 'a', ('i2i16', 'b'))
 *    ('ilt', ('i2i32', 'a@16'), ('i2i32', 'b@16')) => ('ilt', 'a', ('i2i16', 'b'))
 *    ('ige', ('i2i32', 'b@16'), ('i2i32', 'a@16')) => ('ige', ('i2i16', 'b'), 'a')
 *    ('ilt', ('i2i32', 'b@16'), ('i2i32', 'a@16')) => ('ilt', ('i2i16', 'b'), 'a')
 *    ('ieq', ('i2i32', 'a@16'), '#b') => ('iand', ('ieq', 'a', ('i2i16', 'b')), ('ieq', ('i2i32', ('i2i16', 'b')), 'b'))
 *    ('ine', ('i2i32', 'a@16'), '#b') => ('ior', ('ine', 'a', ('i2i16', 'b')), ('ine', ('i2i32', ('i2i16', 'b')), 'b'))
 *    ('ilt', ('i2i32', 'a@16'), '#b') => ('iand', ('ilt', -32768, 'b'), ('ior', ('ilt', 32767, 'b'), ('ilt', 'a', ('i2i16', 'b'))))
 *    ('ilt', '#a', ('i2i32', 'b@16')) => ('iand', ('ilt', 'a', 32767), ('ior', ('ilt', 'a', -32768), ('ilt', ('i2i16', 'a'), 'b')))
 *    ('ige', ('i2i32', 'a@16'), '#b') => ('iand', ('ige', 32767, 'b'), ('ior', ('ige', -32768, 'b'), ('ige', 'a', ('i2i16', 'b'))))
 *    ('ige', '#a', ('i2i32', 'b@16')) => ('iand', ('ige', 'a', -32768), ('ior', ('ige', 'a', 32767), ('ige', ('i2i16', 'a'), 'b')))
 *    ('ieq', ('i2i64', 'a@16'), ('i2i64', 'b@8')) => ('ieq', 'a', ('i2i16', 'b'))
 *    ('ine', ('i2i64', 'a@16'), ('i2i64', 'b@8')) => ('ine', 'a', ('i2i16', 'b'))
 *    ('ige', ('i2i64', 'a@16'), ('i2i64', 'b@8')) => ('ige', 'a', ('i2i16', 'b'))
 *    ('ilt', ('i2i64', 'a@16'), ('i2i64', 'b@8')) => ('ilt', 'a', ('i2i16', 'b'))
 *    ('ige', ('i2i64', 'b@8'), ('i2i64', 'a@16')) => ('ige', ('i2i16', 'b'), 'a')
 *    ('ilt', ('i2i64', 'b@8'), ('i2i64', 'a@16')) => ('ilt', ('i2i16', 'b'), 'a')
 *    ('ieq', ('i2i64', 'a@16'), ('i2i64', 'b@16')) => ('ieq', 'a', ('i2i16', 'b'))
 *    ('ine', ('i2i64', 'a@16'), ('i2i64', 'b@16')) => ('ine', 'a', ('i2i16', 'b'))
 *    ('ige', ('i2i64', 'a@16'), ('i2i64', 'b@16')) => ('ige', 'a', ('i2i16', 'b'))
 *    ('ilt', ('i2i64', 'a@16'), ('i2i64', 'b@16')) => ('ilt', 'a', ('i2i16', 'b'))
 *    ('ige', ('i2i64', 'b@16'), ('i2i64', 'a@16')) => ('ige', ('i2i16', 'b'), 'a')
 *    ('ilt', ('i2i64', 'b@16'), ('i2i64', 'a@16')) => ('ilt', ('i2i16', 'b'), 'a')
 *    ('ieq', ('i2i64', 'a@16'), '#b') => ('iand', ('ieq', 'a', ('i2i16', 'b')), ('ieq', ('i2i64', ('i2i16', 'b')), 'b'))
 *    ('ine', ('i2i64', 'a@16'), '#b') => ('ior', ('ine', 'a', ('i2i16', 'b')), ('ine', ('i2i64', ('i2i16', 'b')), 'b'))
 *    ('ilt', ('i2i64', 'a@16'), '#b') => ('iand', ('ilt', -32768, 'b'), ('ior', ('ilt', 32767, 'b'), ('ilt', 'a', ('i2i16', 'b'))))
 *    ('ilt', '#a', ('i2i64', 'b@16')) => ('iand', ('ilt', 'a', 32767), ('ior', ('ilt', 'a', -32768), ('ilt', ('i2i16', 'a'), 'b')))
 *    ('ige', ('i2i64', 'a@16'), '#b') => ('iand', ('ige', 32767, 'b'), ('ior', ('ige', -32768, 'b'), ('ige', 'a', ('i2i16', 'b'))))
 *    ('ige', '#a', ('i2i64', 'b@16')) => ('iand', ('ige', 'a', -32768), ('ior', ('ige', 'a', 32767), ('ige', ('i2i16', 'a'), 'b')))
 *    ('ieq', ('i2i64', 'a@32'), ('i2i64', 'b@8')) => ('ieq', 'a', ('i2i32', 'b'))
 *    ('ine', ('i2i64', 'a@32'), ('i2i64', 'b@8')) => ('ine', 'a', ('i2i32', 'b'))
 *    ('ige', ('i2i64', 'a@32'), ('i2i64', 'b@8')) => ('ige', 'a', ('i2i32', 'b'))
 *    ('ilt', ('i2i64', 'a@32'), ('i2i64', 'b@8')) => ('ilt', 'a', ('i2i32', 'b'))
 *    ('ige', ('i2i64', 'b@8'), ('i2i64', 'a@32')) => ('ige', ('i2i32', 'b'), 'a')
 *    ('ilt', ('i2i64', 'b@8'), ('i2i64', 'a@32')) => ('ilt', ('i2i32', 'b'), 'a')
 *    ('ieq', ('i2i64', 'a@32'), ('i2i64', 'b@16')) => ('ieq', 'a', ('i2i32', 'b'))
 *    ('ine', ('i2i64', 'a@32'), ('i2i64', 'b@16')) => ('ine', 'a', ('i2i32', 'b'))
 *    ('ige', ('i2i64', 'a@32'), ('i2i64', 'b@16')) => ('ige', 'a', ('i2i32', 'b'))
 *    ('ilt', ('i2i64', 'a@32'), ('i2i64', 'b@16')) => ('ilt', 'a', ('i2i32', 'b'))
 *    ('ige', ('i2i64', 'b@16'), ('i2i64', 'a@32')) => ('ige', ('i2i32', 'b'), 'a')
 *    ('ilt', ('i2i64', 'b@16'), ('i2i64', 'a@32')) => ('ilt', ('i2i32', 'b'), 'a')
 *    ('ieq', ('i2i64', 'a@32'), ('i2i64', 'b@32')) => ('ieq', 'a', ('i2i32', 'b'))
 *    ('ine', ('i2i64', 'a@32'), ('i2i64', 'b@32')) => ('ine', 'a', ('i2i32', 'b'))
 *    ('ige', ('i2i64', 'a@32'), ('i2i64', 'b@32')) => ('ige', 'a', ('i2i32', 'b'))
 *    ('ilt', ('i2i64', 'a@32'), ('i2i64', 'b@32')) => ('ilt', 'a', ('i2i32', 'b'))
 *    ('ige', ('i2i64', 'b@32'), ('i2i64', 'a@32')) => ('ige', ('i2i32', 'b'), 'a')
 *    ('ilt', ('i2i64', 'b@32'), ('i2i64', 'a@32')) => ('ilt', ('i2i32', 'b'), 'a')
 *    ('ieq', ('i2i64', 'a@32'), '#b') => ('iand', ('ieq', 'a', ('i2i32', 'b')), ('ieq', ('i2i64', ('i2i32', 'b')), 'b'))
 *    ('ine', ('i2i64', 'a@32'), '#b') => ('ior', ('ine', 'a', ('i2i32', 'b')), ('ine', ('i2i64', ('i2i32', 'b')), 'b'))
 *    ('ilt', ('i2i64', 'a@32'), '#b') => ('iand', ('ilt', -2147483648, 'b'), ('ior', ('ilt', 2147483647, 'b'), ('ilt', 'a', ('i2i32', 'b'))))
 *    ('ilt', '#a', ('i2i64', 'b@32')) => ('iand', ('ilt', 'a', 2147483647), ('ior', ('ilt', 'a', -2147483648), ('ilt', ('i2i32', 'a'), 'b')))
 *    ('ige', ('i2i64', 'a@32'), '#b') => ('iand', ('ige', 2147483647, 'b'), ('ior', ('ige', -2147483648, 'b'), ('ige', 'a', ('i2i32', 'b'))))
 *    ('ige', '#a', ('i2i64', 'b@32')) => ('iand', ('ige', 'a', -2147483648), ('ior', ('ige', 'a', 2147483647), ('ige', ('i2i32', 'a'), 'b')))
 *    ('ieq', ('u2u16', 'a@8'), ('u2u16', 'b@8')) => ('ieq', 'a', ('u2u8', 'b'))
 *    ('ine', ('u2u16', 'a@8'), ('u2u16', 'b@8')) => ('ine', 'a', ('u2u8', 'b'))
 *    ('uge', ('u2u16', 'a@8'), ('u2u16', 'b@8')) => ('uge', 'a', ('u2u8', 'b'))
 *    ('ult', ('u2u16', 'a@8'), ('u2u16', 'b@8')) => ('ult', 'a', ('u2u8', 'b'))
 *    ('uge', ('u2u16', 'b@8'), ('u2u16', 'a@8')) => ('uge', ('u2u8', 'b'), 'a')
 *    ('ult', ('u2u16', 'b@8'), ('u2u16', 'a@8')) => ('ult', ('u2u8', 'b'), 'a')
 *    ('ieq', ('u2u16', 'a@8'), '#b') => ('iand', ('ieq', 'a', ('u2u8', 'b')), ('ieq', ('u2u16', ('u2u8', 'b')), 'b'))
 *    ('ine', ('u2u16', 'a@8'), '#b') => ('ior', ('ine', 'a', ('u2u8', 'b')), ('ine', ('u2u16', ('u2u8', 'b')), 'b'))
 *    ('ult', ('u2u16', 'a@8'), '#b') => ('iand', ('ult', 0, 'b'), ('ior', ('ult', 255, 'b'), ('ult', 'a', ('u2u8', 'b'))))
 *    ('ult', '#a', ('u2u16', 'b@8')) => ('iand', ('ult', 'a', 255), ('ior', ('ult', 'a', 0), ('ult', ('u2u8', 'a'), 'b')))
 *    ('uge', ('u2u16', 'a@8'), '#b') => ('iand', ('uge', 255, 'b'), ('ior', ('uge', 0, 'b'), ('uge', 'a', ('u2u8', 'b'))))
 *    ('uge', '#a', ('u2u16', 'b@8')) => ('iand', ('uge', 'a', 0), ('ior', ('uge', 'a', 255), ('uge', ('u2u8', 'a'), 'b')))
 *    ('ieq', ('u2u32', 'a@8'), ('u2u32', 'b@8')) => ('ieq', 'a', ('u2u8', 'b'))
 *    ('ine', ('u2u32', 'a@8'), ('u2u32', 'b@8')) => ('ine', 'a', ('u2u8', 'b'))
 *    ('uge', ('u2u32', 'a@8'), ('u2u32', 'b@8')) => ('uge', 'a', ('u2u8', 'b'))
 *    ('ult', ('u2u32', 'a@8'), ('u2u32', 'b@8')) => ('ult', 'a', ('u2u8', 'b'))
 *    ('uge', ('u2u32', 'b@8'), ('u2u32', 'a@8')) => ('uge', ('u2u8', 'b'), 'a')
 *    ('ult', ('u2u32', 'b@8'), ('u2u32', 'a@8')) => ('ult', ('u2u8', 'b'), 'a')
 *    ('ieq', ('u2u32', 'a@8'), '#b') => ('iand', ('ieq', 'a', ('u2u8', 'b')), ('ieq', ('u2u32', ('u2u8', 'b')), 'b'))
 *    ('ine', ('u2u32', 'a@8'), '#b') => ('ior', ('ine', 'a', ('u2u8', 'b')), ('ine', ('u2u32', ('u2u8', 'b')), 'b'))
 *    ('ult', ('u2u32', 'a@8'), '#b') => ('iand', ('ult', 0, 'b'), ('ior', ('ult', 255, 'b'), ('ult', 'a', ('u2u8', 'b'))))
 *    ('ult', '#a', ('u2u32', 'b@8')) => ('iand', ('ult', 'a', 255), ('ior', ('ult', 'a', 0), ('ult', ('u2u8', 'a'), 'b')))
 *    ('uge', ('u2u32', 'a@8'), '#b') => ('iand', ('uge', 255, 'b'), ('ior', ('uge', 0, 'b'), ('uge', 'a', ('u2u8', 'b'))))
 *    ('uge', '#a', ('u2u32', 'b@8')) => ('iand', ('uge', 'a', 0), ('ior', ('uge', 'a', 255), ('uge', ('u2u8', 'a'), 'b')))
 *    ('ieq', ('u2u64', 'a@8'), ('u2u64', 'b@8')) => ('ieq', 'a', ('u2u8', 'b'))
 *    ('ine', ('u2u64', 'a@8'), ('u2u64', 'b@8')) => ('ine', 'a', ('u2u8', 'b'))
 *    ('uge', ('u2u64', 'a@8'), ('u2u64', 'b@8')) => ('uge', 'a', ('u2u8', 'b'))
 *    ('ult', ('u2u64', 'a@8'), ('u2u64', 'b@8')) => ('ult', 'a', ('u2u8', 'b'))
 *    ('uge', ('u2u64', 'b@8'), ('u2u64', 'a@8')) => ('uge', ('u2u8', 'b'), 'a')
 *    ('ult', ('u2u64', 'b@8'), ('u2u64', 'a@8')) => ('ult', ('u2u8', 'b'), 'a')
 *    ('ieq', ('u2u64', 'a@8'), '#b') => ('iand', ('ieq', 'a', ('u2u8', 'b')), ('ieq', ('u2u64', ('u2u8', 'b')), 'b'))
 *    ('ine', ('u2u64', 'a@8'), '#b') => ('ior', ('ine', 'a', ('u2u8', 'b')), ('ine', ('u2u64', ('u2u8', 'b')), 'b'))
 *    ('ult', ('u2u64', 'a@8'), '#b') => ('iand', ('ult', 0, 'b'), ('ior', ('ult', 255, 'b'), ('ult', 'a', ('u2u8', 'b'))))
 *    ('ult', '#a', ('u2u64', 'b@8')) => ('iand', ('ult', 'a', 255), ('ior', ('ult', 'a', 0), ('ult', ('u2u8', 'a'), 'b')))
 *    ('uge', ('u2u64', 'a@8'), '#b') => ('iand', ('uge', 255, 'b'), ('ior', ('uge', 0, 'b'), ('uge', 'a', ('u2u8', 'b'))))
 *    ('uge', '#a', ('u2u64', 'b@8')) => ('iand', ('uge', 'a', 0), ('ior', ('uge', 'a', 255), ('uge', ('u2u8', 'a'), 'b')))
 *    ('ieq', ('u2u32', 'a@16'), ('u2u32', 'b@8')) => ('ieq', 'a', ('u2u16', 'b'))
 *    ('ine', ('u2u32', 'a@16'), ('u2u32', 'b@8')) => ('ine', 'a', ('u2u16', 'b'))
 *    ('uge', ('u2u32', 'a@16'), ('u2u32', 'b@8')) => ('uge', 'a', ('u2u16', 'b'))
 *    ('ult', ('u2u32', 'a@16'), ('u2u32', 'b@8')) => ('ult', 'a', ('u2u16', 'b'))
 *    ('uge', ('u2u32', 'b@8'), ('u2u32', 'a@16')) => ('uge', ('u2u16', 'b'), 'a')
 *    ('ult', ('u2u32', 'b@8'), ('u2u32', 'a@16')) => ('ult', ('u2u16', 'b'), 'a')
 *    ('ieq', ('u2u32', 'a@16'), ('u2u32', 'b@16')) => ('ieq', 'a', ('u2u16', 'b'))
 *    ('ine', ('u2u32', 'a@16'), ('u2u32', 'b@16')) => ('ine', 'a', ('u2u16', 'b'))
 *    ('uge', ('u2u32', 'a@16'), ('u2u32', 'b@16')) => ('uge', 'a', ('u2u16', 'b'))
 *    ('ult', ('u2u32', 'a@16'), ('u2u32', 'b@16')) => ('ult', 'a', ('u2u16', 'b'))
 *    ('uge', ('u2u32', 'b@16'), ('u2u32', 'a@16')) => ('uge', ('u2u16', 'b'), 'a')
 *    ('ult', ('u2u32', 'b@16'), ('u2u32', 'a@16')) => ('ult', ('u2u16', 'b'), 'a')
 *    ('ieq', ('u2u32', 'a@16'), '#b') => ('iand', ('ieq', 'a', ('u2u16', 'b')), ('ieq', ('u2u32', ('u2u16', 'b')), 'b'))
 *    ('ine', ('u2u32', 'a@16'), '#b') => ('ior', ('ine', 'a', ('u2u16', 'b')), ('ine', ('u2u32', ('u2u16', 'b')), 'b'))
 *    ('ult', ('u2u32', 'a@16'), '#b') => ('iand', ('ult', 0, 'b'), ('ior', ('ult', 65535, 'b'), ('ult', 'a', ('u2u16', 'b'))))
 *    ('ult', '#a', ('u2u32', 'b@16')) => ('iand', ('ult', 'a', 65535), ('ior', ('ult', 'a', 0), ('ult', ('u2u16', 'a'), 'b')))
 *    ('uge', ('u2u32', 'a@16'), '#b') => ('iand', ('uge', 65535, 'b'), ('ior', ('uge', 0, 'b'), ('uge', 'a', ('u2u16', 'b'))))
 *    ('uge', '#a', ('u2u32', 'b@16')) => ('iand', ('uge', 'a', 0), ('ior', ('uge', 'a', 65535), ('uge', ('u2u16', 'a'), 'b')))
 *    ('ieq', ('u2u64', 'a@16'), ('u2u64', 'b@8')) => ('ieq', 'a', ('u2u16', 'b'))
 *    ('ine', ('u2u64', 'a@16'), ('u2u64', 'b@8')) => ('ine', 'a', ('u2u16', 'b'))
 *    ('uge', ('u2u64', 'a@16'), ('u2u64', 'b@8')) => ('uge', 'a', ('u2u16', 'b'))
 *    ('ult', ('u2u64', 'a@16'), ('u2u64', 'b@8')) => ('ult', 'a', ('u2u16', 'b'))
 *    ('uge', ('u2u64', 'b@8'), ('u2u64', 'a@16')) => ('uge', ('u2u16', 'b'), 'a')
 *    ('ult', ('u2u64', 'b@8'), ('u2u64', 'a@16')) => ('ult', ('u2u16', 'b'), 'a')
 *    ('ieq', ('u2u64', 'a@16'), ('u2u64', 'b@16')) => ('ieq', 'a', ('u2u16', 'b'))
 *    ('ine', ('u2u64', 'a@16'), ('u2u64', 'b@16')) => ('ine', 'a', ('u2u16', 'b'))
 *    ('uge', ('u2u64', 'a@16'), ('u2u64', 'b@16')) => ('uge', 'a', ('u2u16', 'b'))
 *    ('ult', ('u2u64', 'a@16'), ('u2u64', 'b@16')) => ('ult', 'a', ('u2u16', 'b'))
 *    ('uge', ('u2u64', 'b@16'), ('u2u64', 'a@16')) => ('uge', ('u2u16', 'b'), 'a')
 *    ('ult', ('u2u64', 'b@16'), ('u2u64', 'a@16')) => ('ult', ('u2u16', 'b'), 'a')
 *    ('ieq', ('u2u64', 'a@16'), '#b') => ('iand', ('ieq', 'a', ('u2u16', 'b')), ('ieq', ('u2u64', ('u2u16', 'b')), 'b'))
 *    ('ine', ('u2u64', 'a@16'), '#b') => ('ior', ('ine', 'a', ('u2u16', 'b')), ('ine', ('u2u64', ('u2u16', 'b')), 'b'))
 *    ('ult', ('u2u64', 'a@16'), '#b') => ('iand', ('ult', 0, 'b'), ('ior', ('ult', 65535, 'b'), ('ult', 'a', ('u2u16', 'b'))))
 *    ('ult', '#a', ('u2u64', 'b@16')) => ('iand', ('ult', 'a', 65535), ('ior', ('ult', 'a', 0), ('ult', ('u2u16', 'a'), 'b')))
 *    ('uge', ('u2u64', 'a@16'), '#b') => ('iand', ('uge', 65535, 'b'), ('ior', ('uge', 0, 'b'), ('uge', 'a', ('u2u16', 'b'))))
 *    ('uge', '#a', ('u2u64', 'b@16')) => ('iand', ('uge', 'a', 0), ('ior', ('uge', 'a', 65535), ('uge', ('u2u16', 'a'), 'b')))
 *    ('ieq', ('u2u64', 'a@32'), ('u2u64', 'b@8')) => ('ieq', 'a', ('u2u32', 'b'))
 *    ('ine', ('u2u64', 'a@32'), ('u2u64', 'b@8')) => ('ine', 'a', ('u2u32', 'b'))
 *    ('uge', ('u2u64', 'a@32'), ('u2u64', 'b@8')) => ('uge', 'a', ('u2u32', 'b'))
 *    ('ult', ('u2u64', 'a@32'), ('u2u64', 'b@8')) => ('ult', 'a', ('u2u32', 'b'))
 *    ('uge', ('u2u64', 'b@8'), ('u2u64', 'a@32')) => ('uge', ('u2u32', 'b'), 'a')
 *    ('ult', ('u2u64', 'b@8'), ('u2u64', 'a@32')) => ('ult', ('u2u32', 'b'), 'a')
 *    ('ieq', ('u2u64', 'a@32'), ('u2u64', 'b@16')) => ('ieq', 'a', ('u2u32', 'b'))
 *    ('ine', ('u2u64', 'a@32'), ('u2u64', 'b@16')) => ('ine', 'a', ('u2u32', 'b'))
 *    ('uge', ('u2u64', 'a@32'), ('u2u64', 'b@16')) => ('uge', 'a', ('u2u32', 'b'))
 *    ('ult', ('u2u64', 'a@32'), ('u2u64', 'b@16')) => ('ult', 'a', ('u2u32', 'b'))
 *    ('uge', ('u2u64', 'b@16'), ('u2u64', 'a@32')) => ('uge', ('u2u32', 'b'), 'a')
 *    ('ult', ('u2u64', 'b@16'), ('u2u64', 'a@32')) => ('ult', ('u2u32', 'b'), 'a')
 *    ('ieq', ('u2u64', 'a@32'), ('u2u64', 'b@32')) => ('ieq', 'a', ('u2u32', 'b'))
 *    ('ine', ('u2u64', 'a@32'), ('u2u64', 'b@32')) => ('ine', 'a', ('u2u32', 'b'))
 *    ('uge', ('u2u64', 'a@32'), ('u2u64', 'b@32')) => ('uge', 'a', ('u2u32', 'b'))
 *    ('ult', ('u2u64', 'a@32'), ('u2u64', 'b@32')) => ('ult', 'a', ('u2u32', 'b'))
 *    ('uge', ('u2u64', 'b@32'), ('u2u64', 'a@32')) => ('uge', ('u2u32', 'b'), 'a')
 *    ('ult', ('u2u64', 'b@32'), ('u2u64', 'a@32')) => ('ult', ('u2u32', 'b'), 'a')
 *    ('ieq', ('u2u64', 'a@32'), '#b') => ('iand', ('ieq', 'a', ('u2u32', 'b')), ('ieq', ('u2u64', ('u2u32', 'b')), 'b'))
 *    ('ine', ('u2u64', 'a@32'), '#b') => ('ior', ('ine', 'a', ('u2u32', 'b')), ('ine', ('u2u64', ('u2u32', 'b')), 'b'))
 *    ('ult', ('u2u64', 'a@32'), '#b') => ('iand', ('ult', 0, 'b'), ('ior', ('ult', 4294967295, 'b'), ('ult', 'a', ('u2u32', 'b'))))
 *    ('ult', '#a', ('u2u64', 'b@32')) => ('iand', ('ult', 'a', 4294967295), ('ior', ('ult', 'a', 0), ('ult', ('u2u32', 'a'), 'b')))
 *    ('uge', ('u2u64', 'a@32'), '#b') => ('iand', ('uge', 4294967295, 'b'), ('ior', ('uge', 0, 'b'), ('uge', 'a', ('u2u32', 'b'))))
 *    ('uge', '#a', ('u2u64', 'b@32')) => ('iand', ('uge', 'a', 0), ('ior', ('uge', 'a', 4294967295), ('uge', ('u2u32', 'a'), 'b')))
 *    ('feq', ('f2f32', 'a@16'), ('f2f32', 'b@16')) => ('feq', 'a', ('f2f16', 'b'))
 *    ('fneu', ('f2f32', 'a@16'), ('f2f32', 'b@16')) => ('fneu', 'a', ('f2f16', 'b'))
 *    ('fge', ('f2f32', 'a@16'), ('f2f32', 'b@16')) => ('fge', 'a', ('f2f16', 'b'))
 *    ('flt', ('f2f32', 'a@16'), ('f2f32', 'b@16')) => ('flt', 'a', ('f2f16', 'b'))
 *    ('fge', ('f2f32', 'b@16'), ('f2f32', 'a@16')) => ('fge', ('f2f16', 'b'), 'a')
 *    ('flt', ('f2f32', 'b@16'), ('f2f32', 'a@16')) => ('flt', ('f2f16', 'b'), 'a')
 *    ('feq', ('f2f64', 'a@16'), ('f2f64', 'b@16')) => ('feq', 'a', ('f2f16', 'b'))
 *    ('fneu', ('f2f64', 'a@16'), ('f2f64', 'b@16')) => ('fneu', 'a', ('f2f16', 'b'))
 *    ('fge', ('f2f64', 'a@16'), ('f2f64', 'b@16')) => ('fge', 'a', ('f2f16', 'b'))
 *    ('flt', ('f2f64', 'a@16'), ('f2f64', 'b@16')) => ('flt', 'a', ('f2f16', 'b'))
 *    ('fge', ('f2f64', 'b@16'), ('f2f64', 'a@16')) => ('fge', ('f2f16', 'b'), 'a')
 *    ('flt', ('f2f64', 'b@16'), ('f2f64', 'a@16')) => ('flt', ('f2f16', 'b'), 'a')
 *    ('feq', ('f2f64', 'a@32'), ('f2f64', 'b@16')) => ('feq', 'a', ('f2f32', 'b'))
 *    ('fneu', ('f2f64', 'a@32'), ('f2f64', 'b@16')) => ('fneu', 'a', ('f2f32', 'b'))
 *    ('fge', ('f2f64', 'a@32'), ('f2f64', 'b@16')) => ('fge', 'a', ('f2f32', 'b'))
 *    ('flt', ('f2f64', 'a@32'), ('f2f64', 'b@16')) => ('flt', 'a', ('f2f32', 'b'))
 *    ('fge', ('f2f64', 'b@16'), ('f2f64', 'a@32')) => ('fge', ('f2f32', 'b'), 'a')
 *    ('flt', ('f2f64', 'b@16'), ('f2f64', 'a@32')) => ('flt', ('f2f32', 'b'), 'a')
 *    ('feq', ('f2f64', 'a@32'), ('f2f64', 'b@32')) => ('feq', 'a', ('f2f32', 'b'))
 *    ('fneu', ('f2f64', 'a@32'), ('f2f64', 'b@32')) => ('fneu', 'a', ('f2f32', 'b'))
 *    ('fge', ('f2f64', 'a@32'), ('f2f64', 'b@32')) => ('fge', 'a', ('f2f32', 'b'))
 *    ('flt', ('f2f64', 'a@32'), ('f2f64', 'b@32')) => ('flt', 'a', ('f2f32', 'b'))
 *    ('fge', ('f2f64', 'b@32'), ('f2f64', 'a@32')) => ('fge', ('f2f32', 'b'), 'a')
 *    ('flt', ('f2f64', 'b@32'), ('f2f64', 'a@32')) => ('flt', ('f2f32', 'b'), 'a')
 *    ('i2i32', ('iand', 'a@64', 4294967295)) => ('u2u32', 'a')
 *    ('i2i16', ('iand', 'a@32', 65535)) => ('u2u16', 'a')
 *    ('i2i16', ('iand', 'a@64', 65535)) => ('u2u16', 'a')
 *    ('i2i8', ('iand', 'a@16', 255)) => ('u2u8', 'a')
 *    ('i2i8', ('iand', 'a@32', 255)) => ('u2u8', 'a')
 *    ('i2i8', ('iand', 'a@64', 255)) => ('u2u8', 'a')
 *    ('u2u16(only_lower_8_bits_used)', ('u2u8', 'a@16')) => a
 *    ('extract_u8(only_lower_8_bits_used)', 'a@16', 0) => a
 *    ('bcsel(only_lower_8_bits_used)', 'c', ('u2u16', ('u2u8', 'a@16')), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('bcsel(only_lower_8_bits_used)', 'c', ('u2u16', ('i2i8', 'a@16')), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('bcsel(only_lower_8_bits_used)', 'c', ('extract_u8', 'a@16', 0), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('iadd(only_lower_8_bits_used)', ('u2u16', ('u2u8', 'a@16')), 'b') => ('iadd', 'a', 'b')
 *    ('iadd(only_lower_8_bits_used)', ('u2u16', ('i2i8', 'a@16')), 'b') => ('iadd', 'a', 'b')
 *    ('iadd(only_lower_8_bits_used)', ('extract_u8', 'a@16', 0), 'b') => ('iadd', 'a', 'b')
 *    ('imul(only_lower_8_bits_used)', ('u2u16', ('u2u8', 'a@16')), 'b') => ('imul', 'a', 'b')
 *    ('imul(only_lower_8_bits_used)', ('u2u16', ('i2i8', 'a@16')), 'b') => ('imul', 'a', 'b')
 *    ('imul(only_lower_8_bits_used)', ('extract_u8', 'a@16', 0), 'b') => ('imul', 'a', 'b')
 *    ('iand(only_lower_8_bits_used)', ('u2u16', ('u2u8', 'a@16')), 'b') => ('iand', 'a', 'b')
 *    ('iand(only_lower_8_bits_used)', ('u2u16', ('i2i8', 'a@16')), 'b') => ('iand', 'a', 'b')
 *    ('iand(only_lower_8_bits_used)', ('extract_u8', 'a@16', 0), 'b') => ('iand', 'a', 'b')
 *    ('ior(only_lower_8_bits_used)', ('u2u16', ('u2u8', 'a@16')), 'b') => ('ior', 'a', 'b')
 *    ('ior(only_lower_8_bits_used)', ('u2u16', ('i2i8', 'a@16')), 'b') => ('ior', 'a', 'b')
 *    ('ior(only_lower_8_bits_used)', ('extract_u8', 'a@16', 0), 'b') => ('ior', 'a', 'b')
 *    ('ixor(only_lower_8_bits_used)', ('u2u16', ('u2u8', 'a@16')), 'b') => ('ixor', 'a', 'b')
 *    ('ixor(only_lower_8_bits_used)', ('u2u16', ('i2i8', 'a@16')), 'b') => ('ixor', 'a', 'b')
 *    ('ixor(only_lower_8_bits_used)', ('extract_u8', 'a@16', 0), 'b') => ('ixor', 'a', 'b')
 *    ('i2i16(only_lower_8_bits_used)', ('u2u8', 'a@16')) => a
 *    ('extract_i8(only_lower_8_bits_used)', 'a@16', 0) => a
 *    ('bcsel(only_lower_8_bits_used)', 'c', ('i2i16', ('u2u8', 'a@16')), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('bcsel(only_lower_8_bits_used)', 'c', ('i2i16', ('i2i8', 'a@16')), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('bcsel(only_lower_8_bits_used)', 'c', ('extract_i8', 'a@16', 0), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('iadd(only_lower_8_bits_used)', ('i2i16', ('u2u8', 'a@16')), 'b') => ('iadd', 'a', 'b')
 *    ('iadd(only_lower_8_bits_used)', ('i2i16', ('i2i8', 'a@16')), 'b') => ('iadd', 'a', 'b')
 *    ('iadd(only_lower_8_bits_used)', ('extract_i8', 'a@16', 0), 'b') => ('iadd', 'a', 'b')
 *    ('imul(only_lower_8_bits_used)', ('i2i16', ('u2u8', 'a@16')), 'b') => ('imul', 'a', 'b')
 *    ('imul(only_lower_8_bits_used)', ('i2i16', ('i2i8', 'a@16')), 'b') => ('imul', 'a', 'b')
 *    ('imul(only_lower_8_bits_used)', ('extract_i8', 'a@16', 0), 'b') => ('imul', 'a', 'b')
 *    ('iand(only_lower_8_bits_used)', ('i2i16', ('u2u8', 'a@16')), 'b') => ('iand', 'a', 'b')
 *    ('iand(only_lower_8_bits_used)', ('i2i16', ('i2i8', 'a@16')), 'b') => ('iand', 'a', 'b')
 *    ('iand(only_lower_8_bits_used)', ('extract_i8', 'a@16', 0), 'b') => ('iand', 'a', 'b')
 *    ('ior(only_lower_8_bits_used)', ('i2i16', ('u2u8', 'a@16')), 'b') => ('ior', 'a', 'b')
 *    ('ior(only_lower_8_bits_used)', ('i2i16', ('i2i8', 'a@16')), 'b') => ('ior', 'a', 'b')
 *    ('ior(only_lower_8_bits_used)', ('extract_i8', 'a@16', 0), 'b') => ('ior', 'a', 'b')
 *    ('ixor(only_lower_8_bits_used)', ('i2i16', ('u2u8', 'a@16')), 'b') => ('ixor', 'a', 'b')
 *    ('ixor(only_lower_8_bits_used)', ('i2i16', ('i2i8', 'a@16')), 'b') => ('ixor', 'a', 'b')
 *    ('ixor(only_lower_8_bits_used)', ('extract_i8', 'a@16', 0), 'b') => ('ixor', 'a', 'b')
 *    ('u2u32(only_lower_8_bits_used)', ('u2u8', 'a@32')) => a
 *    ('extract_u8(only_lower_8_bits_used)', 'a@32', 0) => a
 *    ('bcsel(only_lower_8_bits_used)', 'c', ('u2u32', ('u2u8', 'a@32')), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('bcsel(only_lower_8_bits_used)', 'c', ('u2u32', ('i2i8', 'a@32')), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('bcsel(only_lower_8_bits_used)', 'c', ('extract_u8', 'a@32', 0), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('iadd(only_lower_8_bits_used)', ('u2u32', ('u2u8', 'a@32')), 'b') => ('iadd', 'a', 'b')
 *    ('iadd(only_lower_8_bits_used)', ('u2u32', ('i2i8', 'a@32')), 'b') => ('iadd', 'a', 'b')
 *    ('iadd(only_lower_8_bits_used)', ('extract_u8', 'a@32', 0), 'b') => ('iadd', 'a', 'b')
 *    ('imul(only_lower_8_bits_used)', ('u2u32', ('u2u8', 'a@32')), 'b') => ('imul', 'a', 'b')
 *    ('imul(only_lower_8_bits_used)', ('u2u32', ('i2i8', 'a@32')), 'b') => ('imul', 'a', 'b')
 *    ('imul(only_lower_8_bits_used)', ('extract_u8', 'a@32', 0), 'b') => ('imul', 'a', 'b')
 *    ('iand(only_lower_8_bits_used)', ('u2u32', ('u2u8', 'a@32')), 'b') => ('iand', 'a', 'b')
 *    ('iand(only_lower_8_bits_used)', ('u2u32', ('i2i8', 'a@32')), 'b') => ('iand', 'a', 'b')
 *    ('iand(only_lower_8_bits_used)', ('extract_u8', 'a@32', 0), 'b') => ('iand', 'a', 'b')
 *    ('ior(only_lower_8_bits_used)', ('u2u32', ('u2u8', 'a@32')), 'b') => ('ior', 'a', 'b')
 *    ('ior(only_lower_8_bits_used)', ('u2u32', ('i2i8', 'a@32')), 'b') => ('ior', 'a', 'b')
 *    ('ior(only_lower_8_bits_used)', ('extract_u8', 'a@32', 0), 'b') => ('ior', 'a', 'b')
 *    ('ixor(only_lower_8_bits_used)', ('u2u32', ('u2u8', 'a@32')), 'b') => ('ixor', 'a', 'b')
 *    ('ixor(only_lower_8_bits_used)', ('u2u32', ('i2i8', 'a@32')), 'b') => ('ixor', 'a', 'b')
 *    ('ixor(only_lower_8_bits_used)', ('extract_u8', 'a@32', 0), 'b') => ('ixor', 'a', 'b')
 *    ('i2i32(only_lower_8_bits_used)', ('u2u8', 'a@32')) => a
 *    ('extract_i8(only_lower_8_bits_used)', 'a@32', 0) => a
 *    ('bcsel(only_lower_8_bits_used)', 'c', ('i2i32', ('u2u8', 'a@32')), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('bcsel(only_lower_8_bits_used)', 'c', ('i2i32', ('i2i8', 'a@32')), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('bcsel(only_lower_8_bits_used)', 'c', ('extract_i8', 'a@32', 0), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('iadd(only_lower_8_bits_used)', ('i2i32', ('u2u8', 'a@32')), 'b') => ('iadd', 'a', 'b')
 *    ('iadd(only_lower_8_bits_used)', ('i2i32', ('i2i8', 'a@32')), 'b') => ('iadd', 'a', 'b')
 *    ('iadd(only_lower_8_bits_used)', ('extract_i8', 'a@32', 0), 'b') => ('iadd', 'a', 'b')
 *    ('imul(only_lower_8_bits_used)', ('i2i32', ('u2u8', 'a@32')), 'b') => ('imul', 'a', 'b')
 *    ('imul(only_lower_8_bits_used)', ('i2i32', ('i2i8', 'a@32')), 'b') => ('imul', 'a', 'b')
 *    ('imul(only_lower_8_bits_used)', ('extract_i8', 'a@32', 0), 'b') => ('imul', 'a', 'b')
 *    ('iand(only_lower_8_bits_used)', ('i2i32', ('u2u8', 'a@32')), 'b') => ('iand', 'a', 'b')
 *    ('iand(only_lower_8_bits_used)', ('i2i32', ('i2i8', 'a@32')), 'b') => ('iand', 'a', 'b')
 *    ('iand(only_lower_8_bits_used)', ('extract_i8', 'a@32', 0), 'b') => ('iand', 'a', 'b')
 *    ('ior(only_lower_8_bits_used)', ('i2i32', ('u2u8', 'a@32')), 'b') => ('ior', 'a', 'b')
 *    ('ior(only_lower_8_bits_used)', ('i2i32', ('i2i8', 'a@32')), 'b') => ('ior', 'a', 'b')
 *    ('ior(only_lower_8_bits_used)', ('extract_i8', 'a@32', 0), 'b') => ('ior', 'a', 'b')
 *    ('ixor(only_lower_8_bits_used)', ('i2i32', ('u2u8', 'a@32')), 'b') => ('ixor', 'a', 'b')
 *    ('ixor(only_lower_8_bits_used)', ('i2i32', ('i2i8', 'a@32')), 'b') => ('ixor', 'a', 'b')
 *    ('ixor(only_lower_8_bits_used)', ('extract_i8', 'a@32', 0), 'b') => ('ixor', 'a', 'b')
 *    ('u2u32(only_lower_16_bits_used)', ('u2u16', 'a@32')) => a
 *    ('extract_u16(only_lower_16_bits_used)', 'a@32', 0) => a
 *    ('bcsel(only_lower_16_bits_used)', 'c', ('u2u32', ('u2u16', 'a@32')), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('bcsel(only_lower_16_bits_used)', 'c', ('u2u32', ('i2i16', 'a@32')), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('bcsel(only_lower_16_bits_used)', 'c', ('extract_u16', 'a@32', 0), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('iadd(only_lower_16_bits_used)', ('u2u32', ('u2u16', 'a@32')), 'b') => ('iadd', 'a', 'b')
 *    ('iadd(only_lower_16_bits_used)', ('u2u32', ('i2i16', 'a@32')), 'b') => ('iadd', 'a', 'b')
 *    ('iadd(only_lower_16_bits_used)', ('extract_u16', 'a@32', 0), 'b') => ('iadd', 'a', 'b')
 *    ('imul(only_lower_16_bits_used)', ('u2u32', ('u2u16', 'a@32')), 'b') => ('imul', 'a', 'b')
 *    ('imul(only_lower_16_bits_used)', ('u2u32', ('i2i16', 'a@32')), 'b') => ('imul', 'a', 'b')
 *    ('imul(only_lower_16_bits_used)', ('extract_u16', 'a@32', 0), 'b') => ('imul', 'a', 'b')
 *    ('iand(only_lower_16_bits_used)', ('u2u32', ('u2u16', 'a@32')), 'b') => ('iand', 'a', 'b')
 *    ('iand(only_lower_16_bits_used)', ('u2u32', ('i2i16', 'a@32')), 'b') => ('iand', 'a', 'b')
 *    ('iand(only_lower_16_bits_used)', ('extract_u16', 'a@32', 0), 'b') => ('iand', 'a', 'b')
 *    ('ior(only_lower_16_bits_used)', ('u2u32', ('u2u16', 'a@32')), 'b') => ('ior', 'a', 'b')
 *    ('ior(only_lower_16_bits_used)', ('u2u32', ('i2i16', 'a@32')), 'b') => ('ior', 'a', 'b')
 *    ('ior(only_lower_16_bits_used)', ('extract_u16', 'a@32', 0), 'b') => ('ior', 'a', 'b')
 *    ('ixor(only_lower_16_bits_used)', ('u2u32', ('u2u16', 'a@32')), 'b') => ('ixor', 'a', 'b')
 *    ('ixor(only_lower_16_bits_used)', ('u2u32', ('i2i16', 'a@32')), 'b') => ('ixor', 'a', 'b')
 *    ('ixor(only_lower_16_bits_used)', ('extract_u16', 'a@32', 0), 'b') => ('ixor', 'a', 'b')
 *    ('i2i32(only_lower_16_bits_used)', ('u2u16', 'a@32')) => a
 *    ('extract_i16(only_lower_16_bits_used)', 'a@32', 0) => a
 *    ('bcsel(only_lower_16_bits_used)', 'c', ('i2i32', ('u2u16', 'a@32')), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('bcsel(only_lower_16_bits_used)', 'c', ('i2i32', ('i2i16', 'a@32')), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('bcsel(only_lower_16_bits_used)', 'c', ('extract_i16', 'a@32', 0), 'b') => ('bcsel', 'c', 'a', 'b')
 *    ('iadd(only_lower_16_bits_used)', ('i2i32', ('u2u16', 'a@32')), 'b') => ('iadd', 'a', 'b')
 *    ('iadd(only_lower_16_bits_used)', ('i2i32', ('i2i16', 'a@32')), 'b') => ('iadd', 'a', 'b')
 *    ('iadd(only_lower_16_bits_used)', ('extract_i16', 'a@32', 0), 'b') => ('iadd', 'a', 'b')
 *    ('imul(only_lower_16_bits_used)', ('i2i32', ('u2u16', 'a@32')), 'b') => ('imul', 'a', 'b')
 *    ('imul(only_lower_16_bits_used)', ('i2i32', ('i2i16', 'a@32')), 'b') => ('imul', 'a', 'b')
 *    ('imul(only_lower_16_bits_used)', ('extract_i16', 'a@32', 0), 'b') => ('imul', 'a', 'b')
 *    ('iand(only_lower_16_bits_used)', ('i2i32', ('u2u16', 'a@32')), 'b') => ('iand', 'a', 'b')
 *    ('iand(only_lower_16_bits_used)', ('i2i32', ('i2i16', 'a@32')), 'b') => ('iand', 'a', 'b')
 *    ('iand(only_lower_16_bits_used)', ('extract_i16', 'a@32', 0), 'b') => ('iand', 'a', 'b')
 *    ('ior(only_lower_16_bits_used)', ('i2i32', ('u2u16', 'a@32')), 'b') => ('ior', 'a', 'b')
 *    ('ior(only_lower_16_bits_used)', ('i2i32', ('i2i16', 'a@32')), 'b') => ('ior', 'a', 'b')
 *    ('ior(only_lower_16_bits_used)', ('extract_i16', 'a@32', 0), 'b') => ('ior', 'a', 'b')
 *    ('ixor(only_lower_16_bits_used)', ('i2i32', ('u2u16', 'a@32')), 'b') => ('ixor', 'a', 'b')
 *    ('ixor(only_lower_16_bits_used)', ('i2i32', ('i2i16', 'a@32')), 'b') => ('ixor', 'a', 'b')
 *    ('ixor(only_lower_16_bits_used)', ('extract_i16', 'a@32', 0), 'b') => ('ixor', 'a', 'b')
 *    ('ldexp@16', 'x', 'exp') => ('fmul', ('fmul', 'x', ('i2i16', ('ishl', ('iadd', ('ishr', ('imin', ('imax', 'exp', -30), 30), 1), 15), 10))), ('i2i16', ('ishl', ('iadd', ('isub', ('imin', ('imax', 'exp', -30), 30), ('ishr', ('imin', ('imax', 'exp', -30), 30), 1)), 15), 10)))
 *    ('ldexp@32', 'x', 'exp') => ('fmul', ('fmul', 'x', ('ishl', ('iadd', ('ishr', ('imin', ('imax', 'exp', -254), 254), 1), 127), 23)), ('ishl', ('iadd', ('isub', ('imin', ('imax', 'exp', -254), 254), ('ishr', ('imin', ('imax', 'exp', -254), 254), 1)), 127), 23))
 *    ('ldexp@64', 'x', 'exp') => ('fmul', ('fmul', 'x', ('pack_64_2x32_split', 0, ('ishl', ('iadd', ('ishr', ('imin', ('imax', 'exp', -2046), 2046), 1), 1023), 20))), ('pack_64_2x32_split', 0, ('ishl', ('iadd', ('isub', ('imin', ('imax', 'exp', -2046), 2046), ('ishr', ('imin', ('imax', 'exp', -2046), 2046), 1)), 1023), 20)))
 *    ('ior(many-comm-expr)', ('ishl', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 16711935), 8), ('ushr', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 4278255360), 8)), 252645135), 4), ('ushr', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 16711935), 8), ('ushr', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 4278255360), 8)), 4042322160), 4)), 858993459), 2), ('ushr', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 16711935), 8), ('ushr', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 4278255360), 8)), 252645135), 4), ('ushr', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 16711935), 8), ('ushr', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 4278255360), 8)), 4042322160), 4)), 3435973836), 2)), 1431655765), 1), ('ushr', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 16711935), 8), ('ushr', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 4278255360), 8)), 252645135), 4), ('ushr', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 16711935), 8), ('ushr', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 4278255360), 8)), 4042322160), 4)), 858993459), 2), ('ushr', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 16711935), 8), ('ushr', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 4278255360), 8)), 252645135), 4), ('ushr', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 16711935), 8), ('ushr', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 4278255360), 8)), 4042322160), 4)), 3435973836), 2)), 2863311530), 1)) => ('bitfield_reverse', 'x')
 *    ('ior(many-comm-expr)', ('iand', ('ishl', ('ior', ('iand', ('ishl', ('ior', ('iand', ('ishl', ('ior', ('iand', ('ishl', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 2863311530), ('iand', ('ushr', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 1431655765)), 2), 3435973836), ('iand', ('ushr', ('ior', ('iand', ('ishl', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 2863311530), ('iand', ('ushr', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 1431655765)), 2), 858993459)), 4), 4042322160), ('iand', ('ushr', ('ior', ('iand', ('ishl', ('ior', ('iand', ('ishl', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 2863311530), ('iand', ('ushr', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 1431655765)), 2), 3435973836), ('iand', ('ushr', ('ior', ('iand', ('ishl', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 2863311530), ('iand', ('ushr', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 1431655765)), 2), 858993459)), 4), 252645135)), 8), 4278255360), ('iand', ('ushr', ('ior', ('iand', ('ishl', ('ior', ('iand', ('ishl', ('ior', ('iand', ('ishl', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 2863311530), ('iand', ('ushr', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 1431655765)), 2), 3435973836), ('iand', ('ushr', ('ior', ('iand', ('ishl', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 2863311530), ('iand', ('ushr', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 1431655765)), 2), 858993459)), 4), 4042322160), ('iand', ('ushr', ('ior', ('iand', ('ishl', ('ior', ('iand', ('ishl', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 2863311530), ('iand', ('ushr', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 1431655765)), 2), 3435973836), ('iand', ('ushr', ('ior', ('iand', ('ishl', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 2863311530), ('iand', ('ushr', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 1431655765)), 2), 858993459)), 4), 252645135)), 8), 16711935)) => ('bitfield_reverse', 'x')
 *    ('ball_iequal2', ('ieq', 'a', 'b'), -1) => ('ball_iequal2', 'a', 'b')
 *    ('ball_iequal2', ('feq', 'a', 'b'), -1) => ('ball_fequal2', 'a', 'b')
 *    ('bany_inequal2', ('ine', 'a', 'b'), 0) => ('bany_inequal2', 'a', 'b')
 *    ('bany_inequal2', ('fneu', 'a', 'b'), 0) => ('bany_fnequal2', 'a', 'b')
 *    ('ball_iequal3', ('ieq', 'a', 'b'), -1) => ('ball_iequal3', 'a', 'b')
 *    ('ball_iequal3', ('feq', 'a', 'b'), -1) => ('ball_fequal3', 'a', 'b')
 *    ('bany_inequal3', ('ine', 'a', 'b'), 0) => ('bany_inequal3', 'a', 'b')
 *    ('bany_inequal3', ('fneu', 'a', 'b'), 0) => ('bany_fnequal3', 'a', 'b')
 *    ('ball_iequal4', ('ieq', 'a', 'b'), -1) => ('ball_iequal4', 'a', 'b')
 *    ('ball_iequal4', ('feq', 'a', 'b'), -1) => ('ball_fequal4', 'a', 'b')
 *    ('bany_inequal4', ('ine', 'a', 'b'), 0) => ('bany_inequal4', 'a', 'b')
 *    ('bany_inequal4', ('fneu', 'a', 'b'), 0) => ('bany_fnequal4', 'a', 'b')
 *    ('ball_iequal8', ('ieq', 'a', 'b'), -1) => ('ball_iequal8', 'a', 'b')
 *    ('ball_iequal8', ('feq', 'a', 'b'), -1) => ('ball_fequal8', 'a', 'b')
 *    ('bany_inequal8', ('ine', 'a', 'b'), 0) => ('bany_inequal8', 'a', 'b')
 *    ('bany_inequal8', ('fneu', 'a', 'b'), 0) => ('bany_fnequal8', 'a', 'b')
 *    ('ball_iequal16', ('ieq', 'a', 'b'), -1) => ('ball_iequal16', 'a', 'b')
 *    ('ball_iequal16', ('feq', 'a', 'b'), -1) => ('ball_fequal16', 'a', 'b')
 *    ('bany_inequal16', ('ine', 'a', 'b'), 0) => ('bany_inequal16', 'a', 'b')
 *    ('bany_inequal16', ('fneu', 'a', 'b'), 0) => ('bany_fnequal16', 'a', 'b')
 *    ('iand', ('feq', 'a', 'a'), ('flt', 'a', 'b')) => ('!flt', 'a', 'b')
 *    ('iand', ('feq', 'a', 'a'), ('flt', 'b', 'a')) => ('!flt', 'b', 'a')
 *    ('iand', ('feq', 'a', 'a'), ('fge', 'a', 'b')) => ('!fge', 'a', 'b')
 *    ('iand', ('feq', 'a', 'a'), ('fge', 'b', 'a')) => ('!fge', 'b', 'a')
 *    ('iand', ('feq', 'a', 'a'), ('feq', 'a', 'b')) => ('!feq', 'a', 'b')
 *    ('iand', ('feq', 'a', 'a'), ('feq', 'b', 'a')) => ('!feq', 'b', 'a')
 *    ('feq', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('feq', 'b', 'd'), ('feq', 'c', 'd'))
 *    ('fneu', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('fneu', 'b', 'd'), ('fneu', 'c', 'd'))
 *    ('ieq', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('ieq', 'b', 'd'), ('ieq', 'c', 'd'))
 *    ('ine', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('ine', 'b', 'd'), ('ine', 'c', 'd'))
 *    ('flt', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('flt', 'b', 'd'), ('flt', 'c', 'd'))
 *    ('flt', '#d', ('bcsel', 'a', '#b', '#c')) => ('bcsel', 'a', ('flt', 'd', 'b'), ('flt', 'd', 'c'))
 *    ('fge', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('fge', 'b', 'd'), ('fge', 'c', 'd'))
 *    ('fge', '#d', ('bcsel', 'a', '#b', '#c')) => ('bcsel', 'a', ('fge', 'd', 'b'), ('fge', 'd', 'c'))
 *    ('ilt', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('ilt', 'b', 'd'), ('ilt', 'c', 'd'))
 *    ('ilt', '#d', ('bcsel', 'a', '#b', '#c')) => ('bcsel', 'a', ('ilt', 'd', 'b'), ('ilt', 'd', 'c'))
 *    ('ige', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('ige', 'b', 'd'), ('ige', 'c', 'd'))
 *    ('ige', '#d', ('bcsel', 'a', '#b', '#c')) => ('bcsel', 'a', ('ige', 'd', 'b'), ('ige', 'd', 'c'))
 *    ('ult', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('ult', 'b', 'd'), ('ult', 'c', 'd'))
 *    ('ult', '#d', ('bcsel', 'a', '#b', '#c')) => ('bcsel', 'a', ('ult', 'd', 'b'), ('ult', 'd', 'c'))
 *    ('uge', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('uge', 'b', 'd'), ('uge', 'c', 'd'))
 *    ('uge', '#d', ('bcsel', 'a', '#b', '#c')) => ('bcsel', 'a', ('uge', 'd', 'b'), ('uge', 'd', 'c'))
 *    ('fadd', ('bcsel(is_used_once)', 'a', '#b', 'c'), '#d') => ('bcsel', 'a', ('fadd', 'b', 'd'), ('fadd', 'c', 'd'))
 *    ('fmul', ('bcsel(is_used_once)', 'a', '#b', 'c'), '#d') => ('bcsel', 'a', ('fmul', 'b', 'd'), ('fmul', 'c', 'd'))
 *    ('fmulz', ('bcsel(is_used_once)', 'a', '#b', 'c'), '#d') => ('bcsel', 'a', ('fmulz', 'b', 'd'), ('fmulz', 'c', 'd'))
 *    ('iadd', ('bcsel(is_used_once)', 'a', '#b', 'c'), '#d') => ('bcsel', 'a', ('iadd', 'b', 'd'), ('iadd', 'c', 'd'))
 *    ('imul', ('bcsel(is_used_once)', 'a', '#b', 'c'), '#d') => ('bcsel', 'a', ('imul', 'b', 'd'), ('imul', 'c', 'd'))
 *    ('fddx', 'a') => 0.0
 *    ('fddx_fine', 'a') => 0.0
 *    ('fddx_coarse', 'a') => 0.0
 *    ('fddy', 'a') => 0.0
 *    ('fddy_fine', 'a') => 0.0
 *    ('fddy_coarse', 'a') => 0.0
 *    ('umul_low', '#a(is_lower_half_zero)', 'b') => 0
 *    ('imadsh_mix16', '#a@32(is_lower_half_zero)', 'b@32', 'c@32') => c
 *    ('imadsh_mix16', 'a@32', '#b@32(is_upper_half_zero)', 'c@32') => c
 *    ('bcsel', 'a', ('flrp(is_used_once)', 'b', 'c', 'd'), ('flrp', 'b', 'c', 'e')) => ('flrp', 'b', 'c', ('bcsel', 'a', 'd', 'e'))
 *    ('bcsel', 'a', ('flrp', 'b', 'c', 'd'), ('flrp(is_used_once)', 'b', 'c', 'e')) => ('flrp', 'b', 'c', ('bcsel', 'a', 'd', 'e'))
 *    ('bcsel', 'a', ('flrp(is_used_once)', 'b', 'c', 'd'), ('flrp', 'b', 'e', 'd')) => ('flrp', 'b', ('bcsel', 'a', 'c', 'e'), 'd')
 *    ('bcsel', 'a', ('flrp', 'b', 'c', 'd'), ('flrp(is_used_once)', 'b', 'e', 'd')) => ('flrp', 'b', ('bcsel', 'a', 'c', 'e'), 'd')
 *    ('bcsel', 'a', ('flrp(is_used_once)', 'b', 'c', 'd'), ('flrp', 'e', 'c', 'd')) => ('flrp', ('bcsel', 'a', 'b', 'e'), 'c', 'd')
 *    ('bcsel', 'a', ('flrp', 'b', 'c', 'd'), ('flrp(is_used_once)', 'e', 'c', 'd')) => ('flrp', ('bcsel', 'a', 'b', 'e'), 'c', 'd')
 *    ('bcsel', 'a', ('fmulz(is_used_once)', 'b', 'c'), ('fmulz', 'b', 'd(is_not_const)')) => ('fmulz', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fmulz(is_used_once)', 'b', 'c(is_not_const)'), ('fmulz', 'b', 'd')) => ('fmulz', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fmulz', 'b', 'c(is_not_const)'), ('fmulz(is_used_once)', 'b', 'd')) => ('fmulz', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fmulz', 'b', 'c'), ('fmulz(is_used_once)', 'b', 'd(is_not_const)')) => ('fmulz', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fmul(is_used_once)', 'b', 'c'), ('fmul', 'b', 'd(is_not_const)')) => ('fmul', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fmul(is_used_once)', 'b', 'c(is_not_const)'), ('fmul', 'b', 'd')) => ('fmul', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fmul', 'b', 'c(is_not_const)'), ('fmul(is_used_once)', 'b', 'd')) => ('fmul', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fmul', 'b', 'c'), ('fmul(is_used_once)', 'b', 'd(is_not_const)')) => ('fmul', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('iadd(is_used_once)', 'b', 'c'), ('iadd', 'b', 'd(is_not_const)')) => ('iadd', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('iadd(is_used_once)', 'b', 'c(is_not_const)'), ('iadd', 'b', 'd')) => ('iadd', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('iadd', 'b', 'c(is_not_const)'), ('iadd(is_used_once)', 'b', 'd')) => ('iadd', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('iadd', 'b', 'c'), ('iadd(is_used_once)', 'b', 'd(is_not_const)')) => ('iadd', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('imul(is_used_once)', 'b', 'c'), ('imul', 'b', 'd(is_not_const)')) => ('imul', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('imul(is_used_once)', 'b', 'c(is_not_const)'), ('imul', 'b', 'd')) => ('imul', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('imul', 'b', 'c(is_not_const)'), ('imul(is_used_once)', 'b', 'd')) => ('imul', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('imul', 'b', 'c'), ('imul(is_used_once)', 'b', 'd(is_not_const)')) => ('imul', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('iand(is_used_once)', 'b', 'c'), ('iand', 'b', 'd(is_not_const)')) => ('iand', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('iand(is_used_once)', 'b', 'c(is_not_const)'), ('iand', 'b', 'd')) => ('iand', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('iand', 'b', 'c(is_not_const)'), ('iand(is_used_once)', 'b', 'd')) => ('iand', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('iand', 'b', 'c'), ('iand(is_used_once)', 'b', 'd(is_not_const)')) => ('iand', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('ior(is_used_once)', 'b', 'c'), ('ior', 'b', 'd(is_not_const)')) => ('ior', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('ior(is_used_once)', 'b', 'c(is_not_const)'), ('ior', 'b', 'd')) => ('ior', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('ior', 'b', 'c(is_not_const)'), ('ior(is_used_once)', 'b', 'd')) => ('ior', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('ior', 'b', 'c'), ('ior(is_used_once)', 'b', 'd(is_not_const)')) => ('ior', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('ixor(is_used_once)', 'b', 'c'), ('ixor', 'b', 'd(is_not_const)')) => ('ixor', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('ixor(is_used_once)', 'b', 'c(is_not_const)'), ('ixor', 'b', 'd')) => ('ixor', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('ixor', 'b', 'c(is_not_const)'), ('ixor(is_used_once)', 'b', 'd')) => ('ixor', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('ixor', 'b', 'c'), ('ixor(is_used_once)', 'b', 'd(is_not_const)')) => ('ixor', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fmin(is_used_once)', 'b', 'c'), ('fmin', 'b', 'd(is_not_const)')) => ('fmin', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fmin(is_used_once)', 'b', 'c(is_not_const)'), ('fmin', 'b', 'd')) => ('fmin', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fmin', 'b', 'c(is_not_const)'), ('fmin(is_used_once)', 'b', 'd')) => ('fmin', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fmin', 'b', 'c'), ('fmin(is_used_once)', 'b', 'd(is_not_const)')) => ('fmin', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fmax(is_used_once)', 'b', 'c'), ('fmax', 'b', 'd(is_not_const)')) => ('fmax', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fmax(is_used_once)', 'b', 'c(is_not_const)'), ('fmax', 'b', 'd')) => ('fmax', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fmax', 'b', 'c(is_not_const)'), ('fmax(is_used_once)', 'b', 'd')) => ('fmax', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fmax', 'b', 'c'), ('fmax(is_used_once)', 'b', 'd(is_not_const)')) => ('fmax', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('imin(is_used_once)', 'b', 'c'), ('imin', 'b', 'd(is_not_const)')) => ('imin', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('imin(is_used_once)', 'b', 'c(is_not_const)'), ('imin', 'b', 'd')) => ('imin', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('imin', 'b', 'c(is_not_const)'), ('imin(is_used_once)', 'b', 'd')) => ('imin', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('imin', 'b', 'c'), ('imin(is_used_once)', 'b', 'd(is_not_const)')) => ('imin', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('imax(is_used_once)', 'b', 'c'), ('imax', 'b', 'd(is_not_const)')) => ('imax', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('imax(is_used_once)', 'b', 'c(is_not_const)'), ('imax', 'b', 'd')) => ('imax', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('imax', 'b', 'c(is_not_const)'), ('imax(is_used_once)', 'b', 'd')) => ('imax', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('imax', 'b', 'c'), ('imax(is_used_once)', 'b', 'd(is_not_const)')) => ('imax', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('umin(is_used_once)', 'b', 'c'), ('umin', 'b', 'd(is_not_const)')) => ('umin', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('umin(is_used_once)', 'b', 'c(is_not_const)'), ('umin', 'b', 'd')) => ('umin', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('umin', 'b', 'c(is_not_const)'), ('umin(is_used_once)', 'b', 'd')) => ('umin', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('umin', 'b', 'c'), ('umin(is_used_once)', 'b', 'd(is_not_const)')) => ('umin', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('umax(is_used_once)', 'b', 'c'), ('umax', 'b', 'd(is_not_const)')) => ('umax', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('umax(is_used_once)', 'b', 'c(is_not_const)'), ('umax', 'b', 'd')) => ('umax', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('umax', 'b', 'c(is_not_const)'), ('umax(is_used_once)', 'b', 'd')) => ('umax', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('umax', 'b', 'c'), ('umax(is_used_once)', 'b', 'd(is_not_const)')) => ('umax', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fpow(is_used_once)', 'b', 'c'), ('fpow', 'b', 'd')) => ('fpow', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fpow', 'b', 'c'), ('fpow(is_used_once)', 'b', 'd')) => ('fpow', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fpow(is_used_once)', 'b', 'c'), ('fpow', 'd', 'c')) => ('fpow', ('bcsel', 'a', 'b', 'd'), 'c')
 *    ('bcsel', 'a', ('fpow', 'b', 'c'), ('fpow(is_used_once)', 'd', 'c')) => ('fpow', ('bcsel', 'a', 'b', 'd'), 'c')
 *    ('bcsel', 'c', ('frcp(is_used_once)', 'a'), ('frcp(is_used_once)', 'b')) => ('frcp', ('bcsel', 'c', 'a', 'b'))
 *    ('bcsel', 'c', ('frsq(is_used_once)', 'a'), ('frsq(is_used_once)', 'b')) => ('frsq', ('bcsel', 'c', 'a', 'b'))
 *    ('bcsel', 'c', ('fsqrt(is_used_once)', 'a'), ('fsqrt(is_used_once)', 'b')) => ('fsqrt', ('bcsel', 'c', 'a', 'b'))
 *    ('bcsel', 'c', ('fexp2(is_used_once)', 'a'), ('fexp2(is_used_once)', 'b')) => ('fexp2', ('bcsel', 'c', 'a', 'b'))
 *    ('bcsel', 'c', ('flog2(is_used_once)', 'a'), ('flog2(is_used_once)', 'b')) => ('flog2', ('bcsel', 'c', 'a', 'b'))
 *    ('bcsel', 'c', ('fsign(is_used_once)', 'a'), ('fsign(is_used_once)', 'b')) => ('fsign', ('bcsel', 'c', 'a', 'b'))
 *    ('bcsel', 'c', ('fsin(is_used_once)', 'a'), ('fsin(is_used_once)', 'b')) => ('fsin', ('bcsel', 'c', 'a', 'b'))
 *    ('bcsel', 'c', ('fcos(is_used_once)', 'a'), ('fcos(is_used_once)', 'b')) => ('fcos', ('bcsel', 'c', 'a', 'b'))
 *    ('bcsel', 'c', ('fsin_amd(is_used_once)', 'a'), ('fsin_amd(is_used_once)', 'b')) => ('fsin_amd', ('bcsel', 'c', 'a', 'b'))
 *    ('bcsel', 'c', ('fcos_amd(is_used_once)', 'a'), ('fcos_amd(is_used_once)', 'b')) => ('fcos_amd', ('bcsel', 'c', 'a', 'b'))
 *    ('bcsel', 'c', ('fneg(is_used_once)', 'a'), ('fneg(is_used_once)', 'b')) => ('fneg', ('bcsel', 'c', 'a', 'b'))
 *    ('bcsel', 'c', ('fabs(is_used_once)', 'a'), ('fabs(is_used_once)', 'b')) => ('fabs', ('bcsel', 'c', 'a', 'b'))
 *    ('bcsel', 'c', ('fsign(is_used_once)', 'a'), ('fsign(is_used_once)', 'b')) => ('fsign', ('bcsel', 'c', 'a', 'b'))
 *    ('ineg', ('bcsel', 'c', '#a', '#b')) => ('bcsel', 'c', ('ineg', 'a'), ('ineg', 'b'))
 *    ('iabs', ('bcsel', 'c', '#a', '#b')) => ('bcsel', 'c', ('iabs', 'a'), ('iabs', 'b'))
 *    ('inot', ('bcsel', 'c', '#a', '#b')) => ('bcsel', 'c', ('inot', 'a'), ('inot', 'b'))
 *    ('isign', ('bcsel', 'c', '#a', '#b')) => ('bcsel', 'c', ('isign', 'a'), ('isign', 'b'))
 *    ('fisnormal', 'a@16') => ('ult', 4095, ('iadd', ('ishl', 'a', 1), 2048))
 *    ('fisnormal', 'a@32') => ('ult', 33554431, ('iadd', ('ishl', 'a', 1), 16777216))
 *    ('fisnormal', 'a@64') => ('ult', 18014398509481983, ('iadd', ('ishl', 'a', 1), 9007199254740992))
 *    ('f2f16', ('vec2', 'a@32', 'b@32')) => ('vec2', ('f2f16', 'a'), ('f2f16', 'b'))
 *    ('f2fmp', ('vec2', 'a@32', 'b@32')) => ('vec2', ('f2fmp', 'a'), ('f2fmp', 'b'))
 *    ('u2u16', ('vec2', 'a@32', 'b@32')) => ('vec2', ('u2u16', 'a'), ('u2u16', 'b'))
 *    ('i2i16', ('vec2', 'a@32', 'b@32')) => ('vec2', ('i2i16', 'a'), ('i2i16', 'b'))
 *    ('i2imp', ('vec2', 'a@32', 'b@32')) => ('vec2', ('i2imp', 'a'), ('i2imp', 'b'))
 *    ('f2f16', ('vec3', 'a@32', 'b@32', 'c@32')) => ('vec3', ('f2f16', 'a'), ('f2f16', 'b'), ('f2f16', 'c'))
 *    ('f2fmp', ('vec3', 'a@32', 'b@32', 'c@32')) => ('vec3', ('f2fmp', 'a'), ('f2fmp', 'b'), ('f2fmp', 'c'))
 *    ('u2u16', ('vec3', 'a@32', 'b@32', 'c@32')) => ('vec3', ('u2u16', 'a'), ('u2u16', 'b'), ('u2u16', 'c'))
 *    ('i2i16', ('vec3', 'a@32', 'b@32', 'c@32')) => ('vec3', ('i2i16', 'a'), ('i2i16', 'b'), ('i2i16', 'c'))
 *    ('i2imp', ('vec3', 'a@32', 'b@32', 'c@32')) => ('vec3', ('i2imp', 'a'), ('i2imp', 'b'), ('i2imp', 'c'))
 *    ('f2f16', ('vec4', 'a@32', 'b@32', 'c@32', 'd@32')) => ('vec4', ('f2f16', 'a'), ('f2f16', 'b'), ('f2f16', 'c'), ('f2f16', 'd'))
 *    ('f2fmp', ('vec4', 'a@32', 'b@32', 'c@32', 'd@32')) => ('vec4', ('f2fmp', 'a'), ('f2fmp', 'b'), ('f2fmp', 'c'), ('f2fmp', 'd'))
 *    ('u2u16', ('vec4', 'a@32', 'b@32', 'c@32', 'd@32')) => ('vec4', ('u2u16', 'a'), ('u2u16', 'b'), ('u2u16', 'c'), ('u2u16', 'd'))
 *    ('i2i16', ('vec4', 'a@32', 'b@32', 'c@32', 'd@32')) => ('vec4', ('i2i16', 'a'), ('i2i16', 'b'), ('i2i16', 'c'), ('i2i16', 'd'))
 *    ('i2imp', ('vec4', 'a@32', 'b@32', 'c@32', 'd@32')) => ('vec4', ('i2imp', 'a'), ('i2imp', 'b'), ('i2imp', 'c'), ('i2imp', 'd'))
 */


static const nir_search_value_union nir_opt_algebraic_values[] = {
   /* ('imul', 'a', '#b(is_pos_power_of_two)') => ('ishl', 'a', ('find_lsb', 'b')) */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      true,
      nir_type_invalid,
      0,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 0, 1 },
      -1,
   } },

   /* replace0_0 -> 0 in the cache */
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_find_lsb,
      -1, 0,
      { 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 0, 4 },
      -1,
   } },

   /* ('imul', 'a@8', 128) => ('ishl', 'a', 7) */
   { .variable = {
      { nir_search_value_variable, 8 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .constant = {
      { nir_search_value_constant, 8 },
      nir_type_int, { 0x80 /* 128 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 6, 7 },
      -1,
   } },

   /* replace1_0 -> 6 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x7 /* 7 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 6, 9 },
      -1,
   } },

   /* ('imul', 'a@16', 32768) => ('ishl', 'a', 15) */
   { .variable = {
      { nir_search_value_variable, 16 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .constant = {
      { nir_search_value_constant, 16 },
      nir_type_int, { 0x8000 /* 32768 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 11, 12 },
      -1,
   } },

   /* replace2_0 -> 11 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xf /* 15 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 11, 14 },
      -1,
   } },

   /* ('imul', 'a@32', 2147483648) => ('ishl', 'a', 31) */
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x80000000 /* 2147483648 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 16, 17 },
      -1,
   } },

   /* replace3_0 -> 16 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x1f /* 31 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 16, 19 },
      -1,
   } },

   /* ('imul', 'a@64', 9223372036854775808) => ('ishl', 'a', 63) */
   { .variable = {
      { nir_search_value_variable, 64 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0x8000000000000000 /* 9223372036854775808 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 21, 22 },
      -1,
   } },

   /* replace4_0 -> 21 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x3f /* 63 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 21, 24 },
      -1,
   } },

   /* ('imul', 'a', '#b(is_neg_power_of_two)') => ('ineg', ('ishl', 'a', ('find_lsb', ('iabs', 'b')))) */
   /* search5_0 -> 0 in the cache */
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      true,
      nir_type_invalid,
      1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 0, 26 },
      -1,
   } },

   /* replace5_0_0 -> 0 in the cache */
   /* replace5_0_1_0_0 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iabs,
      -1, 0,
      { 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_find_lsb,
      -1, 0,
      { 28 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 0, 29 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 30 },
      -1,
   } },

   /* ('ishl', 'a', '#b') => ('imul', 'a', ('ishl', 1, 'b')) */
   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 32, 33 },
      -1,
   } },

   /* replace6_0 -> 32 in the cache */
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_int, { 0x1 /* 1 */ },
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 35, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 32, 37 },
      -1,
   } },

   /* ('imul@64', 'a', '#b(is_bitcount2)') => ('iadd', ('ishl', 'a', ('ufind_msb', 'b')), ('ishl', 'a', ('find_lsb', 'b'))) */
   /* search7_0 -> 21 in the cache */
   { .variable = {
      { nir_search_value_variable, 64 },
      1, /* b */
      true,
      nir_type_invalid,
      2,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 21, 39 },
      -1,
   } },

   /* replace7_0_0 -> 21 in the cache */
   { .variable = {
      { nir_search_value_variable, 64 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ufind_msb,
      -1, 0,
      { 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 21, 42 },
      -1,
   } },
   /* replace7_1_0 -> 21 in the cache */
   /* replace7_1_1_0 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_find_lsb,
      -1, 0,
      { 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 21, 44 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 43, 45 },
      -1,
   } },

   /* ('unpack_64_2x32_split_x', ('imul_2x32_64(is_used_once)', 'a', 'b')) => ('imul', 'a', 'b') */
   /* search8_0_0 -> 16 in the cache */
   /* search8_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_imul_2x32_64,
      0, 1,
      { 16, 36 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_64_2x32_split_x,
      -1, 1,
      { 47 },
      -1,
   } },

   /* replace8_0 -> 16 in the cache */
   /* replace8_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 16, 36 },
      -1,
   } },

   /* ('unpack_64_2x32_split_x', ('umul_2x32_64(is_used_once)', 'a', 'b')) => ('imul', 'a', 'b') */
   /* search9_0_0 -> 16 in the cache */
   /* search9_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_umul_2x32_64,
      0, 1,
      { 16, 36 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_64_2x32_split_x,
      -1, 1,
      { 50 },
      -1,
   } },

   /* replace9_0 -> 16 in the cache */
   /* replace9_1 -> 36 in the cache */
   /* replace9 -> 49 in the cache */

   /* ('imul_2x32_64', 'a', 'b') => ('pack_64_2x32_split', ('imul', 'a', 'b'), ('imul_high', 'a', 'b')) */
   /* search10_0 -> 16 in the cache */
   /* search10_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_imul_2x32_64,
      0, 1,
      { 16, 36 },
      -1,
   } },

   /* replace10_0_0 -> 16 in the cache */
   /* replace10_0_1 -> 36 in the cache */
   /* replace10_0 -> 49 in the cache */
   /* replace10_1_0 -> 16 in the cache */
   /* replace10_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul_high,
      1, 1,
      { 16, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_pack_64_2x32_split,
      -1, 2,
      { 49, 53 },
      -1,
   } },

   /* ('umul_2x32_64', 'a', 'b') => ('pack_64_2x32_split', ('imul', 'a', 'b'), ('umul_high', 'a', 'b')) */
   /* search11_0 -> 16 in the cache */
   /* search11_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_umul_2x32_64,
      0, 1,
      { 16, 36 },
      -1,
   } },

   /* replace11_0_0 -> 16 in the cache */
   /* replace11_0_1 -> 36 in the cache */
   /* replace11_0 -> 49 in the cache */
   /* replace11_1_0 -> 16 in the cache */
   /* replace11_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_umul_high,
      1, 1,
      { 16, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_pack_64_2x32_split,
      -1, 2,
      { 49, 56 },
      -1,
   } },

   /* ('udiv', 'a', 1) => a */
   /* search12_0 -> 32 in the cache */
   /* search12_1 -> 35 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_udiv,
      -1, 0,
      { 32, 35 },
      -1,
   } },

   /* replace12 -> 32 in the cache */

   /* ('idiv', 'a', 1) => a */
   /* search13_0 -> 32 in the cache */
   /* search13_1 -> 35 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_idiv,
      -1, 0,
      { 32, 35 },
      -1,
   } },

   /* replace13 -> 32 in the cache */

   /* ('umod', 'a', 1) => 0 */
   /* search14_0 -> 32 in the cache */
   /* search14_1 -> 35 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_umod,
      -1, 0,
      { 32, 35 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_int, { 0x0 /* 0 */ },
   } },

   /* ('imod', 'a', 1) => 0 */
   /* search15_0 -> 32 in the cache */
   /* search15_1 -> 35 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imod,
      -1, 0,
      { 32, 35 },
      -1,
   } },

   /* replace15 -> 61 in the cache */

   /* ('imod', 'a', -1) => 0 */
   /* search16_0 -> 32 in the cache */
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_int, { -0x1 /* -1 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imod,
      -1, 0,
      { 32, 63 },
      -1,
   } },

   /* replace16 -> 61 in the cache */

   /* ('irem', 'a', 1) => 0 */
   /* search17_0 -> 32 in the cache */
   /* search17_1 -> 35 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_irem,
      -1, 0,
      { 32, 35 },
      -1,
   } },

   /* replace17 -> 61 in the cache */

   /* ('irem', 'a', -1) => 0 */
   /* search18_0 -> 32 in the cache */
   /* search18_1 -> 63 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_irem,
      -1, 0,
      { 32, 63 },
      -1,
   } },

   /* replace18 -> 61 in the cache */

   /* ('udiv', 'a', '#b(is_pos_power_of_two)') => ('ushr', 'a', ('find_lsb', 'b')) */
   /* search19_0 -> 0 in the cache */
   /* search19_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_udiv,
      -1, 0,
      { 0, 1 },
      -1,
   } },

   /* replace19_0 -> 0 in the cache */
   /* replace19_1_0 -> 3 in the cache */
   /* replace19_1 -> 4 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 0, 4 },
      -1,
   } },

   /* ('idiv', 'a', '#b(is_pos_power_of_two)') => ('imul', ('isign', 'a'), ('ushr', ('iabs', 'a'), ('find_lsb', 'b'))) */
   /* search20_0 -> 0 in the cache */
   /* search20_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_idiv,
      -1, 0,
      { 0, 1 },
      -1,
   } },

   /* replace20_0_0 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_isign,
      -1, 0,
      { 0 },
      -1,
   } },
   /* replace20_1_0_0 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iabs,
      -1, 0,
      { 0 },
      -1,
   } },
   /* replace20_1_1_0 -> 3 in the cache */
   /* replace20_1_1 -> 4 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 71, 4 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 70, 72 },
      -1,
   } },

   /* ('idiv', 'a', '#b(is_neg_power_of_two)') => ('ineg', ('imul', ('isign', 'a'), ('ushr', ('iabs', 'a'), ('find_lsb', ('iabs', 'b'))))) */
   /* search21_0 -> 0 in the cache */
   /* search21_1 -> 26 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_idiv,
      -1, 0,
      { 0, 26 },
      -1,
   } },

   /* replace21_0_0_0 -> 0 in the cache */
   /* replace21_0_0 -> 70 in the cache */
   /* replace21_0_1_0_0 -> 0 in the cache */
   /* replace21_0_1_0 -> 71 in the cache */
   /* replace21_0_1_1_0_0 -> 3 in the cache */
   /* replace21_0_1_1_0 -> 28 in the cache */
   /* replace21_0_1_1 -> 29 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 71, 29 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 70, 75 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 1,
      { 76 },
      -1,
   } },

   /* ('umod', 'a', '#b(is_pos_power_of_two)') => ('iand', 'a', ('isub', 'b', 1)) */
   /* search22_0 -> 0 in the cache */
   /* search22_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_umod,
      -1, 0,
      { 0, 1 },
      -1,
   } },

   /* replace22_0 -> 0 in the cache */
   /* replace22_1_0 -> 3 in the cache */
   { .constant = {
      { nir_search_value_constant, -2 },
      nir_type_int, { 0x1 /* 1 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 3, 79 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 0, 80 },
      -1,
   } },

   /* ('imod', 'a', '#b(is_pos_power_of_two)') => ('iand', 'a', ('isub', 'b', 1)) */
   /* search23_0 -> 0 in the cache */
   /* search23_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_imod,
      -1, 0,
      { 0, 1 },
      -1,
   } },

   /* replace23_0 -> 0 in the cache */
   /* replace23_1_0 -> 3 in the cache */
   /* replace23_1_1 -> 79 in the cache */
   /* replace23_1 -> 80 in the cache */
   /* replace23 -> 81 in the cache */

   /* ('imod', 'a', '#b(is_neg_power_of_two)') => ('bcsel', ('ieq', ('ior', 'a', 'b'), 'b'), 0, ('ior', 'a', 'b')) */
   /* search24_0 -> 0 in the cache */
   /* search24_1 -> 26 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_imod,
      -1, 0,
      { 0, 26 },
      -1,
   } },

   /* replace24_0_0_0 -> 0 in the cache */
   /* replace24_0_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 0, 3 },
      -1,
   } },
   /* replace24_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 84, 3 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, -2 },
      nir_type_int, { 0x0 /* 0 */ },
   } },
   /* replace24_2_0 -> 0 in the cache */
   /* replace24_2_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ior,
      2, 1,
      { 0, 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 3,
      { 85, 86, 87 },
      -1,
   } },

   /* ('irem', 'a', '#b(is_pos_power_of_two)') => ('isub', 'a', ('iand', ('bcsel', ('ilt', 'a', 0), ('iadd', 'a', ('isub', 'b', 1)), 'a'), ('ineg', 'b'))) */
   /* search25_0 -> 0 in the cache */
   /* search25_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_irem,
      -1, 0,
      { 0, 1 },
      -1,
   } },

   /* replace25_0 -> 0 in the cache */
   /* replace25_1_0_0_0 -> 0 in the cache */
   /* replace25_1_0_0_1 -> 86 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 0, 86 },
      -1,
   } },
   /* replace25_1_0_1_0 -> 0 in the cache */
   /* replace25_1_0_1_1_0 -> 3 in the cache */
   /* replace25_1_0_1_1_1 -> 79 in the cache */
   /* replace25_1_0_1_1 -> 80 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 0, 80 },
      -1,
   } },
   /* replace25_1_0_2 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 90, 91, 0 },
      -1,
   } },
   /* replace25_1_1_0 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 92, 93 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 2,
      { 0, 94 },
      -1,
   } },

   /* ('irem', 'a', '#b(is_neg_power_of_two)') => ('irem', 'a', ('iabs', 'b')) */
   /* search26_0 -> 0 in the cache */
   /* search26_1 -> 26 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_irem,
      -1, 0,
      { 0, 26 },
      -1,
   } },

   /* replace26_0 -> 0 in the cache */
   /* replace26_1_0 -> 3 in the cache */
   /* replace26_1 -> 28 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_irem,
      -1, 0,
      { 0, 28 },
      -1,
   } },

   /* ('~fneg', ('fneg', 'a')) => a */
   /* search27_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 98 },
      -1,
   } },

   /* replace27 -> 32 in the cache */

   /* ('ineg', ('ineg', 'a')) => a */
   /* search28_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 100 },
      -1,
   } },

   /* replace28 -> 32 in the cache */

   /* ('fabs', ('fneg', 'a')) => ('fabs', 'a') */
   /* search29_0_0 -> 32 in the cache */
   /* search29_0 -> 98 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 98 },
      -1,
   } },

   /* replace29_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 32 },
      -1,
   } },

   /* ('fabs', ('u2f', 'a')) => ('u2f', 'a') */
   /* search30_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_u2f,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 104 },
      -1,
   } },

   /* replace30_0 -> 32 in the cache */
   /* replace30 -> 104 in the cache */

   /* ('iabs', ('iabs', 'a')) => ('iabs', 'a') */
   /* search31_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_iabs,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_iabs,
      -1, 0,
      { 106 },
      -1,
   } },

   /* replace31_0 -> 32 in the cache */
   /* replace31 -> 106 in the cache */

   /* ('iabs', ('ineg', 'a')) => ('iabs', 'a') */
   /* search32_0_0 -> 32 in the cache */
   /* search32_0 -> 100 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_iabs,
      -1, 0,
      { 100 },
      -1,
   } },

   /* replace32_0 -> 32 in the cache */
   /* replace32 -> 106 in the cache */

   /* ('f2b', ('fneg', 'a')) => ('f2b', 'a') */
   /* search33_0_0 -> 32 in the cache */
   /* search33_0 -> 98 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_f2b,
      -1, 0,
      { 98 },
      -1,
   } },

   /* replace33_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_f2b,
      -1, 0,
      { 32 },
      -1,
   } },

   /* ('~fadd', 'a', 0.0) => a */
   /* search34_0 -> 32 in the cache */
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0x0 /* 0.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 32, 111 },
      -1,
   } },

   /* replace34 -> 32 in the cache */

   /* ('fadd(is_only_used_as_float)', 'a@16', 0.0) => a */
   /* search35_0 -> 11 in the cache */
   { .constant = {
      { nir_search_value_constant, 16 },
      nir_type_float, { 0x0 /* 0.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 11, 113 },
      1,
   } },

   /* replace35 -> 11 in the cache */

   /* ('fadd(is_only_used_as_float)', 'a@32', 0.0) => a */
   /* search36_0 -> 16 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_float, { 0x0 /* 0.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 16, 115 },
      1,
   } },

   /* replace36 -> 16 in the cache */

   /* ('iadd', 'a', 0) => a */
   /* search37_0 -> 32 in the cache */
   /* search37_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 32, 61 },
      -1,
   } },

   /* replace37 -> 32 in the cache */

   /* ('iadd_sat', 'a', 0) => a */
   /* search38_0 -> 32 in the cache */
   /* search38_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_iadd_sat,
      0, 1,
      { 32, 61 },
      -1,
   } },

   /* replace38 -> 32 in the cache */

   /* ('isub_sat', 'a', 0) => a */
   /* search39_0 -> 32 in the cache */
   /* search39_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_isub_sat,
      -1, 0,
      { 32, 61 },
      -1,
   } },

   /* replace39 -> 32 in the cache */

   /* ('uadd_sat', 'a', 0) => a */
   /* search40_0 -> 32 in the cache */
   /* search40_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_uadd_sat,
      0, 1,
      { 32, 61 },
      -1,
   } },

   /* replace40 -> 32 in the cache */

   /* ('usub_sat', 'a', 0) => a */
   /* search41_0 -> 32 in the cache */
   /* search41_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_usub_sat,
      -1, 0,
      { 32, 61 },
      -1,
   } },

   /* replace41 -> 32 in the cache */

   /* ('usadd_4x8_vc4', 'a', 0) => a */
   /* search42_0 -> 16 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x0 /* 0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_usadd_4x8_vc4,
      0, 1,
      { 16, 122 },
      -1,
   } },

   /* replace42 -> 16 in the cache */

   /* ('usadd_4x8_vc4', 'a', -1) => -1 */
   /* search43_0 -> 16 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { -0x1 /* -1 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_usadd_4x8_vc4,
      0, 1,
      { 16, 124 },
      -1,
   } },

   /* replace43 -> 124 in the cache */

   /* ('~fadd', ('fmul', 'a', 'b'), ('fmul', 'a', 'c')) => ('fmul', 'a', ('fadd', 'b', 'c')) */
   { .variable = {
      { nir_search_value_variable, -3 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 126, 127 },
      -1,
   } },
   /* search44_1_0 -> 126 in the cache */
   { .variable = {
      { nir_search_value_variable, -3 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmul,
      2, 1,
      { 126, 129 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 128, 130 },
      -1,
   } },

   /* replace44_0 -> 126 in the cache */
   /* replace44_1_0 -> 127 in the cache */
   /* replace44_1_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 127, 129 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 2,
      { 126, 132 },
      -1,
   } },

   /* ('~fadd', ('fmulz', 'a', 'b'), ('fmulz', 'a', 'c')) => ('fmulz', 'a', ('fadd', 'b', 'c')) */
   /* search45_0_0 -> 16 in the cache */
   /* search45_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      1, 1,
      { 16, 36 },
      -1,
   } },
   /* search45_1_0 -> 16 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      2, 1,
      { 16, 135 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 134, 136 },
      -1,
   } },

   /* replace45_0 -> 16 in the cache */
   /* replace45_1_0 -> 36 in the cache */
   /* replace45_1_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 36, 135 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      0, 2,
      { 16, 138 },
      -1,
   } },

   /* ('~ffma', 'a', 'b', ('ffma(is_used_once)', 'a', 'c', 'd')) => ('ffma', 'a', ('fadd', 'b', 'c'), 'd') */
   /* search46_0 -> 0 in the cache */
   /* search46_1 -> 3 in the cache */
   /* search46_2_0 -> 0 in the cache */
   { .variable = {
      { nir_search_value_variable, -2 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      3, /* d */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ffma,
      1, 1,
      { 0, 140, 141 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 0, 3, 142 },
      -1,
   } },

   /* replace46_0 -> 0 in the cache */
   /* replace46_1_0 -> 3 in the cache */
   /* replace46_1_1 -> 140 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 3, 140 },
      -1,
   } },
   /* replace46_2 -> 141 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 0, 144, 141 },
      -1,
   } },

   /* ('~ffma', 'a', 'b', ('fmul(is_used_once)', 'a', 'c')) => ('fmul', 'a', ('fadd', 'b', 'c')) */
   /* search47_0 -> 0 in the cache */
   /* search47_1 -> 3 in the cache */
   /* search47_2_0 -> 0 in the cache */
   /* search47_2_1 -> 140 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 0, 140 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 0, 3, 146 },
      -1,
   } },

   /* replace47_0 -> 0 in the cache */
   /* replace47_1_0 -> 3 in the cache */
   /* replace47_1_1 -> 140 in the cache */
   /* replace47_1 -> 144 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 2,
      { 0, 144 },
      -1,
   } },

   /* ('~fadd', ('fmul(is_used_once)', 'a', 'b'), ('ffma(is_used_once)', 'a', 'c', 'd')) => ('ffma', 'a', ('fadd', 'b', 'c'), 'd') */
   { .variable = {
      { nir_search_value_variable, -4 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -4 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 149, 150 },
      0,
   } },
   /* search48_1_0 -> 149 in the cache */
   { .variable = {
      { nir_search_value_variable, -4 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -4 },
      3, /* d */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ffma,
      2, 1,
      { 149, 152, 153 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 151, 154 },
      -1,
   } },

   /* replace48_0 -> 149 in the cache */
   /* replace48_1_0 -> 150 in the cache */
   /* replace48_1_1 -> 152 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 150, 152 },
      -1,
   } },
   /* replace48_2 -> 153 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 149, 156, 153 },
      -1,
   } },

   /* ('~ffma', 'a', ('fmul(is_used_once)', 'b', 'c'), ('fmul(is_used_once)', 'b', 'd')) => ('fmul', 'b', ('ffma', 'a', 'c', 'd')) */
   /* search49_0 -> 149 in the cache */
   /* search49_1_0 -> 150 in the cache */
   /* search49_1_1 -> 152 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 150, 152 },
      0,
   } },
   /* search49_2_0 -> 150 in the cache */
   /* search49_2_1 -> 153 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      2, 1,
      { 150, 153 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 3,
      { 149, 158, 159 },
      -1,
   } },

   /* replace49_0 -> 150 in the cache */
   /* replace49_1_0 -> 149 in the cache */
   /* replace49_1_1 -> 152 in the cache */
   /* replace49_1_2 -> 153 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ffma,
      1, 1,
      { 149, 152, 153 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 2,
      { 150, 161 },
      -1,
   } },

   /* ('~ffmaz', 'a', 'b', ('ffmaz(is_used_once)', 'a', 'c', 'd')) => ('ffmaz', 'a', ('fadd', 'b', 'c'), 'd') */
   /* search50_0 -> 16 in the cache */
   /* search50_1 -> 36 in the cache */
   /* search50_2_0 -> 16 in the cache */
   /* search50_2_1 -> 135 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      3, /* d */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      1, 1,
      { 16, 135, 163 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_ffmaz,
      0, 2,
      { 16, 36, 164 },
      -1,
   } },

   /* replace50_0 -> 16 in the cache */
   /* replace50_1_0 -> 36 in the cache */
   /* replace50_1_1 -> 135 in the cache */
   /* replace50_1 -> 138 in the cache */
   /* replace50_2 -> 163 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 2,
      { 16, 138, 163 },
      -1,
   } },

   /* ('~ffmaz', 'a', 'b', ('fmulz(is_used_once)', 'a', 'c')) => ('fmulz', 'a', ('fadd', 'b', 'c')) */
   /* search51_0 -> 16 in the cache */
   /* search51_1 -> 36 in the cache */
   /* search51_2_0 -> 16 in the cache */
   /* search51_2_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      1, 1,
      { 16, 135 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_ffmaz,
      0, 2,
      { 16, 36, 167 },
      -1,
   } },

   /* replace51_0 -> 16 in the cache */
   /* replace51_1_0 -> 36 in the cache */
   /* replace51_1_1 -> 135 in the cache */
   /* replace51_1 -> 138 in the cache */
   /* replace51 -> 139 in the cache */

   /* ('~fadd', ('fmulz(is_used_once)', 'a', 'b'), ('ffmaz(is_used_once)', 'a', 'c', 'd')) => ('ffmaz', 'a', ('fadd', 'b', 'c'), 'd') */
   /* search52_0_0 -> 16 in the cache */
   /* search52_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      1, 1,
      { 16, 36 },
      0,
   } },
   /* search52_1_0 -> 16 in the cache */
   /* search52_1_1 -> 135 in the cache */
   /* search52_1_2 -> 163 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      2, 1,
      { 16, 135, 163 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 169, 170 },
      -1,
   } },

   /* replace52_0 -> 16 in the cache */
   /* replace52_1_0 -> 36 in the cache */
   /* replace52_1_1 -> 135 in the cache */
   /* replace52_1 -> 138 in the cache */
   /* replace52_2 -> 163 in the cache */
   /* replace52 -> 166 in the cache */

   /* ('~ffmaz', 'a', ('fmulz(is_used_once)', 'b', 'c'), ('fmulz(is_used_once)', 'b', 'd')) => ('fmulz', 'b', ('ffmaz', 'a', 'c', 'd')) */
   /* search53_0 -> 16 in the cache */
   /* search53_1_0 -> 36 in the cache */
   /* search53_1_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      1, 1,
      { 36, 135 },
      0,
   } },
   /* search53_2_0 -> 36 in the cache */
   /* search53_2_1 -> 163 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      2, 1,
      { 36, 163 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_ffmaz,
      0, 3,
      { 16, 172, 173 },
      -1,
   } },

   /* replace53_0 -> 36 in the cache */
   /* replace53_1_0 -> 16 in the cache */
   /* replace53_1_1 -> 135 in the cache */
   /* replace53_1_2 -> 163 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      1, 1,
      { 16, 135, 163 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      0, 2,
      { 36, 175 },
      -1,
   } },

   /* ('iadd', ('imul', 'a', 'b'), ('imul', 'a', 'c')) => ('imul', 'a', ('iadd', 'b', 'c')) */
   /* search54_0_0 -> 126 in the cache */
   /* search54_0_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imul,
      1, 1,
      { 126, 127 },
      -1,
   } },
   /* search54_1_0 -> 126 in the cache */
   /* search54_1_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imul,
      2, 1,
      { 126, 129 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 3,
      { 177, 178 },
      -1,
   } },

   /* replace54_0 -> 126 in the cache */
   /* replace54_1_0 -> 127 in the cache */
   /* replace54_1_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 127, 129 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imul,
      0, 2,
      { 126, 180 },
      -1,
   } },

   /* ('iadd', ('ishl', 'b', 'a'), ('ishl', 'c', 'a')) => ('ishl', ('iadd', 'b', 'c'), 'a') */
   { .variable = {
      { nir_search_value_variable, -3 },
      0, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 182, 183 },
      -1,
   } },
   /* search55_1_0 -> 129 in the cache */
   /* search55_1_1 -> 183 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 129, 183 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 184, 185 },
      -1,
   } },

   /* replace55_0_0 -> 182 in the cache */
   /* replace55_0_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 182, 129 },
      -1,
   } },
   /* replace55_1 -> 183 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 187, 183 },
      -1,
   } },

   /* ('iand', ('ior', 'a', 'b'), ('ior', 'a', 'c')) => ('ior', 'a', ('iand', 'b', 'c')) */
   /* search56_0_0 -> 126 in the cache */
   /* search56_0_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 126, 127 },
      -1,
   } },
   /* search56_1_0 -> 126 in the cache */
   /* search56_1_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ior,
      2, 1,
      { 126, 129 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 189, 190 },
      -1,
   } },

   /* replace56_0 -> 126 in the cache */
   /* replace56_1_0 -> 127 in the cache */
   /* replace56_1_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 127, 129 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 126, 192 },
      -1,
   } },

   /* ('ior', ('iand', 'a', 'b'), ('iand', 'a', 'c')) => ('iand', 'a', ('ior', 'b', 'c')) */
   /* search57_0_0 -> 126 in the cache */
   /* search57_0_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 126, 127 },
      -1,
   } },
   /* search57_1_0 -> 126 in the cache */
   /* search57_1_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iand,
      2, 1,
      { 126, 129 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 194, 195 },
      -1,
   } },

   /* replace57_0 -> 126 in the cache */
   /* replace57_1_0 -> 127 in the cache */
   /* replace57_1_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 127, 129 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 126, 197 },
      -1,
   } },

   /* ('ieq', ('iand', 'a', '#b(is_pos_power_of_two)'), 'b') => ('ine', ('iand', 'a', 'b'), 0) */
   /* search58_0_0 -> 0 in the cache */
   /* search58_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 0, 1 },
      -1,
   } },
   /* search58_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 199, 3 },
      -1,
   } },

   /* replace58_0_0 -> 0 in the cache */
   /* replace58_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 0, 3 },
      -1,
   } },
   /* replace58_1 -> 86 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 201, 86 },
      -1,
   } },

   /* ('ine', ('iand', 'a', '#b(is_pos_power_of_two)'), 'b') => ('ieq', ('iand', 'a', 'b'), 0) */
   /* search59_0_0 -> 0 in the cache */
   /* search59_0_1 -> 1 in the cache */
   /* search59_0 -> 199 in the cache */
   /* search59_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 199, 3 },
      -1,
   } },

   /* replace59_0_0 -> 0 in the cache */
   /* replace59_0_1 -> 3 in the cache */
   /* replace59_0 -> 201 in the cache */
   /* replace59_1 -> 86 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 201, 86 },
      -1,
   } },

   /* ('~fadd', ('fneg', 'a'), 'a') => 0.0 */
   /* search60_0_0 -> 32 in the cache */
   /* search60_0 -> 98 in the cache */
   /* search60_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 98, 32 },
      -1,
   } },

   /* replace60 -> 111 in the cache */

   /* ('iadd', ('ineg', 'a'), 'a') => 0 */
   /* search61_0_0 -> 32 in the cache */
   /* search61_0 -> 100 in the cache */
   /* search61_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 100, 32 },
      -1,
   } },

   /* replace61 -> 61 in the cache */

   /* ('iadd', ('ineg', 'a'), ('iadd', 'a', 'b')) => b */
   /* search62_0_0 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 0 },
      -1,
   } },
   /* search62_1_0 -> 0 in the cache */
   /* search62_1_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 0, 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 207, 208 },
      -1,
   } },

   /* replace62 -> 3 in the cache */

   /* ('iadd', 'a', ('iadd', ('ineg', 'a'), 'b')) => b */
   /* search63_0 -> 0 in the cache */
   /* search63_1_0_0 -> 0 in the cache */
   /* search63_1_0 -> 207 in the cache */
   /* search63_1_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 207, 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 0, 210 },
      -1,
   } },

   /* replace63 -> 3 in the cache */

   /* ('~fadd', ('fneg', 'a'), ('fadd', 'a', 'b')) => b */
   /* search64_0_0 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 0 },
      -1,
   } },
   /* search64_1_0 -> 0 in the cache */
   /* search64_1_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 0, 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 212, 213 },
      -1,
   } },

   /* replace64 -> 3 in the cache */

   /* ('~fadd', 'a', ('fadd', ('fneg', 'a'), 'b')) => b */
   /* search65_0 -> 0 in the cache */
   /* search65_1_0_0 -> 0 in the cache */
   /* search65_1_0 -> 212 in the cache */
   /* search65_1_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 212, 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 0, 215 },
      -1,
   } },

   /* replace65 -> 3 in the cache */

   /* ('fadd', ('fsat', 'a'), ('fsat', ('fneg', 'a'))) => ('fsat', ('fabs', 'a')) */
   /* search66_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 32 },
      -1,
   } },
   /* search66_1_0_0 -> 32 in the cache */
   /* search66_1_0 -> 98 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 98 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 217, 218 },
      -1,
   } },

   /* replace66_0_0 -> 32 in the cache */
   /* replace66_0 -> 103 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 103 },
      -1,
   } },

   /* ('~fmul', 'a', 0.0) => 0.0 */
   /* search67_0 -> 32 in the cache */
   /* search67_1 -> 111 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 32, 111 },
      -1,
   } },

   /* replace67 -> 111 in the cache */

   /* ('fmul', 'a@16', 0.0) => 0.0 */
   /* search68_0 -> 11 in the cache */
   /* search68_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 11, 113 },
      -1,
   } },

   /* replace68 -> 113 in the cache */

   /* ('fmul', 'a@32', 0.0) => 0.0 */
   /* search69_0 -> 16 in the cache */
   /* search69_1 -> 115 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 16, 115 },
      -1,
   } },

   /* replace69 -> 115 in the cache */

   /* ('fmulz', 'a', 0.0) => 0.0 */
   /* search70_0 -> 16 in the cache */
   /* search70_1 -> 115 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 16, 115 },
      -1,
   } },

   /* replace70 -> 115 in the cache */

   /* ('fmulz', 'a', 'b(is_finite_not_zero)') => ('fmul', 'a', 'b') */
   /* search71_0 -> 16 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      false,
      nir_type_invalid,
      3,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 16, 225 },
      -1,
   } },

   /* replace71_0 -> 16 in the cache */
   /* replace71_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 16, 36 },
      -1,
   } },

   /* ('fmulz', 'a(is_finite)', 'b(is_finite)') => ('fmul', 'a', 'b') */
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* a */
      false,
      nir_type_invalid,
      4,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      false,
      nir_type_invalid,
      4,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 228, 229 },
      -1,
   } },

   /* replace72_0 -> 16 in the cache */
   /* replace72_1 -> 36 in the cache */
   /* replace72 -> 227 in the cache */

   /* ('fmulz', 'a', 'a') => ('fmul', 'a', 'a') */
   /* search73_0 -> 16 in the cache */
   /* search73_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      -1, 0,
      { 16, 16 },
      -1,
   } },

   /* replace73_0 -> 16 in the cache */
   /* replace73_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      -1, 0,
      { 16, 16 },
      -1,
   } },

   /* ('ffmaz', 'a', 'b(is_finite_not_zero)', 'c') => ('ffma', 'a', 'b', 'c') */
   /* search74_0 -> 16 in the cache */
   /* search74_1 -> 225 in the cache */
   /* search74_2 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 1,
      { 16, 225, 135 },
      -1,
   } },

   /* replace74_0 -> 16 in the cache */
   /* replace74_1 -> 36 in the cache */
   /* replace74_2 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 16, 36, 135 },
      -1,
   } },

   /* ('ffmaz', 'a(is_finite)', 'b(is_finite)', 'c') => ('ffma', 'a', 'b', 'c') */
   /* search75_0 -> 228 in the cache */
   /* search75_1 -> 229 in the cache */
   /* search75_2 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 1,
      { 228, 229, 135 },
      -1,
   } },

   /* replace75_0 -> 16 in the cache */
   /* replace75_1 -> 36 in the cache */
   /* replace75_2 -> 135 in the cache */
   /* replace75 -> 234 in the cache */

   /* ('ffmaz', 'a', 'a', 'b') => ('ffma', 'a', 'a', 'b') */
   /* search76_0 -> 16 in the cache */
   /* search76_1 -> 16 in the cache */
   /* search76_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      -1, 0,
      { 16, 16, 36 },
      -1,
   } },

   /* replace76_0 -> 16 in the cache */
   /* replace76_1 -> 16 in the cache */
   /* replace76_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffma,
      -1, 0,
      { 16, 16, 36 },
      -1,
   } },

   /* ('imul', 'a', 0) => 0 */
   /* search77_0 -> 32 in the cache */
   /* search77_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 32, 61 },
      -1,
   } },

   /* replace77 -> 61 in the cache */

   /* ('umul_unorm_4x8_vc4', 'a', 0) => 0 */
   /* search78_0 -> 16 in the cache */
   /* search78_1 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_umul_unorm_4x8_vc4,
      0, 1,
      { 16, 122 },
      -1,
   } },

   /* replace78 -> 122 in the cache */

   /* ('umul_unorm_4x8_vc4', 'a', -1) => a */
   /* search79_0 -> 16 in the cache */
   /* search79_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_umul_unorm_4x8_vc4,
      0, 1,
      { 16, 124 },
      -1,
   } },

   /* replace79 -> 16 in the cache */

   /* ('~fmul', 'a', 1.0) => a */
   /* search80_0 -> 32 in the cache */
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0x3ff0000000000000 /* 1.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 32, 241 },
      -1,
   } },

   /* replace80 -> 32 in the cache */

   /* ('~fmulz', 'a', 1.0) => a */
   /* search81_0 -> 16 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_float, { 0x3ff0000000000000 /* 1.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 16, 243 },
      -1,
   } },

   /* replace81 -> 16 in the cache */

   /* ('fmul(is_only_used_as_float)', 'a', 1.0) => a */
   /* search82_0 -> 32 in the cache */
   /* search82_1 -> 241 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 32, 241 },
      1,
   } },

   /* replace82 -> 32 in the cache */

   /* ('imul', 'a', 1) => a */
   /* search83_0 -> 32 in the cache */
   /* search83_1 -> 35 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 32, 35 },
      -1,
   } },

   /* replace83 -> 32 in the cache */

   /* ('fmul', 'a', -1.0) => ('fneg', 'a') */
   /* search84_0 -> 32 in the cache */
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0xbff0000000000000 /* -1.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 32, 247 },
      -1,
   } },

   /* replace84_0 -> 32 in the cache */
   /* replace84 -> 98 in the cache */

   /* ('imul', 'a', -1) => ('ineg', 'a') */
   /* search85_0 -> 32 in the cache */
   /* search85_1 -> 63 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 32, 63 },
      -1,
   } },

   /* replace85_0 -> 32 in the cache */
   /* replace85 -> 100 in the cache */

   /* ('fmul', ('fsign', 'a'), ('fmul', 'a', 'a')) => ('fmul', ('fabs', 'a'), 'a') */
   /* search86_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsign,
      -1, 0,
      { 32 },
      -1,
   } },
   /* search86_1_0 -> 32 in the cache */
   /* search86_1_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      -1, 0,
      { 32, 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 250, 251 },
      -1,
   } },

   /* replace86_0_0 -> 32 in the cache */
   /* replace86_0 -> 103 in the cache */
   /* replace86_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 103, 32 },
      -1,
   } },

   /* ('fmul', ('fmul', ('fsign', 'a'), 'a'), 'a') => ('fmul', ('fabs', 'a'), 'a') */
   /* search87_0_0_0 -> 32 in the cache */
   /* search87_0_0 -> 250 in the cache */
   /* search87_0_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 250, 32 },
      -1,
   } },
   /* search87_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 2,
      { 254, 32 },
      -1,
   } },

   /* replace87_0_0 -> 32 in the cache */
   /* replace87_0 -> 103 in the cache */
   /* replace87_1 -> 32 in the cache */
   /* replace87 -> 253 in the cache */

   /* ('~ffma', 0.0, 'a', 'b') => b */
   { .constant = {
      { nir_search_value_constant, -2 },
      nir_type_float, { 0x0 /* 0.0 */ },
   } },
   /* search88_1 -> 0 in the cache */
   /* search88_2 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 256, 0, 3 },
      -1,
   } },

   /* replace88 -> 3 in the cache */

   /* ('ffma@16(is_only_used_as_float)', 0.0, 'a', 'b') => b */
   /* search89_0 -> 113 in the cache */
   /* search89_1 -> 11 in the cache */
   { .variable = {
      { nir_search_value_variable, 16 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 113, 11, 258 },
      1,
   } },

   /* replace89 -> 258 in the cache */

   /* ('ffma@32(is_only_used_as_float)', 0.0, 'a', 'b') => b */
   /* search90_0 -> 115 in the cache */
   /* search90_1 -> 16 in the cache */
   /* search90_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 115, 16, 36 },
      1,
   } },

   /* replace90 -> 36 in the cache */

   /* ('ffmaz', 0.0, 'a', 'b') => ('fadd', 0.0, 'b') */
   /* search91_0 -> 115 in the cache */
   /* search91_1 -> 16 in the cache */
   /* search91_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 1,
      { 115, 16, 36 },
      -1,
   } },

   /* replace91_0 -> 115 in the cache */
   /* replace91_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 115, 36 },
      -1,
   } },

   /* ('~ffma', 'a', 'b', 0.0) => ('fmul', 'a', 'b') */
   /* search92_0 -> 0 in the cache */
   /* search92_1 -> 3 in the cache */
   /* search92_2 -> 256 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 0, 3, 256 },
      -1,
   } },

   /* replace92_0 -> 0 in the cache */
   /* replace92_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* ('ffma@16', 'a', 'b', 0.0) => ('fmul', 'a', 'b') */
   /* search93_0 -> 11 in the cache */
   /* search93_1 -> 258 in the cache */
   /* search93_2 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 11, 258, 113 },
      -1,
   } },

   /* replace93_0 -> 11 in the cache */
   /* replace93_1 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 11, 258 },
      -1,
   } },

   /* ('ffma@32', 'a', 'b', 0.0) => ('fmul', 'a', 'b') */
   /* search94_0 -> 16 in the cache */
   /* search94_1 -> 36 in the cache */
   /* search94_2 -> 115 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 16, 36, 115 },
      -1,
   } },

   /* replace94_0 -> 16 in the cache */
   /* replace94_1 -> 36 in the cache */
   /* replace94 -> 227 in the cache */

   /* ('ffmaz', 'a', 'b', 0.0) => ('fmulz', 'a', 'b') */
   /* search95_0 -> 16 in the cache */
   /* search95_1 -> 36 in the cache */
   /* search95_2 -> 115 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 1,
      { 16, 36, 115 },
      -1,
   } },

   /* replace95_0 -> 16 in the cache */
   /* replace95_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 16, 36 },
      -1,
   } },

   /* ('ffma', 1.0, 'a', 'b') => ('fadd', 'a', 'b') */
   { .constant = {
      { nir_search_value_constant, -2 },
      nir_type_float, { 0x3ff0000000000000 /* 1.0 */ },
   } },
   /* search96_1 -> 0 in the cache */
   /* search96_2 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 270, 0, 3 },
      -1,
   } },

   /* replace96_0 -> 0 in the cache */
   /* replace96_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* ('ffmaz', 1.0, 'a', 'b') => ('fadd', 'a', 'b') */
   /* search97_0 -> 243 in the cache */
   /* search97_1 -> 16 in the cache */
   /* search97_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 1,
      { 243, 16, 36 },
      -1,
   } },

   /* replace97_0 -> 16 in the cache */
   /* replace97_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 16, 36 },
      -1,
   } },

   /* ('ffma', -1.0, 'a', 'b') => ('fadd', ('fneg', 'a'), 'b') */
   { .constant = {
      { nir_search_value_constant, -2 },
      nir_type_float, { 0xbff0000000000000 /* -1.0 */ },
   } },
   /* search98_1 -> 0 in the cache */
   /* search98_2 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 275, 0, 3 },
      -1,
   } },

   /* replace98_0_0 -> 0 in the cache */
   /* replace98_0 -> 212 in the cache */
   /* replace98_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 212, 3 },
      -1,
   } },

   /* ('ffmaz', -1.0, 'a', 'b') => ('fadd', ('fneg', 'a'), 'b') */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_float, { 0xbff0000000000000 /* -1.0 */ },
   } },
   /* search99_1 -> 16 in the cache */
   /* search99_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 1,
      { 278, 16, 36 },
      -1,
   } },

   /* replace99_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 16 },
      -1,
   } },
   /* replace99_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 280, 36 },
      -1,
   } },

   /* ('~ffma', '#a', '#b', 'c') => ('fadd', ('fmul', 'a', 'b'), 'c') */
   { .variable = {
      { nir_search_value_variable, -3 },
      0, /* a */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      1, /* b */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search100_2 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 282, 283, 129 },
      -1,
   } },

   /* replace100_0_0 -> 126 in the cache */
   /* replace100_0_1 -> 127 in the cache */
   /* replace100_0 -> 128 in the cache */
   /* replace100_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 128, 129 },
      -1,
   } },

   /* ('~ffmaz', '#a', '#b', 'c') => ('fadd', ('fmulz', 'a', 'b'), 'c') */
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* a */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search101_1 -> 33 in the cache */
   /* search101_2 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_ffmaz,
      0, 1,
      { 286, 33, 135 },
      -1,
   } },

   /* replace101_0_0 -> 16 in the cache */
   /* replace101_0_1 -> 36 in the cache */
   /* replace101_0 -> 134 in the cache */
   /* replace101_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 134, 135 },
      -1,
   } },

   /* ('~flrp', 'a', 'b', 0.0) => a */
   /* search102_0 -> 0 in the cache */
   /* search102_1 -> 3 in the cache */
   /* search102_2 -> 256 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 0, 3, 256 },
      -1,
   } },

   /* replace102 -> 0 in the cache */

   /* ('~flrp', 'a', 'b', 1.0) => b */
   /* search103_0 -> 0 in the cache */
   /* search103_1 -> 3 in the cache */
   /* search103_2 -> 270 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 0, 3, 270 },
      -1,
   } },

   /* replace103 -> 3 in the cache */

   /* ('~flrp', 'a', 'a', 'b') => a */
   /* search104_0 -> 0 in the cache */
   /* search104_1 -> 0 in the cache */
   /* search104_2 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 0, 0, 3 },
      -1,
   } },

   /* replace104 -> 0 in the cache */

   /* ('~flrp', 0.0, 'a', 'b') => ('fmul', 'a', 'b') */
   /* search105_0 -> 256 in the cache */
   /* search105_1 -> 0 in the cache */
   /* search105_2 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 256, 0, 3 },
      -1,
   } },

   /* replace105_0 -> 0 in the cache */
   /* replace105_1 -> 3 in the cache */
   /* replace105 -> 264 in the cache */

   /* ('~flrp', 'a', ('fadd(is_used_once)', 'a', 'b'), 'c') => ('fadd', ('fmul', 'b', 'c'), 'a') */
   /* search106_0 -> 126 in the cache */
   /* search106_1_0 -> 126 in the cache */
   /* search106_1_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 126, 127 },
      0,
   } },
   /* search106_2 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 1,
      { 126, 293, 129 },
      -1,
   } },

   /* replace106_0_0 -> 127 in the cache */
   /* replace106_0_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 127, 129 },
      -1,
   } },
   /* replace106_1 -> 126 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 295, 126 },
      -1,
   } },

   /* ('sdot_4x8_iadd', 'a', 0, 'b') => b */
   /* search107_0 -> 16 in the cache */
   /* search107_1 -> 122 in the cache */
   /* search107_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sdot_4x8_iadd,
      0, 1,
      { 16, 122, 36 },
      -1,
   } },

   /* replace107 -> 36 in the cache */

   /* ('udot_4x8_uadd', 'a', 0, 'b') => b */
   /* search108_0 -> 16 in the cache */
   /* search108_1 -> 122 in the cache */
   /* search108_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_udot_4x8_uadd,
      0, 1,
      { 16, 122, 36 },
      -1,
   } },

   /* replace108 -> 36 in the cache */

   /* ('sdot_4x8_iadd_sat', 'a', 0, 'b') => b */
   /* search109_0 -> 16 in the cache */
   /* search109_1 -> 122 in the cache */
   /* search109_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sdot_4x8_iadd_sat,
      0, 1,
      { 16, 122, 36 },
      -1,
   } },

   /* replace109 -> 36 in the cache */

   /* ('udot_4x8_uadd_sat', 'a', 0, 'b') => b */
   /* search110_0 -> 16 in the cache */
   /* search110_1 -> 122 in the cache */
   /* search110_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_udot_4x8_uadd_sat,
      0, 1,
      { 16, 122, 36 },
      -1,
   } },

   /* replace110 -> 36 in the cache */

   /* ('sdot_2x16_iadd', 'a', 0, 'b') => b */
   /* search111_0 -> 16 in the cache */
   /* search111_1 -> 122 in the cache */
   /* search111_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sdot_2x16_iadd,
      0, 1,
      { 16, 122, 36 },
      -1,
   } },

   /* replace111 -> 36 in the cache */

   /* ('udot_2x16_uadd', 'a', 0, 'b') => b */
   /* search112_0 -> 16 in the cache */
   /* search112_1 -> 122 in the cache */
   /* search112_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_udot_2x16_uadd,
      0, 1,
      { 16, 122, 36 },
      -1,
   } },

   /* replace112 -> 36 in the cache */

   /* ('sdot_2x16_iadd_sat', 'a', 0, 'b') => b */
   /* search113_0 -> 16 in the cache */
   /* search113_1 -> 122 in the cache */
   /* search113_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sdot_2x16_iadd_sat,
      0, 1,
      { 16, 122, 36 },
      -1,
   } },

   /* replace113 -> 36 in the cache */

   /* ('udot_2x16_uadd_sat', 'a', 0, 'b') => b */
   /* search114_0 -> 16 in the cache */
   /* search114_1 -> 122 in the cache */
   /* search114_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_udot_2x16_uadd_sat,
      0, 1,
      { 16, 122, 36 },
      -1,
   } },

   /* replace114 -> 36 in the cache */

   /* ('sudot_4x8_iadd', 'a', 0, 'b') => b */
   /* search115_0 -> 16 in the cache */
   /* search115_1 -> 122 in the cache */
   /* search115_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sudot_4x8_iadd,
      -1, 0,
      { 16, 122, 36 },
      -1,
   } },

   /* replace115 -> 36 in the cache */

   /* ('sudot_4x8_iadd', 0, 'a', 'b') => b */
   /* search116_0 -> 122 in the cache */
   /* search116_1 -> 16 in the cache */
   /* search116_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sudot_4x8_iadd,
      -1, 0,
      { 122, 16, 36 },
      -1,
   } },

   /* replace116 -> 36 in the cache */

   /* ('sudot_4x8_iadd_sat', 'a', 0, 'b') => b */
   /* search117_0 -> 16 in the cache */
   /* search117_1 -> 122 in the cache */
   /* search117_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sudot_4x8_iadd_sat,
      -1, 0,
      { 16, 122, 36 },
      -1,
   } },

   /* replace117 -> 36 in the cache */

   /* ('sudot_4x8_iadd_sat', 0, 'a', 'b') => b */
   /* search118_0 -> 122 in the cache */
   /* search118_1 -> 16 in the cache */
   /* search118_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sudot_4x8_iadd_sat,
      -1, 0,
      { 122, 16, 36 },
      -1,
   } },

   /* replace118 -> 36 in the cache */

   /* ('iadd', ('sdot_4x8_iadd(is_used_once)', 'a', 'b', '#c'), '#d') => ('sdot_4x8_iadd', 'a', 'b', ('iadd', 'c', 'd')) */
   /* search119_0_0 -> 16 in the cache */
   /* search119_0_1 -> 36 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      2, /* c */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sdot_4x8_iadd,
      1, 1,
      { 16, 36, 309 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      3, /* d */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 310, 311 },
      -1,
   } },

   /* replace119_0 -> 16 in the cache */
   /* replace119_1 -> 36 in the cache */
   /* replace119_2_0 -> 135 in the cache */
   /* replace119_2_1 -> 163 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 135, 163 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sdot_4x8_iadd,
      0, 2,
      { 16, 36, 313 },
      -1,
   } },

   /* ('iadd', ('udot_4x8_uadd(is_used_once)', 'a', 'b', '#c'), '#d') => ('udot_4x8_uadd', 'a', 'b', ('iadd', 'c', 'd')) */
   /* search120_0_0 -> 16 in the cache */
   /* search120_0_1 -> 36 in the cache */
   /* search120_0_2 -> 309 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_udot_4x8_uadd,
      1, 1,
      { 16, 36, 309 },
      0,
   } },
   /* search120_1 -> 311 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 315, 311 },
      -1,
   } },

   /* replace120_0 -> 16 in the cache */
   /* replace120_1 -> 36 in the cache */
   /* replace120_2_0 -> 135 in the cache */
   /* replace120_2_1 -> 163 in the cache */
   /* replace120_2 -> 313 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_udot_4x8_uadd,
      0, 2,
      { 16, 36, 313 },
      -1,
   } },

   /* ('iadd', ('sudot_4x8_iadd(is_used_once)', 'a', 'b', '#c'), '#d') => ('sudot_4x8_iadd', 'a', 'b', ('iadd', 'c', 'd')) */
   /* search121_0_0 -> 16 in the cache */
   /* search121_0_1 -> 36 in the cache */
   /* search121_0_2 -> 309 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sudot_4x8_iadd,
      -1, 0,
      { 16, 36, 309 },
      0,
   } },
   /* search121_1 -> 311 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 318, 311 },
      -1,
   } },

   /* replace121_0 -> 16 in the cache */
   /* replace121_1 -> 36 in the cache */
   /* replace121_2_0 -> 135 in the cache */
   /* replace121_2_1 -> 163 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 135, 163 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sudot_4x8_iadd,
      -1, 1,
      { 16, 36, 320 },
      -1,
   } },

   /* ('iadd', ('sdot_2x16_iadd(is_used_once)', 'a', 'b', '#c'), '#d') => ('sdot_2x16_iadd', 'a', 'b', ('iadd', 'c', 'd')) */
   /* search122_0_0 -> 16 in the cache */
   /* search122_0_1 -> 36 in the cache */
   /* search122_0_2 -> 309 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sdot_2x16_iadd,
      1, 1,
      { 16, 36, 309 },
      0,
   } },
   /* search122_1 -> 311 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 322, 311 },
      -1,
   } },

   /* replace122_0 -> 16 in the cache */
   /* replace122_1 -> 36 in the cache */
   /* replace122_2_0 -> 135 in the cache */
   /* replace122_2_1 -> 163 in the cache */
   /* replace122_2 -> 313 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sdot_2x16_iadd,
      0, 2,
      { 16, 36, 313 },
      -1,
   } },

   /* ('iadd', ('udot_2x16_uadd(is_used_once)', 'a', 'b', '#c'), '#d') => ('udot_2x16_uadd', 'a', 'b', ('iadd', 'c', 'd')) */
   /* search123_0_0 -> 16 in the cache */
   /* search123_0_1 -> 36 in the cache */
   /* search123_0_2 -> 309 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_udot_2x16_uadd,
      1, 1,
      { 16, 36, 309 },
      0,
   } },
   /* search123_1 -> 311 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 325, 311 },
      -1,
   } },

   /* replace123_0 -> 16 in the cache */
   /* replace123_1 -> 36 in the cache */
   /* replace123_2_0 -> 135 in the cache */
   /* replace123_2_1 -> 163 in the cache */
   /* replace123_2 -> 313 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_udot_2x16_uadd,
      0, 2,
      { 16, 36, 313 },
      -1,
   } },

   /* ('iadd', ('sdot_4x8_iadd', 'a(is_not_const)', 'b', 0), 'c') => ('sdot_4x8_iadd', 'a', 'b', 'c') */
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* a */
      false,
      nir_type_invalid,
      5,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search124_0_1 -> 36 in the cache */
   /* search124_0_2 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sdot_4x8_iadd,
      1, 1,
      { 328, 36, 122 },
      -1,
   } },
   /* search124_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 329, 135 },
      -1,
   } },

   /* replace124_0 -> 16 in the cache */
   /* replace124_1 -> 36 in the cache */
   /* replace124_2 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sdot_4x8_iadd,
      0, 1,
      { 16, 36, 135 },
      -1,
   } },

   /* ('iadd', ('udot_4x8_uadd', 'a(is_not_const)', 'b', 0), 'c') => ('udot_4x8_uadd', 'a', 'b', 'c') */
   /* search125_0_0 -> 328 in the cache */
   /* search125_0_1 -> 36 in the cache */
   /* search125_0_2 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_udot_4x8_uadd,
      1, 1,
      { 328, 36, 122 },
      -1,
   } },
   /* search125_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 332, 135 },
      -1,
   } },

   /* replace125_0 -> 16 in the cache */
   /* replace125_1 -> 36 in the cache */
   /* replace125_2 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_udot_4x8_uadd,
      0, 1,
      { 16, 36, 135 },
      -1,
   } },

   /* ('iadd', ('sudot_4x8_iadd', 'a(is_not_const)', 'b', 0), 'c') => ('sudot_4x8_iadd', 'a', 'b', 'c') */
   /* search126_0_0 -> 328 in the cache */
   /* search126_0_1 -> 36 in the cache */
   /* search126_0_2 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sudot_4x8_iadd,
      -1, 0,
      { 328, 36, 122 },
      -1,
   } },
   /* search126_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 335, 135 },
      -1,
   } },

   /* replace126_0 -> 16 in the cache */
   /* replace126_1 -> 36 in the cache */
   /* replace126_2 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sudot_4x8_iadd,
      -1, 0,
      { 16, 36, 135 },
      -1,
   } },

   /* ('iadd', ('sudot_4x8_iadd', 'a', 'b(is_not_const)', 0), 'c') => ('sudot_4x8_iadd', 'a', 'b', 'c') */
   /* search127_0_0 -> 16 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      false,
      nir_type_invalid,
      5,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search127_0_2 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sudot_4x8_iadd,
      -1, 0,
      { 16, 338, 122 },
      -1,
   } },
   /* search127_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 339, 135 },
      -1,
   } },

   /* replace127_0 -> 16 in the cache */
   /* replace127_1 -> 36 in the cache */
   /* replace127_2 -> 135 in the cache */
   /* replace127 -> 337 in the cache */

   /* ('iadd', ('sdot_2x16_iadd', 'a(is_not_const)', 'b', 0), 'c') => ('sdot_2x16_iadd', 'a', 'b', 'c') */
   /* search128_0_0 -> 328 in the cache */
   /* search128_0_1 -> 36 in the cache */
   /* search128_0_2 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sdot_2x16_iadd,
      1, 1,
      { 328, 36, 122 },
      -1,
   } },
   /* search128_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 341, 135 },
      -1,
   } },

   /* replace128_0 -> 16 in the cache */
   /* replace128_1 -> 36 in the cache */
   /* replace128_2 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sdot_2x16_iadd,
      0, 1,
      { 16, 36, 135 },
      -1,
   } },

   /* ('iadd', ('udot_2x16_uadd', 'a(is_not_const)', 'b', 0), 'c') => ('udot_2x16_uadd', 'a', 'b', 'c') */
   /* search129_0_0 -> 328 in the cache */
   /* search129_0_1 -> 36 in the cache */
   /* search129_0_2 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_udot_2x16_uadd,
      1, 1,
      { 328, 36, 122 },
      -1,
   } },
   /* search129_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 344, 135 },
      -1,
   } },

   /* replace129_0 -> 16 in the cache */
   /* replace129_1 -> 36 in the cache */
   /* replace129_2 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_udot_2x16_uadd,
      0, 1,
      { 16, 36, 135 },
      -1,
   } },

   /* ('sdot_4x8_iadd', '#a', '#b', 'c(is_not_const)') => ('iadd', ('sdot_4x8_iadd', 'a', 'b', 0), 'c') */
   /* search130_0 -> 286 in the cache */
   /* search130_1 -> 33 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      2, /* c */
      false,
      nir_type_invalid,
      5,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sdot_4x8_iadd,
      0, 1,
      { 286, 33, 347 },
      -1,
   } },

   /* replace130_0_0 -> 16 in the cache */
   /* replace130_0_1 -> 36 in the cache */
   /* replace130_0_2 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sdot_4x8_iadd,
      1, 1,
      { 16, 36, 122 },
      -1,
   } },
   /* replace130_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 349, 135 },
      -1,
   } },

   /* ('udot_4x8_uadd', '#a', '#b', 'c(is_not_const)') => ('iadd', ('udot_4x8_uadd', 'a', 'b', 0), 'c') */
   /* search131_0 -> 286 in the cache */
   /* search131_1 -> 33 in the cache */
   /* search131_2 -> 347 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_udot_4x8_uadd,
      0, 1,
      { 286, 33, 347 },
      -1,
   } },

   /* replace131_0_0 -> 16 in the cache */
   /* replace131_0_1 -> 36 in the cache */
   /* replace131_0_2 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_udot_4x8_uadd,
      1, 1,
      { 16, 36, 122 },
      -1,
   } },
   /* replace131_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 352, 135 },
      -1,
   } },

   /* ('sudot_4x8_iadd', '#a', '#b', 'c(is_not_const)') => ('iadd', ('sudot_4x8_iadd', 'a', 'b', 0), 'c') */
   /* search132_0 -> 286 in the cache */
   /* search132_1 -> 33 in the cache */
   /* search132_2 -> 347 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sudot_4x8_iadd,
      -1, 0,
      { 286, 33, 347 },
      -1,
   } },

   /* replace132_0_0 -> 16 in the cache */
   /* replace132_0_1 -> 36 in the cache */
   /* replace132_0_2 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sudot_4x8_iadd,
      -1, 0,
      { 16, 36, 122 },
      -1,
   } },
   /* replace132_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 355, 135 },
      -1,
   } },

   /* ('sdot_2x16_iadd', '#a', '#b', 'c(is_not_const)') => ('iadd', ('sdot_2x16_iadd', 'a', 'b', 0), 'c') */
   /* search133_0 -> 286 in the cache */
   /* search133_1 -> 33 in the cache */
   /* search133_2 -> 347 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sdot_2x16_iadd,
      0, 1,
      { 286, 33, 347 },
      -1,
   } },

   /* replace133_0_0 -> 16 in the cache */
   /* replace133_0_1 -> 36 in the cache */
   /* replace133_0_2 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sdot_2x16_iadd,
      1, 1,
      { 16, 36, 122 },
      -1,
   } },
   /* replace133_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 358, 135 },
      -1,
   } },

   /* ('udot_2x16_uadd', '#a', '#b', 'c(is_not_const)') => ('iadd', ('udot_2x16_uadd', 'a', 'b', 0), 'c') */
   /* search134_0 -> 286 in the cache */
   /* search134_1 -> 33 in the cache */
   /* search134_2 -> 347 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_udot_2x16_uadd,
      0, 1,
      { 286, 33, 347 },
      -1,
   } },

   /* replace134_0_0 -> 16 in the cache */
   /* replace134_0_1 -> 36 in the cache */
   /* replace134_0_2 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_udot_2x16_uadd,
      1, 1,
      { 16, 36, 122 },
      -1,
   } },
   /* replace134_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 361, 135 },
      -1,
   } },

   /* ('sdot_4x8_iadd_sat', '#a', '#b', 'c(is_not_const)') => ('iadd_sat', ('sdot_4x8_iadd', 'a', 'b', 0), 'c') */
   /* search135_0 -> 286 in the cache */
   /* search135_1 -> 33 in the cache */
   /* search135_2 -> 347 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sdot_4x8_iadd_sat,
      0, 1,
      { 286, 33, 347 },
      -1,
   } },

   /* replace135_0_0 -> 16 in the cache */
   /* replace135_0_1 -> 36 in the cache */
   /* replace135_0_2 -> 122 in the cache */
   /* replace135_0 -> 349 in the cache */
   /* replace135_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd_sat,
      0, 2,
      { 349, 135 },
      -1,
   } },

   /* ('udot_4x8_uadd_sat', '#a', '#b', 'c(is_not_const)') => ('uadd_sat', ('udot_4x8_uadd', 'a', 'b', 0), 'c') */
   /* search136_0 -> 286 in the cache */
   /* search136_1 -> 33 in the cache */
   /* search136_2 -> 347 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_udot_4x8_uadd_sat,
      0, 1,
      { 286, 33, 347 },
      -1,
   } },

   /* replace136_0_0 -> 16 in the cache */
   /* replace136_0_1 -> 36 in the cache */
   /* replace136_0_2 -> 122 in the cache */
   /* replace136_0 -> 352 in the cache */
   /* replace136_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_uadd_sat,
      0, 2,
      { 352, 135 },
      -1,
   } },

   /* ('sudot_4x8_iadd_sat', '#a', '#b', 'c(is_not_const)') => ('iadd_sat', ('sudot_4x8_iadd', 'a', 'b', 0), 'c') */
   /* search137_0 -> 286 in the cache */
   /* search137_1 -> 33 in the cache */
   /* search137_2 -> 347 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sudot_4x8_iadd_sat,
      -1, 0,
      { 286, 33, 347 },
      -1,
   } },

   /* replace137_0_0 -> 16 in the cache */
   /* replace137_0_1 -> 36 in the cache */
   /* replace137_0_2 -> 122 in the cache */
   /* replace137_0 -> 355 in the cache */
   /* replace137_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd_sat,
      0, 1,
      { 355, 135 },
      -1,
   } },

   /* ('sdot_2x16_iadd_sat', '#a', '#b', 'c(is_not_const)') => ('iadd_sat', ('sdot_2x16_iadd', 'a', 'b', 0), 'c') */
   /* search138_0 -> 286 in the cache */
   /* search138_1 -> 33 in the cache */
   /* search138_2 -> 347 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sdot_2x16_iadd_sat,
      0, 1,
      { 286, 33, 347 },
      -1,
   } },

   /* replace138_0_0 -> 16 in the cache */
   /* replace138_0_1 -> 36 in the cache */
   /* replace138_0_2 -> 122 in the cache */
   /* replace138_0 -> 358 in the cache */
   /* replace138_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd_sat,
      0, 2,
      { 358, 135 },
      -1,
   } },

   /* ('udot_2x16_uadd_sat', '#a', '#b', 'c(is_not_const)') => ('uadd_sat', ('udot_2x16_uadd', 'a', 'b', 0), 'c') */
   /* search139_0 -> 286 in the cache */
   /* search139_1 -> 33 in the cache */
   /* search139_2 -> 347 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_udot_2x16_uadd_sat,
      0, 1,
      { 286, 33, 347 },
      -1,
   } },

   /* replace139_0_0 -> 16 in the cache */
   /* replace139_0_1 -> 36 in the cache */
   /* replace139_0_2 -> 122 in the cache */
   /* replace139_0 -> 361 in the cache */
   /* replace139_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_uadd_sat,
      0, 2,
      { 361, 135 },
      -1,
   } },

   /* ('fmul@32', ('bcsel', ('feq', 'b', 0.0, 'ignore_exact'), 0.0, 'a'), ('bcsel', ('feq', 'a', 0.0, 'ignore_exact'), 0.0, 'b')) => ('fmulz', 'a', 'b') */
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search140_0_0_1 -> 115 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      true,
      nir_op_feq,
      1, 1,
      { 373, 115 },
      -1,
   } },
   /* search140_0_1 -> 115 in the cache */
   /* search140_0_2 -> 183 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 374, 115, 183 },
      -1,
   } },
   /* search140_1_0_0 -> 183 in the cache */
   /* search140_1_0_1 -> 115 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      true,
      nir_op_feq,
      2, 1,
      { 183, 115 },
      -1,
   } },
   /* search140_1_1 -> 115 in the cache */
   /* search140_1_2 -> 373 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 376, 115, 373 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 3,
      { 375, 377 },
      -1,
   } },

   /* replace140_0 -> 183 in the cache */
   /* replace140_1 -> 373 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 183, 373 },
      -1,
   } },

   /* ('fmul@32', 'a', ('bcsel', ('feq', 'a', 0.0, 'ignore_exact'), 0.0, '#b(is_not_const_zero)')) => ('fmulz', 'a', 'b') */
   /* search141_0 -> 16 in the cache */
   /* search141_1_0_0 -> 16 in the cache */
   /* search141_1_0_1 -> 115 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      true,
      nir_op_feq,
      1, 1,
      { 16, 115 },
      -1,
   } },
   /* search141_1_1 -> 115 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      true,
      nir_type_invalid,
      6,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 380, 115, 381 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 2,
      { 16, 382 },
      -1,
   } },

   /* replace141_0 -> 16 in the cache */
   /* replace141_1 -> 36 in the cache */
   /* replace141 -> 269 in the cache */

   /* ('ffma@32', ('bcsel', ('feq', 'b', 0.0, 'ignore_exact'), 0.0, 'a'), ('bcsel', ('feq', 'a', 0.0, 'ignore_exact'), 0.0, 'b'), 'c') => ('ffmaz', 'a', 'b', 'c') */
   /* search142_0_0_0 -> 373 in the cache */
   /* search142_0_0_1 -> 115 in the cache */
   /* search142_0_0 -> 374 in the cache */
   /* search142_0_1 -> 115 in the cache */
   /* search142_0_2 -> 183 in the cache */
   /* search142_0 -> 375 in the cache */
   /* search142_1_0_0 -> 183 in the cache */
   /* search142_1_0_1 -> 115 in the cache */
   /* search142_1_0 -> 376 in the cache */
   /* search142_1_1 -> 115 in the cache */
   /* search142_1_2 -> 373 in the cache */
   /* search142_1 -> 377 in the cache */
   /* search142_2 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 3,
      { 375, 377, 135 },
      -1,
   } },

   /* replace142_0 -> 183 in the cache */
   /* replace142_1 -> 373 in the cache */
   /* replace142_2 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 1,
      { 183, 373, 135 },
      -1,
   } },

   /* ('ffma@32', 'a', ('bcsel', ('feq', 'a', 0.0, 'ignore_exact'), 0.0, '#b(is_not_const_zero)'), 'c') => ('ffmaz', 'a', 'b', 'c') */
   /* search143_0 -> 16 in the cache */
   /* search143_1_0_0 -> 16 in the cache */
   /* search143_1_0_1 -> 115 in the cache */
   /* search143_1_0 -> 380 in the cache */
   /* search143_1_1 -> 115 in the cache */
   /* search143_1_2 -> 381 in the cache */
   /* search143_1 -> 382 in the cache */
   /* search143_2 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 16, 382, 135 },
      -1,
   } },

   /* replace143_0 -> 16 in the cache */
   /* replace143_1 -> 36 in the cache */
   /* replace143_2 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 1,
      { 16, 36, 135 },
      -1,
   } },

   /* ('bcsel', ('feq', 'b', 0.0, 'ignore_exact'), 1.0, ('fexp2', ('fmul@32', 'a', 'b'))) => ('fexp2', ('fmulz', 'a', 'b')) */
   /* search144_0_0 -> 373 in the cache */
   /* search144_0_1 -> 115 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      true,
      nir_op_feq,
      0, 1,
      { 373, 115 },
      -1,
   } },
   /* search144_1 -> 243 in the cache */
   /* search144_2_0_0 -> 183 in the cache */
   /* search144_2_0_1 -> 373 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 183, 373 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fexp2,
      -1, 1,
      { 389 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 388, 243, 390 },
      -1,
   } },

   /* replace144_0_0 -> 183 in the cache */
   /* replace144_0_1 -> 373 in the cache */
   /* replace144_0 -> 379 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fexp2,
      -1, 1,
      { 379 },
      -1,
   } },

   /* ('sdot_4x8_iadd', 'a', 'b', 'c') => ('iadd', ('iadd', ('iadd', ('imul', ('extract_i8', 'a', 0), ('extract_i8', 'b', 0)), ('imul', ('extract_i8', 'a', 1), ('extract_i8', 'b', 1))), ('iadd', ('imul', ('extract_i8', 'a', 2), ('extract_i8', 'b', 2)), ('imul', ('extract_i8', 'a', 3), ('extract_i8', 'b', 3)))), 'c') */
   /* search145_0 -> 16 in the cache */
   /* search145_1 -> 36 in the cache */
   /* search145_2 -> 135 in the cache */
   /* search145 -> 331 in the cache */

   /* replace145_0_0_0_0_0 -> 16 in the cache */
   /* replace145_0_0_0_0_1 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 16, 122 },
      -1,
   } },
   /* replace145_0_0_0_1_0 -> 36 in the cache */
   /* replace145_0_0_0_1_1 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 36, 122 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      3, 1,
      { 393, 394 },
      -1,
   } },
   /* replace145_0_0_1_0_0 -> 16 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x1 /* 1 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 16, 396 },
      -1,
   } },
   /* replace145_0_0_1_1_0 -> 36 in the cache */
   /* replace145_0_0_1_1_1 -> 396 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 36, 396 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      4, 1,
      { 397, 398 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      2, 3,
      { 395, 399 },
      -1,
   } },
   /* replace145_0_1_0_0_0 -> 16 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x2 /* 2 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 16, 401 },
      -1,
   } },
   /* replace145_0_1_0_1_0 -> 36 in the cache */
   /* replace145_0_1_0_1_1 -> 401 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 36, 401 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      6, 1,
      { 402, 403 },
      -1,
   } },
   /* replace145_0_1_1_0_0 -> 16 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x3 /* 3 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 16, 405 },
      -1,
   } },
   /* replace145_0_1_1_1_0 -> 36 in the cache */
   /* replace145_0_1_1_1_1 -> 405 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 36, 405 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      7, 1,
      { 406, 407 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      5, 3,
      { 404, 408 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 7,
      { 400, 409 },
      -1,
   } },
   /* replace145_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 8,
      { 410, 135 },
      -1,
   } },

   /* ('udot_4x8_uadd', 'a', 'b', 'c') => ('iadd', ('iadd', ('iadd', ('imul', ('extract_u8', 'a', 0), ('extract_u8', 'b', 0)), ('imul', ('extract_u8', 'a', 1), ('extract_u8', 'b', 1))), ('iadd', ('imul', ('extract_u8', 'a', 2), ('extract_u8', 'b', 2)), ('imul', ('extract_u8', 'a', 3), ('extract_u8', 'b', 3)))), 'c') */
   /* search146_0 -> 16 in the cache */
   /* search146_1 -> 36 in the cache */
   /* search146_2 -> 135 in the cache */
   /* search146 -> 334 in the cache */

   /* replace146_0_0_0_0_0 -> 16 in the cache */
   /* replace146_0_0_0_0_1 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 16, 122 },
      -1,
   } },
   /* replace146_0_0_0_1_0 -> 36 in the cache */
   /* replace146_0_0_0_1_1 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 36, 122 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      3, 1,
      { 412, 413 },
      -1,
   } },
   /* replace146_0_0_1_0_0 -> 16 in the cache */
   /* replace146_0_0_1_0_1 -> 396 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 16, 396 },
      -1,
   } },
   /* replace146_0_0_1_1_0 -> 36 in the cache */
   /* replace146_0_0_1_1_1 -> 396 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 36, 396 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      4, 1,
      { 415, 416 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      2, 3,
      { 414, 417 },
      -1,
   } },
   /* replace146_0_1_0_0_0 -> 16 in the cache */
   /* replace146_0_1_0_0_1 -> 401 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 16, 401 },
      -1,
   } },
   /* replace146_0_1_0_1_0 -> 36 in the cache */
   /* replace146_0_1_0_1_1 -> 401 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 36, 401 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      6, 1,
      { 419, 420 },
      -1,
   } },
   /* replace146_0_1_1_0_0 -> 16 in the cache */
   /* replace146_0_1_1_0_1 -> 405 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 16, 405 },
      -1,
   } },
   /* replace146_0_1_1_1_0 -> 36 in the cache */
   /* replace146_0_1_1_1_1 -> 405 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 36, 405 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      7, 1,
      { 422, 423 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      5, 3,
      { 421, 424 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 7,
      { 418, 425 },
      -1,
   } },
   /* replace146_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 8,
      { 426, 135 },
      -1,
   } },

   /* ('sudot_4x8_iadd', 'a', 'b', 'c') => ('iadd', ('iadd', ('iadd', ('imul', ('extract_i8', 'a', 0), ('extract_u8', 'b', 0)), ('imul', ('extract_i8', 'a', 1), ('extract_u8', 'b', 1))), ('iadd', ('imul', ('extract_i8', 'a', 2), ('extract_u8', 'b', 2)), ('imul', ('extract_i8', 'a', 3), ('extract_u8', 'b', 3)))), 'c') */
   /* search147_0 -> 16 in the cache */
   /* search147_1 -> 36 in the cache */
   /* search147_2 -> 135 in the cache */
   /* search147 -> 337 in the cache */

   /* replace147_0_0_0_0_0 -> 16 in the cache */
   /* replace147_0_0_0_0_1 -> 122 in the cache */
   /* replace147_0_0_0_0 -> 393 in the cache */
   /* replace147_0_0_0_1_0 -> 36 in the cache */
   /* replace147_0_0_0_1_1 -> 122 in the cache */
   /* replace147_0_0_0_1 -> 413 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      3, 1,
      { 393, 413 },
      -1,
   } },
   /* replace147_0_0_1_0_0 -> 16 in the cache */
   /* replace147_0_0_1_0_1 -> 396 in the cache */
   /* replace147_0_0_1_0 -> 397 in the cache */
   /* replace147_0_0_1_1_0 -> 36 in the cache */
   /* replace147_0_0_1_1_1 -> 396 in the cache */
   /* replace147_0_0_1_1 -> 416 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      4, 1,
      { 397, 416 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      2, 3,
      { 428, 429 },
      -1,
   } },
   /* replace147_0_1_0_0_0 -> 16 in the cache */
   /* replace147_0_1_0_0_1 -> 401 in the cache */
   /* replace147_0_1_0_0 -> 402 in the cache */
   /* replace147_0_1_0_1_0 -> 36 in the cache */
   /* replace147_0_1_0_1_1 -> 401 in the cache */
   /* replace147_0_1_0_1 -> 420 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      6, 1,
      { 402, 420 },
      -1,
   } },
   /* replace147_0_1_1_0_0 -> 16 in the cache */
   /* replace147_0_1_1_0_1 -> 405 in the cache */
   /* replace147_0_1_1_0 -> 406 in the cache */
   /* replace147_0_1_1_1_0 -> 36 in the cache */
   /* replace147_0_1_1_1_1 -> 405 in the cache */
   /* replace147_0_1_1_1 -> 423 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      7, 1,
      { 406, 423 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      5, 3,
      { 431, 432 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 7,
      { 430, 433 },
      -1,
   } },
   /* replace147_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 8,
      { 434, 135 },
      -1,
   } },

   /* ('sdot_2x16_iadd', 'a', 'b', 'c') => ('iadd', ('iadd', ('imul', ('extract_i16', 'a', 0), ('extract_i16', 'b', 0)), ('imul', ('extract_i16', 'a', 1), ('extract_i16', 'b', 1))), 'c') */
   /* search148_0 -> 16 in the cache */
   /* search148_1 -> 36 in the cache */
   /* search148_2 -> 135 in the cache */
   /* search148 -> 343 in the cache */

   /* replace148_0_0_0_0 -> 16 in the cache */
   /* replace148_0_0_0_1 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i16,
      -1, 0,
      { 16, 122 },
      -1,
   } },
   /* replace148_0_0_1_0 -> 36 in the cache */
   /* replace148_0_0_1_1 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i16,
      -1, 0,
      { 36, 122 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      2, 1,
      { 436, 437 },
      -1,
   } },
   /* replace148_0_1_0_0 -> 16 in the cache */
   /* replace148_0_1_0_1 -> 396 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i16,
      -1, 0,
      { 16, 396 },
      -1,
   } },
   /* replace148_0_1_1_0 -> 36 in the cache */
   /* replace148_0_1_1_1 -> 396 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i16,
      -1, 0,
      { 36, 396 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      3, 1,
      { 439, 440 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 3,
      { 438, 441 },
      -1,
   } },
   /* replace148_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 4,
      { 442, 135 },
      -1,
   } },

   /* ('udot_2x16_uadd', 'a', 'b', 'c') => ('iadd', ('iadd', ('imul', ('extract_u16', 'a', 0), ('extract_u16', 'b', 0)), ('imul', ('extract_u16', 'a', 1), ('extract_u16', 'b', 1))), 'c') */
   /* search149_0 -> 16 in the cache */
   /* search149_1 -> 36 in the cache */
   /* search149_2 -> 135 in the cache */
   /* search149 -> 346 in the cache */

   /* replace149_0_0_0_0 -> 16 in the cache */
   /* replace149_0_0_0_1 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 0,
      { 16, 122 },
      -1,
   } },
   /* replace149_0_0_1_0 -> 36 in the cache */
   /* replace149_0_0_1_1 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 0,
      { 36, 122 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      2, 1,
      { 444, 445 },
      -1,
   } },
   /* replace149_0_1_0_0 -> 16 in the cache */
   /* replace149_0_1_0_1 -> 396 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 0,
      { 16, 396 },
      -1,
   } },
   /* replace149_0_1_1_0 -> 36 in the cache */
   /* replace149_0_1_1_1 -> 396 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 0,
      { 36, 396 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      3, 1,
      { 447, 448 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 3,
      { 446, 449 },
      -1,
   } },
   /* replace149_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 4,
      { 450, 135 },
      -1,
   } },

   /* ('udot_4x8_uadd_sat', 'a', 'b', '#c(is_ult_0xfffc07fc)') => ('udot_4x8_uadd', 'a', 'b', 'c') */
   /* search150_0 -> 16 in the cache */
   /* search150_1 -> 36 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      2, /* c */
      true,
      nir_type_invalid,
      7,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_udot_4x8_uadd_sat,
      0, 1,
      { 16, 36, 452 },
      -1,
   } },

   /* replace150_0 -> 16 in the cache */
   /* replace150_1 -> 36 in the cache */
   /* replace150_2 -> 135 in the cache */
   /* replace150 -> 334 in the cache */

   /* ('udot_4x8_uadd_sat', 'a', 'b', 'c') => ('uadd_sat', ('iadd', ('iadd', ('imul', ('extract_u8', 'a', 0), ('extract_u8', 'b', 0)), ('imul', ('extract_u8', 'a', 1), ('extract_u8', 'b', 1))), ('iadd', ('imul', ('extract_u8', 'a', 2), ('extract_u8', 'b', 2)), ('imul', ('extract_u8', 'a', 3), ('extract_u8', 'b', 3)))), 'c') */
   /* search151_0 -> 16 in the cache */
   /* search151_1 -> 36 in the cache */
   /* search151_2 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_udot_4x8_uadd_sat,
      0, 1,
      { 16, 36, 135 },
      -1,
   } },

   /* replace151_0_0_0_0_0 -> 16 in the cache */
   /* replace151_0_0_0_0_1 -> 122 in the cache */
   /* replace151_0_0_0_0 -> 412 in the cache */
   /* replace151_0_0_0_1_0 -> 36 in the cache */
   /* replace151_0_0_0_1_1 -> 122 in the cache */
   /* replace151_0_0_0_1 -> 413 in the cache */
   /* replace151_0_0_0 -> 414 in the cache */
   /* replace151_0_0_1_0_0 -> 16 in the cache */
   /* replace151_0_0_1_0_1 -> 396 in the cache */
   /* replace151_0_0_1_0 -> 415 in the cache */
   /* replace151_0_0_1_1_0 -> 36 in the cache */
   /* replace151_0_0_1_1_1 -> 396 in the cache */
   /* replace151_0_0_1_1 -> 416 in the cache */
   /* replace151_0_0_1 -> 417 in the cache */
   /* replace151_0_0 -> 418 in the cache */
   /* replace151_0_1_0_0_0 -> 16 in the cache */
   /* replace151_0_1_0_0_1 -> 401 in the cache */
   /* replace151_0_1_0_0 -> 419 in the cache */
   /* replace151_0_1_0_1_0 -> 36 in the cache */
   /* replace151_0_1_0_1_1 -> 401 in the cache */
   /* replace151_0_1_0_1 -> 420 in the cache */
   /* replace151_0_1_0 -> 421 in the cache */
   /* replace151_0_1_1_0_0 -> 16 in the cache */
   /* replace151_0_1_1_0_1 -> 405 in the cache */
   /* replace151_0_1_1_0 -> 422 in the cache */
   /* replace151_0_1_1_1_0 -> 36 in the cache */
   /* replace151_0_1_1_1_1 -> 405 in the cache */
   /* replace151_0_1_1_1 -> 423 in the cache */
   /* replace151_0_1_1 -> 424 in the cache */
   /* replace151_0_1 -> 425 in the cache */
   /* replace151_0 -> 426 in the cache */
   /* replace151_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_uadd_sat,
      0, 8,
      { 426, 135 },
      -1,
   } },

   /* ('sdot_4x8_iadd_sat', 'a', 'b', 'c') => ('iadd_sat', ('iadd', ('iadd', ('imul', ('extract_i8', 'a', 0), ('extract_i8', 'b', 0)), ('imul', ('extract_i8', 'a', 1), ('extract_i8', 'b', 1))), ('iadd', ('imul', ('extract_i8', 'a', 2), ('extract_i8', 'b', 2)), ('imul', ('extract_i8', 'a', 3), ('extract_i8', 'b', 3)))), 'c') */
   /* search152_0 -> 16 in the cache */
   /* search152_1 -> 36 in the cache */
   /* search152_2 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sdot_4x8_iadd_sat,
      0, 1,
      { 16, 36, 135 },
      -1,
   } },

   /* replace152_0_0_0_0_0 -> 16 in the cache */
   /* replace152_0_0_0_0_1 -> 122 in the cache */
   /* replace152_0_0_0_0 -> 393 in the cache */
   /* replace152_0_0_0_1_0 -> 36 in the cache */
   /* replace152_0_0_0_1_1 -> 122 in the cache */
   /* replace152_0_0_0_1 -> 394 in the cache */
   /* replace152_0_0_0 -> 395 in the cache */
   /* replace152_0_0_1_0_0 -> 16 in the cache */
   /* replace152_0_0_1_0_1 -> 396 in the cache */
   /* replace152_0_0_1_0 -> 397 in the cache */
   /* replace152_0_0_1_1_0 -> 36 in the cache */
   /* replace152_0_0_1_1_1 -> 396 in the cache */
   /* replace152_0_0_1_1 -> 398 in the cache */
   /* replace152_0_0_1 -> 399 in the cache */
   /* replace152_0_0 -> 400 in the cache */
   /* replace152_0_1_0_0_0 -> 16 in the cache */
   /* replace152_0_1_0_0_1 -> 401 in the cache */
   /* replace152_0_1_0_0 -> 402 in the cache */
   /* replace152_0_1_0_1_0 -> 36 in the cache */
   /* replace152_0_1_0_1_1 -> 401 in the cache */
   /* replace152_0_1_0_1 -> 403 in the cache */
   /* replace152_0_1_0 -> 404 in the cache */
   /* replace152_0_1_1_0_0 -> 16 in the cache */
   /* replace152_0_1_1_0_1 -> 405 in the cache */
   /* replace152_0_1_1_0 -> 406 in the cache */
   /* replace152_0_1_1_1_0 -> 36 in the cache */
   /* replace152_0_1_1_1_1 -> 405 in the cache */
   /* replace152_0_1_1_1 -> 407 in the cache */
   /* replace152_0_1_1 -> 408 in the cache */
   /* replace152_0_1 -> 409 in the cache */
   /* replace152_0 -> 410 in the cache */
   /* replace152_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd_sat,
      0, 8,
      { 410, 135 },
      -1,
   } },

   /* ('sudot_4x8_iadd_sat', 'a', 'b', 'c') => ('iadd_sat', ('iadd', ('iadd', ('imul', ('extract_i8', 'a', 0), ('extract_u8', 'b', 0)), ('imul', ('extract_i8', 'a', 1), ('extract_u8', 'b', 1))), ('iadd', ('imul', ('extract_i8', 'a', 2), ('extract_u8', 'b', 2)), ('imul', ('extract_i8', 'a', 3), ('extract_u8', 'b', 3)))), 'c') */
   /* search153_0 -> 16 in the cache */
   /* search153_1 -> 36 in the cache */
   /* search153_2 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sudot_4x8_iadd_sat,
      -1, 0,
      { 16, 36, 135 },
      -1,
   } },

   /* replace153_0_0_0_0_0 -> 16 in the cache */
   /* replace153_0_0_0_0_1 -> 122 in the cache */
   /* replace153_0_0_0_0 -> 393 in the cache */
   /* replace153_0_0_0_1_0 -> 36 in the cache */
   /* replace153_0_0_0_1_1 -> 122 in the cache */
   /* replace153_0_0_0_1 -> 413 in the cache */
   /* replace153_0_0_0 -> 428 in the cache */
   /* replace153_0_0_1_0_0 -> 16 in the cache */
   /* replace153_0_0_1_0_1 -> 396 in the cache */
   /* replace153_0_0_1_0 -> 397 in the cache */
   /* replace153_0_0_1_1_0 -> 36 in the cache */
   /* replace153_0_0_1_1_1 -> 396 in the cache */
   /* replace153_0_0_1_1 -> 416 in the cache */
   /* replace153_0_0_1 -> 429 in the cache */
   /* replace153_0_0 -> 430 in the cache */
   /* replace153_0_1_0_0_0 -> 16 in the cache */
   /* replace153_0_1_0_0_1 -> 401 in the cache */
   /* replace153_0_1_0_0 -> 402 in the cache */
   /* replace153_0_1_0_1_0 -> 36 in the cache */
   /* replace153_0_1_0_1_1 -> 401 in the cache */
   /* replace153_0_1_0_1 -> 420 in the cache */
   /* replace153_0_1_0 -> 431 in the cache */
   /* replace153_0_1_1_0_0 -> 16 in the cache */
   /* replace153_0_1_1_0_1 -> 405 in the cache */
   /* replace153_0_1_1_0 -> 406 in the cache */
   /* replace153_0_1_1_1_0 -> 36 in the cache */
   /* replace153_0_1_1_1_1 -> 405 in the cache */
   /* replace153_0_1_1_1 -> 423 in the cache */
   /* replace153_0_1_1 -> 432 in the cache */
   /* replace153_0_1 -> 433 in the cache */
   /* replace153_0 -> 434 in the cache */
   /* replace153_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd_sat,
      0, 8,
      { 434, 135 },
      -1,
   } },

   /* ('udot_2x16_uadd_sat', 'a', 'b', 'c') => ('uadd_sat', ('iadd', ('imul', ('extract_u16', 'a', 0), ('extract_u16', 'b', 0)), ('imul', ('extract_u16', 'a', 1), ('extract_u16', 'b', 1))), 'c') */
   /* search154_0 -> 16 in the cache */
   /* search154_1 -> 36 in the cache */
   /* search154_2 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_udot_2x16_uadd_sat,
      0, 1,
      { 16, 36, 135 },
      -1,
   } },

   /* replace154_0_0_0_0 -> 16 in the cache */
   /* replace154_0_0_0_1 -> 122 in the cache */
   /* replace154_0_0_0 -> 444 in the cache */
   /* replace154_0_0_1_0 -> 36 in the cache */
   /* replace154_0_0_1_1 -> 122 in the cache */
   /* replace154_0_0_1 -> 445 in the cache */
   /* replace154_0_0 -> 446 in the cache */
   /* replace154_0_1_0_0 -> 16 in the cache */
   /* replace154_0_1_0_1 -> 396 in the cache */
   /* replace154_0_1_0 -> 447 in the cache */
   /* replace154_0_1_1_0 -> 36 in the cache */
   /* replace154_0_1_1_1 -> 396 in the cache */
   /* replace154_0_1_1 -> 448 in the cache */
   /* replace154_0_1 -> 449 in the cache */
   /* replace154_0 -> 450 in the cache */
   /* replace154_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_uadd_sat,
      0, 4,
      { 450, 135 },
      -1,
   } },

   /* ('sdot_2x16_iadd_sat', 'a', 'b', 'c') => ('iadd_sat', ('iadd', ('imul', ('extract_i16', 'a', 0), ('extract_i16', 'b', 0)), ('imul', ('extract_i16', 'a', 1), ('extract_i16', 'b', 1))), 'c') */
   /* search155_0 -> 16 in the cache */
   /* search155_1 -> 36 in the cache */
   /* search155_2 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sdot_2x16_iadd_sat,
      0, 1,
      { 16, 36, 135 },
      -1,
   } },

   /* replace155_0_0_0_0 -> 16 in the cache */
   /* replace155_0_0_0_1 -> 122 in the cache */
   /* replace155_0_0_0 -> 436 in the cache */
   /* replace155_0_0_1_0 -> 36 in the cache */
   /* replace155_0_0_1_1 -> 122 in the cache */
   /* replace155_0_0_1 -> 437 in the cache */
   /* replace155_0_0 -> 438 in the cache */
   /* replace155_0_1_0_0 -> 16 in the cache */
   /* replace155_0_1_0_1 -> 396 in the cache */
   /* replace155_0_1_0 -> 439 in the cache */
   /* replace155_0_1_1_0 -> 36 in the cache */
   /* replace155_0_1_1_1 -> 396 in the cache */
   /* replace155_0_1_1 -> 440 in the cache */
   /* replace155_0_1 -> 441 in the cache */
   /* replace155_0 -> 442 in the cache */
   /* replace155_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd_sat,
      0, 4,
      { 442, 135 },
      -1,
   } },

   /* ('~flrp@16', 'a', 'b', ('b2f', 'c@1')) => ('bcsel', 'c', 'b', 'a') */
   /* search156_0 -> 11 in the cache */
   /* search156_1 -> 258 in the cache */
   { .variable = {
      { nir_search_value_variable, 1 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 464 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 11, 258, 465 },
      -1,
   } },

   /* replace156_0 -> 464 in the cache */
   /* replace156_1 -> 258 in the cache */
   /* replace156_2 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 464, 258, 11 },
      -1,
   } },

   /* ('~flrp@16', 'a', ('fadd', 'a', 'b'), 'c') => ('fadd', ('fmul', 'b', 'c'), 'a') */
   /* search157_0 -> 11 in the cache */
   /* search157_1_0 -> 11 in the cache */
   /* search157_1_1 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 11, 258 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, 16 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 1,
      { 11, 468, 469 },
      -1,
   } },

   /* replace157_0_0 -> 258 in the cache */
   /* replace157_0_1 -> 469 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 258, 469 },
      -1,
   } },
   /* replace157_1 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 471, 11 },
      -1,
   } },

   /* ('~flrp@16', ('fadd(is_used_once)', 'a', 'b'), ('fadd(is_used_once)', 'a', 'c'), 'd') => ('fadd', ('flrp', 'b', 'c', 'd'), 'a') */
   /* search158_0_0 -> 11 in the cache */
   /* search158_0_1 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 11, 258 },
      0,
   } },
   /* search158_1_0 -> 11 in the cache */
   /* search158_1_1 -> 469 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 11, 469 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, 16 },
      3, /* d */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 2,
      { 473, 474, 475 },
      -1,
   } },

   /* replace158_0_0 -> 258 in the cache */
   /* replace158_0_1 -> 469 in the cache */
   /* replace158_0_2 -> 475 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 258, 469, 475 },
      -1,
   } },
   /* replace158_1 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 477, 11 },
      -1,
   } },

   /* ('~flrp@16', 'a', ('fmul(is_used_once)', 'a', 'b'), 'c') => ('fmul', ('flrp', 1.0, 'b', 'c'), 'a') */
   /* search159_0 -> 11 in the cache */
   /* search159_1_0 -> 11 in the cache */
   /* search159_1_1 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 11, 258 },
      0,
   } },
   /* search159_2 -> 469 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 1,
      { 11, 479, 469 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, 16 },
      nir_type_float, { 0x3ff0000000000000 /* 1.0 */ },
   } },
   /* replace159_0_1 -> 258 in the cache */
   /* replace159_0_2 -> 469 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 481, 258, 469 },
      -1,
   } },
   /* replace159_1 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 482, 11 },
      -1,
   } },

   /* ('~fadd@16', ('fmul', 'a', ('fadd', 1.0, ('fneg', 'c'))), ('fmul', 'b', 'c')) => ('flrp', 'a', 'b', 'c') */
   /* search160_0_0 -> 11 in the cache */
   /* search160_0_1_0 -> 481 in the cache */
   { .variable = {
      { nir_search_value_variable, 16 },
      1, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 484 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fadd,
      2, 1,
      { 481, 485 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 2,
      { 11, 486 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, 16 },
      2, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search160_1_1 -> 484 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      3, 1,
      { 488, 484 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 4,
      { 487, 489 },
      -1,
   } },

   /* replace160_0 -> 11 in the cache */
   /* replace160_1 -> 488 in the cache */
   /* replace160_2 -> 484 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 11, 488, 484 },
      -1,
   } },

   /* ('~fadd@16', ('fmul', 'a', ('fsat', ('fadd', 1.0, ('fneg', 'c')))), ('fmul', 'b', ('fsat', 'c'))) => ('flrp', 'a', 'b', ('fsat', 'c')) */
   /* search161_0_0 -> 11 in the cache */
   /* search161_0_1_0_0 -> 481 in the cache */
   /* search161_0_1_0_1_0 -> 484 in the cache */
   /* search161_0_1_0_1 -> 485 in the cache */
   /* search161_0_1_0 -> 486 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 1,
      { 486 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 2,
      { 11, 492 },
      -1,
   } },
   /* search161_1_0 -> 488 in the cache */
   /* search161_1_1_0 -> 484 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 484 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      3, 1,
      { 488, 494 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 4,
      { 493, 495 },
      -1,
   } },

   /* replace161_0 -> 11 in the cache */
   /* replace161_1 -> 488 in the cache */
   /* replace161_2_0 -> 484 in the cache */
   /* replace161_2 -> 494 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 11, 488, 494 },
      -1,
   } },

   /* ('~fadd@16', 'a', ('fmul', 'c', ('fadd', 'b', ('fneg', 'a')))) => ('flrp', 'a', 'b', 'c') */
   /* search162_0 -> 11 in the cache */
   /* search162_1_0 -> 484 in the cache */
   /* search162_1_1_0 -> 488 in the cache */
   /* search162_1_1_1_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 11 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fadd,
      2, 1,
      { 488, 498 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 2,
      { 484, 499 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 11, 500 },
      -1,
   } },

   /* replace162_0 -> 11 in the cache */
   /* replace162_1 -> 488 in the cache */
   /* replace162_2 -> 484 in the cache */
   /* replace162 -> 491 in the cache */

   /* ('~fadd@16', ('fmul', 'a', ('fadd', 1.0, ('fneg', ('b2f', 'c@1')))), ('fmul', 'b', ('b2f', 'c'))) => ('bcsel', 'c', 'b', 'a') */
   /* search163_0_0 -> 11 in the cache */
   /* search163_0_1_0 -> 481 in the cache */
   { .variable = {
      { nir_search_value_variable, 1 },
      1, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 502 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 503 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fadd,
      2, 1,
      { 481, 504 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 2,
      { 11, 505 },
      -1,
   } },
   /* search163_1_0 -> 488 in the cache */
   /* search163_1_1_0 -> 502 in the cache */
   /* search163_1_1 -> 503 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      3, 1,
      { 488, 503 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 4,
      { 506, 507 },
      -1,
   } },

   /* replace163_0 -> 502 in the cache */
   /* replace163_1 -> 488 in the cache */
   /* replace163_2 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 488, 11 },
      -1,
   } },

   /* ('~fadd@16', 'a', ('fmul', ('b2f', 'c@1'), ('fadd', 'b', ('fneg', 'a')))) => ('bcsel', 'c', 'b', 'a') */
   /* search164_0 -> 11 in the cache */
   /* search164_1_0_0 -> 502 in the cache */
   /* search164_1_0 -> 503 in the cache */
   /* search164_1_1_0 -> 488 in the cache */
   /* search164_1_1_1_0 -> 11 in the cache */
   /* search164_1_1_1 -> 498 in the cache */
   /* search164_1_1 -> 499 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 2,
      { 503, 499 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 11, 510 },
      -1,
   } },

   /* replace164_0 -> 502 in the cache */
   /* replace164_1 -> 488 in the cache */
   /* replace164_2 -> 11 in the cache */
   /* replace164 -> 509 in the cache */

   /* ('~ffma@16', 'a', ('fadd', 1.0, ('fneg', ('b2f', 'c@1'))), ('fmul', 'b', ('b2f', 'c@1'))) => ('bcsel', 'c', 'b', 'a') */
   /* search165_0 -> 11 in the cache */
   /* search165_1_0 -> 481 in the cache */
   /* search165_1_1_0_0 -> 502 in the cache */
   /* search165_1_1_0 -> 503 in the cache */
   /* search165_1_1 -> 504 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 481, 504 },
      -1,
   } },
   /* search165_2_0 -> 488 in the cache */
   /* search165_2_1_0 -> 502 in the cache */
   /* search165_2_1 -> 503 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      2, 1,
      { 488, 503 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 3,
      { 11, 512, 513 },
      -1,
   } },

   /* replace165_0 -> 502 in the cache */
   /* replace165_1 -> 488 in the cache */
   /* replace165_2 -> 11 in the cache */
   /* replace165 -> 509 in the cache */

   /* ('~ffma@16', 'b', ('b2f', 'c@1'), ('ffma', ('fneg', 'a'), ('b2f', 'c@1'), 'a')) => ('bcsel', 'c', 'b', 'a') */
   { .variable = {
      { nir_search_value_variable, 16 },
      0, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search166_1_0 -> 502 in the cache */
   /* search166_1 -> 503 in the cache */
   { .variable = {
      { nir_search_value_variable, 16 },
      2, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 516 },
      -1,
   } },
   /* search166_2_1_0 -> 502 in the cache */
   /* search166_2_1 -> 503 in the cache */
   /* search166_2_2 -> 516 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ffma,
      1, 1,
      { 517, 503, 516 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 515, 503, 518 },
      -1,
   } },

   /* replace166_0 -> 502 in the cache */
   /* replace166_1 -> 515 in the cache */
   /* replace166_2 -> 516 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 515, 516 },
      -1,
   } },

   /* ('~ffma@16', ('b2f', 'c@1'), ('fadd', 'b', ('fneg', 'a')), 'a') => ('bcsel', 'c', 'b', 'a') */
   { .variable = {
      { nir_search_value_variable, 1 },
      0, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 521 },
      -1,
   } },
   /* search167_1_0 -> 258 in the cache */
   /* search167_1_1_0 -> 516 in the cache */
   /* search167_1_1 -> 517 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 258, 517 },
      -1,
   } },
   /* search167_2 -> 516 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 522, 523, 516 },
      -1,
   } },

   /* replace167_0 -> 521 in the cache */
   /* replace167_1 -> 258 in the cache */
   /* replace167_2 -> 516 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 521, 258, 516 },
      -1,
   } },

   /* ('~ffma@16', ('b2f', 'c@1'), ('ffma', ('fneg', 'a'), 'b', 'd'), ('fmul', 'a', 'b')) => ('bcsel', 'c', 'd', ('fmul', 'a', 'b')) */
   /* search168_0_0 -> 521 in the cache */
   /* search168_0 -> 522 in the cache */
   { .variable = {
      { nir_search_value_variable, 16 },
      1, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 526 },
      -1,
   } },
   /* search168_1_1 -> 488 in the cache */
   /* search168_1_2 -> 475 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ffma,
      1, 1,
      { 527, 488, 475 },
      -1,
   } },
   /* search168_2_0 -> 526 in the cache */
   /* search168_2_1 -> 488 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      2, 1,
      { 526, 488 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 3,
      { 522, 528, 529 },
      -1,
   } },

   /* replace168_0 -> 521 in the cache */
   /* replace168_1 -> 475 in the cache */
   /* replace168_2_0 -> 526 in the cache */
   /* replace168_2_1 -> 488 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 526, 488 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 521, 475, 531 },
      -1,
   } },

   /* ('~fadd@16', 1.0, ('fneg', ('fmul', ('fadd', 1.0, ('fneg', 'a')), ('fadd', 1.0, ('fneg', 'b'))))) => ('flrp', 'b', 1.0, 'a') */
   /* search169_0 -> 481 in the cache */
   /* search169_1_0_0_0 -> 481 in the cache */
   /* search169_1_0_0_1_0 -> 11 in the cache */
   /* search169_1_0_0_1 -> 498 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fadd,
      2, 1,
      { 481, 498 },
      -1,
   } },
   /* search169_1_0_1_0 -> 481 in the cache */
   /* search169_1_0_1_1_0 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 258 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fadd,
      3, 1,
      { 481, 534 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 3,
      { 533, 535 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 3,
      { 536 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 4,
      { 481, 537 },
      -1,
   } },

   /* replace169_0 -> 258 in the cache */
   /* replace169_1 -> 481 in the cache */
   /* replace169_2 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 258, 481, 11 },
      -1,
   } },

   /* ('~flrp@32', 'a', 'b', ('b2f', 'c@1')) => ('bcsel', 'c', 'b', 'a') */
   /* search170_0 -> 16 in the cache */
   /* search170_1 -> 36 in the cache */
   /* search170_2_0 -> 464 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 464 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 16, 36, 540 },
      -1,
   } },

   /* replace170_0 -> 464 in the cache */
   /* replace170_1 -> 36 in the cache */
   /* replace170_2 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 464, 36, 16 },
      -1,
   } },

   /* ('~flrp@32', 'a', ('fadd', 'a', 'b'), 'c') => ('fadd', ('fmul', 'b', 'c'), 'a') */
   /* search171_0 -> 16 in the cache */
   /* search171_1_0 -> 16 in the cache */
   /* search171_1_1 -> 36 in the cache */
   /* search171_1 -> 274 in the cache */
   /* search171_2 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 1,
      { 16, 274, 135 },
      -1,
   } },

   /* replace171_0_0 -> 36 in the cache */
   /* replace171_0_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 36, 135 },
      -1,
   } },
   /* replace171_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 544, 16 },
      -1,
   } },

   /* ('~flrp@32', ('fadd(is_used_once)', 'a', 'b'), ('fadd(is_used_once)', 'a', 'c'), 'd') => ('fadd', ('flrp', 'b', 'c', 'd'), 'a') */
   /* search172_0_0 -> 16 in the cache */
   /* search172_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 16, 36 },
      0,
   } },
   /* search172_1_0 -> 16 in the cache */
   /* search172_1_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 16, 135 },
      0,
   } },
   /* search172_2 -> 163 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 2,
      { 546, 547, 163 },
      -1,
   } },

   /* replace172_0_0 -> 36 in the cache */
   /* replace172_0_1 -> 135 in the cache */
   /* replace172_0_2 -> 163 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 36, 135, 163 },
      -1,
   } },
   /* replace172_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 549, 16 },
      -1,
   } },

   /* ('~flrp@32', 'a', ('fmul(is_used_once)', 'a', 'b'), 'c') => ('fmul', ('flrp', 1.0, 'b', 'c'), 'a') */
   /* search173_0 -> 16 in the cache */
   /* search173_1_0 -> 16 in the cache */
   /* search173_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 16, 36 },
      0,
   } },
   /* search173_2 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 1,
      { 16, 551, 135 },
      -1,
   } },

   /* replace173_0_0 -> 243 in the cache */
   /* replace173_0_1 -> 36 in the cache */
   /* replace173_0_2 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 243, 36, 135 },
      -1,
   } },
   /* replace173_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 553, 16 },
      -1,
   } },

   /* ('~fadd@32', ('fmul', 'a', ('fadd', 1.0, ('fneg', 'c'))), ('fmul', 'b', 'c')) => ('flrp', 'a', 'b', 'c') */
   /* search174_0_0 -> 16 in the cache */
   /* search174_0_1_0 -> 243 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 555 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      2, 1,
      { 243, 556 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 2,
      { 16, 557 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      2, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search174_1_1 -> 555 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      3, 1,
      { 559, 555 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 4,
      { 558, 560 },
      -1,
   } },

   /* replace174_0 -> 16 in the cache */
   /* replace174_1 -> 559 in the cache */
   /* replace174_2 -> 555 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 16, 559, 555 },
      -1,
   } },

   /* ('~fadd@32', ('fmul', 'a', ('fsat', ('fadd', 1.0, ('fneg', 'c')))), ('fmul', 'b', ('fsat', 'c'))) => ('flrp', 'a', 'b', ('fsat', 'c')) */
   /* search175_0_0 -> 16 in the cache */
   /* search175_0_1_0_0 -> 243 in the cache */
   /* search175_0_1_0_1_0 -> 555 in the cache */
   /* search175_0_1_0_1 -> 556 in the cache */
   /* search175_0_1_0 -> 557 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 1,
      { 557 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 2,
      { 16, 563 },
      -1,
   } },
   /* search175_1_0 -> 559 in the cache */
   /* search175_1_1_0 -> 555 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 555 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      3, 1,
      { 559, 565 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 4,
      { 564, 566 },
      -1,
   } },

   /* replace175_0 -> 16 in the cache */
   /* replace175_1 -> 559 in the cache */
   /* replace175_2_0 -> 555 in the cache */
   /* replace175_2 -> 565 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 16, 559, 565 },
      -1,
   } },

   /* ('~fadd@32', 'a', ('fmul', 'c', ('fadd', 'b', ('fneg', 'a')))) => ('flrp', 'a', 'b', 'c') */
   /* search176_0 -> 16 in the cache */
   /* search176_1_0 -> 555 in the cache */
   /* search176_1_1_0 -> 559 in the cache */
   /* search176_1_1_1_0 -> 16 in the cache */
   /* search176_1_1_1 -> 280 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      2, 1,
      { 559, 280 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 2,
      { 555, 569 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 16, 570 },
      -1,
   } },

   /* replace176_0 -> 16 in the cache */
   /* replace176_1 -> 559 in the cache */
   /* replace176_2 -> 555 in the cache */
   /* replace176 -> 562 in the cache */

   /* ('~fadd@32', ('fmul', 'a', ('fadd', 1.0, ('fneg', ('b2f', 'c@1')))), ('fmul', 'b', ('b2f', 'c'))) => ('bcsel', 'c', 'b', 'a') */
   /* search177_0_0 -> 16 in the cache */
   /* search177_0_1_0 -> 243 in the cache */
   /* search177_0_1_1_0_0 -> 502 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 502 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 572 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      2, 1,
      { 243, 573 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 2,
      { 16, 574 },
      -1,
   } },
   /* search177_1_0 -> 559 in the cache */
   /* search177_1_1_0 -> 502 in the cache */
   /* search177_1_1 -> 572 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      3, 1,
      { 559, 572 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 4,
      { 575, 576 },
      -1,
   } },

   /* replace177_0 -> 502 in the cache */
   /* replace177_1 -> 559 in the cache */
   /* replace177_2 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 559, 16 },
      -1,
   } },

   /* ('~fadd@32', 'a', ('fmul', ('b2f', 'c@1'), ('fadd', 'b', ('fneg', 'a')))) => ('bcsel', 'c', 'b', 'a') */
   /* search178_0 -> 16 in the cache */
   /* search178_1_0_0 -> 502 in the cache */
   /* search178_1_0 -> 572 in the cache */
   /* search178_1_1_0 -> 559 in the cache */
   /* search178_1_1_1_0 -> 16 in the cache */
   /* search178_1_1_1 -> 280 in the cache */
   /* search178_1_1 -> 569 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 2,
      { 572, 569 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 16, 579 },
      -1,
   } },

   /* replace178_0 -> 502 in the cache */
   /* replace178_1 -> 559 in the cache */
   /* replace178_2 -> 16 in the cache */
   /* replace178 -> 578 in the cache */

   /* ('~ffma@32', 'a', ('fadd', 1.0, ('fneg', ('b2f', 'c@1'))), ('fmul', 'b', ('b2f', 'c@1'))) => ('bcsel', 'c', 'b', 'a') */
   /* search179_0 -> 16 in the cache */
   /* search179_1_0 -> 243 in the cache */
   /* search179_1_1_0_0 -> 502 in the cache */
   /* search179_1_1_0 -> 572 in the cache */
   /* search179_1_1 -> 573 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 243, 573 },
      -1,
   } },
   /* search179_2_0 -> 559 in the cache */
   /* search179_2_1_0 -> 502 in the cache */
   /* search179_2_1 -> 572 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      2, 1,
      { 559, 572 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 3,
      { 16, 581, 582 },
      -1,
   } },

   /* replace179_0 -> 502 in the cache */
   /* replace179_1 -> 559 in the cache */
   /* replace179_2 -> 16 in the cache */
   /* replace179 -> 578 in the cache */

   /* ('~ffma@32', 'b', ('b2f', 'c@1'), ('ffma', ('fneg', 'a'), ('b2f', 'c@1'), 'a')) => ('bcsel', 'c', 'b', 'a') */
   /* search180_0 -> 373 in the cache */
   /* search180_1_0 -> 502 in the cache */
   /* search180_1 -> 572 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      2, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 584 },
      -1,
   } },
   /* search180_2_1_0 -> 502 in the cache */
   /* search180_2_1 -> 572 in the cache */
   /* search180_2_2 -> 584 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffma,
      1, 1,
      { 585, 572, 584 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 373, 572, 586 },
      -1,
   } },

   /* replace180_0 -> 502 in the cache */
   /* replace180_1 -> 373 in the cache */
   /* replace180_2 -> 584 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 373, 584 },
      -1,
   } },

   /* ('~ffma@32', ('b2f', 'c@1'), ('fadd', 'b', ('fneg', 'a')), 'a') => ('bcsel', 'c', 'b', 'a') */
   /* search181_0_0 -> 521 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 521 },
      -1,
   } },
   /* search181_1_0 -> 36 in the cache */
   /* search181_1_1_0 -> 584 in the cache */
   /* search181_1_1 -> 585 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 36, 585 },
      -1,
   } },
   /* search181_2 -> 584 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 589, 590, 584 },
      -1,
   } },

   /* replace181_0 -> 521 in the cache */
   /* replace181_1 -> 36 in the cache */
   /* replace181_2 -> 584 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 521, 36, 584 },
      -1,
   } },

   /* ('~ffma@32', ('b2f', 'c@1'), ('ffma', ('fneg', 'a'), 'b', 'd'), ('fmul', 'a', 'b')) => ('bcsel', 'c', 'd', ('fmul', 'a', 'b')) */
   /* search182_0_0 -> 521 in the cache */
   /* search182_0 -> 589 in the cache */
   /* search182_1_0_0 -> 183 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 183 },
      -1,
   } },
   /* search182_1_1 -> 559 in the cache */
   /* search182_1_2 -> 163 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffma,
      1, 1,
      { 593, 559, 163 },
      -1,
   } },
   /* search182_2_0 -> 183 in the cache */
   /* search182_2_1 -> 559 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      2, 1,
      { 183, 559 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 3,
      { 589, 594, 595 },
      -1,
   } },

   /* replace182_0 -> 521 in the cache */
   /* replace182_1 -> 163 in the cache */
   /* replace182_2_0 -> 183 in the cache */
   /* replace182_2_1 -> 559 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 183, 559 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 521, 163, 597 },
      -1,
   } },

   /* ('~fadd@32', 1.0, ('fneg', ('fmul', ('fadd', 1.0, ('fneg', 'a')), ('fadd', 1.0, ('fneg', 'b'))))) => ('flrp', 'b', 1.0, 'a') */
   /* search183_0 -> 243 in the cache */
   /* search183_1_0_0_0 -> 243 in the cache */
   /* search183_1_0_0_1_0 -> 16 in the cache */
   /* search183_1_0_0_1 -> 280 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      2, 1,
      { 243, 280 },
      -1,
   } },
   /* search183_1_0_1_0 -> 243 in the cache */
   /* search183_1_0_1_1_0 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      3, 1,
      { 243, 600 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 3,
      { 599, 601 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 3,
      { 602 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 4,
      { 243, 603 },
      -1,
   } },

   /* replace183_0 -> 36 in the cache */
   /* replace183_1 -> 243 in the cache */
   /* replace183_2 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 36, 243, 16 },
      -1,
   } },

   /* ('~flrp@64', 'a', 'b', ('b2f', 'c@1')) => ('bcsel', 'c', 'b', 'a') */
   /* search184_0 -> 21 in the cache */
   /* search184_1 -> 41 in the cache */
   /* search184_2_0 -> 464 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 464 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 21, 41, 606 },
      -1,
   } },

   /* replace184_0 -> 464 in the cache */
   /* replace184_1 -> 41 in the cache */
   /* replace184_2 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 464, 41, 21 },
      -1,
   } },

   /* ('~flrp@64', 'a', ('fadd', 'a', 'b'), 'c') => ('fadd', ('fmul', 'b', 'c'), 'a') */
   /* search185_0 -> 21 in the cache */
   /* search185_1_0 -> 21 in the cache */
   /* search185_1_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 21, 41 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, 64 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 1,
      { 21, 609, 610 },
      -1,
   } },

   /* replace185_0_0 -> 41 in the cache */
   /* replace185_0_1 -> 610 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 41, 610 },
      -1,
   } },
   /* replace185_1 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 612, 21 },
      -1,
   } },

   /* ('~flrp@64', ('fadd(is_used_once)', 'a', 'b'), ('fadd(is_used_once)', 'a', 'c'), 'd') => ('fadd', ('flrp', 'b', 'c', 'd'), 'a') */
   /* search186_0_0 -> 21 in the cache */
   /* search186_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 21, 41 },
      0,
   } },
   /* search186_1_0 -> 21 in the cache */
   /* search186_1_1 -> 610 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 21, 610 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, 64 },
      3, /* d */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 2,
      { 614, 615, 616 },
      -1,
   } },

   /* replace186_0_0 -> 41 in the cache */
   /* replace186_0_1 -> 610 in the cache */
   /* replace186_0_2 -> 616 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 41, 610, 616 },
      -1,
   } },
   /* replace186_1 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 618, 21 },
      -1,
   } },

   /* ('~flrp@64', 'a', ('fmul(is_used_once)', 'a', 'b'), 'c') => ('fmul', ('flrp', 1.0, 'b', 'c'), 'a') */
   /* search187_0 -> 21 in the cache */
   /* search187_1_0 -> 21 in the cache */
   /* search187_1_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 21, 41 },
      0,
   } },
   /* search187_2 -> 610 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 1,
      { 21, 620, 610 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_float, { 0x3ff0000000000000 /* 1.0 */ },
   } },
   /* replace187_0_1 -> 41 in the cache */
   /* replace187_0_2 -> 610 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 622, 41, 610 },
      -1,
   } },
   /* replace187_1 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 623, 21 },
      -1,
   } },

   /* ('~fadd@64', ('fmul', 'a', ('fadd', 1.0, ('fneg', 'c'))), ('fmul', 'b', 'c')) => ('flrp', 'a', 'b', 'c') */
   /* search188_0_0 -> 21 in the cache */
   /* search188_0_1_0 -> 622 in the cache */
   { .variable = {
      { nir_search_value_variable, 64 },
      1, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 625 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fadd,
      2, 1,
      { 622, 626 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 2,
      { 21, 627 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, 64 },
      2, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search188_1_1 -> 625 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmul,
      3, 1,
      { 629, 625 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 4,
      { 628, 630 },
      -1,
   } },

   /* replace188_0 -> 21 in the cache */
   /* replace188_1 -> 629 in the cache */
   /* replace188_2 -> 625 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 21, 629, 625 },
      -1,
   } },

   /* ('~fadd@64', ('fmul', 'a', ('fsat', ('fadd', 1.0, ('fneg', 'c')))), ('fmul', 'b', ('fsat', 'c'))) => ('flrp', 'a', 'b', ('fsat', 'c')) */
   /* search189_0_0 -> 21 in the cache */
   /* search189_0_1_0_0 -> 622 in the cache */
   /* search189_0_1_0_1_0 -> 625 in the cache */
   /* search189_0_1_0_1 -> 626 in the cache */
   /* search189_0_1_0 -> 627 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 1,
      { 627 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 2,
      { 21, 633 },
      -1,
   } },
   /* search189_1_0 -> 629 in the cache */
   /* search189_1_1_0 -> 625 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 625 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmul,
      3, 1,
      { 629, 635 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 4,
      { 634, 636 },
      -1,
   } },

   /* replace189_0 -> 21 in the cache */
   /* replace189_1 -> 629 in the cache */
   /* replace189_2_0 -> 625 in the cache */
   /* replace189_2 -> 635 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 21, 629, 635 },
      -1,
   } },

   /* ('~fadd@64', 'a', ('fmul', 'c', ('fadd', 'b', ('fneg', 'a')))) => ('flrp', 'a', 'b', 'c') */
   /* search190_0 -> 21 in the cache */
   /* search190_1_0 -> 625 in the cache */
   /* search190_1_1_0 -> 629 in the cache */
   /* search190_1_1_1_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 21 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fadd,
      2, 1,
      { 629, 639 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 2,
      { 625, 640 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 21, 641 },
      -1,
   } },

   /* replace190_0 -> 21 in the cache */
   /* replace190_1 -> 629 in the cache */
   /* replace190_2 -> 625 in the cache */
   /* replace190 -> 632 in the cache */

   /* ('~fadd@64', ('fmul', 'a', ('fadd', 1.0, ('fneg', ('b2f', 'c@1')))), ('fmul', 'b', ('b2f', 'c'))) => ('bcsel', 'c', 'b', 'a') */
   /* search191_0_0 -> 21 in the cache */
   /* search191_0_1_0 -> 622 in the cache */
   /* search191_0_1_1_0_0 -> 502 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 502 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 643 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fadd,
      2, 1,
      { 622, 644 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 2,
      { 21, 645 },
      -1,
   } },
   /* search191_1_0 -> 629 in the cache */
   /* search191_1_1_0 -> 502 in the cache */
   /* search191_1_1 -> 643 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmul,
      3, 1,
      { 629, 643 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 4,
      { 646, 647 },
      -1,
   } },

   /* replace191_0 -> 502 in the cache */
   /* replace191_1 -> 629 in the cache */
   /* replace191_2 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 629, 21 },
      -1,
   } },

   /* ('~fadd@64', 'a', ('fmul', ('b2f', 'c@1'), ('fadd', 'b', ('fneg', 'a')))) => ('bcsel', 'c', 'b', 'a') */
   /* search192_0 -> 21 in the cache */
   /* search192_1_0_0 -> 502 in the cache */
   /* search192_1_0 -> 643 in the cache */
   /* search192_1_1_0 -> 629 in the cache */
   /* search192_1_1_1_0 -> 21 in the cache */
   /* search192_1_1_1 -> 639 in the cache */
   /* search192_1_1 -> 640 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 2,
      { 643, 640 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 21, 650 },
      -1,
   } },

   /* replace192_0 -> 502 in the cache */
   /* replace192_1 -> 629 in the cache */
   /* replace192_2 -> 21 in the cache */
   /* replace192 -> 649 in the cache */

   /* ('~ffma@64', 'a', ('fadd', 1.0, ('fneg', ('b2f', 'c@1'))), ('fmul', 'b', ('b2f', 'c@1'))) => ('bcsel', 'c', 'b', 'a') */
   /* search193_0 -> 21 in the cache */
   /* search193_1_0 -> 622 in the cache */
   /* search193_1_1_0_0 -> 502 in the cache */
   /* search193_1_1_0 -> 643 in the cache */
   /* search193_1_1 -> 644 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 622, 644 },
      -1,
   } },
   /* search193_2_0 -> 629 in the cache */
   /* search193_2_1_0 -> 502 in the cache */
   /* search193_2_1 -> 643 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmul,
      2, 1,
      { 629, 643 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 3,
      { 21, 652, 653 },
      -1,
   } },

   /* replace193_0 -> 502 in the cache */
   /* replace193_1 -> 629 in the cache */
   /* replace193_2 -> 21 in the cache */
   /* replace193 -> 649 in the cache */

   /* ('~ffma@64', 'b', ('b2f', 'c@1'), ('ffma', ('fneg', 'a'), ('b2f', 'c@1'), 'a')) => ('bcsel', 'c', 'b', 'a') */
   { .variable = {
      { nir_search_value_variable, 64 },
      0, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search194_1_0 -> 502 in the cache */
   /* search194_1 -> 643 in the cache */
   { .variable = {
      { nir_search_value_variable, 64 },
      2, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 656 },
      -1,
   } },
   /* search194_2_1_0 -> 502 in the cache */
   /* search194_2_1 -> 643 in the cache */
   /* search194_2_2 -> 656 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ffma,
      1, 1,
      { 657, 643, 656 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 655, 643, 658 },
      -1,
   } },

   /* replace194_0 -> 502 in the cache */
   /* replace194_1 -> 655 in the cache */
   /* replace194_2 -> 656 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 502, 655, 656 },
      -1,
   } },

   /* ('~ffma@64', ('b2f', 'c@1'), ('fadd', 'b', ('fneg', 'a')), 'a') => ('bcsel', 'c', 'b', 'a') */
   /* search195_0_0 -> 521 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 521 },
      -1,
   } },
   /* search195_1_0 -> 41 in the cache */
   /* search195_1_1_0 -> 656 in the cache */
   /* search195_1_1 -> 657 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 41, 657 },
      -1,
   } },
   /* search195_2 -> 656 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 661, 662, 656 },
      -1,
   } },

   /* replace195_0 -> 521 in the cache */
   /* replace195_1 -> 41 in the cache */
   /* replace195_2 -> 656 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 521, 41, 656 },
      -1,
   } },

   /* ('~ffma@64', ('b2f', 'c@1'), ('ffma', ('fneg', 'a'), 'b', 'd'), ('fmul', 'a', 'b')) => ('bcsel', 'c', 'd', ('fmul', 'a', 'b')) */
   /* search196_0_0 -> 521 in the cache */
   /* search196_0 -> 661 in the cache */
   { .variable = {
      { nir_search_value_variable, 64 },
      1, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 665 },
      -1,
   } },
   /* search196_1_1 -> 629 in the cache */
   /* search196_1_2 -> 616 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ffma,
      1, 1,
      { 666, 629, 616 },
      -1,
   } },
   /* search196_2_0 -> 665 in the cache */
   /* search196_2_1 -> 629 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmul,
      2, 1,
      { 665, 629 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 3,
      { 661, 667, 668 },
      -1,
   } },

   /* replace196_0 -> 521 in the cache */
   /* replace196_1 -> 616 in the cache */
   /* replace196_2_0 -> 665 in the cache */
   /* replace196_2_1 -> 629 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 665, 629 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 521, 616, 670 },
      -1,
   } },

   /* ('~fadd@64', 1.0, ('fneg', ('fmul', ('fadd', 1.0, ('fneg', 'a')), ('fadd', 1.0, ('fneg', 'b'))))) => ('flrp', 'b', 1.0, 'a') */
   /* search197_0 -> 622 in the cache */
   /* search197_1_0_0_0 -> 622 in the cache */
   /* search197_1_0_0_1_0 -> 21 in the cache */
   /* search197_1_0_0_1 -> 639 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fadd,
      2, 1,
      { 622, 639 },
      -1,
   } },
   /* search197_1_0_1_0 -> 622 in the cache */
   /* search197_1_0_1_1_0 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fadd,
      3, 1,
      { 622, 673 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 3,
      { 672, 674 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 3,
      { 675 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 4,
      { 622, 676 },
      -1,
   } },

   /* replace197_0 -> 41 in the cache */
   /* replace197_1 -> 622 in the cache */
   /* replace197_2 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 41, 622, 21 },
      -1,
   } },

   /* ('~flrp', ('fmul(is_used_once)', 'a', 'b'), ('fmul(is_used_once)', 'a', 'c'), 'd') => ('fmul', ('flrp', 'b', 'c', 'd'), 'a') */
   /* search198_0_0 -> 149 in the cache */
   /* search198_0_1 -> 150 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 149, 150 },
      0,
   } },
   /* search198_1_0 -> 149 in the cache */
   /* search198_1_1 -> 152 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 149, 152 },
      0,
   } },
   /* search198_2 -> 153 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 2,
      { 679, 680, 153 },
      -1,
   } },

   /* replace198_0_0 -> 150 in the cache */
   /* replace198_0_1 -> 152 in the cache */
   /* replace198_0_2 -> 153 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 150, 152, 153 },
      -1,
   } },
   /* replace198_1 -> 149 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 682, 149 },
      -1,
   } },

   /* ('~flrp', 'a', 0.0, 'c') => ('fadd', ('fmul', ('fneg', 'a'), 'c'), 'a') */
   /* search199_0 -> 0 in the cache */
   /* search199_1 -> 256 in the cache */
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 0, 256, 684 },
      -1,
   } },

   /* replace199_0_0_0 -> 0 in the cache */
   /* replace199_0_0 -> 212 in the cache */
   /* replace199_0_1 -> 684 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 212, 684 },
      -1,
   } },
   /* replace199_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 686, 0 },
      -1,
   } },

   /* ('ftrunc@16', 'a') => ('bcsel', ('flt', 'a', 0.0), ('fneg', ('ffloor', ('fabs', 'a'))), ('ffloor', ('fabs', 'a'))) */
   /* search200_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ftrunc,
      -1, 0,
      { 11 },
      -1,
   } },

   /* replace200_0_0 -> 11 in the cache */
   /* replace200_0_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 11, 113 },
      -1,
   } },
   /* replace200_1_0_0_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 11 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ffloor,
      -1, 0,
      { 690 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 691 },
      -1,
   } },
   /* replace200_2_0_0 -> 11 in the cache */
   /* replace200_2_0 -> 690 in the cache */
   /* replace200_2 -> 691 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 689, 692, 691 },
      -1,
   } },

   /* ('ftrunc@32', 'a') => ('bcsel', ('flt', 'a', 0.0), ('fneg', ('ffloor', ('fabs', 'a'))), ('ffloor', ('fabs', 'a'))) */
   /* search201_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ftrunc,
      -1, 0,
      { 16 },
      -1,
   } },

   /* replace201_0_0 -> 16 in the cache */
   /* replace201_0_1 -> 115 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 16, 115 },
      -1,
   } },
   /* replace201_1_0_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffloor,
      -1, 0,
      { 696 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 697 },
      -1,
   } },
   /* replace201_2_0_0 -> 16 in the cache */
   /* replace201_2_0 -> 696 in the cache */
   /* replace201_2 -> 697 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 695, 698, 697 },
      -1,
   } },

   /* ('ftrunc@64', 'a') => ('bcsel', ('flt', 'a', 0.0), ('fneg', ('ffloor', ('fabs', 'a'))), ('ffloor', ('fabs', 'a'))) */
   /* search202_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ftrunc,
      -1, 0,
      { 21 },
      -1,
   } },

   /* replace202_0_0 -> 21 in the cache */
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_float, { 0x0 /* 0.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 21, 701 },
      -1,
   } },
   /* replace202_1_0_0_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 21 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ffloor,
      -1, 0,
      { 703 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 704 },
      -1,
   } },
   /* replace202_2_0_0 -> 21 in the cache */
   /* replace202_2_0 -> 703 in the cache */
   /* replace202_2 -> 704 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 702, 705, 704 },
      -1,
   } },

   /* ('ffloor@16', 'a') => ('fsub', 'a', ('ffract', 'a')) */
   /* search203_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ffloor,
      -1, 0,
      { 11 },
      -1,
   } },

   /* replace203_0 -> 11 in the cache */
   /* replace203_1_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 0,
      { 11 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 0,
      { 11, 708 },
      -1,
   } },

   /* ('ffloor@32', 'a') => ('fsub', 'a', ('ffract', 'a')) */
   /* search204_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffloor,
      -1, 0,
      { 16 },
      -1,
   } },

   /* replace204_0 -> 16 in the cache */
   /* replace204_1_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 0,
      { 16, 711 },
      -1,
   } },

   /* ('ffloor@64', 'a') => ('fsub', 'a', ('ffract', 'a')) */
   /* search205_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ffloor,
      -1, 0,
      { 21 },
      -1,
   } },

   /* replace205_0 -> 21 in the cache */
   /* replace205_1_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 0,
      { 21 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 0,
      { 21, 714 },
      -1,
   } },

   /* ('fadd@16', 'a', ('fadd@16', 'b', ('fneg', ('ffract', 'a')))) => ('fadd@16', 'b', ('ffloor', 'a')) */
   /* search206_0 -> 11 in the cache */
   /* search206_1_0 -> 258 in the cache */
   /* search206_1_1_0_0 -> 11 in the cache */
   /* search206_1_1_0 -> 708 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 708 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 258, 716 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 11, 717 },
      -1,
   } },

   /* replace206_0 -> 258 in the cache */
   /* replace206_1_0 -> 11 in the cache */
   /* replace206_1 -> 707 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 258, 707 },
      -1,
   } },

   /* ('fadd@32', 'a', ('fadd@32', 'b', ('fneg', ('ffract', 'a')))) => ('fadd@32', 'b', ('ffloor', 'a')) */
   /* search207_0 -> 16 in the cache */
   /* search207_1_0 -> 36 in the cache */
   /* search207_1_1_0_0 -> 16 in the cache */
   /* search207_1_1_0 -> 711 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 711 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 36, 720 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 16, 721 },
      -1,
   } },

   /* replace207_0 -> 36 in the cache */
   /* replace207_1_0 -> 16 in the cache */
   /* replace207_1 -> 710 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 36, 710 },
      -1,
   } },

   /* ('fadd@64', 'a', ('fadd@64', 'b', ('fneg', ('ffract', 'a')))) => ('fadd@64', 'b', ('ffloor', 'a')) */
   /* search208_0 -> 21 in the cache */
   /* search208_1_0 -> 41 in the cache */
   /* search208_1_1_0_0 -> 21 in the cache */
   /* search208_1_1_0 -> 714 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 714 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 41, 724 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 21, 725 },
      -1,
   } },

   /* replace208_0 -> 41 in the cache */
   /* replace208_1_0 -> 21 in the cache */
   /* replace208_1 -> 713 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 41, 713 },
      -1,
   } },

   /* ('fadd@16', 'a', ('fneg', ('ffract', 'a'))) => ('ffloor', 'a') */
   /* search209_0 -> 11 in the cache */
   /* search209_1_0_0 -> 11 in the cache */
   /* search209_1_0 -> 708 in the cache */
   /* search209_1 -> 716 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 11, 716 },
      -1,
   } },

   /* replace209_0 -> 11 in the cache */
   /* replace209 -> 707 in the cache */

   /* ('fadd@32', 'a', ('fneg', ('ffract', 'a'))) => ('ffloor', 'a') */
   /* search210_0 -> 16 in the cache */
   /* search210_1_0_0 -> 16 in the cache */
   /* search210_1_0 -> 711 in the cache */
   /* search210_1 -> 720 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 16, 720 },
      -1,
   } },

   /* replace210_0 -> 16 in the cache */
   /* replace210 -> 710 in the cache */

   /* ('fadd@64', 'a', ('fneg', ('ffract', 'a'))) => ('ffloor', 'a') */
   /* search211_0 -> 21 in the cache */
   /* search211_1_0_0 -> 21 in the cache */
   /* search211_1_0 -> 714 in the cache */
   /* search211_1 -> 724 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 21, 724 },
      -1,
   } },

   /* replace211_0 -> 21 in the cache */
   /* replace211 -> 713 in the cache */

   /* ('ffract@16', 'a') => ('fsub', 'a', ('ffloor', 'a')) */
   /* search212_0 -> 11 in the cache */
   /* search212 -> 708 in the cache */

   /* replace212_0 -> 11 in the cache */
   /* replace212_1_0 -> 11 in the cache */
   /* replace212_1 -> 707 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 0,
      { 11, 707 },
      -1,
   } },

   /* ('ffract@32', 'a') => ('fsub', 'a', ('ffloor', 'a')) */
   /* search213_0 -> 16 in the cache */
   /* search213 -> 711 in the cache */

   /* replace213_0 -> 16 in the cache */
   /* replace213_1_0 -> 16 in the cache */
   /* replace213_1 -> 710 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 0,
      { 16, 710 },
      -1,
   } },

   /* ('ffract@64', 'a') => ('fsub', 'a', ('ffloor', 'a')) */
   /* search214_0 -> 21 in the cache */
   /* search214 -> 714 in the cache */

   /* replace214_0 -> 21 in the cache */
   /* replace214_1_0 -> 21 in the cache */
   /* replace214_1 -> 713 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 0,
      { 21, 713 },
      -1,
   } },

   /* ('fceil', 'a') => ('fneg', ('ffloor', ('fneg', 'a'))) */
   /* search215_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fceil,
      -1, 0,
      { 32 },
      -1,
   } },

   /* replace215_0_0_0 -> 32 in the cache */
   /* replace215_0_0 -> 98 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffloor,
      -1, 0,
      { 98 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 735 },
      -1,
   } },

   /* ('ffma@16', 'a', 'b', 'c') => ('fadd', ('fmul', 'a', 'b'), 'c') */
   /* search216_0 -> 11 in the cache */
   /* search216_1 -> 258 in the cache */
   /* search216_2 -> 469 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 11, 258, 469 },
      -1,
   } },

   /* replace216_0_0 -> 11 in the cache */
   /* replace216_0_1 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 11, 258 },
      -1,
   } },
   /* replace216_1 -> 469 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 738, 469 },
      -1,
   } },

   /* ('ffma@32', 'a', 'b', 'c') => ('fadd', ('fmul', 'a', 'b'), 'c') */
   /* search217_0 -> 16 in the cache */
   /* search217_1 -> 36 in the cache */
   /* search217_2 -> 135 in the cache */
   /* search217 -> 234 in the cache */

   /* replace217_0_0 -> 16 in the cache */
   /* replace217_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 16, 36 },
      -1,
   } },
   /* replace217_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 740, 135 },
      -1,
   } },

   /* ('ffma@64', 'a', 'b', 'c') => ('fadd', ('fmul', 'a', 'b'), 'c') */
   /* search218_0 -> 21 in the cache */
   /* search218_1 -> 41 in the cache */
   /* search218_2 -> 610 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 21, 41, 610 },
      -1,
   } },

   /* replace218_0_0 -> 21 in the cache */
   /* replace218_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 21, 41 },
      -1,
   } },
   /* replace218_1 -> 610 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 743, 610 },
      -1,
   } },

   /* ('ffmaz', 'a', 'b', 'c') => ('fadd', ('fmulz', 'a', 'b'), 'c') */
   /* search219_0 -> 16 in the cache */
   /* search219_1 -> 36 in the cache */
   /* search219_2 -> 135 in the cache */
   /* search219 -> 387 in the cache */

   /* replace219_0_0 -> 16 in the cache */
   /* replace219_0_1 -> 36 in the cache */
   /* replace219_0 -> 134 in the cache */
   /* replace219_1 -> 135 in the cache */
   /* replace219 -> 288 in the cache */

   /* ('~ffma@16', 'a', 'b', 'c') => ('fadd', ('fmul', 'a', 'b'), 'c') */
   /* search220_0 -> 11 in the cache */
   /* search220_1 -> 258 in the cache */
   /* search220_2 -> 469 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 11, 258, 469 },
      -1,
   } },

   /* replace220_0_0 -> 11 in the cache */
   /* replace220_0_1 -> 258 in the cache */
   /* replace220_0 -> 738 in the cache */
   /* replace220_1 -> 469 in the cache */
   /* replace220 -> 739 in the cache */

   /* ('~ffma@32', 'a', 'b', 'c') => ('fadd', ('fmul', 'a', 'b'), 'c') */
   /* search221_0 -> 16 in the cache */
   /* search221_1 -> 36 in the cache */
   /* search221_2 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 16, 36, 135 },
      -1,
   } },

   /* replace221_0_0 -> 16 in the cache */
   /* replace221_0_1 -> 36 in the cache */
   /* replace221_0 -> 740 in the cache */
   /* replace221_1 -> 135 in the cache */
   /* replace221 -> 741 in the cache */

   /* ('~ffma@64', 'a', 'b', 'c') => ('fadd', ('fmul', 'a', 'b'), 'c') */
   /* search222_0 -> 21 in the cache */
   /* search222_1 -> 41 in the cache */
   /* search222_2 -> 610 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 21, 41, 610 },
      -1,
   } },

   /* replace222_0_0 -> 21 in the cache */
   /* replace222_0_1 -> 41 in the cache */
   /* replace222_0 -> 743 in the cache */
   /* replace222_1 -> 610 in the cache */
   /* replace222 -> 744 in the cache */

   /* ('~ffmaz', 'a', 'b', 'c') => ('fadd', ('fmulz', 'a', 'b'), 'c') */
   /* search223_0 -> 16 in the cache */
   /* search223_1 -> 36 in the cache */
   /* search223_2 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_ffmaz,
      0, 1,
      { 16, 36, 135 },
      -1,
   } },

   /* replace223_0_0 -> 16 in the cache */
   /* replace223_0_1 -> 36 in the cache */
   /* replace223_0 -> 134 in the cache */
   /* replace223_1 -> 135 in the cache */
   /* replace223 -> 288 in the cache */

   /* ('~fmul', ('fadd', ('iand', ('ineg', ('b2i', 'a@bool')), ('fmul', 'b', 'c')), '#d'), '#e') => ('bcsel', 'a', ('fmul', ('fadd', ('fmul', 'b', 'c'), 'd'), 'e'), ('fmul', 'd', 'e')) */
   { .variable = {
      { nir_search_value_variable, 1 },
      0, /* a */
      false,
      nir_type_bool,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_search_op_b2i,
      -1, 0,
      { 749 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 750 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -5 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -5 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_fmul,
      3, 1,
      { 752, 753 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_iand,
      2, 2,
      { 751, 754 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -5 },
      3, /* d */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 3,
      { 755, 756 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -5 },
      4, /* e */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      true,
      false,
      false,
      nir_op_fmul,
      0, 4,
      { 757, 758 },
      -1,
   } },

   { .variable = {
      { nir_search_value_variable, 1 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* replace224_1_0_0_0 -> 752 in the cache */
   /* replace224_1_0_0_1 -> 753 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_fmul,
      2, 1,
      { 752, 753 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -5 },
      3, /* d */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 2,
      { 761, 762 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -5 },
      4, /* e */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 3,
      { 763, 764 },
      -1,
   } },
   /* replace224_2_0 -> 762 in the cache */
   /* replace224_2_1 -> 764 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_fmul,
      3, 1,
      { 762, 764 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 4,
      { 760, 765, 766 },
      -1,
   } },

   /* ('fdph', 'a', 'b') => ('fdot4', ('vec4', 'a.x', 'a.y', 'a.z', 1.0), 'b') */
   /* search225_0 -> 0 in the cache */
   /* search225_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdph,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {1},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {2},
   } },
   /* replace225_0_3 -> 270 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_vec4,
      -1, 0,
      { 769, 770, 771, 270 },
      -1,
   } },
   /* replace225_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot4,
      0, 1,
      { 772, 3 },
      -1,
   } },

   /* ('fdot4', ('vec4', 'a', 'b', 'c', 1.0), 'd') => ('fdph', ('vec3', 'a', 'b', 'c'), 'd') */
   /* search226_0_0 -> 149 in the cache */
   /* search226_0_1 -> 150 in the cache */
   /* search226_0_2 -> 152 in the cache */
   { .constant = {
      { nir_search_value_constant, -4 },
      nir_type_float, { 0x3ff0000000000000 /* 1.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_vec4,
      -1, 0,
      { 149, 150, 152, 774 },
      -1,
   } },
   /* search226_1 -> 153 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fdot4,
      0, 1,
      { 775, 153 },
      -1,
   } },

   /* replace226_0_0 -> 149 in the cache */
   /* replace226_0_1 -> 150 in the cache */
   /* replace226_0_2 -> 152 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_vec3,
      -1, 0,
      { 149, 150, 152 },
      -1,
   } },
   /* replace226_1 -> 153 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fdph,
      -1, 0,
      { 777, 153 },
      -1,
   } },

   /* ('fdot4', ('vec4', 'a', 0.0, 0.0, 0.0), 'b') => ('fmul', 'a', 'b') */
   /* search227_0_0 -> 0 in the cache */
   /* search227_0_1 -> 256 in the cache */
   /* search227_0_2 -> 256 in the cache */
   /* search227_0_3 -> 256 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_vec4,
      -1, 0,
      { 0, 256, 256, 256 },
      -1,
   } },
   /* search227_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot4,
      0, 1,
      { 779, 3 },
      -1,
   } },

   /* replace227_0 -> 0 in the cache */
   /* replace227_1 -> 3 in the cache */
   /* replace227 -> 264 in the cache */

   /* ('fdot4', ('vec4', 'a', 'b', 0.0, 0.0), 'c') => ('fdot2', ('vec2', 'a', 'b'), 'c') */
   /* search228_0_0 -> 126 in the cache */
   /* search228_0_1 -> 127 in the cache */
   { .constant = {
      { nir_search_value_constant, -3 },
      nir_type_float, { 0x0 /* 0.0 */ },
   } },
   /* search228_0_3 -> 781 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_vec4,
      -1, 0,
      { 126, 127, 781, 781 },
      -1,
   } },
   /* search228_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fdot4,
      0, 1,
      { 782, 129 },
      -1,
   } },

   /* replace228_0_0 -> 126 in the cache */
   /* replace228_0_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_vec2,
      -1, 0,
      { 126, 127 },
      -1,
   } },
   /* replace228_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fdot2,
      0, 1,
      { 784, 129 },
      -1,
   } },

   /* ('fdot4', ('vec4', 'a', 'b', 'c', 0.0), 'd') => ('fdot3', ('vec3', 'a', 'b', 'c'), 'd') */
   /* search229_0_0 -> 149 in the cache */
   /* search229_0_1 -> 150 in the cache */
   /* search229_0_2 -> 152 in the cache */
   { .constant = {
      { nir_search_value_constant, -4 },
      nir_type_float, { 0x0 /* 0.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_vec4,
      -1, 0,
      { 149, 150, 152, 786 },
      -1,
   } },
   /* search229_1 -> 153 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fdot4,
      0, 1,
      { 787, 153 },
      -1,
   } },

   /* replace229_0_0 -> 149 in the cache */
   /* replace229_0_1 -> 150 in the cache */
   /* replace229_0_2 -> 152 in the cache */
   /* replace229_0 -> 777 in the cache */
   /* replace229_1 -> 153 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fdot3,
      0, 1,
      { 777, 153 },
      -1,
   } },

   /* ('fdot3', ('vec3', 'a', 0.0, 0.0), 'b') => ('fmul', 'a', 'b') */
   /* search230_0_0 -> 0 in the cache */
   /* search230_0_1 -> 256 in the cache */
   /* search230_0_2 -> 256 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_vec3,
      -1, 0,
      { 0, 256, 256 },
      -1,
   } },
   /* search230_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot3,
      0, 1,
      { 790, 3 },
      -1,
   } },

   /* replace230_0 -> 0 in the cache */
   /* replace230_1 -> 3 in the cache */
   /* replace230 -> 264 in the cache */

   /* ('fdot3', ('vec3', 'a', 'b', 0.0), 'c') => ('fdot2', ('vec2', 'a', 'b'), 'c') */
   /* search231_0_0 -> 126 in the cache */
   /* search231_0_1 -> 127 in the cache */
   /* search231_0_2 -> 781 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_vec3,
      -1, 0,
      { 126, 127, 781 },
      -1,
   } },
   /* search231_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fdot3,
      0, 1,
      { 792, 129 },
      -1,
   } },

   /* replace231_0_0 -> 126 in the cache */
   /* replace231_0_1 -> 127 in the cache */
   /* replace231_0 -> 784 in the cache */
   /* replace231_1 -> 129 in the cache */
   /* replace231 -> 785 in the cache */

   /* ('fdot2', ('vec2', 'a', 0.0), 'b') => ('fmul', 'a', 'b') */
   /* search232_0_0 -> 0 in the cache */
   /* search232_0_1 -> 256 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_vec2,
      -1, 0,
      { 0, 256 },
      -1,
   } },
   /* search232_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot2,
      0, 1,
      { 794, 3 },
      -1,
   } },

   /* replace232_0 -> 0 in the cache */
   /* replace232_1 -> 3 in the cache */
   /* replace232 -> 264 in the cache */

   /* ('fdot2', 'a', 1.0) => ('fadd', 'a.x', 'a.y') */
   /* search233_0 -> 32 in the cache */
   /* search233_1 -> 241 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fdot2,
      0, 1,
      { 32, 241 },
      -1,
   } },

   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0},
   } },
   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {1},
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      -1, 0,
      { 797, 798 },
      -1,
   } },

   /* ('fdot2', 'a', 'b') => ('fsum2', ('fmul', 'a', 'b')) */
   /* search234_0 -> 0 in the cache */
   /* search234_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot2,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace234_0_0 -> 0 in the cache */
   /* replace234_0_1 -> 3 in the cache */
   /* replace234_0 -> 264 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fsum2,
      -1, 1,
      { 264 },
      -1,
   } },

   /* ('fdot3', 'a', 'b') => ('fsum3', ('fmul', 'a', 'b')) */
   /* search235_0 -> 0 in the cache */
   /* search235_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot3,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace235_0_0 -> 0 in the cache */
   /* replace235_0_1 -> 3 in the cache */
   /* replace235_0 -> 264 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fsum3,
      -1, 1,
      { 264 },
      -1,
   } },

   /* ('fdot4', 'a', 'b') => ('fsum4', ('fmul', 'a', 'b')) */
   /* search236_0 -> 0 in the cache */
   /* search236_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot4,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace236_0_0 -> 0 in the cache */
   /* replace236_0_1 -> 3 in the cache */
   /* replace236_0 -> 264 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fsum4,
      -1, 1,
      { 264 },
      -1,
   } },

   /* ('fsum2', 'a') => ('fadd', 'a.x', 'a.y') */
   /* search237_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsum2,
      -1, 0,
      { 32 },
      -1,
   } },

   /* replace237_0 -> 797 in the cache */
   /* replace237_1 -> 798 in the cache */
   /* replace237 -> 799 in the cache */

   /* ('~fadd', ('fneg(is_used_once)', ('fsat(is_used_once)', 'a(is_not_fmul)')), 1.0) => ('fsat', ('fadd', 1.0, ('fneg', 'a'))) */
   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* a */
      false,
      nir_type_invalid,
      8,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 807 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 808 },
      0,
   } },
   /* search238_1 -> 241 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 809, 241 },
      -1,
   } },

   /* replace238_0_0 -> 241 in the cache */
   /* replace238_0_1_0 -> 32 in the cache */
   /* replace238_0_1 -> 98 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 241, 98 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 1,
      { 811 },
      -1,
   } },

   /* ('ishl', ('iadd', ('imul', 'a', '#b'), '#c'), '#d') => ('iadd', ('imul', 'a', ('ishl', 'b', 'd')), ('ishl', 'c', 'd')) */
   /* search239_0_0_0 -> 126 in the cache */
   /* search239_0_0_1 -> 283 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imul,
      1, 1,
      { 126, 283 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      2, /* c */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 813, 814 },
      -1,
   } },
   /* search239_1 -> 311 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 2,
      { 815, 311 },
      -1,
   } },

   /* replace239_0_0 -> 126 in the cache */
   /* replace239_0_1_0 -> 127 in the cache */
   /* replace239_0_1_1 -> 163 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 127, 163 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imul,
      1, 1,
      { 126, 817 },
      -1,
   } },
   /* replace239_1_0 -> 129 in the cache */
   /* replace239_1_1 -> 163 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 129, 163 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 818, 819 },
      -1,
   } },

   /* ('ishl', ('imul', 'a', '#b'), '#c') => ('imul', 'a', ('ishl', 'b', 'c')) */
   /* search240_0_0 -> 0 in the cache */
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 0, 821 },
      -1,
   } },
   /* search240_1 -> 309 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 822, 309 },
      -1,
   } },

   /* replace240_0 -> 0 in the cache */
   /* replace240_1_0 -> 3 in the cache */
   /* replace240_1_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 3, 135 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 0, 824 },
      -1,
   } },

   /* ('ishl@8', ('ishl@8', 'a', '#b'), '#c') => ('bcsel', ('ult', ('iadd', ('iand', 'b', 7), ('iand', 'c', 7)), 8), ('ishl@8', 'a', ('iadd', 'b', 'c')), 0) */
   /* search241_0_0 -> 6 in the cache */
   /* search241_0_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 6, 33 },
      -1,
   } },
   /* search241_1 -> 309 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 826, 309 },
      -1,
   } },

   /* replace241_0_0_0_0 -> 36 in the cache */
   /* replace241_0_0_0_1 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 36, 9 },
      -1,
   } },
   /* replace241_0_0_1_0 -> 135 in the cache */
   /* replace241_0_0_1_1 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      2, 1,
      { 135, 9 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 3,
      { 828, 829 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x8 /* 8 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 3,
      { 830, 831 },
      -1,
   } },
   /* replace241_1_0 -> 6 in the cache */
   /* replace241_1_1_0 -> 36 in the cache */
   /* replace241_1_1_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      3, 1,
      { 36, 135 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 6, 833 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 8 },
      nir_type_int, { 0x0 /* 0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 4,
      { 832, 834, 835 },
      -1,
   } },

   /* ('ushr@8', ('ushr@8', 'a', '#b'), '#c') => ('bcsel', ('ult', ('iadd', ('iand', 'b', 7), ('iand', 'c', 7)), 8), ('ushr@8', 'a', ('iadd', 'b', 'c')), 0) */
   /* search242_0_0 -> 6 in the cache */
   /* search242_0_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 6, 33 },
      -1,
   } },
   /* search242_1 -> 309 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 837, 309 },
      -1,
   } },

   /* replace242_0_0_0_0 -> 36 in the cache */
   /* replace242_0_0_0_1 -> 9 in the cache */
   /* replace242_0_0_0 -> 828 in the cache */
   /* replace242_0_0_1_0 -> 135 in the cache */
   /* replace242_0_0_1_1 -> 9 in the cache */
   /* replace242_0_0_1 -> 829 in the cache */
   /* replace242_0_0 -> 830 in the cache */
   /* replace242_0_1 -> 831 in the cache */
   /* replace242_0 -> 832 in the cache */
   /* replace242_1_0 -> 6 in the cache */
   /* replace242_1_1_0 -> 36 in the cache */
   /* replace242_1_1_1 -> 135 in the cache */
   /* replace242_1_1 -> 833 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 6, 833 },
      -1,
   } },
   /* replace242_2 -> 835 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 4,
      { 832, 839, 835 },
      -1,
   } },

   /* ('ishr@8', ('ishr@8', 'a', '#b'), '#c') => ('ishr@8', 'a', ('imin', ('iadd', ('iand', 'b', 7), ('iand', 'c', 7)), 7)) */
   /* search243_0_0 -> 6 in the cache */
   /* search243_0_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 6, 33 },
      -1,
   } },
   /* search243_1 -> 309 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 841, 309 },
      -1,
   } },

   /* replace243_0 -> 6 in the cache */
   /* replace243_1_0_0_0 -> 36 in the cache */
   /* replace243_1_0_0_1 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      2, 1,
      { 36, 9 },
      -1,
   } },
   /* replace243_1_0_1_0 -> 135 in the cache */
   /* replace243_1_0_1_1 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      3, 1,
      { 135, 9 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 3,
      { 843, 844 },
      -1,
   } },
   /* replace243_1_1 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imin,
      0, 4,
      { 845, 9 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 4,
      { 6, 846 },
      -1,
   } },

   /* ('ishl@16', ('ishl@16', 'a', '#b'), '#c') => ('bcsel', ('ult', ('iadd', ('iand', 'b', 15), ('iand', 'c', 15)), 16), ('ishl@16', 'a', ('iadd', 'b', 'c')), 0) */
   /* search244_0_0 -> 11 in the cache */
   /* search244_0_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 11, 33 },
      -1,
   } },
   /* search244_1 -> 309 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 848, 309 },
      -1,
   } },

   /* replace244_0_0_0_0 -> 36 in the cache */
   /* replace244_0_0_0_1 -> 14 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 36, 14 },
      -1,
   } },
   /* replace244_0_0_1_0 -> 135 in the cache */
   /* replace244_0_0_1_1 -> 14 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      2, 1,
      { 135, 14 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 3,
      { 850, 851 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x10 /* 16 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 3,
      { 852, 853 },
      -1,
   } },
   /* replace244_1_0 -> 11 in the cache */
   /* replace244_1_1_0 -> 36 in the cache */
   /* replace244_1_1_1 -> 135 in the cache */
   /* replace244_1_1 -> 833 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 11, 833 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 16 },
      nir_type_int, { 0x0 /* 0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 4,
      { 854, 855, 856 },
      -1,
   } },

   /* ('ushr@16', ('ushr@16', 'a', '#b'), '#c') => ('bcsel', ('ult', ('iadd', ('iand', 'b', 15), ('iand', 'c', 15)), 16), ('ushr@16', 'a', ('iadd', 'b', 'c')), 0) */
   /* search245_0_0 -> 11 in the cache */
   /* search245_0_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 11, 33 },
      -1,
   } },
   /* search245_1 -> 309 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 858, 309 },
      -1,
   } },

   /* replace245_0_0_0_0 -> 36 in the cache */
   /* replace245_0_0_0_1 -> 14 in the cache */
   /* replace245_0_0_0 -> 850 in the cache */
   /* replace245_0_0_1_0 -> 135 in the cache */
   /* replace245_0_0_1_1 -> 14 in the cache */
   /* replace245_0_0_1 -> 851 in the cache */
   /* replace245_0_0 -> 852 in the cache */
   /* replace245_0_1 -> 853 in the cache */
   /* replace245_0 -> 854 in the cache */
   /* replace245_1_0 -> 11 in the cache */
   /* replace245_1_1_0 -> 36 in the cache */
   /* replace245_1_1_1 -> 135 in the cache */
   /* replace245_1_1 -> 833 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 11, 833 },
      -1,
   } },
   /* replace245_2 -> 856 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 4,
      { 854, 860, 856 },
      -1,
   } },

   /* ('ishr@16', ('ishr@16', 'a', '#b'), '#c') => ('ishr@16', 'a', ('imin', ('iadd', ('iand', 'b', 15), ('iand', 'c', 15)), 15)) */
   /* search246_0_0 -> 11 in the cache */
   /* search246_0_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 11, 33 },
      -1,
   } },
   /* search246_1 -> 309 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 862, 309 },
      -1,
   } },

   /* replace246_0 -> 11 in the cache */
   /* replace246_1_0_0_0 -> 36 in the cache */
   /* replace246_1_0_0_1 -> 14 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      2, 1,
      { 36, 14 },
      -1,
   } },
   /* replace246_1_0_1_0 -> 135 in the cache */
   /* replace246_1_0_1_1 -> 14 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      3, 1,
      { 135, 14 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 3,
      { 864, 865 },
      -1,
   } },
   /* replace246_1_1 -> 14 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imin,
      0, 4,
      { 866, 14 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 4,
      { 11, 867 },
      -1,
   } },

   /* ('ishl@32', ('ishl@32', 'a', '#b'), '#c') => ('bcsel', ('ult', ('iadd', ('iand', 'b', 31), ('iand', 'c', 31)), 32), ('ishl@32', 'a', ('iadd', 'b', 'c')), 0) */
   /* search247_0_0 -> 16 in the cache */
   /* search247_0_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 16, 33 },
      -1,
   } },
   /* search247_1 -> 309 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 869, 309 },
      -1,
   } },

   /* replace247_0_0_0_0 -> 36 in the cache */
   /* replace247_0_0_0_1 -> 19 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 36, 19 },
      -1,
   } },
   /* replace247_0_0_1_0 -> 135 in the cache */
   /* replace247_0_0_1_1 -> 19 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      2, 1,
      { 135, 19 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 3,
      { 871, 872 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x20 /* 32 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 3,
      { 873, 874 },
      -1,
   } },
   /* replace247_1_0 -> 16 in the cache */
   /* replace247_1_1_0 -> 36 in the cache */
   /* replace247_1_1_1 -> 135 in the cache */
   /* replace247_1_1 -> 833 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 16, 833 },
      -1,
   } },
   /* replace247_2 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 4,
      { 875, 876, 122 },
      -1,
   } },

   /* ('ushr@32', ('ushr@32', 'a', '#b'), '#c') => ('bcsel', ('ult', ('iadd', ('iand', 'b', 31), ('iand', 'c', 31)), 32), ('ushr@32', 'a', ('iadd', 'b', 'c')), 0) */
   /* search248_0_0 -> 16 in the cache */
   /* search248_0_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 16, 33 },
      -1,
   } },
   /* search248_1 -> 309 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 878, 309 },
      -1,
   } },

   /* replace248_0_0_0_0 -> 36 in the cache */
   /* replace248_0_0_0_1 -> 19 in the cache */
   /* replace248_0_0_0 -> 871 in the cache */
   /* replace248_0_0_1_0 -> 135 in the cache */
   /* replace248_0_0_1_1 -> 19 in the cache */
   /* replace248_0_0_1 -> 872 in the cache */
   /* replace248_0_0 -> 873 in the cache */
   /* replace248_0_1 -> 874 in the cache */
   /* replace248_0 -> 875 in the cache */
   /* replace248_1_0 -> 16 in the cache */
   /* replace248_1_1_0 -> 36 in the cache */
   /* replace248_1_1_1 -> 135 in the cache */
   /* replace248_1_1 -> 833 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 16, 833 },
      -1,
   } },
   /* replace248_2 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 4,
      { 875, 880, 122 },
      -1,
   } },

   /* ('ishr@32', ('ishr@32', 'a', '#b'), '#c') => ('ishr@32', 'a', ('imin', ('iadd', ('iand', 'b', 31), ('iand', 'c', 31)), 31)) */
   /* search249_0_0 -> 16 in the cache */
   /* search249_0_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 16, 33 },
      -1,
   } },
   /* search249_1 -> 309 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 882, 309 },
      -1,
   } },

   /* replace249_0 -> 16 in the cache */
   /* replace249_1_0_0_0 -> 36 in the cache */
   /* replace249_1_0_0_1 -> 19 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      2, 1,
      { 36, 19 },
      -1,
   } },
   /* replace249_1_0_1_0 -> 135 in the cache */
   /* replace249_1_0_1_1 -> 19 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      3, 1,
      { 135, 19 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 3,
      { 884, 885 },
      -1,
   } },
   /* replace249_1_1 -> 19 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imin,
      0, 4,
      { 886, 19 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 4,
      { 16, 887 },
      -1,
   } },

   /* ('ishl@64', ('ishl@64', 'a', '#b'), '#c') => ('bcsel', ('ult', ('iadd', ('iand', 'b', 63), ('iand', 'c', 63)), 64), ('ishl@64', 'a', ('iadd', 'b', 'c')), 0) */
   /* search250_0_0 -> 21 in the cache */
   /* search250_0_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 21, 33 },
      -1,
   } },
   /* search250_1 -> 309 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 889, 309 },
      -1,
   } },

   /* replace250_0_0_0_0 -> 36 in the cache */
   /* replace250_0_0_0_1 -> 24 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 36, 24 },
      -1,
   } },
   /* replace250_0_0_1_0 -> 135 in the cache */
   /* replace250_0_0_1_1 -> 24 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      2, 1,
      { 135, 24 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 3,
      { 891, 892 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x40 /* 64 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 3,
      { 893, 894 },
      -1,
   } },
   /* replace250_1_0 -> 21 in the cache */
   /* replace250_1_1_0 -> 36 in the cache */
   /* replace250_1_1_1 -> 135 in the cache */
   /* replace250_1_1 -> 833 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 21, 833 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0x0 /* 0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 4,
      { 895, 896, 897 },
      -1,
   } },

   /* ('ushr@64', ('ushr@64', 'a', '#b'), '#c') => ('bcsel', ('ult', ('iadd', ('iand', 'b', 63), ('iand', 'c', 63)), 64), ('ushr@64', 'a', ('iadd', 'b', 'c')), 0) */
   /* search251_0_0 -> 21 in the cache */
   /* search251_0_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 21, 33 },
      -1,
   } },
   /* search251_1 -> 309 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 899, 309 },
      -1,
   } },

   /* replace251_0_0_0_0 -> 36 in the cache */
   /* replace251_0_0_0_1 -> 24 in the cache */
   /* replace251_0_0_0 -> 891 in the cache */
   /* replace251_0_0_1_0 -> 135 in the cache */
   /* replace251_0_0_1_1 -> 24 in the cache */
   /* replace251_0_0_1 -> 892 in the cache */
   /* replace251_0_0 -> 893 in the cache */
   /* replace251_0_1 -> 894 in the cache */
   /* replace251_0 -> 895 in the cache */
   /* replace251_1_0 -> 21 in the cache */
   /* replace251_1_1_0 -> 36 in the cache */
   /* replace251_1_1_1 -> 135 in the cache */
   /* replace251_1_1 -> 833 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 21, 833 },
      -1,
   } },
   /* replace251_2 -> 897 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 4,
      { 895, 901, 897 },
      -1,
   } },

   /* ('ishr@64', ('ishr@64', 'a', '#b'), '#c') => ('ishr@64', 'a', ('imin', ('iadd', ('iand', 'b', 63), ('iand', 'c', 63)), 63)) */
   /* search252_0_0 -> 21 in the cache */
   /* search252_0_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 21, 33 },
      -1,
   } },
   /* search252_1 -> 309 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 903, 309 },
      -1,
   } },

   /* replace252_0 -> 21 in the cache */
   /* replace252_1_0_0_0 -> 36 in the cache */
   /* replace252_1_0_0_1 -> 24 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      2, 1,
      { 36, 24 },
      -1,
   } },
   /* replace252_1_0_1_0 -> 135 in the cache */
   /* replace252_1_0_1_1 -> 24 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      3, 1,
      { 135, 24 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 3,
      { 905, 906 },
      -1,
   } },
   /* replace252_1_1 -> 24 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imin,
      0, 4,
      { 907, 24 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 4,
      { 21, 908 },
      -1,
   } },

   /* ('ishl', ('ushr', 'a@8', '#b'), 'b') => ('iand', 'a', ('ishl', 255, 'b')) */
   /* search253_0_0 -> 6 in the cache */
   /* search253_0_1 -> 33 in the cache */
   /* search253_0 -> 837 in the cache */
   /* search253_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 837, 36 },
      -1,
   } },

   /* replace253_0 -> 6 in the cache */
   { .constant = {
      { nir_search_value_constant, 8 },
      nir_type_int, { 0xff /* 255 */ },
   } },
   /* replace253_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 911, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 6, 912 },
      -1,
   } },

   /* ('ishl', ('ishr', 'a@8', '#b'), 'b') => ('iand', 'a', ('ishl', 255, 'b')) */
   /* search254_0_0 -> 6 in the cache */
   /* search254_0_1 -> 33 in the cache */
   /* search254_0 -> 841 in the cache */
   /* search254_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 841, 36 },
      -1,
   } },

   /* replace254_0 -> 6 in the cache */
   /* replace254_1_0 -> 911 in the cache */
   /* replace254_1_1 -> 36 in the cache */
   /* replace254_1 -> 912 in the cache */
   /* replace254 -> 913 in the cache */

   /* ('ushr', ('ishl', 'a@8', '#b'), 'b') => ('iand', 'a', ('ushr', 255, 'b')) */
   /* search255_0_0 -> 6 in the cache */
   /* search255_0_1 -> 33 in the cache */
   /* search255_0 -> 826 in the cache */
   /* search255_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 826, 36 },
      -1,
   } },

   /* replace255_0 -> 6 in the cache */
   /* replace255_1_0 -> 911 in the cache */
   /* replace255_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 911, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 6, 916 },
      -1,
   } },

   /* ('ishl', ('ushr', 'a@16', '#b'), 'b') => ('iand', 'a', ('ishl', 65535, 'b')) */
   /* search256_0_0 -> 11 in the cache */
   /* search256_0_1 -> 33 in the cache */
   /* search256_0 -> 858 in the cache */
   /* search256_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 858, 36 },
      -1,
   } },

   /* replace256_0 -> 11 in the cache */
   { .constant = {
      { nir_search_value_constant, 16 },
      nir_type_int, { 0xffff /* 65535 */ },
   } },
   /* replace256_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 919, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 11, 920 },
      -1,
   } },

   /* ('ishl', ('ishr', 'a@16', '#b'), 'b') => ('iand', 'a', ('ishl', 65535, 'b')) */
   /* search257_0_0 -> 11 in the cache */
   /* search257_0_1 -> 33 in the cache */
   /* search257_0 -> 862 in the cache */
   /* search257_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 862, 36 },
      -1,
   } },

   /* replace257_0 -> 11 in the cache */
   /* replace257_1_0 -> 919 in the cache */
   /* replace257_1_1 -> 36 in the cache */
   /* replace257_1 -> 920 in the cache */
   /* replace257 -> 921 in the cache */

   /* ('ushr', ('ishl', 'a@16', '#b'), 'b') => ('iand', 'a', ('ushr', 65535, 'b')) */
   /* search258_0_0 -> 11 in the cache */
   /* search258_0_1 -> 33 in the cache */
   /* search258_0 -> 848 in the cache */
   /* search258_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 848, 36 },
      -1,
   } },

   /* replace258_0 -> 11 in the cache */
   /* replace258_1_0 -> 919 in the cache */
   /* replace258_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 919, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 11, 924 },
      -1,
   } },

   /* ('ishl', ('ushr', 'a@32', '#b'), 'b') => ('iand', 'a', ('ishl', 4294967295, 'b')) */
   /* search259_0_0 -> 16 in the cache */
   /* search259_0_1 -> 33 in the cache */
   /* search259_0 -> 878 in the cache */
   /* search259_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 878, 36 },
      -1,
   } },

   /* replace259_0 -> 16 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xffffffff /* 4294967295 */ },
   } },
   /* replace259_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 927, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 16, 928 },
      -1,
   } },

   /* ('ishl', ('ishr', 'a@32', '#b'), 'b') => ('iand', 'a', ('ishl', 4294967295, 'b')) */
   /* search260_0_0 -> 16 in the cache */
   /* search260_0_1 -> 33 in the cache */
   /* search260_0 -> 882 in the cache */
   /* search260_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 882, 36 },
      -1,
   } },

   /* replace260_0 -> 16 in the cache */
   /* replace260_1_0 -> 927 in the cache */
   /* replace260_1_1 -> 36 in the cache */
   /* replace260_1 -> 928 in the cache */
   /* replace260 -> 929 in the cache */

   /* ('ushr', ('ishl', 'a@32', '#b'), 'b') => ('iand', 'a', ('ushr', 4294967295, 'b')) */
   /* search261_0_0 -> 16 in the cache */
   /* search261_0_1 -> 33 in the cache */
   /* search261_0 -> 869 in the cache */
   /* search261_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 869, 36 },
      -1,
   } },

   /* replace261_0 -> 16 in the cache */
   /* replace261_1_0 -> 927 in the cache */
   /* replace261_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 927, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 16, 932 },
      -1,
   } },

   /* ('ishl', ('ushr', 'a@64', '#b'), 'b') => ('iand', 'a', ('ishl', 18446744073709551615, 'b')) */
   /* search262_0_0 -> 21 in the cache */
   /* search262_0_1 -> 33 in the cache */
   /* search262_0 -> 899 in the cache */
   /* search262_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 899, 36 },
      -1,
   } },

   /* replace262_0 -> 21 in the cache */
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0xffffffffffffffff /* 18446744073709551615 */ },
   } },
   /* replace262_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 935, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 21, 936 },
      -1,
   } },

   /* ('ishl', ('ishr', 'a@64', '#b'), 'b') => ('iand', 'a', ('ishl', 18446744073709551615, 'b')) */
   /* search263_0_0 -> 21 in the cache */
   /* search263_0_1 -> 33 in the cache */
   /* search263_0 -> 903 in the cache */
   /* search263_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 903, 36 },
      -1,
   } },

   /* replace263_0 -> 21 in the cache */
   /* replace263_1_0 -> 935 in the cache */
   /* replace263_1_1 -> 36 in the cache */
   /* replace263_1 -> 936 in the cache */
   /* replace263 -> 937 in the cache */

   /* ('ushr', ('ishl', 'a@64', '#b'), 'b') => ('iand', 'a', ('ushr', 18446744073709551615, 'b')) */
   /* search264_0_0 -> 21 in the cache */
   /* search264_0_1 -> 33 in the cache */
   /* search264_0 -> 889 in the cache */
   /* search264_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 889, 36 },
      -1,
   } },

   /* replace264_0 -> 21 in the cache */
   /* replace264_1_0 -> 935 in the cache */
   /* replace264_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 935, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 21, 940 },
      -1,
   } },

   /* ('iand', ('ishl', 'a@32', '#b(is_first_5_bits_uge_2)'), -4) => ('ishl', 'a', 'b') */
   /* search265_0_0 -> 16 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      true,
      nir_type_invalid,
      9,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 16, 942 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { -0x4 /* -4 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 943, 944 },
      -1,
   } },

   /* replace265_0 -> 16 in the cache */
   /* replace265_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 16, 36 },
      -1,
   } },

   /* ('iand', ('imul', 'a', '#b(is_unsigned_multiple_of_4)'), -4) => ('imul', 'a', 'b') */
   /* search266_0_0 -> 0 in the cache */
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      true,
      nir_type_invalid,
      10,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_imul,
      1, 1,
      { 0, 947 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, -2 },
      nir_type_int, { -0x4 /* -4 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 948, 949 },
      -1,
   } },

   /* replace266_0 -> 0 in the cache */
   /* replace266_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* ('iand@32', ('iadd@32', 'a', '#b(is_unsigned_multiple_of_2)'), 4294967294) => ('iadd', ('iand', 'a', 4294967294), 'b') */
   /* search267_0_0 -> 16 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      true,
      nir_type_invalid,
      11,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 16, 952 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xfffffffe /* 4294967294 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 953, 954 },
      -1,
   } },

   /* replace267_0_0 -> 16 in the cache */
   /* replace267_0_1 -> 954 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 16, 954 },
      -1,
   } },
   /* replace267_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 956, 36 },
      -1,
   } },

   /* ('iand@32', ('iadd@32', 'a', '#b(is_unsigned_multiple_of_4)'), 4294967292) => ('iadd', ('iand', 'a', 4294967292), 'b') */
   /* search268_0_0 -> 16 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      true,
      nir_type_invalid,
      10,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 16, 958 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xfffffffc /* 4294967292 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 959, 960 },
      -1,
   } },

   /* replace268_0_0 -> 16 in the cache */
   /* replace268_0_1 -> 960 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 16, 960 },
      -1,
   } },
   /* replace268_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 962, 36 },
      -1,
   } },

   /* ('iand@32', ('iadd@32', 'a', '#b(is_unsigned_multiple_of_8)'), 4294967288) => ('iadd', ('iand', 'a', 4294967288), 'b') */
   /* search269_0_0 -> 16 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      true,
      nir_type_invalid,
      12,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 16, 964 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xfffffff8 /* 4294967288 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 965, 966 },
      -1,
   } },

   /* replace269_0_0 -> 16 in the cache */
   /* replace269_0_1 -> 966 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 16, 966 },
      -1,
   } },
   /* replace269_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 968, 36 },
      -1,
   } },

   /* ('iand@32', ('iadd@32', 'a', '#b(is_unsigned_multiple_of_16)'), 4294967280) => ('iadd', ('iand', 'a', 4294967280), 'b') */
   /* search270_0_0 -> 16 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      true,
      nir_type_invalid,
      13,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 16, 970 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xfffffff0 /* 4294967280 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 971, 972 },
      -1,
   } },

   /* replace270_0_0 -> 16 in the cache */
   /* replace270_0_1 -> 972 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 16, 972 },
      -1,
   } },
   /* replace270_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 974, 36 },
      -1,
   } },

   /* ('iand@32', ('iadd@32', 'a', '#b(is_unsigned_multiple_of_32)'), 4294967264) => ('iadd', ('iand', 'a', 4294967264), 'b') */
   /* search271_0_0 -> 16 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      true,
      nir_type_invalid,
      14,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 16, 976 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xffffffe0 /* 4294967264 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 977, 978 },
      -1,
   } },

   /* replace271_0_0 -> 16 in the cache */
   /* replace271_0_1 -> 978 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 16, 978 },
      -1,
   } },
   /* replace271_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 980, 36 },
      -1,
   } },

   /* ('iand@32', ('iadd@32', 'a', '#b(is_unsigned_multiple_of_64)'), 4294967232) => ('iadd', ('iand', 'a', 4294967232), 'b') */
   /* search272_0_0 -> 16 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      true,
      nir_type_invalid,
      15,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 16, 982 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xffffffc0 /* 4294967232 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 983, 984 },
      -1,
   } },

   /* replace272_0_0 -> 16 in the cache */
   /* replace272_0_1 -> 984 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 16, 984 },
      -1,
   } },
   /* replace272_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 986, 36 },
      -1,
   } },

   /* ('ishl@32', ('iand', 'a@32', 2147483647), 1) => ('ishl', 'a', 1) */
   /* search273_0_0 -> 16 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x7fffffff /* 2147483647 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 16, 988 },
      -1,
   } },
   /* search273_1 -> 396 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 989, 396 },
      -1,
   } },

   /* replace273_0 -> 16 in the cache */
   /* replace273_1 -> 396 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 16, 396 },
      -1,
   } },

   /* ('iand', ('ishl', 'a@32', 1), 4294967294) => ('ishl', 'a', 1) */
   /* search274_0_0 -> 16 in the cache */
   /* search274_0_1 -> 396 in the cache */
   /* search274_0 -> 991 in the cache */
   /* search274_1 -> 954 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 991, 954 },
      -1,
   } },

   /* replace274_0 -> 16 in the cache */
   /* replace274_1 -> 396 in the cache */
   /* replace274 -> 991 in the cache */

   /* ('iand', ('ushr', 'a@32', 1), 2147483647) => ('ushr', 'a', 1) */
   /* search275_0_0 -> 16 in the cache */
   /* search275_0_1 -> 396 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 16, 396 },
      -1,
   } },
   /* search275_1 -> 988 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 993, 988 },
      -1,
   } },

   /* replace275_0 -> 16 in the cache */
   /* replace275_1 -> 396 in the cache */
   /* replace275 -> 993 in the cache */

   /* ('ishl@32', ('iand', 'a@32', 1073741823), 2) => ('ishl', 'a', 2) */
   /* search276_0_0 -> 16 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x3fffffff /* 1073741823 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 16, 995 },
      -1,
   } },
   /* search276_1 -> 401 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 996, 401 },
      -1,
   } },

   /* replace276_0 -> 16 in the cache */
   /* replace276_1 -> 401 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 16, 401 },
      -1,
   } },

   /* ('iand', ('ishl', 'a@32', 2), 4294967292) => ('ishl', 'a', 2) */
   /* search277_0_0 -> 16 in the cache */
   /* search277_0_1 -> 401 in the cache */
   /* search277_0 -> 998 in the cache */
   /* search277_1 -> 960 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 998, 960 },
      -1,
   } },

   /* replace277_0 -> 16 in the cache */
   /* replace277_1 -> 401 in the cache */
   /* replace277 -> 998 in the cache */

   /* ('iand', ('ushr', 'a@32', 2), 1073741823) => ('ushr', 'a', 2) */
   /* search278_0_0 -> 16 in the cache */
   /* search278_0_1 -> 401 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 16, 401 },
      -1,
   } },
   /* search278_1 -> 995 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1000, 995 },
      -1,
   } },

   /* replace278_0 -> 16 in the cache */
   /* replace278_1 -> 401 in the cache */
   /* replace278 -> 1000 in the cache */

   /* ('ishl@32', ('iand', 'a@32', 65535), 16) => ('ishl', 'a', 16) */
   /* search279_0_0 -> 16 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xffff /* 65535 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 16, 1002 },
      -1,
   } },
   /* search279_1 -> 853 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 1003, 853 },
      -1,
   } },

   /* replace279_0 -> 16 in the cache */
   /* replace279_1 -> 853 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 16, 853 },
      -1,
   } },

   /* ('iand', ('ishl', 'a@32', 16), 4294901760) => ('ishl', 'a', 16) */
   /* search280_0_0 -> 16 in the cache */
   /* search280_0_1 -> 853 in the cache */
   /* search280_0 -> 1005 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xffff0000 /* 4294901760 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1005, 1006 },
      -1,
   } },

   /* replace280_0 -> 16 in the cache */
   /* replace280_1 -> 853 in the cache */
   /* replace280 -> 1005 in the cache */

   /* ('iand', ('ushr', 'a@32', 16), 65535) => ('ushr', 'a', 16) */
   /* search281_0_0 -> 16 in the cache */
   /* search281_0_1 -> 853 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 16, 853 },
      -1,
   } },
   /* search281_1 -> 1002 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1008, 1002 },
      -1,
   } },

   /* replace281_0 -> 16 in the cache */
   /* replace281_1 -> 853 in the cache */
   /* replace281 -> 1008 in the cache */

   /* ('ishl@32', ('iand', 'a@32', 255), 24) => ('ishl', 'a', 24) */
   /* search282_0_0 -> 16 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xff /* 255 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 16, 1010 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x18 /* 24 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 1011, 1012 },
      -1,
   } },

   /* replace282_0 -> 16 in the cache */
   /* replace282_1 -> 1012 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 16, 1012 },
      -1,
   } },

   /* ('iand', ('ishl', 'a@32', 24), 4278190080) => ('ishl', 'a', 24) */
   /* search283_0_0 -> 16 in the cache */
   /* search283_0_1 -> 1012 in the cache */
   /* search283_0 -> 1014 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xff000000 /* 4278190080 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1014, 1015 },
      -1,
   } },

   /* replace283_0 -> 16 in the cache */
   /* replace283_1 -> 1012 in the cache */
   /* replace283 -> 1014 in the cache */

   /* ('iand', ('ushr', 'a@32', 24), 255) => ('ushr', 'a', 24) */
   /* search284_0_0 -> 16 in the cache */
   /* search284_0_1 -> 1012 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 16, 1012 },
      -1,
   } },
   /* search284_1 -> 1010 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1017, 1010 },
      -1,
   } },

   /* replace284_0 -> 16 in the cache */
   /* replace284_1 -> 1012 in the cache */
   /* replace284 -> 1017 in the cache */

   /* ('ishl', ('iadd', 'a', '#b'), '#c') => ('iadd', ('ishl', 'a', 'c'), ('ishl', 'b', 'c')) */
   /* search285_0_0 -> 0 in the cache */
   /* search285_0_1 -> 821 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 0, 821 },
      -1,
   } },
   /* search285_1 -> 309 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 1019, 309 },
      -1,
   } },

   /* replace285_0_0 -> 0 in the cache */
   /* replace285_0_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 0, 135 },
      -1,
   } },
   /* replace285_1_0 -> 3 in the cache */
   /* replace285_1_1 -> 135 in the cache */
   /* replace285_1 -> 824 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 1021, 824 },
      -1,
   } },

   /* ('imul', ('iadd(is_used_once)', 'a', '#b'), '#c') => ('iadd', ('imul', 'a', 'c'), ('imul', 'b', 'c')) */
   /* search286_0_0 -> 126 in the cache */
   /* search286_0_1 -> 283 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 126, 283 },
      0,
   } },
   /* search286_1 -> 814 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imul,
      0, 2,
      { 1023, 814 },
      -1,
   } },

   /* replace286_0_0 -> 126 in the cache */
   /* replace286_0_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imul,
      1, 1,
      { 126, 129 },
      -1,
   } },
   /* replace286_1_0 -> 127 in the cache */
   /* replace286_1_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imul,
      2, 1,
      { 127, 129 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 3,
      { 1025, 1026 },
      -1,
   } },

   /* ('imul', ('iadd(is_used_once)', ('iadd(is_used_once)', 'a', '#b'), 'c'), '#d') => ('iadd', ('imul', ('iadd', 'a', 'c'), 'd'), ('imul', 'b', 'd')) */
   /* search287_0_0_0 -> 149 in the cache */
   { .variable = {
      { nir_search_value_variable, -4 },
      1, /* b */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iadd,
      2, 1,
      { 149, 1028 },
      0,
   } },
   /* search287_0_1 -> 152 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 2,
      { 1029, 152 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, -4 },
      3, /* d */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imul,
      0, 3,
      { 1030, 1031 },
      -1,
   } },

   /* replace287_0_0_0 -> 149 in the cache */
   /* replace287_0_0_1 -> 152 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iadd,
      2, 1,
      { 149, 152 },
      -1,
   } },
   /* replace287_0_1 -> 153 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imul,
      1, 2,
      { 1033, 153 },
      -1,
   } },
   /* replace287_1_0 -> 150 in the cache */
   /* replace287_1_1 -> 153 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imul,
      3, 1,
      { 150, 153 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 4,
      { 1034, 1035 },
      -1,
   } },

   /* ('ishl', ('iadd(is_used_once)', ('iadd(is_used_once)', 'a', '#b'), 'c'), '#d') => ('iadd', ('ishl', ('iadd', 'a', 'c'), 'd'), ('ishl', 'b', 'd')) */
   /* search288_0_0_0 -> 126 in the cache */
   /* search288_0_0_1 -> 283 in the cache */
   /* search288_0_0 -> 1023 in the cache */
   /* search288_0_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 1023, 129 },
      0,
   } },
   /* search288_1 -> 311 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 2,
      { 1037, 311 },
      -1,
   } },

   /* replace288_0_0_0 -> 126 in the cache */
   /* replace288_0_0_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 126, 129 },
      -1,
   } },
   /* replace288_0_1 -> 163 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 1039, 163 },
      -1,
   } },
   /* replace288_1_0 -> 127 in the cache */
   /* replace288_1_1 -> 163 in the cache */
   /* replace288_1 -> 817 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 1040, 817 },
      -1,
   } },

   /* ('inot', ('flt(is_used_once)', 'a(is_a_number)', 'b(is_a_number)')) => ('fge', 'a', 'b') */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      16,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      16,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1042, 1043 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 1044 },
      -1,
   } },

   /* replace289_0 -> 0 in the cache */
   /* replace289_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* ('inot', ('fge(is_used_once)', 'a(is_a_number)', 'b(is_a_number)')) => ('flt', 'a', 'b') */
   /* search290_0_0 -> 1042 in the cache */
   /* search290_0_1 -> 1043 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1042, 1043 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 1047 },
      -1,
   } },

   /* replace290_0 -> 0 in the cache */
   /* replace290_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* ('inot', ('feq(is_used_once)', 'a', 'b')) => ('fneu', 'a', 'b') */
   /* search291_0_0 -> 0 in the cache */
   /* search291_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 0, 3 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 1,
      { 1050 },
      -1,
   } },

   /* replace291_0 -> 0 in the cache */
   /* replace291_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* ('inot', ('fneu(is_used_once)', 'a', 'b')) => ('feq', 'a', 'b') */
   /* search292_0_0 -> 0 in the cache */
   /* search292_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 0, 3 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 1,
      { 1053 },
      -1,
   } },

   /* replace292_0 -> 0 in the cache */
   /* replace292_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* ('inot', ('ilt(is_used_once)', 'a', 'b')) => ('ige', 'a', 'b') */
   /* search293_0_0 -> 0 in the cache */
   /* search293_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 0, 3 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 1056 },
      -1,
   } },

   /* replace293_0 -> 0 in the cache */
   /* replace293_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* ('inot', ('ult(is_used_once)', 'a', 'b')) => ('uge', 'a', 'b') */
   /* search294_0_0 -> 0 in the cache */
   /* search294_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 0, 3 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 1059 },
      -1,
   } },

   /* replace294_0 -> 0 in the cache */
   /* replace294_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* ('inot', ('ige(is_used_once)', 'a', 'b')) => ('ilt', 'a', 'b') */
   /* search295_0_0 -> 0 in the cache */
   /* search295_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 0, 3 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 1062 },
      -1,
   } },

   /* replace295_0 -> 0 in the cache */
   /* replace295_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* ('inot', ('uge(is_used_once)', 'a', 'b')) => ('ult', 'a', 'b') */
   /* search296_0_0 -> 0 in the cache */
   /* search296_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 0, 3 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 1065 },
      -1,
   } },

   /* replace296_0 -> 0 in the cache */
   /* replace296_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* ('inot', ('ieq(is_used_once)', 'a', 'b')) => ('ine', 'a', 'b') */
   /* search297_0_0 -> 0 in the cache */
   /* search297_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 0, 3 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 1,
      { 1068 },
      -1,
   } },

   /* replace297_0 -> 0 in the cache */
   /* replace297_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* ('inot', ('ine(is_used_once)', 'a', 'b')) => ('ieq', 'a', 'b') */
   /* search298_0_0 -> 0 in the cache */
   /* search298_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 0, 3 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 1,
      { 1071 },
      -1,
   } },

   /* replace298_0 -> 0 in the cache */
   /* replace298_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* ('iand', ('feq', 'a', 'b'), ('fneu', 'a', 'b')) => False */
   /* search299_0_0 -> 0 in the cache */
   /* search299_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      1, 1,
      { 0, 3 },
      -1,
   } },
   /* search299_1_0 -> 0 in the cache */
   /* search299_1_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      2, 1,
      { 0, 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 1074, 1075 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, 1 },
      nir_type_bool, { NIR_FALSE /* False */ },
   } },

   /* ('iand', ('flt', 'a', 'b'), ('flt', 'b', 'a')) => False */
   /* search300_0_0 -> 0 in the cache */
   /* search300_0_1 -> 3 in the cache */
   /* search300_0 -> 1049 in the cache */
   /* search300_1_0 -> 3 in the cache */
   /* search300_1_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 3, 0 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1049, 1078 },
      -1,
   } },

   /* replace300 -> 1077 in the cache */

   /* ('iand', ('ieq', 'a', 'b'), ('ine', 'a', 'b')) => False */
   /* search301_0_0 -> 0 in the cache */
   /* search301_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 0, 3 },
      -1,
   } },
   /* search301_1_0 -> 0 in the cache */
   /* search301_1_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 0, 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 1080, 1081 },
      -1,
   } },

   /* replace301 -> 1077 in the cache */

   /* ('iand', ('ilt', 'a', 'b'), ('ilt', 'b', 'a')) => False */
   /* search302_0_0 -> 0 in the cache */
   /* search302_0_1 -> 3 in the cache */
   /* search302_0 -> 1064 in the cache */
   /* search302_1_0 -> 3 in the cache */
   /* search302_1_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 3, 0 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1064, 1083 },
      -1,
   } },

   /* replace302 -> 1077 in the cache */

   /* ('iand', ('ult', 'a', 'b'), ('ult', 'b', 'a')) => False */
   /* search303_0_0 -> 0 in the cache */
   /* search303_0_1 -> 3 in the cache */
   /* search303_0 -> 1067 in the cache */
   /* search303_1_0 -> 3 in the cache */
   /* search303_1_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 3, 0 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1067, 1085 },
      -1,
   } },

   /* replace303 -> 1077 in the cache */

   /* ('flt', ('fneg', 'a'), ('fneg', 'b')) => ('flt', 'b', 'a') */
   /* search304_0_0 -> 0 in the cache */
   /* search304_0 -> 212 in the cache */
   /* search304_1_0 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 212, 1087 },
      -1,
   } },

   /* replace304_0 -> 3 in the cache */
   /* replace304_1 -> 0 in the cache */
   /* replace304 -> 1078 in the cache */

   /* ('fge', ('fneg', 'a'), ('fneg', 'b')) => ('fge', 'b', 'a') */
   /* search305_0_0 -> 0 in the cache */
   /* search305_0 -> 212 in the cache */
   /* search305_1_0 -> 3 in the cache */
   /* search305_1 -> 1087 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 212, 1087 },
      -1,
   } },

   /* replace305_0 -> 3 in the cache */
   /* replace305_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 3, 0 },
      -1,
   } },

   /* ('feq', ('fneg', 'a'), ('fneg', 'b')) => ('feq', 'b', 'a') */
   /* search306_0_0 -> 0 in the cache */
   /* search306_0 -> 212 in the cache */
   /* search306_1_0 -> 3 in the cache */
   /* search306_1 -> 1087 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 212, 1087 },
      -1,
   } },

   /* replace306_0 -> 3 in the cache */
   /* replace306_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 3, 0 },
      -1,
   } },

   /* ('fneu', ('fneg', 'a'), ('fneg', 'b')) => ('fneu', 'b', 'a') */
   /* search307_0_0 -> 0 in the cache */
   /* search307_0 -> 212 in the cache */
   /* search307_1_0 -> 3 in the cache */
   /* search307_1 -> 1087 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 212, 1087 },
      -1,
   } },

   /* replace307_0 -> 3 in the cache */
   /* replace307_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 3, 0 },
      -1,
   } },

   /* ('flt', ('fneg', 'a'), -1.0) => ('flt', 1.0, 'a') */
   /* search308_0_0 -> 32 in the cache */
   /* search308_0 -> 98 in the cache */
   /* search308_1 -> 247 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 98, 247 },
      -1,
   } },

   /* replace308_0 -> 241 in the cache */
   /* replace308_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 241, 32 },
      -1,
   } },

   /* ('flt', -1.0, ('fneg', 'a')) => ('flt', 'a', 1.0) */
   /* search309_0 -> 247 in the cache */
   /* search309_1_0 -> 32 in the cache */
   /* search309_1 -> 98 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 247, 98 },
      -1,
   } },

   /* replace309_0 -> 32 in the cache */
   /* replace309_1 -> 241 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 32, 241 },
      -1,
   } },

   /* ('fge', ('fneg', 'a'), -1.0) => ('fge', 1.0, 'a') */
   /* search310_0_0 -> 32 in the cache */
   /* search310_0 -> 98 in the cache */
   /* search310_1 -> 247 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 98, 247 },
      -1,
   } },

   /* replace310_0 -> 241 in the cache */
   /* replace310_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 241, 32 },
      -1,
   } },

   /* ('fge', -1.0, ('fneg', 'a')) => ('fge', 'a', 1.0) */
   /* search311_0 -> 247 in the cache */
   /* search311_1_0 -> 32 in the cache */
   /* search311_1 -> 98 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 247, 98 },
      -1,
   } },

   /* replace311_0 -> 32 in the cache */
   /* replace311_1 -> 241 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 32, 241 },
      -1,
   } },

   /* ('fneu', ('fneg', 'a'), -1.0) => ('fneu', 1.0, 'a') */
   /* search312_0_0 -> 32 in the cache */
   /* search312_0 -> 98 in the cache */
   /* search312_1 -> 247 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 98, 247 },
      -1,
   } },

   /* replace312_0 -> 241 in the cache */
   /* replace312_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 241, 32 },
      -1,
   } },

   /* ('feq', -1.0, ('fneg', 'a')) => ('feq', 'a', 1.0) */
   /* search313_0 -> 247 in the cache */
   /* search313_1_0 -> 32 in the cache */
   /* search313_1 -> 98 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 247, 98 },
      -1,
   } },

   /* replace313_0 -> 32 in the cache */
   /* replace313_1 -> 241 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 32, 241 },
      -1,
   } },

   /* ('ieq', ('ineg', 'a'), 0) => ('ieq', 'a', 0) */
   /* search314_0_0 -> 32 in the cache */
   /* search314_0 -> 100 in the cache */
   /* search314_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 100, 61 },
      -1,
   } },

   /* replace314_0 -> 32 in the cache */
   /* replace314_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 32, 61 },
      -1,
   } },

   /* ('ine', ('ineg', 'a'), 0) => ('ine', 'a', 0) */
   /* search315_0_0 -> 32 in the cache */
   /* search315_0 -> 100 in the cache */
   /* search315_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 100, 61 },
      -1,
   } },

   /* replace315_0 -> 32 in the cache */
   /* replace315_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 32, 61 },
      -1,
   } },

   /* ('ieq', ('iabs', 'a'), 0) => ('ieq', 'a', 0) */
   /* search316_0_0 -> 32 in the cache */
   /* search316_0 -> 106 in the cache */
   /* search316_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 106, 61 },
      -1,
   } },

   /* replace316_0 -> 32 in the cache */
   /* replace316_1 -> 61 in the cache */
   /* replace316 -> 1108 in the cache */

   /* ('ine', ('iabs', 'a'), 0) => ('ine', 'a', 0) */
   /* search317_0_0 -> 32 in the cache */
   /* search317_0 -> 106 in the cache */
   /* search317_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 106, 61 },
      -1,
   } },

   /* replace317_0 -> 32 in the cache */
   /* replace317_1 -> 61 in the cache */
   /* replace317 -> 1110 in the cache */

   /* ('flt', '#b(is_gt_0_and_lt_1)', ('fsat(is_used_once)', 'a')) => ('flt', 'b', 'a') */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* b */
      true,
      nir_type_invalid,
      17,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 1114 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1113, 1115 },
      -1,
   } },

   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* replace318_1 -> 1114 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1117, 1114 },
      -1,
   } },

   /* ('fge', ('fsat(is_used_once)', 'a'), '#b(is_gt_0_and_lt_1)') => ('fge', 'a', 'b') */
   /* search319_0_0 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 0 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      true,
      nir_type_invalid,
      17,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1119, 1120 },
      -1,
   } },

   /* replace319_0 -> 0 in the cache */
   /* replace319_1 -> 3 in the cache */
   /* replace319 -> 1046 in the cache */

   /* ('feq', ('fsat(is_used_once)', 'a'), '#b(is_gt_0_and_lt_1)') => ('feq', 'a', 'b') */
   /* search320_0_0 -> 0 in the cache */
   /* search320_0 -> 1119 in the cache */
   /* search320_1 -> 1120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 1119, 1120 },
      -1,
   } },

   /* replace320_0 -> 0 in the cache */
   /* replace320_1 -> 3 in the cache */
   /* replace320 -> 1055 in the cache */

   /* ('fneu', ('fsat(is_used_once)', 'a'), '#b(is_gt_0_and_lt_1)') => ('fneu', 'a', 'b') */
   /* search321_0_0 -> 0 in the cache */
   /* search321_0 -> 1119 in the cache */
   /* search321_1 -> 1120 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 1119, 1120 },
      -1,
   } },

   /* replace321_0 -> 0 in the cache */
   /* replace321_1 -> 3 in the cache */
   /* replace321 -> 1052 in the cache */

   /* ('fge', ('fsat(is_used_once)', 'a'), 1.0) => ('fge', 'a', 1.0) */
   /* search322_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 32 },
      0,
   } },
   /* search322_1 -> 241 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1124, 241 },
      -1,
   } },

   /* replace322_0 -> 32 in the cache */
   /* replace322_1 -> 241 in the cache */
   /* replace322 -> 1102 in the cache */

   /* ('flt', 0.0, ('fsat(is_used_once)', 'a')) => ('flt', 0.0, 'a') */
   /* search323_0 -> 111 in the cache */
   /* search323_1_0 -> 32 in the cache */
   /* search323_1 -> 1124 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 111, 1124 },
      -1,
   } },

   /* replace323_0 -> 111 in the cache */
   /* replace323_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 111, 32 },
      -1,
   } },

   /* ('fge', 0.0, ('b2f', 'a@1')) => ('inot', 'a') */
   { .constant = {
      { nir_search_value_constant, 0 },
      nir_type_float, { 0x0 /* 0.0 */ },
   } },
   /* search324_1_0 -> 760 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 760 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1128, 1129 },
      -1,
   } },

   /* replace324_0 -> 760 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 760 },
      -1,
   } },

   /* ('fge', ('fneg', ('b2f', 'a@1')), 0.0) => ('inot', 'a') */
   /* search325_0_0_0 -> 760 in the cache */
   /* search325_0_0 -> 1129 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 1129 },
      -1,
   } },
   /* search325_1 -> 1128 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1132, 1128 },
      -1,
   } },

   /* replace325_0 -> 760 in the cache */
   /* replace325 -> 1131 in the cache */

   /* ('fneu', ('fadd', ('b2f', 'a@1'), ('b2f', 'b@1')), 0.0) => ('ior', 'a', 'b') */
   /* search326_0_0_0 -> 760 in the cache */
   /* search326_0_0 -> 1129 in the cache */
   { .variable = {
      { nir_search_value_variable, 1 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 1134 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 1129, 1135 },
      -1,
   } },
   /* search326_1 -> 1128 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 2,
      { 1136, 1128 },
      -1,
   } },

   /* replace326_0 -> 760 in the cache */
   /* replace326_1 -> 1134 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 760, 1134 },
      -1,
   } },

   /* ('fneu', ('bcsel', 'a', 1.0, ('b2f', 'b@1')), 0.0) => ('ior', 'a', 'b') */
   /* search327_0_0 -> 760 in the cache */
   { .constant = {
      { nir_search_value_constant, 0 },
      nir_type_float, { 0x3ff0000000000000 /* 1.0 */ },
   } },
   /* search327_0_2_0 -> 1134 in the cache */
   /* search327_0_2 -> 1135 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 760, 1139, 1135 },
      -1,
   } },
   /* search327_1 -> 1128 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 1140, 1128 },
      -1,
   } },

   /* replace327_0 -> 760 in the cache */
   /* replace327_1 -> 1134 in the cache */
   /* replace327 -> 1138 in the cache */

   /* ('fneu', ('b2f', 'a@1'), ('fneg', ('b2f', 'b@1'))) => ('ior', 'a', 'b') */
   /* search328_0_0 -> 760 in the cache */
   /* search328_0 -> 1129 in the cache */
   /* search328_1_0_0 -> 1134 in the cache */
   /* search328_1_0 -> 1135 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 1135 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 1129, 1142 },
      -1,
   } },

   /* replace328_0 -> 760 in the cache */
   /* replace328_1 -> 1134 in the cache */
   /* replace328 -> 1138 in the cache */

   /* ('fneu', ('fmul', ('b2f', 'a@1'), ('b2f', 'b@1')), 0.0) => ('iand', 'a', 'b') */
   /* search329_0_0_0 -> 760 in the cache */
   /* search329_0_0 -> 1129 in the cache */
   /* search329_0_1_0 -> 1134 in the cache */
   /* search329_0_1 -> 1135 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 1129, 1135 },
      -1,
   } },
   /* search329_1 -> 1128 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 2,
      { 1144, 1128 },
      -1,
   } },

   /* replace329_0 -> 760 in the cache */
   /* replace329_1 -> 1134 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 760, 1134 },
      -1,
   } },

   /* ('fneu', ('bcsel', 'a', ('b2f', 'b@1'), 0.0), 0.0) => ('iand', 'a', 'b') */
   /* search330_0_0 -> 760 in the cache */
   /* search330_0_1_0 -> 1134 in the cache */
   /* search330_0_1 -> 1135 in the cache */
   /* search330_0_2 -> 1128 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 760, 1135, 1128 },
      -1,
   } },
   /* search330_1 -> 1128 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 1147, 1128 },
      -1,
   } },

   /* replace330_0 -> 760 in the cache */
   /* replace330_1 -> 1134 in the cache */
   /* replace330 -> 1146 in the cache */

   /* ('fneu', ('fadd', ('b2f', 'a@1'), ('fneg', ('b2f', 'b@1'))), 0.0) => ('ixor', 'a', 'b') */
   /* search331_0_0_0 -> 760 in the cache */
   /* search331_0_0 -> 1129 in the cache */
   /* search331_0_1_0_0 -> 1134 in the cache */
   /* search331_0_1_0 -> 1135 in the cache */
   /* search331_0_1 -> 1142 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 1129, 1142 },
      -1,
   } },
   /* search331_1 -> 1128 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 2,
      { 1149, 1128 },
      -1,
   } },

   /* replace331_0 -> 760 in the cache */
   /* replace331_1 -> 1134 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 760, 1134 },
      -1,
   } },

   /* ('fneu', ('b2f', 'a@1'), ('b2f', 'b@1')) => ('ixor', 'a', 'b') */
   /* search332_0_0 -> 760 in the cache */
   /* search332_0 -> 1129 in the cache */
   /* search332_1_0 -> 1134 in the cache */
   /* search332_1 -> 1135 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 1129, 1135 },
      -1,
   } },

   /* replace332_0 -> 760 in the cache */
   /* replace332_1 -> 1134 in the cache */
   /* replace332 -> 1151 in the cache */

   /* ('fneu', ('fneg', ('b2f', 'a@1')), ('fneg', ('b2f', 'b@1'))) => ('ixor', 'a', 'b') */
   /* search333_0_0_0 -> 760 in the cache */
   /* search333_0_0 -> 1129 in the cache */
   /* search333_0 -> 1132 in the cache */
   /* search333_1_0_0 -> 1134 in the cache */
   /* search333_1_0 -> 1135 in the cache */
   /* search333_1 -> 1142 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 1132, 1142 },
      -1,
   } },

   /* replace333_0 -> 760 in the cache */
   /* replace333_1 -> 1134 in the cache */
   /* replace333 -> 1151 in the cache */

   /* ('feq', ('fadd', ('b2f', 'a@1'), ('b2f', 'b@1')), 0.0) => ('inot', ('ior', 'a', 'b')) */
   /* search334_0_0_0 -> 760 in the cache */
   /* search334_0_0 -> 1129 in the cache */
   /* search334_0_1_0 -> 1134 in the cache */
   /* search334_0_1 -> 1135 in the cache */
   /* search334_0 -> 1136 in the cache */
   /* search334_1 -> 1128 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 2,
      { 1136, 1128 },
      -1,
   } },

   /* replace334_0_0 -> 760 in the cache */
   /* replace334_0_1 -> 1134 in the cache */
   /* replace334_0 -> 1138 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 1,
      { 1138 },
      -1,
   } },

   /* ('feq', ('bcsel', 'a', 1.0, ('b2f', 'b@1')), 0.0) => ('inot', ('ior', 'a', 'b')) */
   /* search335_0_0 -> 760 in the cache */
   /* search335_0_1 -> 1139 in the cache */
   /* search335_0_2_0 -> 1134 in the cache */
   /* search335_0_2 -> 1135 in the cache */
   /* search335_0 -> 1140 in the cache */
   /* search335_1 -> 1128 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 1140, 1128 },
      -1,
   } },

   /* replace335_0_0 -> 760 in the cache */
   /* replace335_0_1 -> 1134 in the cache */
   /* replace335_0 -> 1138 in the cache */
   /* replace335 -> 1155 in the cache */

   /* ('feq', ('b2f', 'a@1'), ('fneg', ('b2f', 'b@1'))) => ('inot', ('ior', 'a', 'b')) */
   /* search336_0_0 -> 760 in the cache */
   /* search336_0 -> 1129 in the cache */
   /* search336_1_0_0 -> 1134 in the cache */
   /* search336_1_0 -> 1135 in the cache */
   /* search336_1 -> 1142 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 1129, 1142 },
      -1,
   } },

   /* replace336_0_0 -> 760 in the cache */
   /* replace336_0_1 -> 1134 in the cache */
   /* replace336_0 -> 1138 in the cache */
   /* replace336 -> 1155 in the cache */

   /* ('feq', ('fmul', ('b2f', 'a@1'), ('b2f', 'b@1')), 0.0) => ('inot', ('iand', 'a', 'b')) */
   /* search337_0_0_0 -> 760 in the cache */
   /* search337_0_0 -> 1129 in the cache */
   /* search337_0_1_0 -> 1134 in the cache */
   /* search337_0_1 -> 1135 in the cache */
   /* search337_0 -> 1144 in the cache */
   /* search337_1 -> 1128 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 2,
      { 1144, 1128 },
      -1,
   } },

   /* replace337_0_0 -> 760 in the cache */
   /* replace337_0_1 -> 1134 in the cache */
   /* replace337_0 -> 1146 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 1,
      { 1146 },
      -1,
   } },

   /* ('feq', ('bcsel', 'a', ('b2f', 'b@1'), 0.0), 0.0) => ('inot', ('iand', 'a', 'b')) */
   /* search338_0_0 -> 760 in the cache */
   /* search338_0_1_0 -> 1134 in the cache */
   /* search338_0_1 -> 1135 in the cache */
   /* search338_0_2 -> 1128 in the cache */
   /* search338_0 -> 1147 in the cache */
   /* search338_1 -> 1128 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 1147, 1128 },
      -1,
   } },

   /* replace338_0_0 -> 760 in the cache */
   /* replace338_0_1 -> 1134 in the cache */
   /* replace338_0 -> 1146 in the cache */
   /* replace338 -> 1159 in the cache */

   /* ('feq', ('fadd', ('b2f', 'a@1'), ('fneg', ('b2f', 'b@1'))), 0.0) => ('ieq', 'a', 'b') */
   /* search339_0_0_0 -> 760 in the cache */
   /* search339_0_0 -> 1129 in the cache */
   /* search339_0_1_0_0 -> 1134 in the cache */
   /* search339_0_1_0 -> 1135 in the cache */
   /* search339_0_1 -> 1142 in the cache */
   /* search339_0 -> 1149 in the cache */
   /* search339_1 -> 1128 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 2,
      { 1149, 1128 },
      -1,
   } },

   /* replace339_0 -> 760 in the cache */
   /* replace339_1 -> 1134 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 760, 1134 },
      -1,
   } },

   /* ('feq', ('b2f', 'a@1'), ('b2f', 'b@1')) => ('ieq', 'a', 'b') */
   /* search340_0_0 -> 760 in the cache */
   /* search340_0 -> 1129 in the cache */
   /* search340_1_0 -> 1134 in the cache */
   /* search340_1 -> 1135 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 1129, 1135 },
      -1,
   } },

   /* replace340_0 -> 760 in the cache */
   /* replace340_1 -> 1134 in the cache */
   /* replace340 -> 1162 in the cache */

   /* ('feq', ('fneg', ('b2f', 'a@1')), ('fneg', ('b2f', 'b@1'))) => ('ieq', 'a', 'b') */
   /* search341_0_0_0 -> 760 in the cache */
   /* search341_0_0 -> 1129 in the cache */
   /* search341_0 -> 1132 in the cache */
   /* search341_1_0_0 -> 1134 in the cache */
   /* search341_1_0 -> 1135 in the cache */
   /* search341_1 -> 1142 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 1132, 1142 },
      -1,
   } },

   /* replace341_0 -> 760 in the cache */
   /* replace341_1 -> 1134 in the cache */
   /* replace341 -> 1162 in the cache */

   /* ('flt', ('fneg', ('fadd', ('b2f', 'a@1'), ('b2f', 'b@1'))), 0.0) => ('ior', 'a', 'b') */
   /* search342_0_0_0_0 -> 760 in the cache */
   /* search342_0_0_0 -> 1129 in the cache */
   /* search342_0_0_1_0 -> 1134 in the cache */
   /* search342_0_0_1 -> 1135 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 1129, 1135 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 1165 },
      -1,
   } },
   /* search342_1 -> 1128 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 1166, 1128 },
      -1,
   } },

   /* replace342_0 -> 760 in the cache */
   /* replace342_1 -> 1134 in the cache */
   /* replace342 -> 1138 in the cache */

   /* ('flt', 0.0, ('fadd', ('b2f', 'a@1'), ('b2f', 'b@1'))) => ('ior', 'a', 'b') */
   /* search343_0 -> 1128 in the cache */
   /* search343_1_0_0 -> 760 in the cache */
   /* search343_1_0 -> 1129 in the cache */
   /* search343_1_1_0 -> 1134 in the cache */
   /* search343_1_1 -> 1135 in the cache */
   /* search343_1 -> 1165 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 1128, 1165 },
      -1,
   } },

   /* replace343_0 -> 760 in the cache */
   /* replace343_1 -> 1134 in the cache */
   /* replace343 -> 1138 in the cache */

   /* ('fge', ('fneg', ('fadd', ('b2f', 'a@1'), ('b2f', 'b@1'))), 0.0) => ('inot', ('ior', 'a', 'b')) */
   /* search344_0_0_0_0 -> 760 in the cache */
   /* search344_0_0_0 -> 1129 in the cache */
   /* search344_0_0_1_0 -> 1134 in the cache */
   /* search344_0_0_1 -> 1135 in the cache */
   /* search344_0_0 -> 1165 in the cache */
   /* search344_0 -> 1166 in the cache */
   /* search344_1 -> 1128 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 1166, 1128 },
      -1,
   } },

   /* replace344_0_0 -> 760 in the cache */
   /* replace344_0_1 -> 1134 in the cache */
   /* replace344_0 -> 1138 in the cache */
   /* replace344 -> 1155 in the cache */

   /* ('fge', 0.0, ('fadd', ('b2f', 'a@1'), ('b2f', 'b@1'))) => ('inot', ('ior', 'a', 'b')) */
   /* search345_0 -> 1128 in the cache */
   /* search345_1_0_0 -> 760 in the cache */
   /* search345_1_0 -> 1129 in the cache */
   /* search345_1_1_0 -> 1134 in the cache */
   /* search345_1_1 -> 1135 in the cache */
   /* search345_1 -> 1165 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 1128, 1165 },
      -1,
   } },

   /* replace345_0_0 -> 760 in the cache */
   /* replace345_0_1 -> 1134 in the cache */
   /* replace345_0 -> 1138 in the cache */
   /* replace345 -> 1155 in the cache */

   /* ('flt', 'a', ('fneg', 'a')) => ('flt', 'a', 0.0) */
   /* search346_0 -> 32 in the cache */
   /* search346_1_0 -> 32 in the cache */
   /* search346_1 -> 98 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 32, 98 },
      -1,
   } },

   /* replace346_0 -> 32 in the cache */
   /* replace346_1 -> 111 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 32, 111 },
      -1,
   } },

   /* ('fge', 'a', ('fneg', 'a')) => ('fge', 'a', 0.0) */
   /* search347_0 -> 32 in the cache */
   /* search347_1_0 -> 32 in the cache */
   /* search347_1 -> 98 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 32, 98 },
      -1,
   } },

   /* replace347_0 -> 32 in the cache */
   /* replace347_1 -> 111 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 32, 111 },
      -1,
   } },

   /* ('flt', ('fmin', 'c', ('fneg', ('fadd', ('b2f', 'a@1'), ('b2f', 'b@1')))), 0.0) => ('ior', ('flt', 'c', 0.0), ('ior', 'a', 'b')) */
   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 1 },
      1, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 1176 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, 1 },
      2, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 1178 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 1177, 1179 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 1180 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 2,
      { 1175, 1181 },
      -1,
   } },
   /* search348_1 -> 111 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 2,
      { 1182, 111 },
      -1,
   } },

   /* replace348_0_0 -> 1175 in the cache */
   /* replace348_0_1 -> 111 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1175, 111 },
      -1,
   } },
   /* replace348_1_0 -> 1176 in the cache */
   /* replace348_1_1 -> 1178 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 1176, 1178 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 1184, 1185 },
      -1,
   } },

   /* ('~flt', ('fadd', 'a', 'b'), 'a') => ('flt', 'b', 0.0) */
   /* search349_0_0 -> 0 in the cache */
   /* search349_0_1 -> 3 in the cache */
   /* search349_0 -> 272 in the cache */
   /* search349_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 272, 0 },
      -1,
   } },

   /* replace349_0 -> 3 in the cache */
   /* replace349_1 -> 256 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 3, 256 },
      -1,
   } },

   /* ('~fge', ('fadd', 'a', 'b'), 'a') => ('fge', 'b', 0.0) */
   /* search350_0_0 -> 0 in the cache */
   /* search350_0_1 -> 3 in the cache */
   /* search350_0 -> 272 in the cache */
   /* search350_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 272, 0 },
      -1,
   } },

   /* replace350_0 -> 3 in the cache */
   /* replace350_1 -> 256 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 3, 256 },
      -1,
   } },

   /* ('~feq', ('fadd', 'a', 'b'), 'a') => ('feq', 'b', 0.0) */
   /* search351_0_0 -> 0 in the cache */
   /* search351_0_1 -> 3 in the cache */
   /* search351_0 -> 213 in the cache */
   /* search351_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_feq,
      0, 2,
      { 213, 0 },
      -1,
   } },

   /* replace351_0 -> 3 in the cache */
   /* replace351_1 -> 256 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 3, 256 },
      -1,
   } },

   /* ('~fneu', ('fadd', 'a', 'b'), 'a') => ('fneu', 'b', 0.0) */
   /* search352_0_0 -> 0 in the cache */
   /* search352_0_1 -> 3 in the cache */
   /* search352_0 -> 213 in the cache */
   /* search352_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_fneu,
      0, 2,
      { 213, 0 },
      -1,
   } },

   /* replace352_0 -> 3 in the cache */
   /* replace352_1 -> 256 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 3, 256 },
      -1,
   } },

   /* ('~flt', ('fadd(is_used_once)', 'a', '#b'), '#c') => ('flt', 'a', ('fadd', 'c', ('fneg', 'b'))) */
   /* search353_0_0 -> 126 in the cache */
   /* search353_0_1 -> 283 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 126, 283 },
      0,
   } },
   /* search353_1 -> 814 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 1195, 814 },
      -1,
   } },

   /* replace353_0 -> 126 in the cache */
   /* replace353_1_0 -> 129 in the cache */
   /* replace353_1_1_0 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 129, 1197 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 126, 1198 },
      -1,
   } },

   /* ('~flt', ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', '#b')), '#c') => ('flt', ('fneg', ('fadd', 'c', 'b')), 'a') */
   /* search354_0_0_0 -> 126 in the cache */
   /* search354_0_0_1 -> 283 in the cache */
   /* search354_0_0 -> 1195 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 1195 },
      0,
   } },
   /* search354_1 -> 814 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 1200, 814 },
      -1,
   } },

   /* replace354_0_0_0 -> 129 in the cache */
   /* replace354_0_0_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 129, 127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 1202 },
      -1,
   } },
   /* replace354_1 -> 126 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 1203, 126 },
      -1,
   } },

   /* ('~fge', ('fadd(is_used_once)', 'a', '#b'), '#c') => ('fge', 'a', ('fadd', 'c', ('fneg', 'b'))) */
   /* search355_0_0 -> 126 in the cache */
   /* search355_0_1 -> 283 in the cache */
   /* search355_0 -> 1195 in the cache */
   /* search355_1 -> 814 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 1195, 814 },
      -1,
   } },

   /* replace355_0 -> 126 in the cache */
   /* replace355_1_0 -> 129 in the cache */
   /* replace355_1_1_0 -> 127 in the cache */
   /* replace355_1_1 -> 1197 in the cache */
   /* replace355_1 -> 1198 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 126, 1198 },
      -1,
   } },

   /* ('~fge', ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', '#b')), '#c') => ('fge', ('fneg', ('fadd', 'c', 'b')), 'a') */
   /* search356_0_0_0 -> 126 in the cache */
   /* search356_0_0_1 -> 283 in the cache */
   /* search356_0_0 -> 1195 in the cache */
   /* search356_0 -> 1200 in the cache */
   /* search356_1 -> 814 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 1200, 814 },
      -1,
   } },

   /* replace356_0_0_0 -> 129 in the cache */
   /* replace356_0_0_1 -> 127 in the cache */
   /* replace356_0_0 -> 1202 in the cache */
   /* replace356_0 -> 1203 in the cache */
   /* replace356_1 -> 126 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 1203, 126 },
      -1,
   } },

   /* ('~feq', ('fadd(is_used_once)', 'a', '#b'), '#c') => ('feq', 'a', ('fadd', 'c', ('fneg', 'b'))) */
   /* search357_0_0 -> 126 in the cache */
   /* search357_0_1 -> 283 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 126, 283 },
      0,
   } },
   /* search357_1 -> 814 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_feq,
      0, 2,
      { 1209, 814 },
      -1,
   } },

   /* replace357_0 -> 126 in the cache */
   /* replace357_1_0 -> 129 in the cache */
   /* replace357_1_1_0 -> 127 in the cache */
   /* replace357_1_1 -> 1197 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 129, 1197 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 2,
      { 126, 1211 },
      -1,
   } },

   /* ('~feq', ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', '#b')), '#c') => ('feq', ('fneg', ('fadd', 'c', 'b')), 'a') */
   /* search358_0_0_0 -> 126 in the cache */
   /* search358_0_0_1 -> 283 in the cache */
   /* search358_0_0 -> 1209 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 1209 },
      0,
   } },
   /* search358_1 -> 814 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_feq,
      0, 2,
      { 1213, 814 },
      -1,
   } },

   /* replace358_0_0_0 -> 129 in the cache */
   /* replace358_0_0_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 129, 127 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 1215 },
      -1,
   } },
   /* replace358_1 -> 126 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 2,
      { 1216, 126 },
      -1,
   } },

   /* ('~fneu', ('fadd(is_used_once)', 'a', '#b'), '#c') => ('fneu', 'a', ('fadd', 'c', ('fneg', 'b'))) */
   /* search359_0_0 -> 126 in the cache */
   /* search359_0_1 -> 283 in the cache */
   /* search359_0 -> 1209 in the cache */
   /* search359_1 -> 814 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_fneu,
      0, 2,
      { 1209, 814 },
      -1,
   } },

   /* replace359_0 -> 126 in the cache */
   /* replace359_1_0 -> 129 in the cache */
   /* replace359_1_1_0 -> 127 in the cache */
   /* replace359_1_1 -> 1197 in the cache */
   /* replace359_1 -> 1211 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 2,
      { 126, 1211 },
      -1,
   } },

   /* ('~fneu', ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', '#b')), '#c') => ('fneu', ('fneg', ('fadd', 'c', 'b')), 'a') */
   /* search360_0_0_0 -> 126 in the cache */
   /* search360_0_0_1 -> 283 in the cache */
   /* search360_0_0 -> 1209 in the cache */
   /* search360_0 -> 1213 in the cache */
   /* search360_1 -> 814 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_fneu,
      0, 2,
      { 1213, 814 },
      -1,
   } },

   /* replace360_0_0_0 -> 129 in the cache */
   /* replace360_0_0_1 -> 127 in the cache */
   /* replace360_0_0 -> 1215 in the cache */
   /* replace360_0 -> 1216 in the cache */
   /* replace360_1 -> 126 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 2,
      { 1216, 126 },
      -1,
   } },

   /* ('ieq', ('iadd', 'a', 'b'), 'a') => ('ieq', 'b', 0) */
   /* search361_0_0 -> 0 in the cache */
   /* search361_0_1 -> 3 in the cache */
   /* search361_0 -> 208 in the cache */
   /* search361_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 208, 0 },
      -1,
   } },

   /* replace361_0 -> 3 in the cache */
   /* replace361_1 -> 86 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 3, 86 },
      -1,
   } },

   /* ('ine', ('iadd', 'a', 'b'), 'a') => ('ine', 'b', 0) */
   /* search362_0_0 -> 0 in the cache */
   /* search362_0_1 -> 3 in the cache */
   /* search362_0 -> 208 in the cache */
   /* search362_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 208, 0 },
      -1,
   } },

   /* replace362_0 -> 3 in the cache */
   /* replace362_1 -> 86 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 3, 86 },
      -1,
   } },

   /* ('feq', ('b2f', 'a@1'), 0.0) => ('inot', 'a') */
   /* search363_0_0 -> 760 in the cache */
   /* search363_0 -> 1129 in the cache */
   /* search363_1 -> 1128 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 1129, 1128 },
      -1,
   } },

   /* replace363_0 -> 760 in the cache */
   /* replace363 -> 1131 in the cache */

   /* ('fneu', ('b2f', 'a@1'), 0.0) => a */
   /* search364_0_0 -> 760 in the cache */
   /* search364_0 -> 1129 in the cache */
   /* search364_1 -> 1128 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 1129, 1128 },
      -1,
   } },

   /* replace364 -> 760 in the cache */

   /* ('ieq', ('b2i', 'a@1'), 0) => ('inot', 'a') */
   /* search365_0_0 -> 760 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2i,
      -1, 0,
      { 760 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 0 },
      nir_type_int, { 0x0 /* 0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1228, 1229 },
      -1,
   } },

   /* replace365_0 -> 760 in the cache */
   /* replace365 -> 1131 in the cache */

   /* ('ine', ('b2i', 'a@1'), 0) => a */
   /* search366_0_0 -> 760 in the cache */
   /* search366_0 -> 1228 in the cache */
   /* search366_1 -> 1229 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1228, 1229 },
      -1,
   } },

   /* replace366 -> 760 in the cache */

   /* ('fneu', ('u2f', 'a'), 0.0) => ('ine', 'a', 0) */
   /* search367_0_0 -> 32 in the cache */
   /* search367_0 -> 104 in the cache */
   /* search367_1 -> 1128 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 104, 1128 },
      -1,
   } },

   /* replace367_0 -> 32 in the cache */
   /* replace367_1 -> 61 in the cache */
   /* replace367 -> 1110 in the cache */

   /* ('feq', ('u2f', 'a'), 0.0) => ('ieq', 'a', 0) */
   /* search368_0_0 -> 32 in the cache */
   /* search368_0 -> 104 in the cache */
   /* search368_1 -> 1128 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 104, 1128 },
      -1,
   } },

   /* replace368_0 -> 32 in the cache */
   /* replace368_1 -> 61 in the cache */
   /* replace368 -> 1108 in the cache */

   /* ('fge', ('u2f', 'a'), 0.0) => True */
   /* search369_0_0 -> 32 in the cache */
   /* search369_0 -> 104 in the cache */
   /* search369_1 -> 1128 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 104, 1128 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, 1 },
      nir_type_bool, { NIR_TRUE /* True */ },
   } },

   /* ('fge', 0.0, ('u2f', 'a')) => ('uge', 0, 'a') */
   /* search370_0 -> 1128 in the cache */
   /* search370_1_0 -> 32 in the cache */
   /* search370_1 -> 104 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1128, 104 },
      -1,
   } },

   /* replace370_0 -> 61 in the cache */
   /* replace370_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 61, 32 },
      -1,
   } },

   /* ('flt', ('u2f', 'a'), 0.0) => False */
   /* search371_0_0 -> 32 in the cache */
   /* search371_0 -> 104 in the cache */
   /* search371_1 -> 1128 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 104, 1128 },
      -1,
   } },

   /* replace371 -> 1077 in the cache */

   /* ('flt', 0.0, ('u2f', 'a')) => ('ult', 0, 'a') */
   /* search372_0 -> 1128 in the cache */
   /* search372_1_0 -> 32 in the cache */
   /* search372_1 -> 104 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1128, 104 },
      -1,
   } },

   /* replace372_0 -> 61 in the cache */
   /* replace372_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 61, 32 },
      -1,
   } },

   /* ('fneu', ('i2f', 'a'), 0.0) => ('ine', 'a', 0) */
   /* search373_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_i2f,
      -1, 0,
      { 32 },
      -1,
   } },
   /* search373_1 -> 1128 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 1241, 1128 },
      -1,
   } },

   /* replace373_0 -> 32 in the cache */
   /* replace373_1 -> 61 in the cache */
   /* replace373 -> 1110 in the cache */

   /* ('feq', ('i2f', 'a'), 0.0) => ('ieq', 'a', 0) */
   /* search374_0_0 -> 32 in the cache */
   /* search374_0 -> 1241 in the cache */
   /* search374_1 -> 1128 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 1241, 1128 },
      -1,
   } },

   /* replace374_0 -> 32 in the cache */
   /* replace374_1 -> 61 in the cache */
   /* replace374 -> 1108 in the cache */

   /* ('fge', ('i2f', 'a'), 0.0) => ('ige', 'a', 0) */
   /* search375_0_0 -> 32 in the cache */
   /* search375_0 -> 1241 in the cache */
   /* search375_1 -> 1128 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1241, 1128 },
      -1,
   } },

   /* replace375_0 -> 32 in the cache */
   /* replace375_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 32, 61 },
      -1,
   } },

   /* ('fge', 0.0, ('i2f', 'a')) => ('ige', 0, 'a') */
   /* search376_0 -> 1128 in the cache */
   /* search376_1_0 -> 32 in the cache */
   /* search376_1 -> 1241 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1128, 1241 },
      -1,
   } },

   /* replace376_0 -> 61 in the cache */
   /* replace376_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 61, 32 },
      -1,
   } },

   /* ('flt', ('i2f', 'a'), 0.0) => ('ilt', 'a', 0) */
   /* search377_0_0 -> 32 in the cache */
   /* search377_0 -> 1241 in the cache */
   /* search377_1 -> 1128 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1241, 1128 },
      -1,
   } },

   /* replace377_0 -> 32 in the cache */
   /* replace377_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 32, 61 },
      -1,
   } },

   /* ('flt', 0.0, ('i2f', 'a')) => ('ilt', 0, 'a') */
   /* search378_0 -> 1128 in the cache */
   /* search378_1_0 -> 32 in the cache */
   /* search378_1 -> 1241 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1128, 1241 },
      -1,
   } },

   /* replace378_0 -> 61 in the cache */
   /* replace378_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 61, 32 },
      -1,
   } },

   /* ('~flt', 0.0, ('fabs', 'a')) => ('fneu', 'a', 0.0) */
   /* search379_0 -> 111 in the cache */
   /* search379_1_0 -> 32 in the cache */
   /* search379_1 -> 103 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 111, 103 },
      -1,
   } },

   /* replace379_0 -> 32 in the cache */
   /* replace379_1 -> 111 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 32, 111 },
      -1,
   } },

   /* ('~flt', ('fneg', ('fabs', 'a')), 0.0) => ('fneu', 'a', 0.0) */
   /* search380_0_0_0 -> 32 in the cache */
   /* search380_0_0 -> 103 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 103 },
      -1,
   } },
   /* search380_1 -> 111 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1254, 111 },
      -1,
   } },

   /* replace380_0 -> 32 in the cache */
   /* replace380_1 -> 111 in the cache */
   /* replace380 -> 1253 in the cache */

   /* ('fge', 0.0, ('fabs', 'a')) => ('feq', 'a', 0.0) */
   /* search381_0 -> 111 in the cache */
   /* search381_1_0 -> 32 in the cache */
   /* search381_1 -> 103 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 111, 103 },
      -1,
   } },

   /* replace381_0 -> 32 in the cache */
   /* replace381_1 -> 111 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 32, 111 },
      -1,
   } },

   /* ('fge', ('fneg', ('fabs', 'a')), 0.0) => ('feq', 'a', 0.0) */
   /* search382_0_0_0 -> 32 in the cache */
   /* search382_0_0 -> 103 in the cache */
   /* search382_0 -> 1254 in the cache */
   /* search382_1 -> 111 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1254, 111 },
      -1,
   } },

   /* replace382_0 -> 32 in the cache */
   /* replace382_1 -> 111 in the cache */
   /* replace382 -> 1257 in the cache */

   /* ('iand', ('fge', 'a', 0.0), ('fge', 1.0, 'a')) => ('feq', 'a', ('fsat', 'a')) */
   /* search383_0_0 -> 32 in the cache */
   /* search383_0_1 -> 111 in the cache */
   /* search383_0 -> 1174 in the cache */
   /* search383_1_0 -> 241 in the cache */
   /* search383_1_1 -> 32 in the cache */
   /* search383_1 -> 1100 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1174, 1100 },
      -1,
   } },

   /* replace383_0 -> 32 in the cache */
   /* replace383_1_0 -> 32 in the cache */
   /* replace383_1 -> 217 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 32, 217 },
      -1,
   } },

   /* ('fmax', ('b2f(is_used_once)', 'a@1'), ('b2f', 'b@1')) => ('b2f', ('ior', 'a', 'b')) */
   /* search384_0_0 -> 760 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 760 },
      0,
   } },
   /* search384_1_0 -> 1134 in the cache */
   /* search384_1 -> 1135 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 1261, 1135 },
      -1,
   } },

   /* replace384_0_0 -> 760 in the cache */
   /* replace384_0_1 -> 1134 in the cache */
   /* replace384_0 -> 1138 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 1,
      { 1138 },
      -1,
   } },

   /* ('fmax', ('fneg(is_used_once)', ('b2f(is_used_once)', 'a@1')), ('fneg', ('b2f', 'b@1'))) => ('fneg', ('b2f', ('iand', 'a', 'b'))) */
   /* search385_0_0_0 -> 760 in the cache */
   /* search385_0_0 -> 1261 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 1261 },
      0,
   } },
   /* search385_1_0_0 -> 1134 in the cache */
   /* search385_1_0 -> 1135 in the cache */
   /* search385_1 -> 1142 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 1264, 1142 },
      -1,
   } },

   /* replace385_0_0_0 -> 760 in the cache */
   /* replace385_0_0_1 -> 1134 in the cache */
   /* replace385_0_0 -> 1146 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 1,
      { 1146 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 1266 },
      -1,
   } },

   /* ('fmin', ('b2f(is_used_once)', 'a@1'), ('b2f', 'b@1')) => ('b2f', ('iand', 'a', 'b')) */
   /* search386_0_0 -> 760 in the cache */
   /* search386_0 -> 1261 in the cache */
   /* search386_1_0 -> 1134 in the cache */
   /* search386_1 -> 1135 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 1261, 1135 },
      -1,
   } },

   /* replace386_0_0 -> 760 in the cache */
   /* replace386_0_1 -> 1134 in the cache */
   /* replace386_0 -> 1146 in the cache */
   /* replace386 -> 1266 in the cache */

   /* ('fmin', ('fneg(is_used_once)', ('b2f(is_used_once)', 'a@1')), ('fneg', ('b2f', 'b@1'))) => ('fneg', ('b2f', ('ior', 'a', 'b'))) */
   /* search387_0_0_0 -> 760 in the cache */
   /* search387_0_0 -> 1261 in the cache */
   /* search387_0 -> 1264 in the cache */
   /* search387_1_0_0 -> 1134 in the cache */
   /* search387_1_0 -> 1135 in the cache */
   /* search387_1 -> 1142 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 1264, 1142 },
      -1,
   } },

   /* replace387_0_0_0 -> 760 in the cache */
   /* replace387_0_0_1 -> 1134 in the cache */
   /* replace387_0_0 -> 1138 in the cache */
   /* replace387_0 -> 1263 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 1263 },
      -1,
   } },

   /* ('fmin', ('b2f', 'a@1'), '#b') => ('bcsel', 'a', ('fmin', 'b', 1.0), ('fmin', 'b', 0.0)) */
   /* search388_0_0 -> 760 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 760 },
      -1,
   } },
   /* search388_1 -> 821 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 1271, 821 },
      -1,
   } },

   /* replace388_0 -> 760 in the cache */
   /* replace388_1_0 -> 3 in the cache */
   /* replace388_1_1 -> 270 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 3, 270 },
      -1,
   } },
   /* replace388_2_0 -> 3 in the cache */
   /* replace388_2_1 -> 256 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmin,
      1, 1,
      { 3, 256 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 760, 1273, 1274 },
      -1,
   } },

   /* ('flt', ('fadd(is_used_once)', 'a', ('fneg', 'b')), 0.0) => ('flt', 'a', 'b') */
   /* search389_0_0 -> 0 in the cache */
   /* search389_0_1_0 -> 3 in the cache */
   /* search389_0_1 -> 1087 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 0, 1087 },
      0,
   } },
   /* search389_1 -> 256 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 1276, 256 },
      -1,
   } },

   /* replace389_0 -> 0 in the cache */
   /* replace389_1 -> 3 in the cache */
   /* replace389 -> 1049 in the cache */

   /* ('fge', ('fneg', ('fabs', 'a')), 0.0) => ('feq', 'a', 0.0) */
   /* search390_0_0_0 -> 32 in the cache */
   /* search390_0_0 -> 103 in the cache */
   /* search390_0 -> 1254 in the cache */
   /* search390_1 -> 111 in the cache */
   /* search390 -> 1258 in the cache */

   /* replace390_0 -> 32 in the cache */
   /* replace390_1 -> 111 in the cache */
   /* replace390 -> 1257 in the cache */

   /* ('~bcsel', ('flt', 'b', 'a'), 'b', 'a') => ('fmin', 'a', 'b') */
   /* search391_0_0 -> 1117 in the cache */
   /* search391_0_1 -> 1114 in the cache */
   /* search391_0 -> 1118 in the cache */
   /* search391_1 -> 1117 in the cache */
   /* search391_2 -> 1114 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1118, 1117, 1114 },
      -1,
   } },

   /* replace391_0 -> 1114 in the cache */
   /* replace391_1 -> 1117 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 1114, 1117 },
      -1,
   } },

   /* ('~bcsel', ('flt', 'a', 'b'), 'b', 'a') => ('fmax', 'a', 'b') */
   /* search392_0_0 -> 0 in the cache */
   /* search392_0_1 -> 3 in the cache */
   /* search392_0 -> 1049 in the cache */
   /* search392_1 -> 3 in the cache */
   /* search392_2 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1049, 3, 0 },
      -1,
   } },

   /* replace392_0 -> 0 in the cache */
   /* replace392_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* ('~bcsel', ('fge', 'a', 'b'), 'b', 'a') => ('fmin', 'a', 'b') */
   /* search393_0_0 -> 0 in the cache */
   /* search393_0_1 -> 3 in the cache */
   /* search393_0 -> 1046 in the cache */
   /* search393_1 -> 3 in the cache */
   /* search393_2 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1046, 3, 0 },
      -1,
   } },

   /* replace393_0 -> 0 in the cache */
   /* replace393_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* ('~bcsel', ('fge', 'b', 'a'), 'b', 'a') => ('fmax', 'a', 'b') */
   /* search394_0_0 -> 1117 in the cache */
   /* search394_0_1 -> 1114 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1117, 1114 },
      -1,
   } },
   /* search394_1 -> 1117 in the cache */
   /* search394_2 -> 1114 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1284, 1117, 1114 },
      -1,
   } },

   /* replace394_0 -> 1114 in the cache */
   /* replace394_1 -> 1117 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 1114, 1117 },
      -1,
   } },

   /* ('bcsel', ('ult', 'b', 'a'), 'b', 'a') => ('umin', 'a', 'b') */
   /* search395_0_0 -> 1117 in the cache */
   /* search395_0_1 -> 1114 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 1117, 1114 },
      -1,
   } },
   /* search395_1 -> 1117 in the cache */
   /* search395_2 -> 1114 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1287, 1117, 1114 },
      -1,
   } },

   /* replace395_0 -> 1114 in the cache */
   /* replace395_1 -> 1117 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_umin,
      0, 1,
      { 1114, 1117 },
      -1,
   } },

   /* ('bcsel', ('ult', 'a', 'b'), 'b', 'a') => ('umax', 'a', 'b') */
   /* search396_0_0 -> 0 in the cache */
   /* search396_0_1 -> 3 in the cache */
   /* search396_0 -> 1067 in the cache */
   /* search396_1 -> 3 in the cache */
   /* search396_2 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1067, 3, 0 },
      -1,
   } },

   /* replace396_0 -> 0 in the cache */
   /* replace396_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_umax,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* ('bcsel', ('uge', 'a', 'b'), 'b', 'a') => ('umin', 'a', 'b') */
   /* search397_0_0 -> 0 in the cache */
   /* search397_0_1 -> 3 in the cache */
   /* search397_0 -> 1061 in the cache */
   /* search397_1 -> 3 in the cache */
   /* search397_2 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1061, 3, 0 },
      -1,
   } },

   /* replace397_0 -> 0 in the cache */
   /* replace397_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_umin,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* ('bcsel', ('uge', 'b', 'a'), 'b', 'a') => ('umax', 'a', 'b') */
   /* search398_0_0 -> 1117 in the cache */
   /* search398_0_1 -> 1114 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 1117, 1114 },
      -1,
   } },
   /* search398_1 -> 1117 in the cache */
   /* search398_2 -> 1114 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1294, 1117, 1114 },
      -1,
   } },

   /* replace398_0 -> 1114 in the cache */
   /* replace398_1 -> 1117 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_umax,
      0, 1,
      { 1114, 1117 },
      -1,
   } },

   /* ('bcsel', ('ilt', 'b', 'a'), 'b', 'a') => ('imin', 'a', 'b') */
   /* search399_0_0 -> 1117 in the cache */
   /* search399_0_1 -> 1114 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 1117, 1114 },
      -1,
   } },
   /* search399_1 -> 1117 in the cache */
   /* search399_2 -> 1114 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1297, 1117, 1114 },
      -1,
   } },

   /* replace399_0 -> 1114 in the cache */
   /* replace399_1 -> 1117 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_imin,
      0, 1,
      { 1114, 1117 },
      -1,
   } },

   /* ('bcsel', ('ilt', 'a', 'b'), 'b', 'a') => ('imax', 'a', 'b') */
   /* search400_0_0 -> 0 in the cache */
   /* search400_0_1 -> 3 in the cache */
   /* search400_0 -> 1064 in the cache */
   /* search400_1 -> 3 in the cache */
   /* search400_2 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1064, 3, 0 },
      -1,
   } },

   /* replace400_0 -> 0 in the cache */
   /* replace400_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* ('bcsel', ('ige', 'a', 'b'), 'b', 'a') => ('imin', 'a', 'b') */
   /* search401_0_0 -> 0 in the cache */
   /* search401_0_1 -> 3 in the cache */
   /* search401_0 -> 1058 in the cache */
   /* search401_1 -> 3 in the cache */
   /* search401_2 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1058, 3, 0 },
      -1,
   } },

   /* replace401_0 -> 0 in the cache */
   /* replace401_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_imin,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* ('bcsel', ('ige', 'b', 'a'), 'b', 'a') => ('imax', 'a', 'b') */
   /* search402_0_0 -> 1117 in the cache */
   /* search402_0_1 -> 1114 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 1117, 1114 },
      -1,
   } },
   /* search402_1 -> 1117 in the cache */
   /* search402_2 -> 1114 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1304, 1117, 1114 },
      -1,
   } },

   /* replace402_0 -> 1114 in the cache */
   /* replace402_1 -> 1117 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 1114, 1117 },
      -1,
   } },

   /* ('bcsel', ('inot', 'a'), 'b', 'c') => ('bcsel', 'a', 'c', 'b') */
   /* search403_0_0 -> 760 in the cache */
   /* search403_0 -> 1131 in the cache */
   /* search403_1 -> 127 in the cache */
   /* search403_2 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1131, 127, 129 },
      -1,
   } },

   /* replace403_0 -> 760 in the cache */
   /* replace403_1 -> 129 in the cache */
   /* replace403_2 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 760, 129, 127 },
      -1,
   } },

   /* ('bcsel', 'a', ('bcsel', 'a', 'b', 'c'), 'd') => ('bcsel', 'a', 'b', 'd') */
   /* search404_0 -> 760 in the cache */
   /* search404_1_0 -> 760 in the cache */
   /* search404_1_1 -> 150 in the cache */
   /* search404_1_2 -> 152 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 760, 150, 152 },
      -1,
   } },
   /* search404_2 -> 153 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 760, 1309, 153 },
      -1,
   } },

   /* replace404_0 -> 760 in the cache */
   /* replace404_1 -> 150 in the cache */
   /* replace404_2 -> 153 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 760, 150, 153 },
      -1,
   } },

   /* ('bcsel', 'a', 'b', ('bcsel', 'a', 'c', 'd')) => ('bcsel', 'a', 'b', 'd') */
   /* search405_0 -> 760 in the cache */
   /* search405_1 -> 150 in the cache */
   /* search405_2_0 -> 760 in the cache */
   /* search405_2_1 -> 152 in the cache */
   /* search405_2_2 -> 153 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 760, 152, 153 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 760, 150, 1312 },
      -1,
   } },

   /* replace405_0 -> 760 in the cache */
   /* replace405_1 -> 150 in the cache */
   /* replace405_2 -> 153 in the cache */
   /* replace405 -> 1311 in the cache */

   /* ('bcsel', 'a', ('bcsel', 'b', 'c', 'd'), ('bcsel(is_used_once)', 'b', 'c', 'e')) => ('bcsel', 'b', 'c', ('bcsel', 'a', 'd', 'e')) */
   /* search406_0 -> 760 in the cache */
   /* search406_1_0 -> 1134 in the cache */
   /* search406_1_1 -> 753 in the cache */
   /* search406_1_2 -> 762 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1134, 753, 762 },
      -1,
   } },
   /* search406_2_0 -> 1134 in the cache */
   /* search406_2_1 -> 753 in the cache */
   /* search406_2_2 -> 764 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1134, 753, 764 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 760, 1314, 1315 },
      -1,
   } },

   /* replace406_0 -> 1134 in the cache */
   /* replace406_1 -> 753 in the cache */
   /* replace406_2_0 -> 760 in the cache */
   /* replace406_2_1 -> 762 in the cache */
   /* replace406_2_2 -> 764 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 760, 762, 764 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1134, 753, 1317 },
      -1,
   } },

   /* ('bcsel', 'a', ('bcsel(is_used_once)', 'b', 'c', 'd'), ('bcsel', 'b', 'c', 'e')) => ('bcsel', 'b', 'c', ('bcsel', 'a', 'd', 'e')) */
   /* search407_0 -> 760 in the cache */
   /* search407_1_0 -> 1134 in the cache */
   /* search407_1_1 -> 753 in the cache */
   /* search407_1_2 -> 762 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1134, 753, 762 },
      0,
   } },
   /* search407_2_0 -> 1134 in the cache */
   /* search407_2_1 -> 753 in the cache */
   /* search407_2_2 -> 764 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1134, 753, 764 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 760, 1319, 1320 },
      -1,
   } },

   /* replace407_0 -> 1134 in the cache */
   /* replace407_1 -> 753 in the cache */
   /* replace407_2_0 -> 760 in the cache */
   /* replace407_2_1 -> 762 in the cache */
   /* replace407_2_2 -> 764 in the cache */
   /* replace407_2 -> 1317 in the cache */
   /* replace407 -> 1318 in the cache */

   /* ('bcsel', 'a', ('bcsel', 'b', 'c', 'd'), ('bcsel(is_used_once)', 'b', 'e', 'd')) => ('bcsel', 'b', ('bcsel', 'a', 'c', 'e'), 'd') */
   /* search408_0 -> 760 in the cache */
   /* search408_1_0 -> 1134 in the cache */
   /* search408_1_1 -> 152 in the cache */
   /* search408_1_2 -> 153 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1134, 152, 153 },
      -1,
   } },
   /* search408_2_0 -> 1134 in the cache */
   { .variable = {
      { nir_search_value_variable, -4 },
      4, /* e */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search408_2_2 -> 153 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1134, 1323, 153 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 760, 1322, 1324 },
      -1,
   } },

   /* replace408_0 -> 1134 in the cache */
   /* replace408_1_0 -> 760 in the cache */
   /* replace408_1_1 -> 152 in the cache */
   /* replace408_1_2 -> 1323 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 760, 152, 1323 },
      -1,
   } },
   /* replace408_2 -> 153 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1134, 1326, 153 },
      -1,
   } },

   /* ('bcsel', 'a', ('bcsel(is_used_once)', 'b', 'c', 'd'), ('bcsel', 'b', 'e', 'd')) => ('bcsel', 'b', ('bcsel', 'a', 'c', 'e'), 'd') */
   /* search409_0 -> 760 in the cache */
   /* search409_1_0 -> 1134 in the cache */
   /* search409_1_1 -> 152 in the cache */
   /* search409_1_2 -> 153 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1134, 152, 153 },
      0,
   } },
   /* search409_2_0 -> 1134 in the cache */
   /* search409_2_1 -> 1323 in the cache */
   /* search409_2_2 -> 153 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1134, 1323, 153 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 760, 1328, 1329 },
      -1,
   } },

   /* replace409_0 -> 1134 in the cache */
   /* replace409_1_0 -> 760 in the cache */
   /* replace409_1_1 -> 152 in the cache */
   /* replace409_1_2 -> 1323 in the cache */
   /* replace409_1 -> 1326 in the cache */
   /* replace409_2 -> 153 in the cache */
   /* replace409 -> 1327 in the cache */

   /* ('bcsel', 'a', True, 'b') => ('ior', 'a', 'b') */
   /* search410_0 -> 760 in the cache */
   /* search410_1 -> 1235 in the cache */
   /* search410_2 -> 1134 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 760, 1235, 1134 },
      -1,
   } },

   /* replace410_0 -> 760 in the cache */
   /* replace410_1 -> 1134 in the cache */
   /* replace410 -> 1138 in the cache */

   /* ('bcsel', 'a', 'a', 'b') => ('ior', 'a', 'b') */
   /* search411_0 -> 760 in the cache */
   /* search411_1 -> 760 in the cache */
   /* search411_2 -> 1134 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 760, 760, 1134 },
      -1,
   } },

   /* replace411_0 -> 760 in the cache */
   /* replace411_1 -> 1134 in the cache */
   /* replace411 -> 1138 in the cache */

   /* ('bcsel', 'a', 'b', False) => ('iand', 'a', 'b') */
   /* search412_0 -> 760 in the cache */
   /* search412_1 -> 1134 in the cache */
   /* search412_2 -> 1077 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 760, 1134, 1077 },
      -1,
   } },

   /* replace412_0 -> 760 in the cache */
   /* replace412_1 -> 1134 in the cache */
   /* replace412 -> 1146 in the cache */

   /* ('bcsel', 'a', 'b', 'a') => ('iand', 'a', 'b') */
   /* search413_0 -> 760 in the cache */
   /* search413_1 -> 1134 in the cache */
   /* search413_2 -> 760 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 760, 1134, 760 },
      -1,
   } },

   /* replace413_0 -> 760 in the cache */
   /* replace413_1 -> 1134 in the cache */
   /* replace413 -> 1146 in the cache */

   /* ('~fmin', 'a', 'a') => a */
   /* search414_0 -> 32 in the cache */
   /* search414_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fmin,
      -1, 0,
      { 32, 32 },
      -1,
   } },

   /* replace414 -> 32 in the cache */

   /* ('~fmax', 'a', 'a') => a */
   /* search415_0 -> 32 in the cache */
   /* search415_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fmax,
      -1, 0,
      { 32, 32 },
      -1,
   } },

   /* replace415 -> 32 in the cache */

   /* ('imin', 'a', 'a') => a */
   /* search416_0 -> 32 in the cache */
   /* search416_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imin,
      -1, 0,
      { 32, 32 },
      -1,
   } },

   /* replace416 -> 32 in the cache */

   /* ('imax', 'a', 'a') => a */
   /* search417_0 -> 32 in the cache */
   /* search417_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imax,
      -1, 0,
      { 32, 32 },
      -1,
   } },

   /* replace417 -> 32 in the cache */

   /* ('umin', 'a', 'a') => a */
   /* search418_0 -> 32 in the cache */
   /* search418_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_umin,
      -1, 0,
      { 32, 32 },
      -1,
   } },

   /* replace418 -> 32 in the cache */

   /* ('umin', 'a', 0) => 0 */
   /* search419_0 -> 32 in the cache */
   /* search419_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_umin,
      0, 1,
      { 32, 61 },
      -1,
   } },

   /* replace419 -> 61 in the cache */

   /* ('umin', 'a', -1) => a */
   /* search420_0 -> 32 in the cache */
   /* search420_1 -> 63 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_umin,
      0, 1,
      { 32, 63 },
      -1,
   } },

   /* replace420 -> 32 in the cache */

   /* ('umax', 'a', 'a') => a */
   /* search421_0 -> 32 in the cache */
   /* search421_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_umax,
      -1, 0,
      { 32, 32 },
      -1,
   } },

   /* replace421 -> 32 in the cache */

   /* ('umax', 'a', 0) => a */
   /* search422_0 -> 32 in the cache */
   /* search422_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_umax,
      0, 1,
      { 32, 61 },
      -1,
   } },

   /* replace422 -> 32 in the cache */

   /* ('umax', 'a', -1) => -1 */
   /* search423_0 -> 32 in the cache */
   /* search423_1 -> 63 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_umax,
      0, 1,
      { 32, 63 },
      -1,
   } },

   /* replace423 -> 63 in the cache */

   /* ('fmax', ('fmax', 'a', 'b'), 'b') => ('fmax', 'a', 'b') */
   /* search424_0_0 -> 0 in the cache */
   /* search424_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmax,
      1, 1,
      { 0, 3 },
      -1,
   } },
   /* search424_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 2,
      { 1345, 3 },
      -1,
   } },

   /* replace424_0 -> 0 in the cache */
   /* replace424_1 -> 3 in the cache */
   /* replace424 -> 1281 in the cache */

   /* ('umax', ('umax', 'a', 'b'), 'b') => ('umax', 'a', 'b') */
   /* search425_0_0 -> 0 in the cache */
   /* search425_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_umax,
      1, 1,
      { 0, 3 },
      -1,
   } },
   /* search425_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_umax,
      0, 2,
      { 1347, 3 },
      -1,
   } },

   /* replace425_0 -> 0 in the cache */
   /* replace425_1 -> 3 in the cache */
   /* replace425 -> 1291 in the cache */

   /* ('imax', ('imax', 'a', 'b'), 'b') => ('imax', 'a', 'b') */
   /* search426_0_0 -> 0 in the cache */
   /* search426_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_imax,
      1, 1,
      { 0, 3 },
      -1,
   } },
   /* search426_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_imax,
      0, 2,
      { 1349, 3 },
      -1,
   } },

   /* replace426_0 -> 0 in the cache */
   /* replace426_1 -> 3 in the cache */
   /* replace426 -> 1301 in the cache */

   /* ('fmin', ('fmin', 'a', 'b'), 'b') => ('fmin', 'a', 'b') */
   /* search427_0_0 -> 0 in the cache */
   /* search427_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmin,
      1, 1,
      { 0, 3 },
      -1,
   } },
   /* search427_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 2,
      { 1351, 3 },
      -1,
   } },

   /* replace427_0 -> 0 in the cache */
   /* replace427_1 -> 3 in the cache */
   /* replace427 -> 1283 in the cache */

   /* ('umin', ('umin', 'a', 'b'), 'b') => ('umin', 'a', 'b') */
   /* search428_0_0 -> 0 in the cache */
   /* search428_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_umin,
      1, 1,
      { 0, 3 },
      -1,
   } },
   /* search428_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_umin,
      0, 2,
      { 1353, 3 },
      -1,
   } },

   /* replace428_0 -> 0 in the cache */
   /* replace428_1 -> 3 in the cache */
   /* replace428 -> 1293 in the cache */

   /* ('imin', ('imin', 'a', 'b'), 'b') => ('imin', 'a', 'b') */
   /* search429_0_0 -> 0 in the cache */
   /* search429_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_imin,
      1, 1,
      { 0, 3 },
      -1,
   } },
   /* search429_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_imin,
      0, 2,
      { 1355, 3 },
      -1,
   } },

   /* replace429_0 -> 0 in the cache */
   /* replace429_1 -> 3 in the cache */
   /* replace429 -> 1303 in the cache */

   /* ('fmax', ('fmax', ('fmax', 'a', 'b'), 'c'), 'a') => ('fmax', ('fmax', 'a', 'b'), 'c') */
   /* search430_0_0_0 -> 126 in the cache */
   /* search430_0_0_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmax,
      2, 1,
      { 126, 127 },
      -1,
   } },
   /* search430_0_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmax,
      1, 2,
      { 1357, 129 },
      -1,
   } },
   /* search430_1 -> 126 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 3,
      { 1358, 126 },
      -1,
   } },

   /* replace430_0_0 -> 126 in the cache */
   /* replace430_0_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmax,
      1, 1,
      { 126, 127 },
      -1,
   } },
   /* replace430_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 2,
      { 1360, 129 },
      -1,
   } },

   /* ('umax', ('umax', ('umax', 'a', 'b'), 'c'), 'a') => ('umax', ('umax', 'a', 'b'), 'c') */
   /* search431_0_0_0 -> 126 in the cache */
   /* search431_0_0_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_umax,
      2, 1,
      { 126, 127 },
      -1,
   } },
   /* search431_0_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_umax,
      1, 2,
      { 1362, 129 },
      -1,
   } },
   /* search431_1 -> 126 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_umax,
      0, 3,
      { 1363, 126 },
      -1,
   } },

   /* replace431_0_0 -> 126 in the cache */
   /* replace431_0_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_umax,
      1, 1,
      { 126, 127 },
      -1,
   } },
   /* replace431_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_umax,
      0, 2,
      { 1365, 129 },
      -1,
   } },

   /* ('imax', ('imax', ('imax', 'a', 'b'), 'c'), 'a') => ('imax', ('imax', 'a', 'b'), 'c') */
   /* search432_0_0_0 -> 126 in the cache */
   /* search432_0_0_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imax,
      2, 1,
      { 126, 127 },
      -1,
   } },
   /* search432_0_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imax,
      1, 2,
      { 1367, 129 },
      -1,
   } },
   /* search432_1 -> 126 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imax,
      0, 3,
      { 1368, 126 },
      -1,
   } },

   /* replace432_0_0 -> 126 in the cache */
   /* replace432_0_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imax,
      1, 1,
      { 126, 127 },
      -1,
   } },
   /* replace432_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imax,
      0, 2,
      { 1370, 129 },
      -1,
   } },

   /* ('fmin', ('fmin', ('fmin', 'a', 'b'), 'c'), 'a') => ('fmin', ('fmin', 'a', 'b'), 'c') */
   /* search433_0_0_0 -> 126 in the cache */
   /* search433_0_0_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmin,
      2, 1,
      { 126, 127 },
      -1,
   } },
   /* search433_0_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmin,
      1, 2,
      { 1372, 129 },
      -1,
   } },
   /* search433_1 -> 126 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 3,
      { 1373, 126 },
      -1,
   } },

   /* replace433_0_0 -> 126 in the cache */
   /* replace433_0_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmin,
      1, 1,
      { 126, 127 },
      -1,
   } },
   /* replace433_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 2,
      { 1375, 129 },
      -1,
   } },

   /* ('umin', ('umin', ('umin', 'a', 'b'), 'c'), 'a') => ('umin', ('umin', 'a', 'b'), 'c') */
   /* search434_0_0_0 -> 126 in the cache */
   /* search434_0_0_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_umin,
      2, 1,
      { 126, 127 },
      -1,
   } },
   /* search434_0_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_umin,
      1, 2,
      { 1377, 129 },
      -1,
   } },
   /* search434_1 -> 126 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_umin,
      0, 3,
      { 1378, 126 },
      -1,
   } },

   /* replace434_0_0 -> 126 in the cache */
   /* replace434_0_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_umin,
      1, 1,
      { 126, 127 },
      -1,
   } },
   /* replace434_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_umin,
      0, 2,
      { 1380, 129 },
      -1,
   } },

   /* ('imin', ('imin', ('imin', 'a', 'b'), 'c'), 'a') => ('imin', ('imin', 'a', 'b'), 'c') */
   /* search435_0_0_0 -> 126 in the cache */
   /* search435_0_0_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imin,
      2, 1,
      { 126, 127 },
      -1,
   } },
   /* search435_0_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imin,
      1, 2,
      { 1382, 129 },
      -1,
   } },
   /* search435_1 -> 126 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imin,
      0, 3,
      { 1383, 126 },
      -1,
   } },

   /* replace435_0_0 -> 126 in the cache */
   /* replace435_0_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imin,
      1, 1,
      { 126, 127 },
      -1,
   } },
   /* replace435_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imin,
      0, 2,
      { 1385, 129 },
      -1,
   } },

   /* ('ieq', ('b2i8', 'a@1'), ('b2i8', 'b@1')) => ('ieq', 'a', 'b') */
   /* search436_0_0 -> 760 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_b2i8,
      -1, 0,
      { 760 },
      -1,
   } },
   /* search436_1_0 -> 1134 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_b2i8,
      -1, 0,
      { 1134 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1387, 1388 },
      -1,
   } },

   /* replace436_0 -> 760 in the cache */
   /* replace436_1 -> 1134 in the cache */
   /* replace436 -> 1162 in the cache */

   /* ('ine', ('b2i8', 'a@1'), ('b2i8', 'b@1')) => ('ine', 'a', 'b') */
   /* search437_0_0 -> 760 in the cache */
   /* search437_0 -> 1387 in the cache */
   /* search437_1_0 -> 1134 in the cache */
   /* search437_1 -> 1388 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1387, 1388 },
      -1,
   } },

   /* replace437_0 -> 760 in the cache */
   /* replace437_1 -> 1134 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 760, 1134 },
      -1,
   } },

   /* ('ieq', ('b2i16', 'a@1'), ('b2i16', 'b@1')) => ('ieq', 'a', 'b') */
   /* search438_0_0 -> 760 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_b2i16,
      -1, 0,
      { 760 },
      -1,
   } },
   /* search438_1_0 -> 1134 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_b2i16,
      -1, 0,
      { 1134 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1392, 1393 },
      -1,
   } },

   /* replace438_0 -> 760 in the cache */
   /* replace438_1 -> 1134 in the cache */
   /* replace438 -> 1162 in the cache */

   /* ('ine', ('b2i16', 'a@1'), ('b2i16', 'b@1')) => ('ine', 'a', 'b') */
   /* search439_0_0 -> 760 in the cache */
   /* search439_0 -> 1392 in the cache */
   /* search439_1_0 -> 1134 in the cache */
   /* search439_1 -> 1393 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1392, 1393 },
      -1,
   } },

   /* replace439_0 -> 760 in the cache */
   /* replace439_1 -> 1134 in the cache */
   /* replace439 -> 1391 in the cache */

   /* ('ieq', ('b2i32', 'a@1'), ('b2i32', 'b@1')) => ('ieq', 'a', 'b') */
   /* search440_0_0 -> 760 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_b2i32,
      -1, 0,
      { 760 },
      -1,
   } },
   /* search440_1_0 -> 1134 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_b2i32,
      -1, 0,
      { 1134 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1396, 1397 },
      -1,
   } },

   /* replace440_0 -> 760 in the cache */
   /* replace440_1 -> 1134 in the cache */
   /* replace440 -> 1162 in the cache */

   /* ('ine', ('b2i32', 'a@1'), ('b2i32', 'b@1')) => ('ine', 'a', 'b') */
   /* search441_0_0 -> 760 in the cache */
   /* search441_0 -> 1396 in the cache */
   /* search441_1_0 -> 1134 in the cache */
   /* search441_1 -> 1397 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1396, 1397 },
      -1,
   } },

   /* replace441_0 -> 760 in the cache */
   /* replace441_1 -> 1134 in the cache */
   /* replace441 -> 1391 in the cache */

   /* ('ieq', ('b2i64', 'a@1'), ('b2i64', 'b@1')) => ('ieq', 'a', 'b') */
   /* search442_0_0 -> 760 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_b2i64,
      -1, 0,
      { 760 },
      -1,
   } },
   /* search442_1_0 -> 1134 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_b2i64,
      -1, 0,
      { 1134 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1400, 1401 },
      -1,
   } },

   /* replace442_0 -> 760 in the cache */
   /* replace442_1 -> 1134 in the cache */
   /* replace442 -> 1162 in the cache */

   /* ('ine', ('b2i64', 'a@1'), ('b2i64', 'b@1')) => ('ine', 'a', 'b') */
   /* search443_0_0 -> 760 in the cache */
   /* search443_0 -> 1400 in the cache */
   /* search443_1_0 -> 1134 in the cache */
   /* search443_1 -> 1401 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1400, 1401 },
      -1,
   } },

   /* replace443_0 -> 760 in the cache */
   /* replace443_1 -> 1134 in the cache */
   /* replace443 -> 1391 in the cache */

   /* ('feq', ('b2f16', 'a@1'), ('b2f16', 'b@1')) => ('ieq', 'a', 'b') */
   /* search444_0_0 -> 760 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_b2f16,
      -1, 0,
      { 760 },
      -1,
   } },
   /* search444_1_0 -> 1134 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_b2f16,
      -1, 0,
      { 1134 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 1404, 1405 },
      -1,
   } },

   /* replace444_0 -> 760 in the cache */
   /* replace444_1 -> 1134 in the cache */
   /* replace444 -> 1162 in the cache */

   /* ('fneu', ('b2f16', 'a@1'), ('b2f16', 'b@1')) => ('ine', 'a', 'b') */
   /* search445_0_0 -> 760 in the cache */
   /* search445_0 -> 1404 in the cache */
   /* search445_1_0 -> 1134 in the cache */
   /* search445_1 -> 1405 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 1404, 1405 },
      -1,
   } },

   /* replace445_0 -> 760 in the cache */
   /* replace445_1 -> 1134 in the cache */
   /* replace445 -> 1391 in the cache */

   /* ('feq', ('b2f32', 'a@1'), ('b2f32', 'b@1')) => ('ieq', 'a', 'b') */
   /* search446_0_0 -> 760 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_b2f32,
      -1, 0,
      { 760 },
      -1,
   } },
   /* search446_1_0 -> 1134 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_b2f32,
      -1, 0,
      { 1134 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 1408, 1409 },
      -1,
   } },

   /* replace446_0 -> 760 in the cache */
   /* replace446_1 -> 1134 in the cache */
   /* replace446 -> 1162 in the cache */

   /* ('fneu', ('b2f32', 'a@1'), ('b2f32', 'b@1')) => ('ine', 'a', 'b') */
   /* search447_0_0 -> 760 in the cache */
   /* search447_0 -> 1408 in the cache */
   /* search447_1_0 -> 1134 in the cache */
   /* search447_1 -> 1409 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 1408, 1409 },
      -1,
   } },

   /* replace447_0 -> 760 in the cache */
   /* replace447_1 -> 1134 in the cache */
   /* replace447 -> 1391 in the cache */

   /* ('feq', ('b2f64', 'a@1'), ('b2f64', 'b@1')) => ('ieq', 'a', 'b') */
   /* search448_0_0 -> 760 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_b2f64,
      -1, 0,
      { 760 },
      -1,
   } },
   /* search448_1_0 -> 1134 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_b2f64,
      -1, 0,
      { 1134 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 1412, 1413 },
      -1,
   } },

   /* replace448_0 -> 760 in the cache */
   /* replace448_1 -> 1134 in the cache */
   /* replace448 -> 1162 in the cache */

   /* ('fneu', ('b2f64', 'a@1'), ('b2f64', 'b@1')) => ('ine', 'a', 'b') */
   /* search449_0_0 -> 760 in the cache */
   /* search449_0 -> 1412 in the cache */
   /* search449_1_0 -> 1134 in the cache */
   /* search449_1 -> 1413 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 1412, 1413 },
      -1,
   } },

   /* replace449_0 -> 760 in the cache */
   /* replace449_1 -> 1134 in the cache */
   /* replace449 -> 1391 in the cache */

   /* ('iand@8', 'a', ('inot', ('ishr', 'a', 7))) => ('imax', 'a', 0) */
   /* search450_0 -> 6 in the cache */
   /* search450_1_0_0 -> 6 in the cache */
   /* search450_1_0_1 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 6, 9 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 1416 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 6, 1417 },
      -1,
   } },

   /* replace450_0 -> 6 in the cache */
   /* replace450_1 -> 835 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 6, 835 },
      -1,
   } },

   /* ('ieq', ('iand', 'a@8', 128), 0) => ('ige', 'a', 0) */
   /* search451_0_0 -> 6 in the cache */
   /* search451_0_1 -> 7 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 6, 7 },
      -1,
   } },
   /* search451_1 -> 835 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 1420, 835 },
      -1,
   } },

   /* replace451_0 -> 6 in the cache */
   /* replace451_1 -> 835 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 6, 835 },
      -1,
   } },

   /* ('ine', ('iand', 'a@8', 128), 128) => ('ige', 'a', 0) */
   /* search452_0_0 -> 6 in the cache */
   /* search452_0_1 -> 7 in the cache */
   /* search452_0 -> 1420 in the cache */
   /* search452_1 -> 7 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 1420, 7 },
      -1,
   } },

   /* replace452_0 -> 6 in the cache */
   /* replace452_1 -> 835 in the cache */
   /* replace452 -> 1422 in the cache */

   /* ('ine', ('iand', 'a@8', 128), 0) => ('ilt', 'a', 0) */
   /* search453_0_0 -> 6 in the cache */
   /* search453_0_1 -> 7 in the cache */
   /* search453_0 -> 1420 in the cache */
   /* search453_1 -> 835 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 1420, 835 },
      -1,
   } },

   /* replace453_0 -> 6 in the cache */
   /* replace453_1 -> 835 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 6, 835 },
      -1,
   } },

   /* ('ieq', ('iand', 'a@8', 128), 128) => ('ilt', 'a', 0) */
   /* search454_0_0 -> 6 in the cache */
   /* search454_0_1 -> 7 in the cache */
   /* search454_0 -> 1420 in the cache */
   /* search454_1 -> 7 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 1420, 7 },
      -1,
   } },

   /* replace454_0 -> 6 in the cache */
   /* replace454_1 -> 835 in the cache */
   /* replace454 -> 1425 in the cache */

   /* ('ine', ('ushr', 'a@8', 7), 0) => ('ilt', 'a', 0) */
   /* search455_0_0 -> 6 in the cache */
   /* search455_0_1 -> 9 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 6, 9 },
      -1,
   } },
   /* search455_1 -> 835 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1427, 835 },
      -1,
   } },

   /* replace455_0 -> 6 in the cache */
   /* replace455_1 -> 835 in the cache */
   /* replace455 -> 1425 in the cache */

   /* ('ieq', ('ushr', 'a@8', 7), 0) => ('ige', 'a', 0) */
   /* search456_0_0 -> 6 in the cache */
   /* search456_0_1 -> 9 in the cache */
   /* search456_0 -> 1427 in the cache */
   /* search456_1 -> 835 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1427, 835 },
      -1,
   } },

   /* replace456_0 -> 6 in the cache */
   /* replace456_1 -> 835 in the cache */
   /* replace456 -> 1422 in the cache */

   /* ('ieq', ('ushr', 'a@8', 7), 1) => ('ilt', 'a', 0) */
   /* search457_0_0 -> 6 in the cache */
   /* search457_0_1 -> 9 in the cache */
   /* search457_0 -> 1427 in the cache */
   { .constant = {
      { nir_search_value_constant, 8 },
      nir_type_int, { 0x1 /* 1 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1427, 1430 },
      -1,
   } },

   /* replace457_0 -> 6 in the cache */
   /* replace457_1 -> 835 in the cache */
   /* replace457 -> 1425 in the cache */

   /* ('ine', ('ushr', 'a@8', 7), 1) => ('ige', 'a', 0) */
   /* search458_0_0 -> 6 in the cache */
   /* search458_0_1 -> 9 in the cache */
   /* search458_0 -> 1427 in the cache */
   /* search458_1 -> 1430 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1427, 1430 },
      -1,
   } },

   /* replace458_0 -> 6 in the cache */
   /* replace458_1 -> 835 in the cache */
   /* replace458 -> 1422 in the cache */

   /* ('ine', ('ishr', 'a@8', 7), 0) => ('ilt', 'a', 0) */
   /* search459_0_0 -> 6 in the cache */
   /* search459_0_1 -> 9 in the cache */
   /* search459_0 -> 1416 in the cache */
   /* search459_1 -> 835 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1416, 835 },
      -1,
   } },

   /* replace459_0 -> 6 in the cache */
   /* replace459_1 -> 835 in the cache */
   /* replace459 -> 1425 in the cache */

   /* ('ieq', ('ishr', 'a@8', 7), 0) => ('ige', 'a', 0) */
   /* search460_0_0 -> 6 in the cache */
   /* search460_0_1 -> 9 in the cache */
   /* search460_0 -> 1416 in the cache */
   /* search460_1 -> 835 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1416, 835 },
      -1,
   } },

   /* replace460_0 -> 6 in the cache */
   /* replace460_1 -> 835 in the cache */
   /* replace460 -> 1422 in the cache */

   /* ('ieq', ('ishr', 'a@8', 7), -1) => ('ilt', 'a', 0) */
   /* search461_0_0 -> 6 in the cache */
   /* search461_0_1 -> 9 in the cache */
   /* search461_0 -> 1416 in the cache */
   { .constant = {
      { nir_search_value_constant, 8 },
      nir_type_int, { -0x1 /* -1 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1416, 1435 },
      -1,
   } },

   /* replace461_0 -> 6 in the cache */
   /* replace461_1 -> 835 in the cache */
   /* replace461 -> 1425 in the cache */

   /* ('ine', ('ishr', 'a@8', 7), -1) => ('ige', 'a', 0) */
   /* search462_0_0 -> 6 in the cache */
   /* search462_0_1 -> 9 in the cache */
   /* search462_0 -> 1416 in the cache */
   /* search462_1 -> 1435 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1416, 1435 },
      -1,
   } },

   /* replace462_0 -> 6 in the cache */
   /* replace462_1 -> 835 in the cache */
   /* replace462 -> 1422 in the cache */

   /* ('iand@16', 'a', ('inot', ('ishr', 'a', 15))) => ('imax', 'a', 0) */
   /* search463_0 -> 11 in the cache */
   /* search463_1_0_0 -> 11 in the cache */
   /* search463_1_0_1 -> 14 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 11, 14 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 1438 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 11, 1439 },
      -1,
   } },

   /* replace463_0 -> 11 in the cache */
   /* replace463_1 -> 856 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 11, 856 },
      -1,
   } },

   /* ('ieq', ('iand', 'a@16', 32768), 0) => ('ige', 'a', 0) */
   /* search464_0_0 -> 11 in the cache */
   /* search464_0_1 -> 12 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 11, 12 },
      -1,
   } },
   /* search464_1 -> 856 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 1442, 856 },
      -1,
   } },

   /* replace464_0 -> 11 in the cache */
   /* replace464_1 -> 856 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 11, 856 },
      -1,
   } },

   /* ('ine', ('iand', 'a@16', 32768), 32768) => ('ige', 'a', 0) */
   /* search465_0_0 -> 11 in the cache */
   /* search465_0_1 -> 12 in the cache */
   /* search465_0 -> 1442 in the cache */
   /* search465_1 -> 12 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 1442, 12 },
      -1,
   } },

   /* replace465_0 -> 11 in the cache */
   /* replace465_1 -> 856 in the cache */
   /* replace465 -> 1444 in the cache */

   /* ('ine', ('iand', 'a@16', 32768), 0) => ('ilt', 'a', 0) */
   /* search466_0_0 -> 11 in the cache */
   /* search466_0_1 -> 12 in the cache */
   /* search466_0 -> 1442 in the cache */
   /* search466_1 -> 856 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 1442, 856 },
      -1,
   } },

   /* replace466_0 -> 11 in the cache */
   /* replace466_1 -> 856 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 11, 856 },
      -1,
   } },

   /* ('ieq', ('iand', 'a@16', 32768), 32768) => ('ilt', 'a', 0) */
   /* search467_0_0 -> 11 in the cache */
   /* search467_0_1 -> 12 in the cache */
   /* search467_0 -> 1442 in the cache */
   /* search467_1 -> 12 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 1442, 12 },
      -1,
   } },

   /* replace467_0 -> 11 in the cache */
   /* replace467_1 -> 856 in the cache */
   /* replace467 -> 1447 in the cache */

   /* ('ine', ('ushr', 'a@16', 15), 0) => ('ilt', 'a', 0) */
   /* search468_0_0 -> 11 in the cache */
   /* search468_0_1 -> 14 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 11, 14 },
      -1,
   } },
   /* search468_1 -> 856 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1449, 856 },
      -1,
   } },

   /* replace468_0 -> 11 in the cache */
   /* replace468_1 -> 856 in the cache */
   /* replace468 -> 1447 in the cache */

   /* ('ieq', ('ushr', 'a@16', 15), 0) => ('ige', 'a', 0) */
   /* search469_0_0 -> 11 in the cache */
   /* search469_0_1 -> 14 in the cache */
   /* search469_0 -> 1449 in the cache */
   /* search469_1 -> 856 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1449, 856 },
      -1,
   } },

   /* replace469_0 -> 11 in the cache */
   /* replace469_1 -> 856 in the cache */
   /* replace469 -> 1444 in the cache */

   /* ('ieq', ('ushr', 'a@16', 15), 1) => ('ilt', 'a', 0) */
   /* search470_0_0 -> 11 in the cache */
   /* search470_0_1 -> 14 in the cache */
   /* search470_0 -> 1449 in the cache */
   { .constant = {
      { nir_search_value_constant, 16 },
      nir_type_int, { 0x1 /* 1 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1449, 1452 },
      -1,
   } },

   /* replace470_0 -> 11 in the cache */
   /* replace470_1 -> 856 in the cache */
   /* replace470 -> 1447 in the cache */

   /* ('ine', ('ushr', 'a@16', 15), 1) => ('ige', 'a', 0) */
   /* search471_0_0 -> 11 in the cache */
   /* search471_0_1 -> 14 in the cache */
   /* search471_0 -> 1449 in the cache */
   /* search471_1 -> 1452 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1449, 1452 },
      -1,
   } },

   /* replace471_0 -> 11 in the cache */
   /* replace471_1 -> 856 in the cache */
   /* replace471 -> 1444 in the cache */

   /* ('ine', ('ishr', 'a@16', 15), 0) => ('ilt', 'a', 0) */
   /* search472_0_0 -> 11 in the cache */
   /* search472_0_1 -> 14 in the cache */
   /* search472_0 -> 1438 in the cache */
   /* search472_1 -> 856 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1438, 856 },
      -1,
   } },

   /* replace472_0 -> 11 in the cache */
   /* replace472_1 -> 856 in the cache */
   /* replace472 -> 1447 in the cache */

   /* ('ieq', ('ishr', 'a@16', 15), 0) => ('ige', 'a', 0) */
   /* search473_0_0 -> 11 in the cache */
   /* search473_0_1 -> 14 in the cache */
   /* search473_0 -> 1438 in the cache */
   /* search473_1 -> 856 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1438, 856 },
      -1,
   } },

   /* replace473_0 -> 11 in the cache */
   /* replace473_1 -> 856 in the cache */
   /* replace473 -> 1444 in the cache */

   /* ('ieq', ('ishr', 'a@16', 15), -1) => ('ilt', 'a', 0) */
   /* search474_0_0 -> 11 in the cache */
   /* search474_0_1 -> 14 in the cache */
   /* search474_0 -> 1438 in the cache */
   { .constant = {
      { nir_search_value_constant, 16 },
      nir_type_int, { -0x1 /* -1 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1438, 1457 },
      -1,
   } },

   /* replace474_0 -> 11 in the cache */
   /* replace474_1 -> 856 in the cache */
   /* replace474 -> 1447 in the cache */

   /* ('ine', ('ishr', 'a@16', 15), -1) => ('ige', 'a', 0) */
   /* search475_0_0 -> 11 in the cache */
   /* search475_0_1 -> 14 in the cache */
   /* search475_0 -> 1438 in the cache */
   /* search475_1 -> 1457 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1438, 1457 },
      -1,
   } },

   /* replace475_0 -> 11 in the cache */
   /* replace475_1 -> 856 in the cache */
   /* replace475 -> 1444 in the cache */

   /* ('iand@32', 'a', ('inot', ('ishr', 'a', 31))) => ('imax', 'a', 0) */
   /* search476_0 -> 16 in the cache */
   /* search476_1_0_0 -> 16 in the cache */
   /* search476_1_0_1 -> 19 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 16, 19 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 1460 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 16, 1461 },
      -1,
   } },

   /* replace476_0 -> 16 in the cache */
   /* replace476_1 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 16, 122 },
      -1,
   } },

   /* ('ieq', ('iand', 'a@32', 2147483648), 0) => ('ige', 'a', 0) */
   /* search477_0_0 -> 16 in the cache */
   /* search477_0_1 -> 17 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 16, 17 },
      -1,
   } },
   /* search477_1 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 1464, 122 },
      -1,
   } },

   /* replace477_0 -> 16 in the cache */
   /* replace477_1 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 16, 122 },
      -1,
   } },

   /* ('ine', ('iand', 'a@32', 2147483648), 2147483648) => ('ige', 'a', 0) */
   /* search478_0_0 -> 16 in the cache */
   /* search478_0_1 -> 17 in the cache */
   /* search478_0 -> 1464 in the cache */
   /* search478_1 -> 17 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 1464, 17 },
      -1,
   } },

   /* replace478_0 -> 16 in the cache */
   /* replace478_1 -> 122 in the cache */
   /* replace478 -> 1466 in the cache */

   /* ('ine', ('iand', 'a@32', 2147483648), 0) => ('ilt', 'a', 0) */
   /* search479_0_0 -> 16 in the cache */
   /* search479_0_1 -> 17 in the cache */
   /* search479_0 -> 1464 in the cache */
   /* search479_1 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 1464, 122 },
      -1,
   } },

   /* replace479_0 -> 16 in the cache */
   /* replace479_1 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 16, 122 },
      -1,
   } },

   /* ('ieq', ('iand', 'a@32', 2147483648), 2147483648) => ('ilt', 'a', 0) */
   /* search480_0_0 -> 16 in the cache */
   /* search480_0_1 -> 17 in the cache */
   /* search480_0 -> 1464 in the cache */
   /* search480_1 -> 17 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 1464, 17 },
      -1,
   } },

   /* replace480_0 -> 16 in the cache */
   /* replace480_1 -> 122 in the cache */
   /* replace480 -> 1469 in the cache */

   /* ('ine', ('ushr', 'a@32', 31), 0) => ('ilt', 'a', 0) */
   /* search481_0_0 -> 16 in the cache */
   /* search481_0_1 -> 19 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 16, 19 },
      -1,
   } },
   /* search481_1 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1471, 122 },
      -1,
   } },

   /* replace481_0 -> 16 in the cache */
   /* replace481_1 -> 122 in the cache */
   /* replace481 -> 1469 in the cache */

   /* ('ieq', ('ushr', 'a@32', 31), 0) => ('ige', 'a', 0) */
   /* search482_0_0 -> 16 in the cache */
   /* search482_0_1 -> 19 in the cache */
   /* search482_0 -> 1471 in the cache */
   /* search482_1 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1471, 122 },
      -1,
   } },

   /* replace482_0 -> 16 in the cache */
   /* replace482_1 -> 122 in the cache */
   /* replace482 -> 1466 in the cache */

   /* ('ieq', ('ushr', 'a@32', 31), 1) => ('ilt', 'a', 0) */
   /* search483_0_0 -> 16 in the cache */
   /* search483_0_1 -> 19 in the cache */
   /* search483_0 -> 1471 in the cache */
   /* search483_1 -> 396 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1471, 396 },
      -1,
   } },

   /* replace483_0 -> 16 in the cache */
   /* replace483_1 -> 122 in the cache */
   /* replace483 -> 1469 in the cache */

   /* ('ine', ('ushr', 'a@32', 31), 1) => ('ige', 'a', 0) */
   /* search484_0_0 -> 16 in the cache */
   /* search484_0_1 -> 19 in the cache */
   /* search484_0 -> 1471 in the cache */
   /* search484_1 -> 396 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1471, 396 },
      -1,
   } },

   /* replace484_0 -> 16 in the cache */
   /* replace484_1 -> 122 in the cache */
   /* replace484 -> 1466 in the cache */

   /* ('ine', ('ishr', 'a@32', 31), 0) => ('ilt', 'a', 0) */
   /* search485_0_0 -> 16 in the cache */
   /* search485_0_1 -> 19 in the cache */
   /* search485_0 -> 1460 in the cache */
   /* search485_1 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1460, 122 },
      -1,
   } },

   /* replace485_0 -> 16 in the cache */
   /* replace485_1 -> 122 in the cache */
   /* replace485 -> 1469 in the cache */

   /* ('ieq', ('ishr', 'a@32', 31), 0) => ('ige', 'a', 0) */
   /* search486_0_0 -> 16 in the cache */
   /* search486_0_1 -> 19 in the cache */
   /* search486_0 -> 1460 in the cache */
   /* search486_1 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1460, 122 },
      -1,
   } },

   /* replace486_0 -> 16 in the cache */
   /* replace486_1 -> 122 in the cache */
   /* replace486 -> 1466 in the cache */

   /* ('ieq', ('ishr', 'a@32', 31), -1) => ('ilt', 'a', 0) */
   /* search487_0_0 -> 16 in the cache */
   /* search487_0_1 -> 19 in the cache */
   /* search487_0 -> 1460 in the cache */
   /* search487_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1460, 124 },
      -1,
   } },

   /* replace487_0 -> 16 in the cache */
   /* replace487_1 -> 122 in the cache */
   /* replace487 -> 1469 in the cache */

   /* ('ine', ('ishr', 'a@32', 31), -1) => ('ige', 'a', 0) */
   /* search488_0_0 -> 16 in the cache */
   /* search488_0_1 -> 19 in the cache */
   /* search488_0 -> 1460 in the cache */
   /* search488_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1460, 124 },
      -1,
   } },

   /* replace488_0 -> 16 in the cache */
   /* replace488_1 -> 122 in the cache */
   /* replace488 -> 1466 in the cache */

   /* ('iand@64', 'a', ('inot', ('ishr', 'a', 63))) => ('imax', 'a', 0) */
   /* search489_0 -> 21 in the cache */
   /* search489_1_0_0 -> 21 in the cache */
   /* search489_1_0_1 -> 24 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 21, 24 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 1480 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 21, 1481 },
      -1,
   } },

   /* replace489_0 -> 21 in the cache */
   /* replace489_1 -> 897 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 21, 897 },
      -1,
   } },

   /* ('ieq', ('iand', 'a@64', 9223372036854775808), 0) => ('ige', 'a', 0) */
   /* search490_0_0 -> 21 in the cache */
   /* search490_0_1 -> 22 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 21, 22 },
      -1,
   } },
   /* search490_1 -> 897 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 1484, 897 },
      -1,
   } },

   /* replace490_0 -> 21 in the cache */
   /* replace490_1 -> 897 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 21, 897 },
      -1,
   } },

   /* ('ine', ('iand', 'a@64', 9223372036854775808), 9223372036854775808) => ('ige', 'a', 0) */
   /* search491_0_0 -> 21 in the cache */
   /* search491_0_1 -> 22 in the cache */
   /* search491_0 -> 1484 in the cache */
   /* search491_1 -> 22 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 1484, 22 },
      -1,
   } },

   /* replace491_0 -> 21 in the cache */
   /* replace491_1 -> 897 in the cache */
   /* replace491 -> 1486 in the cache */

   /* ('ine', ('iand', 'a@64', 9223372036854775808), 0) => ('ilt', 'a', 0) */
   /* search492_0_0 -> 21 in the cache */
   /* search492_0_1 -> 22 in the cache */
   /* search492_0 -> 1484 in the cache */
   /* search492_1 -> 897 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 1484, 897 },
      -1,
   } },

   /* replace492_0 -> 21 in the cache */
   /* replace492_1 -> 897 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 21, 897 },
      -1,
   } },

   /* ('ieq', ('iand', 'a@64', 9223372036854775808), 9223372036854775808) => ('ilt', 'a', 0) */
   /* search493_0_0 -> 21 in the cache */
   /* search493_0_1 -> 22 in the cache */
   /* search493_0 -> 1484 in the cache */
   /* search493_1 -> 22 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 1484, 22 },
      -1,
   } },

   /* replace493_0 -> 21 in the cache */
   /* replace493_1 -> 897 in the cache */
   /* replace493 -> 1489 in the cache */

   /* ('ine', ('ushr', 'a@64', 63), 0) => ('ilt', 'a', 0) */
   /* search494_0_0 -> 21 in the cache */
   /* search494_0_1 -> 24 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 21, 24 },
      -1,
   } },
   /* search494_1 -> 897 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1491, 897 },
      -1,
   } },

   /* replace494_0 -> 21 in the cache */
   /* replace494_1 -> 897 in the cache */
   /* replace494 -> 1489 in the cache */

   /* ('ieq', ('ushr', 'a@64', 63), 0) => ('ige', 'a', 0) */
   /* search495_0_0 -> 21 in the cache */
   /* search495_0_1 -> 24 in the cache */
   /* search495_0 -> 1491 in the cache */
   /* search495_1 -> 897 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1491, 897 },
      -1,
   } },

   /* replace495_0 -> 21 in the cache */
   /* replace495_1 -> 897 in the cache */
   /* replace495 -> 1486 in the cache */

   /* ('ieq', ('ushr', 'a@64', 63), 1) => ('ilt', 'a', 0) */
   /* search496_0_0 -> 21 in the cache */
   /* search496_0_1 -> 24 in the cache */
   /* search496_0 -> 1491 in the cache */
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0x1 /* 1 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1491, 1494 },
      -1,
   } },

   /* replace496_0 -> 21 in the cache */
   /* replace496_1 -> 897 in the cache */
   /* replace496 -> 1489 in the cache */

   /* ('ine', ('ushr', 'a@64', 63), 1) => ('ige', 'a', 0) */
   /* search497_0_0 -> 21 in the cache */
   /* search497_0_1 -> 24 in the cache */
   /* search497_0 -> 1491 in the cache */
   /* search497_1 -> 1494 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1491, 1494 },
      -1,
   } },

   /* replace497_0 -> 21 in the cache */
   /* replace497_1 -> 897 in the cache */
   /* replace497 -> 1486 in the cache */

   /* ('ine', ('ishr', 'a@64', 63), 0) => ('ilt', 'a', 0) */
   /* search498_0_0 -> 21 in the cache */
   /* search498_0_1 -> 24 in the cache */
   /* search498_0 -> 1480 in the cache */
   /* search498_1 -> 897 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1480, 897 },
      -1,
   } },

   /* replace498_0 -> 21 in the cache */
   /* replace498_1 -> 897 in the cache */
   /* replace498 -> 1489 in the cache */

   /* ('ieq', ('ishr', 'a@64', 63), 0) => ('ige', 'a', 0) */
   /* search499_0_0 -> 21 in the cache */
   /* search499_0_1 -> 24 in the cache */
   /* search499_0 -> 1480 in the cache */
   /* search499_1 -> 897 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1480, 897 },
      -1,
   } },

   /* replace499_0 -> 21 in the cache */
   /* replace499_1 -> 897 in the cache */
   /* replace499 -> 1486 in the cache */

   /* ('ieq', ('ishr', 'a@64', 63), -1) => ('ilt', 'a', 0) */
   /* search500_0_0 -> 21 in the cache */
   /* search500_0_1 -> 24 in the cache */
   /* search500_0 -> 1480 in the cache */
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { -0x1 /* -1 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1480, 1499 },
      -1,
   } },

   /* replace500_0 -> 21 in the cache */
   /* replace500_1 -> 897 in the cache */
   /* replace500 -> 1489 in the cache */

   /* ('ine', ('ishr', 'a@64', 63), -1) => ('ige', 'a', 0) */
   /* search501_0_0 -> 21 in the cache */
   /* search501_0_1 -> 24 in the cache */
   /* search501_0 -> 1480 in the cache */
   /* search501_1 -> 1499 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1480, 1499 },
      -1,
   } },

   /* replace501_0 -> 21 in the cache */
   /* replace501_1 -> 897 in the cache */
   /* replace501 -> 1486 in the cache */

   /* ('fmin', 'a', ('fneg', 'a')) => ('fneg', ('fabs', 'a')) */
   /* search502_0 -> 32 in the cache */
   /* search502_1_0 -> 32 in the cache */
   /* search502_1 -> 98 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 32, 98 },
      -1,
   } },

   /* replace502_0_0 -> 32 in the cache */
   /* replace502_0 -> 103 in the cache */
   /* replace502 -> 1254 in the cache */

   /* ('imin', 'a', ('ineg', 'a')) => ('ineg', ('iabs', 'a')) */
   /* search503_0 -> 32 in the cache */
   /* search503_1_0 -> 32 in the cache */
   /* search503_1 -> 100 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imin,
      0, 1,
      { 32, 100 },
      -1,
   } },

   /* replace503_0_0 -> 32 in the cache */
   /* replace503_0 -> 106 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 106 },
      -1,
   } },

   /* ('fmin', 'a', ('fneg', ('fabs', 'a'))) => ('fneg', ('fabs', 'a')) */
   /* search504_0 -> 32 in the cache */
   /* search504_1_0_0 -> 32 in the cache */
   /* search504_1_0 -> 103 in the cache */
   /* search504_1 -> 1254 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 32, 1254 },
      -1,
   } },

   /* replace504_0_0 -> 32 in the cache */
   /* replace504_0 -> 103 in the cache */
   /* replace504 -> 1254 in the cache */

   /* ('imin', 'a', ('ineg', ('iabs', 'a'))) => ('ineg', ('iabs', 'a')) */
   /* search505_0 -> 32 in the cache */
   /* search505_1_0_0 -> 32 in the cache */
   /* search505_1_0 -> 106 in the cache */
   /* search505_1 -> 1504 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imin,
      0, 1,
      { 32, 1504 },
      -1,
   } },

   /* replace505_0_0 -> 32 in the cache */
   /* replace505_0 -> 106 in the cache */
   /* replace505 -> 1504 in the cache */

   /* ('~fmin', 'a', ('fabs', 'a')) => a */
   /* search506_0 -> 32 in the cache */
   /* search506_1_0 -> 32 in the cache */
   /* search506_1 -> 103 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 32, 103 },
      -1,
   } },

   /* replace506 -> 32 in the cache */

   /* ('imin', 'a', ('iabs', 'a')) => a */
   /* search507_0 -> 32 in the cache */
   /* search507_1_0 -> 32 in the cache */
   /* search507_1 -> 106 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imin,
      0, 1,
      { 32, 106 },
      -1,
   } },

   /* replace507 -> 32 in the cache */

   /* ('~fmax', 'a', ('fneg', ('fabs', 'a'))) => a */
   /* search508_0 -> 32 in the cache */
   /* search508_1_0_0 -> 32 in the cache */
   /* search508_1_0 -> 103 in the cache */
   /* search508_1 -> 1254 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 32, 1254 },
      -1,
   } },

   /* replace508 -> 32 in the cache */

   /* ('imax', 'a', ('ineg', ('iabs', 'a'))) => a */
   /* search509_0 -> 32 in the cache */
   /* search509_1_0_0 -> 32 in the cache */
   /* search509_1_0 -> 106 in the cache */
   /* search509_1 -> 1504 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 32, 1504 },
      -1,
   } },

   /* replace509 -> 32 in the cache */

   /* ('fmax', 'a', ('fabs', 'a')) => ('fabs', 'a') */
   /* search510_0 -> 32 in the cache */
   /* search510_1_0 -> 32 in the cache */
   /* search510_1 -> 103 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 32, 103 },
      -1,
   } },

   /* replace510_0 -> 32 in the cache */
   /* replace510 -> 103 in the cache */

   /* ('imax', 'a', ('iabs', 'a')) => ('iabs', 'a') */
   /* search511_0 -> 32 in the cache */
   /* search511_1_0 -> 32 in the cache */
   /* search511_1 -> 106 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 32, 106 },
      -1,
   } },

   /* replace511_0 -> 32 in the cache */
   /* replace511 -> 106 in the cache */

   /* ('fmax', 'a', ('fneg', 'a')) => ('fabs', 'a') */
   /* search512_0 -> 32 in the cache */
   /* search512_1_0 -> 32 in the cache */
   /* search512_1 -> 98 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 32, 98 },
      -1,
   } },

   /* replace512_0 -> 32 in the cache */
   /* replace512 -> 103 in the cache */

   /* ('imax', 'a', ('ineg', 'a')) => ('iabs', 'a') */
   /* search513_0 -> 32 in the cache */
   /* search513_1_0 -> 32 in the cache */
   /* search513_1 -> 100 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 32, 100 },
      -1,
   } },

   /* replace513_0 -> 32 in the cache */
   /* replace513 -> 106 in the cache */

   /* ('~fmax', ('fabs', 'a'), 0.0) => ('fabs', 'a') */
   /* search514_0_0 -> 32 in the cache */
   /* search514_0 -> 103 in the cache */
   /* search514_1 -> 111 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 103, 111 },
      -1,
   } },

   /* replace514_0 -> 32 in the cache */
   /* replace514 -> 103 in the cache */

   /* ('fmin', ('fmax', 'a', 0.0), 1.0) => ('fsat', 'a') */
   /* search515_0_0 -> 32 in the cache */
   /* search515_0_1 -> 111 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmax,
      1, 1,
      { 32, 111 },
      -1,
   } },
   /* search515_1 -> 241 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 2,
      { 1516, 241 },
      -1,
   } },

   /* replace515_0 -> 32 in the cache */
   /* replace515 -> 217 in the cache */

   /* ('~fmax', ('fmin', 'a', 1.0), 0.0) => ('fsat', 'a') */
   /* search516_0_0 -> 32 in the cache */
   /* search516_0_1 -> 241 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmin,
      1, 1,
      { 32, 241 },
      -1,
   } },
   /* search516_1 -> 111 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fmax,
      0, 2,
      { 1518, 111 },
      -1,
   } },

   /* replace516_0 -> 32 in the cache */
   /* replace516 -> 217 in the cache */

   /* ('~fmin', ('fmax', 'a', -1.0), 0.0) => ('fneg', ('fsat', ('fneg', 'a'))) */
   /* search517_0_0 -> 32 in the cache */
   /* search517_0_1 -> 247 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmax,
      1, 1,
      { 32, 247 },
      -1,
   } },
   /* search517_1 -> 111 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fmin,
      0, 2,
      { 1520, 111 },
      -1,
   } },

   /* replace517_0_0_0 -> 32 in the cache */
   /* replace517_0_0 -> 98 in the cache */
   /* replace517_0 -> 218 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 218 },
      -1,
   } },

   /* ('~fmax', ('fmin', 'a', 0.0), -1.0) => ('fneg', ('fsat', ('fneg', 'a'))) */
   /* search518_0_0 -> 32 in the cache */
   /* search518_0_1 -> 111 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmin,
      1, 1,
      { 32, 111 },
      -1,
   } },
   /* search518_1 -> 247 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fmax,
      0, 2,
      { 1523, 247 },
      -1,
   } },

   /* replace518_0_0_0 -> 32 in the cache */
   /* replace518_0_0 -> 98 in the cache */
   /* replace518_0 -> 218 in the cache */
   /* replace518 -> 1522 in the cache */

   /* ('fsat', ('fsign', 'a')) => ('b2f', ('!flt', 0.0, 'a')) */
   /* search519_0_0 -> 32 in the cache */
   /* search519_0 -> 250 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 250 },
      -1,
   } },

   /* replace519_0_0 -> 111 in the cache */
   /* replace519_0_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      nir_op_flt,
      -1, 0,
      { 111, 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 1526 },
      -1,
   } },

   /* ('fsat', ('b2f', 'a')) => ('b2f', 'a') */
   /* search520_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 1528 },
      -1,
   } },

   /* replace520_0 -> 32 in the cache */
   /* replace520 -> 1528 in the cache */

   /* ('fsat', 'a') => ('fmin', ('fmax', 'a', 0.0), 1.0) */
   /* search521_0 -> 32 in the cache */
   /* search521 -> 217 in the cache */

   /* replace521_0_0 -> 32 in the cache */
   /* replace521_0_1 -> 111 in the cache */
   /* replace521_0 -> 1516 in the cache */
   /* replace521_1 -> 241 in the cache */
   /* replace521 -> 1517 in the cache */

   /* ('fsat', ('fsat', 'a')) => ('fsat', 'a') */
   /* search522_0_0 -> 32 in the cache */
   /* search522_0 -> 217 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 217 },
      -1,
   } },

   /* replace522_0 -> 32 in the cache */
   /* replace522 -> 217 in the cache */

   /* ('fsat', ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', 'b'))) => ('fsat', ('fadd', ('fneg', 'a'), ('fneg', 'b'))) */
   /* search523_0_0_0 -> 0 in the cache */
   /* search523_0_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 0, 3 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 1531 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 1,
      { 1532 },
      -1,
   } },

   /* replace523_0_0_0 -> 0 in the cache */
   /* replace523_0_0 -> 212 in the cache */
   /* replace523_0_1_0 -> 3 in the cache */
   /* replace523_0_1 -> 1087 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 212, 1087 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 1,
      { 1534 },
      -1,
   } },

   /* ('fsat', ('fneg(is_used_once)', ('fmul(is_used_once)', 'a', 'b'))) => ('fsat', ('fmul', ('fneg', 'a'), 'b')) */
   /* search524_0_0_0 -> 0 in the cache */
   /* search524_0_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 0, 3 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 1536 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 1,
      { 1537 },
      -1,
   } },

   /* replace524_0_0_0 -> 0 in the cache */
   /* replace524_0_0 -> 212 in the cache */
   /* replace524_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 212, 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 1,
      { 1539 },
      -1,
   } },

   /* ('fsat', ('fneg(is_used_once)', ('fmulz(is_used_once)', 'a', 'b'))) => ('fsat', ('fmulz', ('fneg', 'a'), 'b')) */
   /* search525_0_0_0 -> 16 in the cache */
   /* search525_0_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 16, 36 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 1541 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 1,
      { 1542 },
      -1,
   } },

   /* replace525_0_0_0 -> 16 in the cache */
   /* replace525_0_0 -> 280 in the cache */
   /* replace525_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 280, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 1,
      { 1544 },
      -1,
   } },

   /* ('fsat', ('fabs(is_used_once)', ('fmul(is_used_once)', 'a', 'b'))) => ('fsat', ('fmul', ('fabs', 'a'), ('fabs', 'b'))) */
   /* search526_0_0_0 -> 0 in the cache */
   /* search526_0_0_1 -> 3 in the cache */
   /* search526_0_0 -> 1536 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 1,
      { 1536 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 1,
      { 1546 },
      -1,
   } },

   /* replace526_0_0_0 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 0 },
      -1,
   } },
   /* replace526_0_1_0 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 1548, 1549 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 1,
      { 1550 },
      -1,
   } },

   /* ('fmin', ('fmax', ('fmin', ('fmax', 'a', 'b'), 'c'), 'b'), 'c') => ('fmin', ('fmax', 'a', 'b'), 'c') */
   /* search527_0_0_0_0 -> 126 in the cache */
   /* search527_0_0_0_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmax,
      3, 1,
      { 126, 127 },
      -1,
   } },
   /* search527_0_0_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmin,
      2, 2,
      { 1552, 129 },
      -1,
   } },
   /* search527_0_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmax,
      1, 3,
      { 1553, 127 },
      -1,
   } },
   /* search527_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 4,
      { 1554, 129 },
      -1,
   } },

   /* replace527_0_0 -> 126 in the cache */
   /* replace527_0_1 -> 127 in the cache */
   /* replace527_0 -> 1360 in the cache */
   /* replace527_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 2,
      { 1360, 129 },
      -1,
   } },

   /* ('imin', ('imax', ('imin', ('imax', 'a', 'b'), 'c'), 'b'), 'c') => ('imin', ('imax', 'a', 'b'), 'c') */
   /* search528_0_0_0_0 -> 126 in the cache */
   /* search528_0_0_0_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imax,
      3, 1,
      { 126, 127 },
      -1,
   } },
   /* search528_0_0_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imin,
      2, 2,
      { 1557, 129 },
      -1,
   } },
   /* search528_0_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imax,
      1, 3,
      { 1558, 127 },
      -1,
   } },
   /* search528_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imin,
      0, 4,
      { 1559, 129 },
      -1,
   } },

   /* replace528_0_0 -> 126 in the cache */
   /* replace528_0_1 -> 127 in the cache */
   /* replace528_0 -> 1370 in the cache */
   /* replace528_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imin,
      0, 2,
      { 1370, 129 },
      -1,
   } },

   /* ('umin', ('umax', ('umin', ('umax', 'a', 'b'), 'c'), 'b'), 'c') => ('umin', ('umax', 'a', 'b'), 'c') */
   /* search529_0_0_0_0 -> 126 in the cache */
   /* search529_0_0_0_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_umax,
      3, 1,
      { 126, 127 },
      -1,
   } },
   /* search529_0_0_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_umin,
      2, 2,
      { 1562, 129 },
      -1,
   } },
   /* search529_0_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_umax,
      1, 3,
      { 1563, 127 },
      -1,
   } },
   /* search529_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_umin,
      0, 4,
      { 1564, 129 },
      -1,
   } },

   /* replace529_0_0 -> 126 in the cache */
   /* replace529_0_1 -> 127 in the cache */
   /* replace529_0 -> 1365 in the cache */
   /* replace529_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_umin,
      0, 2,
      { 1365, 129 },
      -1,
   } },

   /* ('fmax', ('fsat', 'a'), '#b(is_zero_to_one)') => ('fsat', ('fmax', 'a', 'b')) */
   /* search530_0_0 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 0 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      true,
      nir_type_invalid,
      18,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 1567, 1568 },
      -1,
   } },

   /* replace530_0_0 -> 0 in the cache */
   /* replace530_0_1 -> 3 in the cache */
   /* replace530_0 -> 1281 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 1,
      { 1281 },
      -1,
   } },

   /* ('~fmin', ('fsat', 'a'), '#b(is_zero_to_one)') => ('fsat', ('fmin', 'a', 'b')) */
   /* search531_0_0 -> 0 in the cache */
   /* search531_0 -> 1567 in the cache */
   /* search531_1 -> 1568 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 1567, 1568 },
      -1,
   } },

   /* replace531_0_0 -> 0 in the cache */
   /* replace531_0_1 -> 3 in the cache */
   /* replace531_0 -> 1283 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 1,
      { 1283 },
      -1,
   } },

   /* ('fmax', ('fneg', ('fmin', 'b', 'a')), 'b') => ('fmax', ('fabs', 'b'), ('fneg', 'a')) */
   /* search532_0_0_0 -> 1117 in the cache */
   /* search532_0_0_1 -> 1114 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmin,
      1, 1,
      { 1117, 1114 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 1573 },
      -1,
   } },
   /* search532_1 -> 1117 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 2,
      { 1574, 1117 },
      -1,
   } },

   /* replace532_0_0 -> 1117 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 1117 },
      -1,
   } },
   /* replace532_1_0 -> 1114 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 1114 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 1576, 1577 },
      -1,
   } },

   /* ('fmin', ('fneg', ('fmax', 'b', 'a')), 'b') => ('fmin', ('fneg', ('fabs', 'b')), ('fneg', 'a')) */
   /* search533_0_0_0 -> 1117 in the cache */
   /* search533_0_0_1 -> 1114 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmax,
      1, 1,
      { 1117, 1114 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 1579 },
      -1,
   } },
   /* search533_1 -> 1117 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 2,
      { 1580, 1117 },
      -1,
   } },

   /* replace533_0_0_0 -> 1117 in the cache */
   /* replace533_0_0 -> 1576 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 1576 },
      -1,
   } },
   /* replace533_1_0 -> 1114 in the cache */
   /* replace533_1 -> 1577 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 1582, 1577 },
      -1,
   } },

   /* ('fmax', ('fadd(is_used_once)', ('fneg', 'a(is_not_negative)'), '#b(is_zero_to_one)'), 0.0) => ('fsat', ('fadd', ('fneg', 'a'), 'b')) */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      19,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 1584 },
      -1,
   } },
   /* search534_0_1 -> 1568 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 1585, 1568 },
      0,
   } },
   /* search534_1 -> 256 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 2,
      { 1586, 256 },
      -1,
   } },

   /* replace534_0_0_0 -> 0 in the cache */
   /* replace534_0_0 -> 212 in the cache */
   /* replace534_0_1 -> 3 in the cache */
   /* replace534_0 -> 277 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 1,
      { 277 },
      -1,
   } },

   /* ('extract_u8', ('imin', ('imax', 'a', 0), 255), 0) => ('imin', ('imax', 'a', 0), 255) */
   /* search535_0_0_0 -> 32 in the cache */
   /* search535_0_0_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imax,
      1, 1,
      { 32, 61 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_int, { 0xff /* 255 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imin,
      0, 2,
      { 1589, 1590 },
      -1,
   } },
   /* search535_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 2,
      { 1591, 61 },
      -1,
   } },

   /* replace535_0_0 -> 32 in the cache */
   /* replace535_0_1 -> 61 in the cache */
   /* replace535_0 -> 1589 in the cache */
   /* replace535_1 -> 1590 in the cache */
   /* replace535 -> 1591 in the cache */

   /* ('ior', ('flt(is_used_once)', 'a', 'b'), ('flt', 'a', 'c')) => ('flt', 'a', ('!fmax', 'b', 'c')) */
   /* search536_0_0 -> 126 in the cache */
   /* search536_0_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 126, 127 },
      0,
   } },
   /* search536_1_0 -> 126 in the cache */
   /* search536_1_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 126, 129 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1593, 1594 },
      -1,
   } },

   /* replace536_0 -> 126 in the cache */
   /* replace536_1_0 -> 127 in the cache */
   /* replace536_1_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      true,
      false,
      nir_op_fmax,
      0, 1,
      { 127, 129 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 126, 1596 },
      -1,
   } },

   /* ('ior', ('flt(is_used_once)', 'a', 'c'), ('flt', 'b', 'c')) => ('flt', ('!fmin', 'a', 'b'), 'c') */
   /* search537_0_0 -> 0 in the cache */
   /* search537_0_1 -> 684 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 0, 684 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      2, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search537_1_1 -> 684 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1599, 684 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1598, 1600 },
      -1,
   } },

   /* replace537_0_0 -> 0 in the cache */
   /* replace537_0_1 -> 1599 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      true,
      false,
      nir_op_fmin,
      0, 1,
      { 0, 1599 },
      -1,
   } },
   /* replace537_1 -> 684 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 1602, 684 },
      -1,
   } },

   /* ('ior', ('fge(is_used_once)', 'a', 'b'), ('fge', 'a', 'c')) => ('fge', 'a', ('!fmin', 'b', 'c')) */
   /* search538_0_0 -> 126 in the cache */
   /* search538_0_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 126, 127 },
      0,
   } },
   /* search538_1_0 -> 126 in the cache */
   /* search538_1_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 126, 129 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1604, 1605 },
      -1,
   } },

   /* replace538_0 -> 126 in the cache */
   /* replace538_1_0 -> 127 in the cache */
   /* replace538_1_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      true,
      false,
      nir_op_fmin,
      0, 1,
      { 127, 129 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 126, 1607 },
      -1,
   } },

   /* ('ior', ('fge(is_used_once)', 'a', 'c'), ('fge', 'b', 'c')) => ('fge', ('!fmax', 'a', 'b'), 'c') */
   /* search539_0_0 -> 0 in the cache */
   /* search539_0_1 -> 684 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 0, 684 },
      0,
   } },
   /* search539_1_0 -> 1599 in the cache */
   /* search539_1_1 -> 684 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1599, 684 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1609, 1610 },
      -1,
   } },

   /* replace539_0_0 -> 0 in the cache */
   /* replace539_0_1 -> 1599 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      true,
      false,
      nir_op_fmax,
      0, 1,
      { 0, 1599 },
      -1,
   } },
   /* replace539_1 -> 684 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 1612, 684 },
      -1,
   } },

   /* ('ior', ('flt', 'a', '#b'), ('flt', 'a', '#c')) => ('flt', 'a', ('!fmax', 'b', 'c')) */
   /* search540_0_0 -> 126 in the cache */
   /* search540_0_1 -> 283 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 126, 283 },
      -1,
   } },
   /* search540_1_0 -> 126 in the cache */
   /* search540_1_1 -> 814 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 126, 814 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1614, 1615 },
      -1,
   } },

   /* replace540_0 -> 126 in the cache */
   /* replace540_1_0 -> 127 in the cache */
   /* replace540_1_1 -> 129 in the cache */
   /* replace540_1 -> 1596 in the cache */
   /* replace540 -> 1597 in the cache */

   /* ('ior', ('flt', '#a', 'c'), ('flt', '#b', 'c')) => ('flt', ('!fmin', 'a', 'b'), 'c') */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search541_0_1 -> 684 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1617, 684 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      2, /* b */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search541_1_1 -> 684 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1619, 684 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1618, 1620 },
      -1,
   } },

   /* replace541_0_0 -> 0 in the cache */
   /* replace541_0_1 -> 1599 in the cache */
   /* replace541_0 -> 1602 in the cache */
   /* replace541_1 -> 684 in the cache */
   /* replace541 -> 1603 in the cache */

   /* ('ior', ('fge', 'a', '#b'), ('fge', 'a', '#c')) => ('fge', 'a', ('!fmin', 'b', 'c')) */
   /* search542_0_0 -> 126 in the cache */
   /* search542_0_1 -> 283 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 126, 283 },
      -1,
   } },
   /* search542_1_0 -> 126 in the cache */
   /* search542_1_1 -> 814 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 126, 814 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1622, 1623 },
      -1,
   } },

   /* replace542_0 -> 126 in the cache */
   /* replace542_1_0 -> 127 in the cache */
   /* replace542_1_1 -> 129 in the cache */
   /* replace542_1 -> 1607 in the cache */
   /* replace542 -> 1608 in the cache */

   /* ('ior', ('fge', '#a', 'c'), ('fge', '#b', 'c')) => ('fge', ('!fmax', 'a', 'b'), 'c') */
   /* search543_0_0 -> 1617 in the cache */
   /* search543_0_1 -> 684 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1617, 684 },
      -1,
   } },
   /* search543_1_0 -> 1619 in the cache */
   /* search543_1_1 -> 684 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1619, 684 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1625, 1626 },
      -1,
   } },

   /* replace543_0_0 -> 0 in the cache */
   /* replace543_0_1 -> 1599 in the cache */
   /* replace543_0 -> 1612 in the cache */
   /* replace543_1 -> 684 in the cache */
   /* replace543 -> 1613 in the cache */

   /* ('~iand', ('flt(is_used_once)', 'a', 'b'), ('flt', 'a', 'c')) => ('flt', 'a', ('fmin', 'b', 'c')) */
   /* search544_0_0 -> 126 in the cache */
   /* search544_0_1 -> 127 in the cache */
   /* search544_0 -> 1593 in the cache */
   /* search544_1_0 -> 126 in the cache */
   /* search544_1_1 -> 129 in the cache */
   /* search544_1 -> 1594 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1593, 1594 },
      -1,
   } },

   /* replace544_0 -> 126 in the cache */
   /* replace544_1_0 -> 127 in the cache */
   /* replace544_1_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 127, 129 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 126, 1629 },
      -1,
   } },

   /* ('~iand', ('flt(is_used_once)', 'a', 'c'), ('flt', 'b', 'c')) => ('flt', ('fmax', 'a', 'b'), 'c') */
   /* search545_0_0 -> 0 in the cache */
   /* search545_0_1 -> 684 in the cache */
   /* search545_0 -> 1598 in the cache */
   /* search545_1_0 -> 1599 in the cache */
   /* search545_1_1 -> 684 in the cache */
   /* search545_1 -> 1600 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1598, 1600 },
      -1,
   } },

   /* replace545_0_0 -> 0 in the cache */
   /* replace545_0_1 -> 1599 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 0, 1599 },
      -1,
   } },
   /* replace545_1 -> 684 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 1632, 684 },
      -1,
   } },

   /* ('~iand', ('fge(is_used_once)', 'a', 'b'), ('fge', 'a', 'c')) => ('fge', 'a', ('fmax', 'b', 'c')) */
   /* search546_0_0 -> 126 in the cache */
   /* search546_0_1 -> 127 in the cache */
   /* search546_0 -> 1604 in the cache */
   /* search546_1_0 -> 126 in the cache */
   /* search546_1_1 -> 129 in the cache */
   /* search546_1 -> 1605 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1604, 1605 },
      -1,
   } },

   /* replace546_0 -> 126 in the cache */
   /* replace546_1_0 -> 127 in the cache */
   /* replace546_1_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 127, 129 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 126, 1635 },
      -1,
   } },

   /* ('~iand', ('fge(is_used_once)', 'a', 'c'), ('fge', 'b', 'c')) => ('fge', ('fmin', 'a', 'b'), 'c') */
   /* search547_0_0 -> 0 in the cache */
   /* search547_0_1 -> 684 in the cache */
   /* search547_0 -> 1609 in the cache */
   /* search547_1_0 -> 1599 in the cache */
   /* search547_1_1 -> 684 in the cache */
   /* search547_1 -> 1610 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1609, 1610 },
      -1,
   } },

   /* replace547_0_0 -> 0 in the cache */
   /* replace547_0_1 -> 1599 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 0, 1599 },
      -1,
   } },
   /* replace547_1 -> 684 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 1638, 684 },
      -1,
   } },

   /* ('iand', ('flt', 'a', '#b(is_a_number)'), ('flt', 'a', '#c(is_a_number)')) => ('flt', 'a', ('fmin', 'b', 'c')) */
   /* search548_0_0 -> 126 in the cache */
   { .variable = {
      { nir_search_value_variable, -3 },
      1, /* b */
      true,
      nir_type_invalid,
      16,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 126, 1640 },
      -1,
   } },
   /* search548_1_0 -> 126 in the cache */
   { .variable = {
      { nir_search_value_variable, -3 },
      2, /* c */
      true,
      nir_type_invalid,
      16,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 126, 1642 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1641, 1643 },
      -1,
   } },

   /* replace548_0 -> 126 in the cache */
   /* replace548_1_0 -> 127 in the cache */
   /* replace548_1_1 -> 129 in the cache */
   /* replace548_1 -> 1629 in the cache */
   /* replace548 -> 1630 in the cache */

   /* ('iand', ('flt', '#a(is_a_number)', 'c'), ('flt', '#b(is_a_number)', 'c')) => ('flt', ('fmax', 'a', 'b'), 'c') */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      true,
      nir_type_invalid,
      16,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search549_0_1 -> 684 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1645, 684 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      2, /* b */
      true,
      nir_type_invalid,
      16,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search549_1_1 -> 684 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1647, 684 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1646, 1648 },
      -1,
   } },

   /* replace549_0_0 -> 0 in the cache */
   /* replace549_0_1 -> 1599 in the cache */
   /* replace549_0 -> 1632 in the cache */
   /* replace549_1 -> 684 in the cache */
   /* replace549 -> 1633 in the cache */

   /* ('iand', ('fge', 'a', '#b(is_a_number)'), ('fge', 'a', '#c(is_a_number)')) => ('fge', 'a', ('fmax', 'b', 'c')) */
   /* search550_0_0 -> 126 in the cache */
   /* search550_0_1 -> 1640 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 126, 1640 },
      -1,
   } },
   /* search550_1_0 -> 126 in the cache */
   /* search550_1_1 -> 1642 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 126, 1642 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1650, 1651 },
      -1,
   } },

   /* replace550_0 -> 126 in the cache */
   /* replace550_1_0 -> 127 in the cache */
   /* replace550_1_1 -> 129 in the cache */
   /* replace550_1 -> 1635 in the cache */
   /* replace550 -> 1636 in the cache */

   /* ('iand', ('fge', '#a(is_a_number)', 'c'), ('fge', '#b(is_a_number)', 'c')) => ('fge', ('fmin', 'a', 'b'), 'c') */
   /* search551_0_0 -> 1645 in the cache */
   /* search551_0_1 -> 684 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1645, 684 },
      -1,
   } },
   /* search551_1_0 -> 1647 in the cache */
   /* search551_1_1 -> 684 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1647, 684 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1653, 1654 },
      -1,
   } },

   /* replace551_0_0 -> 0 in the cache */
   /* replace551_0_1 -> 1599 in the cache */
   /* replace551_0 -> 1638 in the cache */
   /* replace551_1 -> 684 in the cache */
   /* replace551 -> 1639 in the cache */

   /* ('ior', ('ilt(is_used_once)', 'a', 'b'), ('ilt', 'a', 'c')) => ('ilt', 'a', ('imax', 'b', 'c')) */
   /* search552_0_0 -> 126 in the cache */
   /* search552_0_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 126, 127 },
      0,
   } },
   /* search552_1_0 -> 126 in the cache */
   /* search552_1_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 126, 129 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1656, 1657 },
      -1,
   } },

   /* replace552_0 -> 126 in the cache */
   /* replace552_1_0 -> 127 in the cache */
   /* replace552_1_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 127, 129 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 126, 1659 },
      -1,
   } },

   /* ('ior', ('ilt(is_used_once)', 'a', 'c'), ('ilt', 'b', 'c')) => ('ilt', ('imin', 'a', 'b'), 'c') */
   /* search553_0_0 -> 0 in the cache */
   /* search553_0_1 -> 684 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 0, 684 },
      0,
   } },
   /* search553_1_0 -> 1599 in the cache */
   /* search553_1_1 -> 684 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 1599, 684 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1661, 1662 },
      -1,
   } },

   /* replace553_0_0 -> 0 in the cache */
   /* replace553_0_1 -> 1599 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_imin,
      0, 1,
      { 0, 1599 },
      -1,
   } },
   /* replace553_1 -> 684 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 1664, 684 },
      -1,
   } },

   /* ('ior', ('ige(is_used_once)', 'a', 'b'), ('ige', 'a', 'c')) => ('ige', 'a', ('imin', 'b', 'c')) */
   /* search554_0_0 -> 126 in the cache */
   /* search554_0_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 126, 127 },
      0,
   } },
   /* search554_1_0 -> 126 in the cache */
   /* search554_1_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 126, 129 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1666, 1667 },
      -1,
   } },

   /* replace554_0 -> 126 in the cache */
   /* replace554_1_0 -> 127 in the cache */
   /* replace554_1_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imin,
      0, 1,
      { 127, 129 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 1,
      { 126, 1669 },
      -1,
   } },

   /* ('ior', ('ige(is_used_once)', 'a', 'c'), ('ige', 'b', 'c')) => ('ige', ('imax', 'a', 'b'), 'c') */
   /* search555_0_0 -> 0 in the cache */
   /* search555_0_1 -> 684 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 0, 684 },
      0,
   } },
   /* search555_1_0 -> 1599 in the cache */
   /* search555_1_1 -> 684 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 1599, 684 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1671, 1672 },
      -1,
   } },

   /* replace555_0_0 -> 0 in the cache */
   /* replace555_0_1 -> 1599 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 0, 1599 },
      -1,
   } },
   /* replace555_1 -> 684 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 1,
      { 1674, 684 },
      -1,
   } },

   /* ('ior', ('ult(is_used_once)', 'a', 'b'), ('ult', 'a', 'c')) => ('ult', 'a', ('umax', 'b', 'c')) */
   /* search556_0_0 -> 126 in the cache */
   /* search556_0_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 126, 127 },
      0,
   } },
   /* search556_1_0 -> 126 in the cache */
   /* search556_1_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 126, 129 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1676, 1677 },
      -1,
   } },

   /* replace556_0 -> 126 in the cache */
   /* replace556_1_0 -> 127 in the cache */
   /* replace556_1_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_umax,
      0, 1,
      { 127, 129 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 1,
      { 126, 1679 },
      -1,
   } },

   /* ('ior', ('ult(is_used_once)', 'a', 'c'), ('ult', 'b', 'c')) => ('ult', ('umin', 'a', 'b'), 'c') */
   /* search557_0_0 -> 0 in the cache */
   /* search557_0_1 -> 684 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 0, 684 },
      0,
   } },
   /* search557_1_0 -> 1599 in the cache */
   /* search557_1_1 -> 684 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 1599, 684 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1681, 1682 },
      -1,
   } },

   /* replace557_0_0 -> 0 in the cache */
   /* replace557_0_1 -> 1599 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_umin,
      0, 1,
      { 0, 1599 },
      -1,
   } },
   /* replace557_1 -> 684 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 1,
      { 1684, 684 },
      -1,
   } },

   /* ('ior', ('uge(is_used_once)', 'a', 'b'), ('uge', 'a', 'c')) => ('uge', 'a', ('umin', 'b', 'c')) */
   /* search558_0_0 -> 126 in the cache */
   /* search558_0_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 126, 127 },
      0,
   } },
   /* search558_1_0 -> 126 in the cache */
   /* search558_1_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 126, 129 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1686, 1687 },
      -1,
   } },

   /* replace558_0 -> 126 in the cache */
   /* replace558_1_0 -> 127 in the cache */
   /* replace558_1_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_umin,
      0, 1,
      { 127, 129 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 1,
      { 126, 1689 },
      -1,
   } },

   /* ('ior', ('uge(is_used_once)', 'a', 'c'), ('uge', 'b', 'c')) => ('uge', ('umax', 'a', 'b'), 'c') */
   /* search559_0_0 -> 0 in the cache */
   /* search559_0_1 -> 684 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 0, 684 },
      0,
   } },
   /* search559_1_0 -> 1599 in the cache */
   /* search559_1_1 -> 684 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 1599, 684 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1691, 1692 },
      -1,
   } },

   /* replace559_0_0 -> 0 in the cache */
   /* replace559_0_1 -> 1599 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_umax,
      0, 1,
      { 0, 1599 },
      -1,
   } },
   /* replace559_1 -> 684 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 1,
      { 1694, 684 },
      -1,
   } },

   /* ('iand', ('ilt(is_used_once)', 'a', 'b'), ('ilt', 'a', 'c')) => ('ilt', 'a', ('imin', 'b', 'c')) */
   /* search560_0_0 -> 126 in the cache */
   /* search560_0_1 -> 127 in the cache */
   /* search560_0 -> 1656 in the cache */
   /* search560_1_0 -> 126 in the cache */
   /* search560_1_1 -> 129 in the cache */
   /* search560_1 -> 1657 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1656, 1657 },
      -1,
   } },

   /* replace560_0 -> 126 in the cache */
   /* replace560_1_0 -> 127 in the cache */
   /* replace560_1_1 -> 129 in the cache */
   /* replace560_1 -> 1669 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 126, 1669 },
      -1,
   } },

   /* ('iand', ('ilt(is_used_once)', 'a', 'c'), ('ilt', 'b', 'c')) => ('ilt', ('imax', 'a', 'b'), 'c') */
   /* search561_0_0 -> 0 in the cache */
   /* search561_0_1 -> 684 in the cache */
   /* search561_0 -> 1661 in the cache */
   /* search561_1_0 -> 1599 in the cache */
   /* search561_1_1 -> 684 in the cache */
   /* search561_1 -> 1662 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1661, 1662 },
      -1,
   } },

   /* replace561_0_0 -> 0 in the cache */
   /* replace561_0_1 -> 1599 in the cache */
   /* replace561_0 -> 1674 in the cache */
   /* replace561_1 -> 684 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 1674, 684 },
      -1,
   } },

   /* ('iand', ('ige(is_used_once)', 'a', 'b'), ('ige', 'a', 'c')) => ('ige', 'a', ('imax', 'b', 'c')) */
   /* search562_0_0 -> 126 in the cache */
   /* search562_0_1 -> 127 in the cache */
   /* search562_0 -> 1666 in the cache */
   /* search562_1_0 -> 126 in the cache */
   /* search562_1_1 -> 129 in the cache */
   /* search562_1 -> 1667 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1666, 1667 },
      -1,
   } },

   /* replace562_0 -> 126 in the cache */
   /* replace562_1_0 -> 127 in the cache */
   /* replace562_1_1 -> 129 in the cache */
   /* replace562_1 -> 1659 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 1,
      { 126, 1659 },
      -1,
   } },

   /* ('iand', ('ige(is_used_once)', 'a', 'c'), ('ige', 'b', 'c')) => ('ige', ('imin', 'a', 'b'), 'c') */
   /* search563_0_0 -> 0 in the cache */
   /* search563_0_1 -> 684 in the cache */
   /* search563_0 -> 1671 in the cache */
   /* search563_1_0 -> 1599 in the cache */
   /* search563_1_1 -> 684 in the cache */
   /* search563_1 -> 1672 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1671, 1672 },
      -1,
   } },

   /* replace563_0_0 -> 0 in the cache */
   /* replace563_0_1 -> 1599 in the cache */
   /* replace563_0 -> 1664 in the cache */
   /* replace563_1 -> 684 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 1,
      { 1664, 684 },
      -1,
   } },

   /* ('iand', ('ult(is_used_once)', 'a', 'b'), ('ult', 'a', 'c')) => ('ult', 'a', ('umin', 'b', 'c')) */
   /* search564_0_0 -> 126 in the cache */
   /* search564_0_1 -> 127 in the cache */
   /* search564_0 -> 1676 in the cache */
   /* search564_1_0 -> 126 in the cache */
   /* search564_1_1 -> 129 in the cache */
   /* search564_1 -> 1677 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1676, 1677 },
      -1,
   } },

   /* replace564_0 -> 126 in the cache */
   /* replace564_1_0 -> 127 in the cache */
   /* replace564_1_1 -> 129 in the cache */
   /* replace564_1 -> 1689 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 1,
      { 126, 1689 },
      -1,
   } },

   /* ('iand', ('ult(is_used_once)', 'a', 'c'), ('ult', 'b', 'c')) => ('ult', ('umax', 'a', 'b'), 'c') */
   /* search565_0_0 -> 0 in the cache */
   /* search565_0_1 -> 684 in the cache */
   /* search565_0 -> 1681 in the cache */
   /* search565_1_0 -> 1599 in the cache */
   /* search565_1_1 -> 684 in the cache */
   /* search565_1 -> 1682 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1681, 1682 },
      -1,
   } },

   /* replace565_0_0 -> 0 in the cache */
   /* replace565_0_1 -> 1599 in the cache */
   /* replace565_0 -> 1694 in the cache */
   /* replace565_1 -> 684 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 1,
      { 1694, 684 },
      -1,
   } },

   /* ('iand', ('uge(is_used_once)', 'a', 'b'), ('uge', 'a', 'c')) => ('uge', 'a', ('umax', 'b', 'c')) */
   /* search566_0_0 -> 126 in the cache */
   /* search566_0_1 -> 127 in the cache */
   /* search566_0 -> 1686 in the cache */
   /* search566_1_0 -> 126 in the cache */
   /* search566_1_1 -> 129 in the cache */
   /* search566_1 -> 1687 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1686, 1687 },
      -1,
   } },

   /* replace566_0 -> 126 in the cache */
   /* replace566_1_0 -> 127 in the cache */
   /* replace566_1_1 -> 129 in the cache */
   /* replace566_1 -> 1679 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 1,
      { 126, 1679 },
      -1,
   } },

   /* ('iand', ('uge(is_used_once)', 'a', 'c'), ('uge', 'b', 'c')) => ('uge', ('umin', 'a', 'b'), 'c') */
   /* search567_0_0 -> 0 in the cache */
   /* search567_0_1 -> 684 in the cache */
   /* search567_0 -> 1691 in the cache */
   /* search567_1_0 -> 1599 in the cache */
   /* search567_1_1 -> 684 in the cache */
   /* search567_1 -> 1692 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1691, 1692 },
      -1,
   } },

   /* replace567_0_0 -> 0 in the cache */
   /* replace567_0_1 -> 1599 in the cache */
   /* replace567_0 -> 1684 in the cache */
   /* replace567_1 -> 684 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 1,
      { 1684, 684 },
      -1,
   } },

   /* ('ior', ('ior(is_used_once)', ('flt(is_used_once)', 'a', 'c'), 'd'), ('flt', 'b', 'c')) => ('ior', ('flt', ('!fmin', 'a', 'b'), 'c'), 'd') */
   /* search568_0_0_0 -> 0 in the cache */
   /* search568_0_0_1 -> 684 in the cache */
   /* search568_0_0 -> 1598 in the cache */
   { .variable = {
      { nir_search_value_variable, 1 },
      2, /* d */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 1598, 1712 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      3, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search568_1_1 -> 684 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1714, 684 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 1713, 1715 },
      -1,
   } },

   /* replace568_0_0_0 -> 0 in the cache */
   /* replace568_0_0_1 -> 1714 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      true,
      false,
      nir_op_fmin,
      1, 1,
      { 0, 1714 },
      -1,
   } },
   /* replace568_0_1 -> 684 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 1717, 684 },
      -1,
   } },
   /* replace568_1 -> 1712 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 1718, 1712 },
      -1,
   } },

   /* ('ior', ('ior(is_used_once)', ('flt', 'a', 'c'), 'd'), ('flt(is_used_once)', 'b', 'c')) => ('ior', ('flt', ('!fmin', 'a', 'b'), 'c'), 'd') */
   /* search569_0_0_0 -> 0 in the cache */
   /* search569_0_0_1 -> 684 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 0, 684 },
      -1,
   } },
   /* search569_0_1 -> 1712 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 1720, 1712 },
      0,
   } },
   /* search569_1_0 -> 1714 in the cache */
   /* search569_1_1 -> 684 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1714, 684 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 1721, 1722 },
      -1,
   } },

   /* replace569_0_0_0 -> 0 in the cache */
   /* replace569_0_0_1 -> 1714 in the cache */
   /* replace569_0_0 -> 1717 in the cache */
   /* replace569_0_1 -> 684 in the cache */
   /* replace569_0 -> 1718 in the cache */
   /* replace569_1 -> 1712 in the cache */
   /* replace569 -> 1719 in the cache */

   /* ('ior', ('ior(is_used_once)', ('flt(is_used_once)', 'a', 'b'), 'd'), ('flt', 'a', 'c')) => ('ior', ('flt', 'a', ('!fmax', 'b', 'c')), 'd') */
   /* search570_0_0_0 -> 149 in the cache */
   /* search570_0_0_1 -> 150 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 149, 150 },
      0,
   } },
   /* search570_0_1 -> 1712 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 1724, 1712 },
      0,
   } },
   /* search570_1_0 -> 149 in the cache */
   { .variable = {
      { nir_search_value_variable, -4 },
      3, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 149, 1726 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 1725, 1727 },
      -1,
   } },

   /* replace570_0_0 -> 149 in the cache */
   /* replace570_0_1_0 -> 150 in the cache */
   /* replace570_0_1_1 -> 1726 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      true,
      false,
      nir_op_fmax,
      1, 1,
      { 150, 1726 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 149, 1729 },
      -1,
   } },
   /* replace570_1 -> 1712 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 1730, 1712 },
      -1,
   } },

   /* ('ior', ('ior(is_used_once)', ('flt', 'a', 'b'), 'd'), ('flt(is_used_once)', 'a', 'c')) => ('ior', ('flt', 'a', ('!fmax', 'b', 'c')), 'd') */
   /* search571_0_0_0 -> 149 in the cache */
   /* search571_0_0_1 -> 150 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 149, 150 },
      -1,
   } },
   /* search571_0_1 -> 1712 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 1732, 1712 },
      0,
   } },
   /* search571_1_0 -> 149 in the cache */
   /* search571_1_1 -> 1726 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 149, 1726 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 1733, 1734 },
      -1,
   } },

   /* replace571_0_0 -> 149 in the cache */
   /* replace571_0_1_0 -> 150 in the cache */
   /* replace571_0_1_1 -> 1726 in the cache */
   /* replace571_0_1 -> 1729 in the cache */
   /* replace571_0 -> 1730 in the cache */
   /* replace571_1 -> 1712 in the cache */
   /* replace571 -> 1731 in the cache */

   /* ('ior', ('flt', 'a(is_a_number)', 'b(is_a_number)'), ('flt', 'b', 'a')) => ('fneu', 'a', 'b') */
   /* search572_0_0 -> 1042 in the cache */
   /* search572_0_1 -> 1043 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1042, 1043 },
      -1,
   } },
   /* search572_1_0 -> 3 in the cache */
   /* search572_1_1 -> 0 in the cache */
   /* search572_1 -> 1078 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1736, 1078 },
      -1,
   } },

   /* replace572_0 -> 0 in the cache */
   /* replace572_1 -> 3 in the cache */
   /* replace572 -> 1052 in the cache */

   /* ('umin', ('iand', 'a', '#b(is_pos_power_of_two)'), ('iand', 'c', 'b')) => ('iand', ('iand', 'a', 'b'), ('iand', 'c', 'b')) */
   /* search573_0_0 -> 0 in the cache */
   /* search573_0_1 -> 1 in the cache */
   /* search573_0 -> 199 in the cache */
   /* search573_1_0 -> 140 in the cache */
   /* search573_1_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iand,
      2, 1,
      { 140, 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_umin,
      0, 3,
      { 199, 1738 },
      -1,
   } },

   /* replace573_0_0 -> 0 in the cache */
   /* replace573_0_1 -> 3 in the cache */
   /* replace573_0 -> 201 in the cache */
   /* replace573_1_0 -> 140 in the cache */
   /* replace573_1_1 -> 3 in the cache */
   /* replace573_1 -> 1738 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 201, 1738 },
      -1,
   } },

   /* ('ior', ('flt(is_used_once)', 0.0, 'a@16'), ('flt', 'b@16', 0.0)) => ('flt', 0.0, ('fmax', 'a', ('fneg', 'b'))) */
   /* search574_0_0 -> 113 in the cache */
   /* search574_0_1 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 113, 11 },
      0,
   } },
   /* search574_1_0 -> 258 in the cache */
   /* search574_1_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 258, 113 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1741, 1742 },
      -1,
   } },

   /* replace574_0 -> 113 in the cache */
   /* replace574_1_0 -> 11 in the cache */
   /* replace574_1_1_0 -> 258 in the cache */
   /* replace574_1_1 -> 534 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 11, 534 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 113, 1744 },
      -1,
   } },

   /* ('ior', ('flt', 0.0, 'a@16'), ('flt(is_used_once)', 'b@16', 0.0)) => ('flt', 0.0, ('fmax', 'a', ('fneg', 'b'))) */
   /* search575_0_0 -> 113 in the cache */
   /* search575_0_1 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 113, 11 },
      -1,
   } },
   /* search575_1_0 -> 258 in the cache */
   /* search575_1_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 258, 113 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1746, 1747 },
      -1,
   } },

   /* replace575_0 -> 113 in the cache */
   /* replace575_1_0 -> 11 in the cache */
   /* replace575_1_1_0 -> 258 in the cache */
   /* replace575_1_1 -> 534 in the cache */
   /* replace575_1 -> 1744 in the cache */
   /* replace575 -> 1745 in the cache */

   /* ('ior', ('fge(is_used_once)', 0.0, 'a@16'), ('fge', 'b@16', 0.0)) => ('fge', 0.0, ('fmin', 'a', ('fneg', 'b'))) */
   /* search576_0_0 -> 113 in the cache */
   /* search576_0_1 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 113, 11 },
      0,
   } },
   /* search576_1_0 -> 258 in the cache */
   /* search576_1_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 258, 113 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1749, 1750 },
      -1,
   } },

   /* replace576_0 -> 113 in the cache */
   /* replace576_1_0 -> 11 in the cache */
   /* replace576_1_1_0 -> 258 in the cache */
   /* replace576_1_1 -> 534 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 11, 534 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 113, 1752 },
      -1,
   } },

   /* ('ior', ('fge', 0.0, 'a@16'), ('fge(is_used_once)', 'b@16', 0.0)) => ('fge', 0.0, ('fmin', 'a', ('fneg', 'b'))) */
   /* search577_0_0 -> 113 in the cache */
   /* search577_0_1 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 113, 11 },
      -1,
   } },
   /* search577_1_0 -> 258 in the cache */
   /* search577_1_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 258, 113 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1754, 1755 },
      -1,
   } },

   /* replace577_0 -> 113 in the cache */
   /* replace577_1_0 -> 11 in the cache */
   /* replace577_1_1_0 -> 258 in the cache */
   /* replace577_1_1 -> 534 in the cache */
   /* replace577_1 -> 1752 in the cache */
   /* replace577 -> 1753 in the cache */

   /* ('~iand', ('flt(is_used_once)', 0.0, 'a@16'), ('flt', 'b@16', 0.0)) => ('flt', 0.0, ('fmin', 'a', ('fneg', 'b'))) */
   /* search578_0_0 -> 113 in the cache */
   /* search578_0_1 -> 11 in the cache */
   /* search578_0 -> 1741 in the cache */
   /* search578_1_0 -> 258 in the cache */
   /* search578_1_1 -> 113 in the cache */
   /* search578_1 -> 1742 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1741, 1742 },
      -1,
   } },

   /* replace578_0 -> 113 in the cache */
   /* replace578_1_0 -> 11 in the cache */
   /* replace578_1_1_0 -> 258 in the cache */
   /* replace578_1_1 -> 534 in the cache */
   /* replace578_1 -> 1752 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 113, 1752 },
      -1,
   } },

   /* ('~iand', ('flt', 0.0, 'a@16'), ('flt(is_used_once)', 'b@16', 0.0)) => ('flt', 0.0, ('fmin', 'a', ('fneg', 'b'))) */
   /* search579_0_0 -> 113 in the cache */
   /* search579_0_1 -> 11 in the cache */
   /* search579_0 -> 1746 in the cache */
   /* search579_1_0 -> 258 in the cache */
   /* search579_1_1 -> 113 in the cache */
   /* search579_1 -> 1747 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1746, 1747 },
      -1,
   } },

   /* replace579_0 -> 113 in the cache */
   /* replace579_1_0 -> 11 in the cache */
   /* replace579_1_1_0 -> 258 in the cache */
   /* replace579_1_1 -> 534 in the cache */
   /* replace579_1 -> 1752 in the cache */
   /* replace579 -> 1758 in the cache */

   /* ('~iand', ('fge(is_used_once)', 0.0, 'a@16'), ('fge', 'b@16', 0.0)) => ('fge', 0.0, ('fmax', 'a', ('fneg', 'b'))) */
   /* search580_0_0 -> 113 in the cache */
   /* search580_0_1 -> 11 in the cache */
   /* search580_0 -> 1749 in the cache */
   /* search580_1_0 -> 258 in the cache */
   /* search580_1_1 -> 113 in the cache */
   /* search580_1 -> 1750 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1749, 1750 },
      -1,
   } },

   /* replace580_0 -> 113 in the cache */
   /* replace580_1_0 -> 11 in the cache */
   /* replace580_1_1_0 -> 258 in the cache */
   /* replace580_1_1 -> 534 in the cache */
   /* replace580_1 -> 1744 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 113, 1744 },
      -1,
   } },

   /* ('~iand', ('fge', 0.0, 'a@16'), ('fge(is_used_once)', 'b@16', 0.0)) => ('fge', 0.0, ('fmax', 'a', ('fneg', 'b'))) */
   /* search581_0_0 -> 113 in the cache */
   /* search581_0_1 -> 11 in the cache */
   /* search581_0 -> 1754 in the cache */
   /* search581_1_0 -> 258 in the cache */
   /* search581_1_1 -> 113 in the cache */
   /* search581_1 -> 1755 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1754, 1755 },
      -1,
   } },

   /* replace581_0 -> 113 in the cache */
   /* replace581_1_0 -> 11 in the cache */
   /* replace581_1_1_0 -> 258 in the cache */
   /* replace581_1_1 -> 534 in the cache */
   /* replace581_1 -> 1744 in the cache */
   /* replace581 -> 1761 in the cache */

   /* ('bcsel@16', ('feq', 'a', 0.0), 1.0, ('i2f16', ('iadd', ('b2i16', ('flt', 0.0, 'a@16')), ('ineg', ('b2i16', ('flt', 'a@16', 0.0)))))) => ('i2f16', ('iadd', ('b2i32', ('!fge', 'a', 0.0)), ('ineg', ('b2i32', ('!flt', 'a', 0.0))))) */
   /* search582_0_0 -> 11 in the cache */
   /* search582_0_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 11, 113 },
      -1,
   } },
   /* search582_1 -> 481 in the cache */
   /* search582_2_0_0_0_0 -> 113 in the cache */
   /* search582_2_0_0_0_1 -> 11 in the cache */
   /* search582_2_0_0_0 -> 1746 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_b2i16,
      -1, 0,
      { 1746 },
      -1,
   } },
   /* search582_2_0_1_0_0_0 -> 11 in the cache */
   /* search582_2_0_1_0_0_1 -> 113 in the cache */
   /* search582_2_0_1_0_0 -> 689 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_b2i16,
      -1, 0,
      { 689 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 1765 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 1764, 1766 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2f16,
      -1, 1,
      { 1767 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 1763, 481, 1768 },
      -1,
   } },

   /* replace582_0_0_0_0 -> 11 in the cache */
   /* replace582_0_0_0_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      nir_op_fge,
      -1, 0,
      { 11, 113 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_b2i32,
      -1, 0,
      { 1770 },
      -1,
   } },
   /* replace582_0_1_0_0_0 -> 11 in the cache */
   /* replace582_0_1_0_0_1 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      nir_op_flt,
      -1, 0,
      { 11, 113 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_b2i32,
      -1, 0,
      { 1772 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 1773 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 1771, 1774 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2f16,
      -1, 1,
      { 1775 },
      -1,
   } },

   /* ('bcsel', 'a', ('b2f(is_used_once)', 'b@16'), ('b2f', 'c@16')) => ('b2f', ('bcsel', 'a', 'b', 'c')) */
   /* search583_0 -> 760 in the cache */
   /* search583_1_0 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 258 },
      0,
   } },
   /* search583_2_0 -> 469 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 469 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 760, 1777, 1778 },
      -1,
   } },

   /* replace583_0_0 -> 760 in the cache */
   /* replace583_0_1 -> 258 in the cache */
   /* replace583_0_2 -> 469 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 760, 258, 469 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 1780 },
      -1,
   } },

   /* ('~i2f16', ('f2i', 'a@16')) => ('ftrunc', 'a') */
   /* search584_0_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_f2i,
      -1, 0,
      { 11 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_i2f16,
      -1, 0,
      { 1782 },
      -1,
   } },

   /* replace584_0 -> 11 in the cache */
   /* replace584 -> 688 in the cache */

   /* ('~f2i16', ('i2f', 'a@16')) => a */
   /* search585_0_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_i2f,
      -1, 0,
      { 11 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_f2i16,
      -1, 0,
      { 1784 },
      -1,
   } },

   /* replace585 -> 11 in the cache */

   /* ('~f2i16', ('u2f', 'a@16')) => a */
   /* search586_0_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_u2f,
      -1, 0,
      { 11 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_f2i16,
      -1, 0,
      { 1786 },
      -1,
   } },

   /* replace586 -> 11 in the cache */

   /* ('~f2u16', ('i2f', 'a@16')) => a */
   /* search587_0_0 -> 11 in the cache */
   /* search587_0 -> 1784 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_f2u16,
      -1, 0,
      { 1784 },
      -1,
   } },

   /* replace587 -> 11 in the cache */

   /* ('~f2u16', ('u2f', 'a@16')) => a */
   /* search588_0_0 -> 11 in the cache */
   /* search588_0 -> 1786 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_f2u16,
      -1, 0,
      { 1786 },
      -1,
   } },

   /* replace588 -> 11 in the cache */

   /* ('fadd', ('b2f16', ('flt', 0.0, 'a@16')), ('fneg', ('b2f16', ('flt', 'a@16', 0.0)))) => ('fsign', 'a') */
   /* search589_0_0_0 -> 113 in the cache */
   /* search589_0_0_1 -> 11 in the cache */
   /* search589_0_0 -> 1746 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_b2f16,
      -1, 0,
      { 1746 },
      -1,
   } },
   /* search589_1_0_0_0 -> 11 in the cache */
   /* search589_1_0_0_1 -> 113 in the cache */
   /* search589_1_0_0 -> 689 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_b2f16,
      -1, 0,
      { 689 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 1791 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 1790, 1792 },
      -1,
   } },

   /* replace589_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fsign,
      -1, 0,
      { 11 },
      -1,
   } },

   /* ('iadd', ('b2i16', ('flt', 0, 'a@16')), ('ineg', ('b2i16', ('flt', 'a@16', 0)))) => ('f2i16', ('fsign', 'a')) */
   /* search590_0_0_0 -> 856 in the cache */
   /* search590_0_0_1 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 856, 11 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_b2i16,
      -1, 0,
      { 1795 },
      -1,
   } },
   /* search590_1_0_0_0 -> 11 in the cache */
   /* search590_1_0_0_1 -> 856 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 11, 856 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_b2i16,
      -1, 0,
      { 1797 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 1798 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 1796, 1799 },
      -1,
   } },

   /* replace590_0_0 -> 11 in the cache */
   /* replace590_0 -> 1794 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2i16,
      -1, 0,
      { 1794 },
      -1,
   } },

   /* ('~f2f16', ('f2f', 'a')) => ('f2f16', 'a') */
   /* search591_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_f2f,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 1802 },
      -1,
   } },

   /* replace591_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 32 },
      -1,
   } },

   /* ('~f2f16', ('u2f', 'a')) => ('u2f16', 'a') */
   /* search592_0_0 -> 32 in the cache */
   /* search592_0 -> 104 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 104 },
      -1,
   } },

   /* replace592_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2f16,
      -1, 0,
      { 32 },
      -1,
   } },

   /* ('~f2f16', ('i2f', 'a')) => ('i2f16', 'a') */
   /* search593_0_0 -> 32 in the cache */
   /* search593_0 -> 1241 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 1241 },
      -1,
   } },

   /* replace593_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2f16,
      -1, 0,
      { 32 },
      -1,
   } },

   /* ('~f2u16', ('f2f', 'a')) => ('f2u16', 'a') */
   /* search594_0_0 -> 32 in the cache */
   /* search594_0 -> 1802 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_f2u16,
      -1, 0,
      { 1802 },
      -1,
   } },

   /* replace594_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2u16,
      -1, 0,
      { 32 },
      -1,
   } },

   /* ('~f2i16', ('f2f', 'a')) => ('f2i16', 'a') */
   /* search595_0_0 -> 32 in the cache */
   /* search595_0 -> 1802 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_f2i16,
      -1, 0,
      { 1802 },
      -1,
   } },

   /* replace595_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2i16,
      -1, 0,
      { 32 },
      -1,
   } },

   /* ('f2f16', ('f2f32', 'a@16')) => a */
   /* search596_0_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 11 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 1813 },
      -1,
   } },

   /* replace596 -> 11 in the cache */

   /* ('i2i16', ('i2i32', 'a@16')) => a */
   /* search597_0_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 11 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 1815 },
      -1,
   } },

   /* replace597 -> 11 in the cache */

   /* ('u2u16', ('u2u32', 'a@16')) => a */
   /* search598_0_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 11 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 1817 },
      -1,
   } },

   /* replace598 -> 11 in the cache */

   /* ('f2u32', ('f2f32', 'a@16')) => ('f2u32', 'a') */
   /* search599_0_0 -> 11 in the cache */
   /* search599_0 -> 1813 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2u32,
      -1, 0,
      { 1813 },
      -1,
   } },

   /* replace599_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2u32,
      -1, 0,
      { 11 },
      -1,
   } },

   /* ('f2i32', ('f2f32', 'a@16')) => ('f2i32', 'a') */
   /* search600_0_0 -> 11 in the cache */
   /* search600_0 -> 1813 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2i32,
      -1, 0,
      { 1813 },
      -1,
   } },

   /* replace600_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2i32,
      -1, 0,
      { 11 },
      -1,
   } },

   /* ('f2f16', ('u2f32', 'a')) => ('u2f16', 'a') */
   /* search601_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2f32,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 1823 },
      -1,
   } },

   /* replace601_0 -> 32 in the cache */
   /* replace601 -> 1806 in the cache */

   /* ('f2f16', ('i2f32', 'a')) => ('i2f16', 'a') */
   /* search602_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2f32,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 1825 },
      -1,
   } },

   /* replace602_0 -> 32 in the cache */
   /* replace602 -> 1808 in the cache */

   /* ('u2f32', ('u2u32', 'a@16')) => ('u2f32', 'a') */
   /* search603_0_0 -> 11 in the cache */
   /* search603_0 -> 1817 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2f32,
      -1, 0,
      { 1817 },
      -1,
   } },

   /* replace603_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2f32,
      -1, 0,
      { 11 },
      -1,
   } },

   /* ('i2f32', ('i2i32', 'a@16')) => ('i2f32', 'a') */
   /* search604_0_0 -> 11 in the cache */
   /* search604_0 -> 1815 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2f32,
      -1, 0,
      { 1815 },
      -1,
   } },

   /* replace604_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2f32,
      -1, 0,
      { 11 },
      -1,
   } },

   /* ('f2f16', ('f2f64', 'a@16')) => a */
   /* search605_0_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_f2f64,
      -1, 0,
      { 11 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 1831 },
      -1,
   } },

   /* replace605 -> 11 in the cache */

   /* ('i2i16', ('i2i64', 'a@16')) => a */
   /* search606_0_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 11 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 1833 },
      -1,
   } },

   /* replace606 -> 11 in the cache */

   /* ('u2u16', ('u2u64', 'a@16')) => a */
   /* search607_0_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 11 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 1835 },
      -1,
   } },

   /* replace607 -> 11 in the cache */

   /* ('f2u64', ('f2f64', 'a@16')) => ('f2u64', 'a') */
   /* search608_0_0 -> 11 in the cache */
   /* search608_0 -> 1831 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_f2u64,
      -1, 0,
      { 1831 },
      -1,
   } },

   /* replace608_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_f2u64,
      -1, 0,
      { 11 },
      -1,
   } },

   /* ('f2i64', ('f2f64', 'a@16')) => ('f2i64', 'a') */
   /* search609_0_0 -> 11 in the cache */
   /* search609_0 -> 1831 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_f2i64,
      -1, 0,
      { 1831 },
      -1,
   } },

   /* replace609_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_f2i64,
      -1, 0,
      { 11 },
      -1,
   } },

   /* ('f2f16', ('u2f64', 'a')) => ('u2f16', 'a') */
   /* search610_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2f64,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 1841 },
      -1,
   } },

   /* replace610_0 -> 32 in the cache */
   /* replace610 -> 1806 in the cache */

   /* ('f2f16', ('i2f64', 'a')) => ('i2f16', 'a') */
   /* search611_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2f64,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 1843 },
      -1,
   } },

   /* replace611_0 -> 32 in the cache */
   /* replace611 -> 1808 in the cache */

   /* ('u2f64', ('u2u64', 'a@16')) => ('u2f64', 'a') */
   /* search612_0_0 -> 11 in the cache */
   /* search612_0 -> 1835 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2f64,
      -1, 0,
      { 1835 },
      -1,
   } },

   /* replace612_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2f64,
      -1, 0,
      { 11 },
      -1,
   } },

   /* ('i2f64', ('i2i64', 'a@16')) => ('i2f64', 'a') */
   /* search613_0_0 -> 11 in the cache */
   /* search613_0 -> 1833 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2f64,
      -1, 0,
      { 1833 },
      -1,
   } },

   /* replace613_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2f64,
      -1, 0,
      { 11 },
      -1,
   } },

   /* ('ior', ('flt(is_used_once)', 0.0, 'a@32'), ('flt', 'b@32', 0.0)) => ('flt', 0.0, ('fmax', 'a', ('fneg', 'b'))) */
   /* search614_0_0 -> 115 in the cache */
   /* search614_0_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 115, 16 },
      0,
   } },
   /* search614_1_0 -> 36 in the cache */
   /* search614_1_1 -> 115 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 36, 115 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1849, 1850 },
      -1,
   } },

   /* replace614_0 -> 115 in the cache */
   /* replace614_1_0 -> 16 in the cache */
   /* replace614_1_1_0 -> 36 in the cache */
   /* replace614_1_1 -> 600 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 16, 600 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 115, 1852 },
      -1,
   } },

   /* ('ior', ('flt', 0.0, 'a@32'), ('flt(is_used_once)', 'b@32', 0.0)) => ('flt', 0.0, ('fmax', 'a', ('fneg', 'b'))) */
   /* search615_0_0 -> 115 in the cache */
   /* search615_0_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 115, 16 },
      -1,
   } },
   /* search615_1_0 -> 36 in the cache */
   /* search615_1_1 -> 115 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 36, 115 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1854, 1855 },
      -1,
   } },

   /* replace615_0 -> 115 in the cache */
   /* replace615_1_0 -> 16 in the cache */
   /* replace615_1_1_0 -> 36 in the cache */
   /* replace615_1_1 -> 600 in the cache */
   /* replace615_1 -> 1852 in the cache */
   /* replace615 -> 1853 in the cache */

   /* ('ior', ('fge(is_used_once)', 0.0, 'a@32'), ('fge', 'b@32', 0.0)) => ('fge', 0.0, ('fmin', 'a', ('fneg', 'b'))) */
   /* search616_0_0 -> 115 in the cache */
   /* search616_0_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 115, 16 },
      0,
   } },
   /* search616_1_0 -> 36 in the cache */
   /* search616_1_1 -> 115 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 36, 115 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1857, 1858 },
      -1,
   } },

   /* replace616_0 -> 115 in the cache */
   /* replace616_1_0 -> 16 in the cache */
   /* replace616_1_1_0 -> 36 in the cache */
   /* replace616_1_1 -> 600 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 16, 600 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 115, 1860 },
      -1,
   } },

   /* ('ior', ('fge', 0.0, 'a@32'), ('fge(is_used_once)', 'b@32', 0.0)) => ('fge', 0.0, ('fmin', 'a', ('fneg', 'b'))) */
   /* search617_0_0 -> 115 in the cache */
   /* search617_0_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 115, 16 },
      -1,
   } },
   /* search617_1_0 -> 36 in the cache */
   /* search617_1_1 -> 115 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 36, 115 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1862, 1863 },
      -1,
   } },

   /* replace617_0 -> 115 in the cache */
   /* replace617_1_0 -> 16 in the cache */
   /* replace617_1_1_0 -> 36 in the cache */
   /* replace617_1_1 -> 600 in the cache */
   /* replace617_1 -> 1860 in the cache */
   /* replace617 -> 1861 in the cache */

   /* ('~iand', ('flt(is_used_once)', 0.0, 'a@32'), ('flt', 'b@32', 0.0)) => ('flt', 0.0, ('fmin', 'a', ('fneg', 'b'))) */
   /* search618_0_0 -> 115 in the cache */
   /* search618_0_1 -> 16 in the cache */
   /* search618_0 -> 1849 in the cache */
   /* search618_1_0 -> 36 in the cache */
   /* search618_1_1 -> 115 in the cache */
   /* search618_1 -> 1850 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1849, 1850 },
      -1,
   } },

   /* replace618_0 -> 115 in the cache */
   /* replace618_1_0 -> 16 in the cache */
   /* replace618_1_1_0 -> 36 in the cache */
   /* replace618_1_1 -> 600 in the cache */
   /* replace618_1 -> 1860 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 115, 1860 },
      -1,
   } },

   /* ('~iand', ('flt', 0.0, 'a@32'), ('flt(is_used_once)', 'b@32', 0.0)) => ('flt', 0.0, ('fmin', 'a', ('fneg', 'b'))) */
   /* search619_0_0 -> 115 in the cache */
   /* search619_0_1 -> 16 in the cache */
   /* search619_0 -> 1854 in the cache */
   /* search619_1_0 -> 36 in the cache */
   /* search619_1_1 -> 115 in the cache */
   /* search619_1 -> 1855 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1854, 1855 },
      -1,
   } },

   /* replace619_0 -> 115 in the cache */
   /* replace619_1_0 -> 16 in the cache */
   /* replace619_1_1_0 -> 36 in the cache */
   /* replace619_1_1 -> 600 in the cache */
   /* replace619_1 -> 1860 in the cache */
   /* replace619 -> 1866 in the cache */

   /* ('~iand', ('fge(is_used_once)', 0.0, 'a@32'), ('fge', 'b@32', 0.0)) => ('fge', 0.0, ('fmax', 'a', ('fneg', 'b'))) */
   /* search620_0_0 -> 115 in the cache */
   /* search620_0_1 -> 16 in the cache */
   /* search620_0 -> 1857 in the cache */
   /* search620_1_0 -> 36 in the cache */
   /* search620_1_1 -> 115 in the cache */
   /* search620_1 -> 1858 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1857, 1858 },
      -1,
   } },

   /* replace620_0 -> 115 in the cache */
   /* replace620_1_0 -> 16 in the cache */
   /* replace620_1_1_0 -> 36 in the cache */
   /* replace620_1_1 -> 600 in the cache */
   /* replace620_1 -> 1852 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 115, 1852 },
      -1,
   } },

   /* ('~iand', ('fge', 0.0, 'a@32'), ('fge(is_used_once)', 'b@32', 0.0)) => ('fge', 0.0, ('fmax', 'a', ('fneg', 'b'))) */
   /* search621_0_0 -> 115 in the cache */
   /* search621_0_1 -> 16 in the cache */
   /* search621_0 -> 1862 in the cache */
   /* search621_1_0 -> 36 in the cache */
   /* search621_1_1 -> 115 in the cache */
   /* search621_1 -> 1863 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1862, 1863 },
      -1,
   } },

   /* replace621_0 -> 115 in the cache */
   /* replace621_1_0 -> 16 in the cache */
   /* replace621_1_1_0 -> 36 in the cache */
   /* replace621_1_1 -> 600 in the cache */
   /* replace621_1 -> 1852 in the cache */
   /* replace621 -> 1869 in the cache */

   /* ('bcsel@32', ('feq', 'a', 0.0), 1.0, ('i2f32', ('iadd', ('b2i32', ('flt', 0.0, 'a@32')), ('ineg', ('b2i32', ('flt', 'a@32', 0.0)))))) => ('i2f32', ('iadd', ('b2i32', ('!fge', 'a', 0.0)), ('ineg', ('b2i32', ('!flt', 'a', 0.0))))) */
   /* search622_0_0 -> 16 in the cache */
   /* search622_0_1 -> 115 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 16, 115 },
      -1,
   } },
   /* search622_1 -> 243 in the cache */
   /* search622_2_0_0_0_0 -> 115 in the cache */
   /* search622_2_0_0_0_1 -> 16 in the cache */
   /* search622_2_0_0_0 -> 1854 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_b2i32,
      -1, 0,
      { 1854 },
      -1,
   } },
   /* search622_2_0_1_0_0_0 -> 16 in the cache */
   /* search622_2_0_1_0_0_1 -> 115 in the cache */
   /* search622_2_0_1_0_0 -> 695 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_b2i32,
      -1, 0,
      { 695 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 1873 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 1872, 1874 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2f32,
      -1, 1,
      { 1875 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 1871, 243, 1876 },
      -1,
   } },

   /* replace622_0_0_0_0 -> 16 in the cache */
   /* replace622_0_0_0_1 -> 115 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      nir_op_fge,
      -1, 0,
      { 16, 115 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_b2i32,
      -1, 0,
      { 1878 },
      -1,
   } },
   /* replace622_0_1_0_0_0 -> 16 in the cache */
   /* replace622_0_1_0_0_1 -> 115 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      nir_op_flt,
      -1, 0,
      { 16, 115 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_b2i32,
      -1, 0,
      { 1880 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 1881 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 1879, 1882 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2f32,
      -1, 1,
      { 1883 },
      -1,
   } },

   /* ('bcsel', 'a', ('b2f(is_used_once)', 'b@32'), ('b2f', 'c@32')) => ('b2f', ('bcsel', 'a', 'b', 'c')) */
   /* search623_0 -> 760 in the cache */
   /* search623_1_0 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 36 },
      0,
   } },
   /* search623_2_0 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 135 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 760, 1885, 1886 },
      -1,
   } },

   /* replace623_0_0 -> 760 in the cache */
   /* replace623_0_1 -> 36 in the cache */
   /* replace623_0_2 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 760, 36, 135 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 1888 },
      -1,
   } },

   /* ('~i2f32', ('f2i', 'a@32')) => ('ftrunc', 'a') */
   /* search624_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_f2i,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_i2f32,
      -1, 0,
      { 1890 },
      -1,
   } },

   /* replace624_0 -> 16 in the cache */
   /* replace624 -> 694 in the cache */

   /* ('~f2i32', ('i2f', 'a@32')) => a */
   /* search625_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_i2f,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2i32,
      -1, 0,
      { 1892 },
      -1,
   } },

   /* replace625 -> 16 in the cache */

   /* ('~f2i32', ('u2f', 'a@32')) => a */
   /* search626_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_u2f,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2i32,
      -1, 0,
      { 1894 },
      -1,
   } },

   /* replace626 -> 16 in the cache */

   /* ('~f2u32', ('i2f', 'a@32')) => a */
   /* search627_0_0 -> 16 in the cache */
   /* search627_0 -> 1892 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2u32,
      -1, 0,
      { 1892 },
      -1,
   } },

   /* replace627 -> 16 in the cache */

   /* ('~f2u32', ('u2f', 'a@32')) => a */
   /* search628_0_0 -> 16 in the cache */
   /* search628_0 -> 1894 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2u32,
      -1, 0,
      { 1894 },
      -1,
   } },

   /* replace628 -> 16 in the cache */

   /* ('fadd', ('b2f32', ('flt', 0.0, 'a@32')), ('fneg', ('b2f32', ('flt', 'a@32', 0.0)))) => ('fsign', 'a') */
   /* search629_0_0_0 -> 115 in the cache */
   /* search629_0_0_1 -> 16 in the cache */
   /* search629_0_0 -> 1854 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_b2f32,
      -1, 0,
      { 1854 },
      -1,
   } },
   /* search629_1_0_0_0 -> 16 in the cache */
   /* search629_1_0_0_1 -> 115 in the cache */
   /* search629_1_0_0 -> 695 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_b2f32,
      -1, 0,
      { 695 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 1899 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 1898, 1900 },
      -1,
   } },

   /* replace629_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fsign,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('iadd', ('b2i32', ('flt', 0, 'a@32')), ('ineg', ('b2i32', ('flt', 'a@32', 0)))) => ('f2i32', ('fsign', 'a')) */
   /* search630_0_0_0 -> 122 in the cache */
   /* search630_0_0_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 122, 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_b2i32,
      -1, 0,
      { 1903 },
      -1,
   } },
   /* search630_1_0_0_0 -> 16 in the cache */
   /* search630_1_0_0_1 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 16, 122 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_b2i32,
      -1, 0,
      { 1905 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 1906 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 1904, 1907 },
      -1,
   } },

   /* replace630_0_0 -> 16 in the cache */
   /* replace630_0 -> 1902 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2i32,
      -1, 0,
      { 1902 },
      -1,
   } },

   /* ('~f2f32', ('f2f', 'a')) => ('f2f32', 'a') */
   /* search631_0_0 -> 32 in the cache */
   /* search631_0 -> 1802 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 1802 },
      -1,
   } },

   /* replace631_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 32 },
      -1,
   } },

   /* ('~f2f32', ('u2f', 'a')) => ('u2f32', 'a') */
   /* search632_0_0 -> 32 in the cache */
   /* search632_0 -> 104 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 104 },
      -1,
   } },

   /* replace632_0 -> 32 in the cache */
   /* replace632 -> 1823 in the cache */

   /* ('~f2f32', ('i2f', 'a')) => ('i2f32', 'a') */
   /* search633_0_0 -> 32 in the cache */
   /* search633_0 -> 1241 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 1241 },
      -1,
   } },

   /* replace633_0 -> 32 in the cache */
   /* replace633 -> 1825 in the cache */

   /* ('~f2u32', ('f2f', 'a')) => ('f2u32', 'a') */
   /* search634_0_0 -> 32 in the cache */
   /* search634_0 -> 1802 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2u32,
      -1, 0,
      { 1802 },
      -1,
   } },

   /* replace634_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2u32,
      -1, 0,
      { 32 },
      -1,
   } },

   /* ('~f2i32', ('f2f', 'a')) => ('f2i32', 'a') */
   /* search635_0_0 -> 32 in the cache */
   /* search635_0 -> 1802 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2i32,
      -1, 0,
      { 1802 },
      -1,
   } },

   /* replace635_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2i32,
      -1, 0,
      { 32 },
      -1,
   } },

   /* ('f2f32', ('f2f64', 'a@32')) => a */
   /* search636_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_f2f64,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 1918 },
      -1,
   } },

   /* replace636 -> 16 in the cache */

   /* ('i2i32', ('i2i64', 'a@32')) => a */
   /* search637_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 1920 },
      -1,
   } },

   /* replace637 -> 16 in the cache */

   /* ('u2u32', ('u2u64', 'a@32')) => a */
   /* search638_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 1922 },
      -1,
   } },

   /* replace638 -> 16 in the cache */

   /* ('f2u64', ('f2f64', 'a@32')) => ('f2u64', 'a') */
   /* search639_0_0 -> 16 in the cache */
   /* search639_0 -> 1918 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_f2u64,
      -1, 0,
      { 1918 },
      -1,
   } },

   /* replace639_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_f2u64,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('f2i64', ('f2f64', 'a@32')) => ('f2i64', 'a') */
   /* search640_0_0 -> 16 in the cache */
   /* search640_0 -> 1918 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_f2i64,
      -1, 0,
      { 1918 },
      -1,
   } },

   /* replace640_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_f2i64,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('f2f32', ('u2f64', 'a')) => ('u2f32', 'a') */
   /* search641_0_0 -> 32 in the cache */
   /* search641_0 -> 1841 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 1841 },
      -1,
   } },

   /* replace641_0 -> 32 in the cache */
   /* replace641 -> 1823 in the cache */

   /* ('f2f32', ('i2f64', 'a')) => ('i2f32', 'a') */
   /* search642_0_0 -> 32 in the cache */
   /* search642_0 -> 1843 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 1843 },
      -1,
   } },

   /* replace642_0 -> 32 in the cache */
   /* replace642 -> 1825 in the cache */

   /* ('u2f64', ('u2u64', 'a@32')) => ('u2f64', 'a') */
   /* search643_0_0 -> 16 in the cache */
   /* search643_0 -> 1922 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2f64,
      -1, 0,
      { 1922 },
      -1,
   } },

   /* replace643_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2f64,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('i2f64', ('i2i64', 'a@32')) => ('i2f64', 'a') */
   /* search644_0_0 -> 16 in the cache */
   /* search644_0 -> 1920 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2f64,
      -1, 0,
      { 1920 },
      -1,
   } },

   /* replace644_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2f64,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('ior', ('flt(is_used_once)', 0.0, 'a@64'), ('flt', 'b@64', 0.0)) => ('flt', 0.0, ('fmax', 'a', ('fneg', 'b'))) */
   /* search645_0_0 -> 701 in the cache */
   /* search645_0_1 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 701, 21 },
      0,
   } },
   /* search645_1_0 -> 41 in the cache */
   /* search645_1_1 -> 701 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 41, 701 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1934, 1935 },
      -1,
   } },

   /* replace645_0 -> 701 in the cache */
   /* replace645_1_0 -> 21 in the cache */
   /* replace645_1_1_0 -> 41 in the cache */
   /* replace645_1_1 -> 673 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 21, 673 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 701, 1937 },
      -1,
   } },

   /* ('ior', ('flt', 0.0, 'a@64'), ('flt(is_used_once)', 'b@64', 0.0)) => ('flt', 0.0, ('fmax', 'a', ('fneg', 'b'))) */
   /* search646_0_0 -> 701 in the cache */
   /* search646_0_1 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 701, 21 },
      -1,
   } },
   /* search646_1_0 -> 41 in the cache */
   /* search646_1_1 -> 701 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 41, 701 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1939, 1940 },
      -1,
   } },

   /* replace646_0 -> 701 in the cache */
   /* replace646_1_0 -> 21 in the cache */
   /* replace646_1_1_0 -> 41 in the cache */
   /* replace646_1_1 -> 673 in the cache */
   /* replace646_1 -> 1937 in the cache */
   /* replace646 -> 1938 in the cache */

   /* ('ior', ('fge(is_used_once)', 0.0, 'a@64'), ('fge', 'b@64', 0.0)) => ('fge', 0.0, ('fmin', 'a', ('fneg', 'b'))) */
   /* search647_0_0 -> 701 in the cache */
   /* search647_0_1 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 701, 21 },
      0,
   } },
   /* search647_1_0 -> 41 in the cache */
   /* search647_1_1 -> 701 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 41, 701 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1942, 1943 },
      -1,
   } },

   /* replace647_0 -> 701 in the cache */
   /* replace647_1_0 -> 21 in the cache */
   /* replace647_1_1_0 -> 41 in the cache */
   /* replace647_1_1 -> 673 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 21, 673 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 701, 1945 },
      -1,
   } },

   /* ('ior', ('fge', 0.0, 'a@64'), ('fge(is_used_once)', 'b@64', 0.0)) => ('fge', 0.0, ('fmin', 'a', ('fneg', 'b'))) */
   /* search648_0_0 -> 701 in the cache */
   /* search648_0_1 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 701, 21 },
      -1,
   } },
   /* search648_1_0 -> 41 in the cache */
   /* search648_1_1 -> 701 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 41, 701 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1947, 1948 },
      -1,
   } },

   /* replace648_0 -> 701 in the cache */
   /* replace648_1_0 -> 21 in the cache */
   /* replace648_1_1_0 -> 41 in the cache */
   /* replace648_1_1 -> 673 in the cache */
   /* replace648_1 -> 1945 in the cache */
   /* replace648 -> 1946 in the cache */

   /* ('~iand', ('flt(is_used_once)', 0.0, 'a@64'), ('flt', 'b@64', 0.0)) => ('flt', 0.0, ('fmin', 'a', ('fneg', 'b'))) */
   /* search649_0_0 -> 701 in the cache */
   /* search649_0_1 -> 21 in the cache */
   /* search649_0 -> 1934 in the cache */
   /* search649_1_0 -> 41 in the cache */
   /* search649_1_1 -> 701 in the cache */
   /* search649_1 -> 1935 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1934, 1935 },
      -1,
   } },

   /* replace649_0 -> 701 in the cache */
   /* replace649_1_0 -> 21 in the cache */
   /* replace649_1_1_0 -> 41 in the cache */
   /* replace649_1_1 -> 673 in the cache */
   /* replace649_1 -> 1945 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 701, 1945 },
      -1,
   } },

   /* ('~iand', ('flt', 0.0, 'a@64'), ('flt(is_used_once)', 'b@64', 0.0)) => ('flt', 0.0, ('fmin', 'a', ('fneg', 'b'))) */
   /* search650_0_0 -> 701 in the cache */
   /* search650_0_1 -> 21 in the cache */
   /* search650_0 -> 1939 in the cache */
   /* search650_1_0 -> 41 in the cache */
   /* search650_1_1 -> 701 in the cache */
   /* search650_1 -> 1940 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1939, 1940 },
      -1,
   } },

   /* replace650_0 -> 701 in the cache */
   /* replace650_1_0 -> 21 in the cache */
   /* replace650_1_1_0 -> 41 in the cache */
   /* replace650_1_1 -> 673 in the cache */
   /* replace650_1 -> 1945 in the cache */
   /* replace650 -> 1951 in the cache */

   /* ('~iand', ('fge(is_used_once)', 0.0, 'a@64'), ('fge', 'b@64', 0.0)) => ('fge', 0.0, ('fmax', 'a', ('fneg', 'b'))) */
   /* search651_0_0 -> 701 in the cache */
   /* search651_0_1 -> 21 in the cache */
   /* search651_0 -> 1942 in the cache */
   /* search651_1_0 -> 41 in the cache */
   /* search651_1_1 -> 701 in the cache */
   /* search651_1 -> 1943 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1942, 1943 },
      -1,
   } },

   /* replace651_0 -> 701 in the cache */
   /* replace651_1_0 -> 21 in the cache */
   /* replace651_1_1_0 -> 41 in the cache */
   /* replace651_1_1 -> 673 in the cache */
   /* replace651_1 -> 1937 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 701, 1937 },
      -1,
   } },

   /* ('~iand', ('fge', 0.0, 'a@64'), ('fge(is_used_once)', 'b@64', 0.0)) => ('fge', 0.0, ('fmax', 'a', ('fneg', 'b'))) */
   /* search652_0_0 -> 701 in the cache */
   /* search652_0_1 -> 21 in the cache */
   /* search652_0 -> 1947 in the cache */
   /* search652_1_0 -> 41 in the cache */
   /* search652_1_1 -> 701 in the cache */
   /* search652_1 -> 1948 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1947, 1948 },
      -1,
   } },

   /* replace652_0 -> 701 in the cache */
   /* replace652_1_0 -> 21 in the cache */
   /* replace652_1_1_0 -> 41 in the cache */
   /* replace652_1_1 -> 673 in the cache */
   /* replace652_1 -> 1937 in the cache */
   /* replace652 -> 1954 in the cache */

   /* ('bcsel@64', ('feq', 'a', 0.0), 1.0, ('i2f64', ('iadd', ('b2i64', ('flt', 0.0, 'a@64')), ('ineg', ('b2i64', ('flt', 'a@64', 0.0)))))) => ('i2f64', ('iadd', ('b2i32', ('!fge', 'a', 0.0)), ('ineg', ('b2i32', ('!flt', 'a', 0.0))))) */
   /* search653_0_0 -> 21 in the cache */
   /* search653_0_1 -> 701 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 21, 701 },
      -1,
   } },
   /* search653_1 -> 622 in the cache */
   /* search653_2_0_0_0_0 -> 701 in the cache */
   /* search653_2_0_0_0_1 -> 21 in the cache */
   /* search653_2_0_0_0 -> 1939 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_b2i64,
      -1, 0,
      { 1939 },
      -1,
   } },
   /* search653_2_0_1_0_0_0 -> 21 in the cache */
   /* search653_2_0_1_0_0_1 -> 701 in the cache */
   /* search653_2_0_1_0_0 -> 702 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_b2i64,
      -1, 0,
      { 702 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 1958 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 1957, 1959 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2f64,
      -1, 1,
      { 1960 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 1956, 622, 1961 },
      -1,
   } },

   /* replace653_0_0_0_0 -> 21 in the cache */
   /* replace653_0_0_0_1 -> 701 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      nir_op_fge,
      -1, 0,
      { 21, 701 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_b2i32,
      -1, 0,
      { 1963 },
      -1,
   } },
   /* replace653_0_1_0_0_0 -> 21 in the cache */
   /* replace653_0_1_0_0_1 -> 701 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      nir_op_flt,
      -1, 0,
      { 21, 701 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_b2i32,
      -1, 0,
      { 1965 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 1966 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 1964, 1967 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2f64,
      -1, 1,
      { 1968 },
      -1,
   } },

   /* ('bcsel', 'a', ('b2f(is_used_once)', 'b@64'), ('b2f', 'c@64')) => ('b2f', ('bcsel', 'a', 'b', 'c')) */
   /* search654_0 -> 760 in the cache */
   /* search654_1_0 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 41 },
      0,
   } },
   /* search654_2_0 -> 610 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 610 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 760, 1970, 1971 },
      -1,
   } },

   /* replace654_0_0 -> 760 in the cache */
   /* replace654_0_1 -> 41 in the cache */
   /* replace654_0_2 -> 610 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 760, 41, 610 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 1973 },
      -1,
   } },

   /* ('~i2f64', ('f2i', 'a@64')) => ('ftrunc', 'a') */
   /* search655_0_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_f2i,
      -1, 0,
      { 21 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_i2f64,
      -1, 0,
      { 1975 },
      -1,
   } },

   /* replace655_0 -> 21 in the cache */
   /* replace655 -> 700 in the cache */

   /* ('~f2i64', ('i2f', 'a@64')) => a */
   /* search656_0_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_i2f,
      -1, 0,
      { 21 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_f2i64,
      -1, 0,
      { 1977 },
      -1,
   } },

   /* replace656 -> 21 in the cache */

   /* ('~f2i64', ('u2f', 'a@64')) => a */
   /* search657_0_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_u2f,
      -1, 0,
      { 21 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_f2i64,
      -1, 0,
      { 1979 },
      -1,
   } },

   /* replace657 -> 21 in the cache */

   /* ('~f2u64', ('i2f', 'a@64')) => a */
   /* search658_0_0 -> 21 in the cache */
   /* search658_0 -> 1977 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_f2u64,
      -1, 0,
      { 1977 },
      -1,
   } },

   /* replace658 -> 21 in the cache */

   /* ('~f2u64', ('u2f', 'a@64')) => a */
   /* search659_0_0 -> 21 in the cache */
   /* search659_0 -> 1979 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_f2u64,
      -1, 0,
      { 1979 },
      -1,
   } },

   /* replace659 -> 21 in the cache */

   /* ('fadd', ('b2f64', ('flt', 0.0, 'a@64')), ('fneg', ('b2f64', ('flt', 'a@64', 0.0)))) => ('fsign', 'a') */
   /* search660_0_0_0 -> 701 in the cache */
   /* search660_0_0_1 -> 21 in the cache */
   /* search660_0_0 -> 1939 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_b2f64,
      -1, 0,
      { 1939 },
      -1,
   } },
   /* search660_1_0_0_0 -> 21 in the cache */
   /* search660_1_0_0_1 -> 701 in the cache */
   /* search660_1_0_0 -> 702 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_b2f64,
      -1, 0,
      { 702 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 1984 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 1983, 1985 },
      -1,
   } },

   /* replace660_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fsign,
      -1, 0,
      { 21 },
      -1,
   } },

   /* ('iadd', ('b2i64', ('flt', 0, 'a@64')), ('ineg', ('b2i64', ('flt', 'a@64', 0)))) => ('f2i64', ('fsign', 'a')) */
   /* search661_0_0_0 -> 897 in the cache */
   /* search661_0_0_1 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 897, 21 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_b2i64,
      -1, 0,
      { 1988 },
      -1,
   } },
   /* search661_1_0_0_0 -> 21 in the cache */
   /* search661_1_0_0_1 -> 897 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 21, 897 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_b2i64,
      -1, 0,
      { 1990 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 1991 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 1989, 1992 },
      -1,
   } },

   /* replace661_0_0 -> 21 in the cache */
   /* replace661_0 -> 1987 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_f2i64,
      -1, 0,
      { 1987 },
      -1,
   } },

   /* ('~f2f64', ('f2f', 'a')) => ('f2f64', 'a') */
   /* search662_0_0 -> 32 in the cache */
   /* search662_0 -> 1802 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_f2f64,
      -1, 0,
      { 1802 },
      -1,
   } },

   /* replace662_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_f2f64,
      -1, 0,
      { 32 },
      -1,
   } },

   /* ('~f2f64', ('u2f', 'a')) => ('u2f64', 'a') */
   /* search663_0_0 -> 32 in the cache */
   /* search663_0 -> 104 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_f2f64,
      -1, 0,
      { 104 },
      -1,
   } },

   /* replace663_0 -> 32 in the cache */
   /* replace663 -> 1841 in the cache */

   /* ('~f2f64', ('i2f', 'a')) => ('i2f64', 'a') */
   /* search664_0_0 -> 32 in the cache */
   /* search664_0 -> 1241 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_f2f64,
      -1, 0,
      { 1241 },
      -1,
   } },

   /* replace664_0 -> 32 in the cache */
   /* replace664 -> 1843 in the cache */

   /* ('~f2u64', ('f2f', 'a')) => ('f2u64', 'a') */
   /* search665_0_0 -> 32 in the cache */
   /* search665_0 -> 1802 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_f2u64,
      -1, 0,
      { 1802 },
      -1,
   } },

   /* replace665_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_f2u64,
      -1, 0,
      { 32 },
      -1,
   } },

   /* ('~f2i64', ('f2f', 'a')) => ('f2i64', 'a') */
   /* search666_0_0 -> 32 in the cache */
   /* search666_0 -> 1802 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_f2i64,
      -1, 0,
      { 1802 },
      -1,
   } },

   /* replace666_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_f2i64,
      -1, 0,
      { 32 },
      -1,
   } },

   /* ('f2fmp', ('u2f32', 'a@32')) => ('u2fmp', 'a') */
   /* search667_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2f32,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2fmp,
      -1, 0,
      { 2003 },
      -1,
   } },

   /* replace667_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2fmp,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('f2fmp', ('i2f32', 'a@32')) => ('i2fmp', 'a') */
   /* search668_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2f32,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2fmp,
      -1, 0,
      { 2006 },
      -1,
   } },

   /* replace668_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2fmp,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('f2u16', ('f2fmp', 'a@32')) => ('f2u16', 'a') */
   /* search669_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2fmp,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2u16,
      -1, 0,
      { 2009 },
      -1,
   } },

   /* replace669_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2u16,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('f2i16', ('f2fmp', 'a@32')) => ('f2i16', 'a') */
   /* search670_0_0 -> 16 in the cache */
   /* search670_0 -> 2009 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2i16,
      -1, 0,
      { 2009 },
      -1,
   } },

   /* replace670_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2i16,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('i2imp', ('f2u32', 'a@32')) => ('f2ump', 'a') */
   /* search671_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2u32,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2imp,
      -1, 0,
      { 2014 },
      -1,
   } },

   /* replace671_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2ump,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('i2imp', ('f2i32', 'a@32')) => ('f2imp', 'a') */
   /* search672_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2i32,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2imp,
      -1, 0,
      { 2017 },
      -1,
   } },

   /* replace672_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2imp,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('u2f16', ('i2imp', 'a@32')) => ('u2f16', 'a') */
   /* search673_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2imp,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2f16,
      -1, 0,
      { 2020 },
      -1,
   } },

   /* replace673_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2f16,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('i2f16', ('i2imp', 'a@32')) => ('i2f16', 'a') */
   /* search674_0_0 -> 16 in the cache */
   /* search674_0 -> 2020 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2f16,
      -1, 0,
      { 2020 },
      -1,
   } },

   /* replace674_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2f16,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('iand', ('u2u16', ('u2u8', 'a@16')), '#b') => ('iand', 'a', ('iand', 'b', 255)) */
   /* search675_0_0_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 11 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 2025 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, 16 },
      1, /* b */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 2026, 2027 },
      -1,
   } },

   /* replace675_0 -> 11 in the cache */
   /* replace675_1_0 -> 258 in the cache */
   { .constant = {
      { nir_search_value_constant, 16 },
      nir_type_int, { 0xff /* 255 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 258, 2029 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 11, 2030 },
      -1,
   } },

   /* ('u2u16', ('u2u8(is_used_once)', ('iand', 'a@16', '#b'))) => ('iand', 'a', ('iand', 'b', 255)) */
   /* search676_0_0_0 -> 11 in the cache */
   /* search676_0_0_1 -> 2027 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 11, 2027 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 1,
      { 2032 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 1,
      { 2033 },
      -1,
   } },

   /* replace676_0 -> 11 in the cache */
   /* replace676_1_0 -> 258 in the cache */
   /* replace676_1_1 -> 2029 in the cache */
   /* replace676_1 -> 2030 in the cache */
   /* replace676 -> 2031 in the cache */

   /* ('u2u8', ('iand', ('u2u16', ('u2u8', 'a@16')), ('u2u16', ('u2u8', 'b@16')))) => ('u2u8', ('iand', 'a', 'b')) */
   /* search677_0_0_0_0 -> 11 in the cache */
   /* search677_0_0_0 -> 2025 in the cache */
   /* search677_0_0 -> 2026 in the cache */
   /* search677_0_1_0_0 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 258 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 2035 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 2026, 2036 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 1,
      { 2037 },
      -1,
   } },

   /* replace677_0_0 -> 11 in the cache */
   /* replace677_0_1 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 11, 258 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 1,
      { 2039 },
      -1,
   } },

   /* ('u2u8', ('iand', ('u2u16', ('u2u8', 'a@32')), ('u2u16', ('u2u8', 'b@32')))) => ('u2u8', ('iand', 'a', 'b')) */
   /* search678_0_0_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 2041 },
      -1,
   } },
   /* search678_0_1_0_0 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 2043 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 2042, 2044 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 1,
      { 2045 },
      -1,
   } },

   /* replace678_0_0 -> 16 in the cache */
   /* replace678_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 16, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 1,
      { 2047 },
      -1,
   } },

   /* ('iand', ('extract_i8', 'a', '#b'), ('extract_i8', 'c', 'b')) => ('extract_i8', ('iand', 'a', 'c'), 'b') */
   /* search679_0_0 -> 0 in the cache */
   /* search679_0_1 -> 821 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 0, 821 },
      -1,
   } },
   /* search679_1_0 -> 140 in the cache */
   /* search679_1_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 140, 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 2049, 2050 },
      -1,
   } },

   /* replace679_0_0 -> 0 in the cache */
   /* replace679_0_1 -> 140 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 0, 140 },
      -1,
   } },
   /* replace679_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 1,
      { 2052, 3 },
      -1,
   } },

   /* ('iand', ('extract_u8', 'a', '#b'), ('extract_u8', 'c', 'b')) => ('extract_u8', ('iand', 'a', 'c'), 'b') */
   /* search680_0_0 -> 0 in the cache */
   /* search680_0_1 -> 821 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 0, 821 },
      -1,
   } },
   /* search680_1_0 -> 140 in the cache */
   /* search680_1_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 140, 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 2054, 2055 },
      -1,
   } },

   /* replace680_0_0 -> 0 in the cache */
   /* replace680_0_1 -> 140 in the cache */
   /* replace680_0 -> 2052 in the cache */
   /* replace680_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 1,
      { 2052, 3 },
      -1,
   } },

   /* ('iand', ('extract_i16', 'a', '#b'), ('extract_i16', 'c', 'b')) => ('extract_i16', ('iand', 'a', 'c'), 'b') */
   /* search681_0_0 -> 0 in the cache */
   /* search681_0_1 -> 821 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_i16,
      -1, 0,
      { 0, 821 },
      -1,
   } },
   /* search681_1_0 -> 140 in the cache */
   /* search681_1_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_i16,
      -1, 0,
      { 140, 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 2058, 2059 },
      -1,
   } },

   /* replace681_0_0 -> 0 in the cache */
   /* replace681_0_1 -> 140 in the cache */
   /* replace681_0 -> 2052 in the cache */
   /* replace681_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_i16,
      -1, 1,
      { 2052, 3 },
      -1,
   } },

   /* ('iand', ('extract_u16', 'a', '#b'), ('extract_u16', 'c', 'b')) => ('extract_u16', ('iand', 'a', 'c'), 'b') */
   /* search682_0_0 -> 0 in the cache */
   /* search682_0_1 -> 821 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 0,
      { 0, 821 },
      -1,
   } },
   /* search682_1_0 -> 140 in the cache */
   /* search682_1_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 0,
      { 140, 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 2062, 2063 },
      -1,
   } },

   /* replace682_0_0 -> 0 in the cache */
   /* replace682_0_1 -> 140 in the cache */
   /* replace682_0 -> 2052 in the cache */
   /* replace682_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 1,
      { 2052, 3 },
      -1,
   } },

   /* ('iand', ('ushr(is_used_once)', 'a', '#b'), ('ushr', 'c', 'b')) => ('ushr', ('iand', 'a', 'c'), 'b') */
   /* search683_0_0 -> 126 in the cache */
   /* search683_0_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 126, 33 },
      0,
   } },
   /* search683_1_0 -> 129 in the cache */
   /* search683_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 129, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 2066, 2067 },
      -1,
   } },

   /* replace683_0_0 -> 126 in the cache */
   /* replace683_0_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 126, 129 },
      -1,
   } },
   /* replace683_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 2069, 36 },
      -1,
   } },

   /* ('iand', ('ishr(is_used_once)', 'a', '#b'), ('ishr', 'c', 'b')) => ('ishr', ('iand', 'a', 'c'), 'b') */
   /* search684_0_0 -> 126 in the cache */
   /* search684_0_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 126, 33 },
      0,
   } },
   /* search684_1_0 -> 129 in the cache */
   /* search684_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 129, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 2071, 2072 },
      -1,
   } },

   /* replace684_0_0 -> 126 in the cache */
   /* replace684_0_1 -> 129 in the cache */
   /* replace684_0 -> 2069 in the cache */
   /* replace684_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 1,
      { 2069, 36 },
      -1,
   } },

   /* ('iand', ('ishl(is_used_once)', 'a', '#b'), ('ishl', 'c', 'b')) => ('ishl', ('iand', 'a', 'c'), 'b') */
   /* search685_0_0 -> 126 in the cache */
   /* search685_0_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 126, 33 },
      0,
   } },
   /* search685_1_0 -> 129 in the cache */
   /* search685_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 129, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 2075, 2076 },
      -1,
   } },

   /* replace685_0_0 -> 126 in the cache */
   /* replace685_0_1 -> 129 in the cache */
   /* replace685_0 -> 2069 in the cache */
   /* replace685_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 2069, 36 },
      -1,
   } },

   /* ('u2u8', ('ior', ('u2u16', ('u2u8', 'a@16')), ('u2u16', ('u2u8', 'b@16')))) => ('u2u8', ('ior', 'a', 'b')) */
   /* search686_0_0_0_0 -> 11 in the cache */
   /* search686_0_0_0 -> 2025 in the cache */
   /* search686_0_0 -> 2026 in the cache */
   /* search686_0_1_0_0 -> 258 in the cache */
   /* search686_0_1_0 -> 2035 in the cache */
   /* search686_0_1 -> 2036 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 2026, 2036 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 1,
      { 2079 },
      -1,
   } },

   /* replace686_0_0 -> 11 in the cache */
   /* replace686_0_1 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 11, 258 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 1,
      { 2081 },
      -1,
   } },

   /* ('u2u8', ('ior', ('u2u16', ('u2u8', 'a@32')), ('u2u16', ('u2u8', 'b@32')))) => ('u2u8', ('ior', 'a', 'b')) */
   /* search687_0_0_0_0 -> 16 in the cache */
   /* search687_0_0_0 -> 2041 in the cache */
   /* search687_0_0 -> 2042 in the cache */
   /* search687_0_1_0_0 -> 36 in the cache */
   /* search687_0_1_0 -> 2043 in the cache */
   /* search687_0_1 -> 2044 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 2042, 2044 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 1,
      { 2083 },
      -1,
   } },

   /* replace687_0_0 -> 16 in the cache */
   /* replace687_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 16, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 1,
      { 2085 },
      -1,
   } },

   /* ('ior', ('extract_i8', 'a', '#b'), ('extract_i8', 'c', 'b')) => ('extract_i8', ('ior', 'a', 'c'), 'b') */
   /* search688_0_0 -> 0 in the cache */
   /* search688_0_1 -> 821 in the cache */
   /* search688_0 -> 2049 in the cache */
   /* search688_1_0 -> 140 in the cache */
   /* search688_1_1 -> 3 in the cache */
   /* search688_1 -> 2050 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 2049, 2050 },
      -1,
   } },

   /* replace688_0_0 -> 0 in the cache */
   /* replace688_0_1 -> 140 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 0, 140 },
      -1,
   } },
   /* replace688_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 1,
      { 2088, 3 },
      -1,
   } },

   /* ('ior', ('extract_u8', 'a', '#b'), ('extract_u8', 'c', 'b')) => ('extract_u8', ('ior', 'a', 'c'), 'b') */
   /* search689_0_0 -> 0 in the cache */
   /* search689_0_1 -> 821 in the cache */
   /* search689_0 -> 2054 in the cache */
   /* search689_1_0 -> 140 in the cache */
   /* search689_1_1 -> 3 in the cache */
   /* search689_1 -> 2055 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 2054, 2055 },
      -1,
   } },

   /* replace689_0_0 -> 0 in the cache */
   /* replace689_0_1 -> 140 in the cache */
   /* replace689_0 -> 2088 in the cache */
   /* replace689_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 1,
      { 2088, 3 },
      -1,
   } },

   /* ('ior', ('extract_i16', 'a', '#b'), ('extract_i16', 'c', 'b')) => ('extract_i16', ('ior', 'a', 'c'), 'b') */
   /* search690_0_0 -> 0 in the cache */
   /* search690_0_1 -> 821 in the cache */
   /* search690_0 -> 2058 in the cache */
   /* search690_1_0 -> 140 in the cache */
   /* search690_1_1 -> 3 in the cache */
   /* search690_1 -> 2059 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 2058, 2059 },
      -1,
   } },

   /* replace690_0_0 -> 0 in the cache */
   /* replace690_0_1 -> 140 in the cache */
   /* replace690_0 -> 2088 in the cache */
   /* replace690_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_i16,
      -1, 1,
      { 2088, 3 },
      -1,
   } },

   /* ('ior', ('extract_u16', 'a', '#b'), ('extract_u16', 'c', 'b')) => ('extract_u16', ('ior', 'a', 'c'), 'b') */
   /* search691_0_0 -> 0 in the cache */
   /* search691_0_1 -> 821 in the cache */
   /* search691_0 -> 2062 in the cache */
   /* search691_1_0 -> 140 in the cache */
   /* search691_1_1 -> 3 in the cache */
   /* search691_1 -> 2063 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 2062, 2063 },
      -1,
   } },

   /* replace691_0_0 -> 0 in the cache */
   /* replace691_0_1 -> 140 in the cache */
   /* replace691_0 -> 2088 in the cache */
   /* replace691_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 1,
      { 2088, 3 },
      -1,
   } },

   /* ('ior', ('ushr(is_used_once)', 'a', '#b'), ('ushr', 'c', 'b')) => ('ushr', ('ior', 'a', 'c'), 'b') */
   /* search692_0_0 -> 126 in the cache */
   /* search692_0_1 -> 33 in the cache */
   /* search692_0 -> 2066 in the cache */
   /* search692_1_0 -> 129 in the cache */
   /* search692_1_1 -> 36 in the cache */
   /* search692_1 -> 2067 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 2066, 2067 },
      -1,
   } },

   /* replace692_0_0 -> 126 in the cache */
   /* replace692_0_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 126, 129 },
      -1,
   } },
   /* replace692_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 2097, 36 },
      -1,
   } },

   /* ('ior', ('ishr(is_used_once)', 'a', '#b'), ('ishr', 'c', 'b')) => ('ishr', ('ior', 'a', 'c'), 'b') */
   /* search693_0_0 -> 126 in the cache */
   /* search693_0_1 -> 33 in the cache */
   /* search693_0 -> 2071 in the cache */
   /* search693_1_0 -> 129 in the cache */
   /* search693_1_1 -> 36 in the cache */
   /* search693_1 -> 2072 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 2071, 2072 },
      -1,
   } },

   /* replace693_0_0 -> 126 in the cache */
   /* replace693_0_1 -> 129 in the cache */
   /* replace693_0 -> 2097 in the cache */
   /* replace693_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 1,
      { 2097, 36 },
      -1,
   } },

   /* ('ior', ('ishl(is_used_once)', 'a', '#b'), ('ishl', 'c', 'b')) => ('ishl', ('ior', 'a', 'c'), 'b') */
   /* search694_0_0 -> 126 in the cache */
   /* search694_0_1 -> 33 in the cache */
   /* search694_0 -> 2075 in the cache */
   /* search694_1_0 -> 129 in the cache */
   /* search694_1_1 -> 36 in the cache */
   /* search694_1 -> 2076 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 2075, 2076 },
      -1,
   } },

   /* replace694_0_0 -> 126 in the cache */
   /* replace694_0_1 -> 129 in the cache */
   /* replace694_0 -> 2097 in the cache */
   /* replace694_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 2097, 36 },
      -1,
   } },

   /* ('u2u8', ('ixor', ('u2u16', ('u2u8', 'a@16')), ('u2u16', ('u2u8', 'b@16')))) => ('u2u8', ('ixor', 'a', 'b')) */
   /* search695_0_0_0_0 -> 11 in the cache */
   /* search695_0_0_0 -> 2025 in the cache */
   /* search695_0_0 -> 2026 in the cache */
   /* search695_0_1_0_0 -> 258 in the cache */
   /* search695_0_1_0 -> 2035 in the cache */
   /* search695_0_1 -> 2036 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 2026, 2036 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 1,
      { 2103 },
      -1,
   } },

   /* replace695_0_0 -> 11 in the cache */
   /* replace695_0_1 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 11, 258 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 1,
      { 2105 },
      -1,
   } },

   /* ('u2u8', ('ixor', ('u2u16', ('u2u8', 'a@32')), ('u2u16', ('u2u8', 'b@32')))) => ('u2u8', ('ixor', 'a', 'b')) */
   /* search696_0_0_0_0 -> 16 in the cache */
   /* search696_0_0_0 -> 2041 in the cache */
   /* search696_0_0 -> 2042 in the cache */
   /* search696_0_1_0_0 -> 36 in the cache */
   /* search696_0_1_0 -> 2043 in the cache */
   /* search696_0_1 -> 2044 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 2042, 2044 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 1,
      { 2107 },
      -1,
   } },

   /* replace696_0_0 -> 16 in the cache */
   /* replace696_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 16, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 1,
      { 2109 },
      -1,
   } },

   /* ('ixor', ('extract_i8', 'a', '#b'), ('extract_i8', 'c', 'b')) => ('extract_i8', ('ixor', 'a', 'c'), 'b') */
   /* search697_0_0 -> 0 in the cache */
   /* search697_0_1 -> 821 in the cache */
   /* search697_0 -> 2049 in the cache */
   /* search697_1_0 -> 140 in the cache */
   /* search697_1_1 -> 3 in the cache */
   /* search697_1 -> 2050 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 2049, 2050 },
      -1,
   } },

   /* replace697_0_0 -> 0 in the cache */
   /* replace697_0_1 -> 140 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 0, 140 },
      -1,
   } },
   /* replace697_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 1,
      { 2112, 3 },
      -1,
   } },

   /* ('ixor', ('extract_u8', 'a', '#b'), ('extract_u8', 'c', 'b')) => ('extract_u8', ('ixor', 'a', 'c'), 'b') */
   /* search698_0_0 -> 0 in the cache */
   /* search698_0_1 -> 821 in the cache */
   /* search698_0 -> 2054 in the cache */
   /* search698_1_0 -> 140 in the cache */
   /* search698_1_1 -> 3 in the cache */
   /* search698_1 -> 2055 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 2054, 2055 },
      -1,
   } },

   /* replace698_0_0 -> 0 in the cache */
   /* replace698_0_1 -> 140 in the cache */
   /* replace698_0 -> 2112 in the cache */
   /* replace698_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 1,
      { 2112, 3 },
      -1,
   } },

   /* ('ixor', ('extract_i16', 'a', '#b'), ('extract_i16', 'c', 'b')) => ('extract_i16', ('ixor', 'a', 'c'), 'b') */
   /* search699_0_0 -> 0 in the cache */
   /* search699_0_1 -> 821 in the cache */
   /* search699_0 -> 2058 in the cache */
   /* search699_1_0 -> 140 in the cache */
   /* search699_1_1 -> 3 in the cache */
   /* search699_1 -> 2059 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 2058, 2059 },
      -1,
   } },

   /* replace699_0_0 -> 0 in the cache */
   /* replace699_0_1 -> 140 in the cache */
   /* replace699_0 -> 2112 in the cache */
   /* replace699_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_i16,
      -1, 1,
      { 2112, 3 },
      -1,
   } },

   /* ('ixor', ('extract_u16', 'a', '#b'), ('extract_u16', 'c', 'b')) => ('extract_u16', ('ixor', 'a', 'c'), 'b') */
   /* search700_0_0 -> 0 in the cache */
   /* search700_0_1 -> 821 in the cache */
   /* search700_0 -> 2062 in the cache */
   /* search700_1_0 -> 140 in the cache */
   /* search700_1_1 -> 3 in the cache */
   /* search700_1 -> 2063 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 2062, 2063 },
      -1,
   } },

   /* replace700_0_0 -> 0 in the cache */
   /* replace700_0_1 -> 140 in the cache */
   /* replace700_0 -> 2112 in the cache */
   /* replace700_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 1,
      { 2112, 3 },
      -1,
   } },

   /* ('ixor', ('ushr(is_used_once)', 'a', '#b'), ('ushr', 'c', 'b')) => ('ushr', ('ixor', 'a', 'c'), 'b') */
   /* search701_0_0 -> 126 in the cache */
   /* search701_0_1 -> 33 in the cache */
   /* search701_0 -> 2066 in the cache */
   /* search701_1_0 -> 129 in the cache */
   /* search701_1_1 -> 36 in the cache */
   /* search701_1 -> 2067 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 2066, 2067 },
      -1,
   } },

   /* replace701_0_0 -> 126 in the cache */
   /* replace701_0_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 126, 129 },
      -1,
   } },
   /* replace701_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 2121, 36 },
      -1,
   } },

   /* ('ixor', ('ishr(is_used_once)', 'a', '#b'), ('ishr', 'c', 'b')) => ('ishr', ('ixor', 'a', 'c'), 'b') */
   /* search702_0_0 -> 126 in the cache */
   /* search702_0_1 -> 33 in the cache */
   /* search702_0 -> 2071 in the cache */
   /* search702_1_0 -> 129 in the cache */
   /* search702_1_1 -> 36 in the cache */
   /* search702_1 -> 2072 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 2071, 2072 },
      -1,
   } },

   /* replace702_0_0 -> 126 in the cache */
   /* replace702_0_1 -> 129 in the cache */
   /* replace702_0 -> 2121 in the cache */
   /* replace702_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 1,
      { 2121, 36 },
      -1,
   } },

   /* ('ixor', ('ishl(is_used_once)', 'a', '#b'), ('ishl', 'c', 'b')) => ('ishl', ('ixor', 'a', 'c'), 'b') */
   /* search703_0_0 -> 126 in the cache */
   /* search703_0_1 -> 33 in the cache */
   /* search703_0 -> 2075 in the cache */
   /* search703_1_0 -> 129 in the cache */
   /* search703_1_1 -> 36 in the cache */
   /* search703_1 -> 2076 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 2075, 2076 },
      -1,
   } },

   /* replace703_0_0 -> 126 in the cache */
   /* replace703_0_1 -> 129 in the cache */
   /* replace703_0 -> 2121 in the cache */
   /* replace703_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 2121, 36 },
      -1,
   } },

   /* ('iand', ('ieq', 'a@8', 0), ('ieq', 'b@8', 0)) => ('ieq', ('ior', 'a', 'b'), 0) */
   /* search704_0_0 -> 6 in the cache */
   /* search704_0_1 -> 835 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 6, 835 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, 8 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search704_1_1 -> 835 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 2128, 835 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 2127, 2129 },
      -1,
   } },

   /* replace704_0_0 -> 6 in the cache */
   /* replace704_0_1 -> 2128 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 6, 2128 },
      -1,
   } },
   /* replace704_1 -> 835 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 2131, 835 },
      -1,
   } },

   /* ('ior', ('ine', 'a@8', 0), ('ine', 'b@8', 0)) => ('ine', ('ior', 'a', 'b'), 0) */
   /* search705_0_0 -> 6 in the cache */
   /* search705_0_1 -> 835 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 6, 835 },
      -1,
   } },
   /* search705_1_0 -> 2128 in the cache */
   /* search705_1_1 -> 835 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 2128, 835 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 2133, 2134 },
      -1,
   } },

   /* replace705_0_0 -> 6 in the cache */
   /* replace705_0_1 -> 2128 in the cache */
   /* replace705_0 -> 2131 in the cache */
   /* replace705_1 -> 835 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 2131, 835 },
      -1,
   } },

   /* ('iand', ('ieq', 'a@8', 0), ('ieq', 'b@8', 0)) => ('ieq', ('umax', 'a', 'b'), 0) */
   /* search706_0_0 -> 6 in the cache */
   /* search706_0_1 -> 835 in the cache */
   /* search706_0 -> 2127 in the cache */
   /* search706_1_0 -> 2128 in the cache */
   /* search706_1_1 -> 835 in the cache */
   /* search706_1 -> 2129 in the cache */
   /* search706 -> 2130 in the cache */

   /* replace706_0_0 -> 6 in the cache */
   /* replace706_0_1 -> 2128 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_umax,
      1, 1,
      { 6, 2128 },
      -1,
   } },
   /* replace706_1 -> 835 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 2137, 835 },
      -1,
   } },

   /* ('ior', ('ieq', 'a@8', 0), ('ieq', 'b@8', 0)) => ('ieq', ('umin', 'a', 'b'), 0) */
   /* search707_0_0 -> 6 in the cache */
   /* search707_0_1 -> 835 in the cache */
   /* search707_0 -> 2127 in the cache */
   /* search707_1_0 -> 2128 in the cache */
   /* search707_1_1 -> 835 in the cache */
   /* search707_1 -> 2129 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 2127, 2129 },
      -1,
   } },

   /* replace707_0_0 -> 6 in the cache */
   /* replace707_0_1 -> 2128 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_umin,
      1, 1,
      { 6, 2128 },
      -1,
   } },
   /* replace707_1 -> 835 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 2140, 835 },
      -1,
   } },

   /* ('iand', ('ine', 'a@8', 0), ('ine', 'b@8', 0)) => ('ine', ('umin', 'a', 'b'), 0) */
   /* search708_0_0 -> 6 in the cache */
   /* search708_0_1 -> 835 in the cache */
   /* search708_0 -> 2133 in the cache */
   /* search708_1_0 -> 2128 in the cache */
   /* search708_1_1 -> 835 in the cache */
   /* search708_1 -> 2134 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 2133, 2134 },
      -1,
   } },

   /* replace708_0_0 -> 6 in the cache */
   /* replace708_0_1 -> 2128 in the cache */
   /* replace708_0 -> 2140 in the cache */
   /* replace708_1 -> 835 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 2140, 835 },
      -1,
   } },

   /* ('ior', ('ine', 'a@8', 0), ('ine', 'b@8', 0)) => ('ine', ('umax', 'a', 'b'), 0) */
   /* search709_0_0 -> 6 in the cache */
   /* search709_0_1 -> 835 in the cache */
   /* search709_0 -> 2133 in the cache */
   /* search709_1_0 -> 2128 in the cache */
   /* search709_1_1 -> 835 in the cache */
   /* search709_1 -> 2134 in the cache */
   /* search709 -> 2135 in the cache */

   /* replace709_0_0 -> 6 in the cache */
   /* replace709_0_1 -> 2128 in the cache */
   /* replace709_0 -> 2137 in the cache */
   /* replace709_1 -> 835 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 2137, 835 },
      -1,
   } },

   /* ('ineg', ('b2i8', 'a@8')) => a */
   /* search710_0_0 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_b2i8,
      -1, 0,
      { 6 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 2145 },
      -1,
   } },

   /* replace710 -> 6 in the cache */

   /* ('ishl', 'a@8', ('iand', 7, 'b')) => ('ishl', 'a', 'b') */
   /* search711_0 -> 6 in the cache */
   /* search711_1_0 -> 9 in the cache */
   /* search711_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 9, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 6, 2147 },
      -1,
   } },

   /* replace711_0 -> 6 in the cache */
   /* replace711_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 6, 36 },
      -1,
   } },

   /* ('ishr', 'a@8', ('iand', 7, 'b')) => ('ishr', 'a', 'b') */
   /* search712_0 -> 6 in the cache */
   /* search712_1_0 -> 9 in the cache */
   /* search712_1_1 -> 36 in the cache */
   /* search712_1 -> 2147 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 1,
      { 6, 2147 },
      -1,
   } },

   /* replace712_0 -> 6 in the cache */
   /* replace712_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 6, 36 },
      -1,
   } },

   /* ('ushr', 'a@8', ('iand', 7, 'b')) => ('ushr', 'a', 'b') */
   /* search713_0 -> 6 in the cache */
   /* search713_1_0 -> 9 in the cache */
   /* search713_1_1 -> 36 in the cache */
   /* search713_1 -> 2147 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 6, 2147 },
      -1,
   } },

   /* replace713_0 -> 6 in the cache */
   /* replace713_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 6, 36 },
      -1,
   } },

   /* ('ushr', 'a@8', ('ishl(is_used_once)', ('iand', 'b', 1), 2)) => ('ushr', 'a', ('ishl', 'b', 2)) */
   /* search714_0 -> 6 in the cache */
   /* search714_1_0_0 -> 36 in the cache */
   /* search714_1_0_1 -> 396 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 36, 396 },
      -1,
   } },
   /* search714_1_1 -> 401 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 2154, 401 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 6, 2155 },
      -1,
   } },

   /* replace714_0 -> 6 in the cache */
   /* replace714_1_0 -> 36 in the cache */
   /* replace714_1_1 -> 401 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 36, 401 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 6, 2157 },
      -1,
   } },

   /* ('iand', ('ieq', 'a@16', 0), ('ieq', 'b@16', 0)) => ('ieq', ('ior', 'a', 'b'), 0) */
   /* search715_0_0 -> 11 in the cache */
   /* search715_0_1 -> 856 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 11, 856 },
      -1,
   } },
   /* search715_1_0 -> 258 in the cache */
   /* search715_1_1 -> 856 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 258, 856 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 2159, 2160 },
      -1,
   } },

   /* replace715_0_0 -> 11 in the cache */
   /* replace715_0_1 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 11, 258 },
      -1,
   } },
   /* replace715_1 -> 856 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 2162, 856 },
      -1,
   } },

   /* ('ior', ('ine', 'a@16', 0), ('ine', 'b@16', 0)) => ('ine', ('ior', 'a', 'b'), 0) */
   /* search716_0_0 -> 11 in the cache */
   /* search716_0_1 -> 856 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 11, 856 },
      -1,
   } },
   /* search716_1_0 -> 258 in the cache */
   /* search716_1_1 -> 856 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 258, 856 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 2164, 2165 },
      -1,
   } },

   /* replace716_0_0 -> 11 in the cache */
   /* replace716_0_1 -> 258 in the cache */
   /* replace716_0 -> 2162 in the cache */
   /* replace716_1 -> 856 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 2162, 856 },
      -1,
   } },

   /* ('iand', ('ieq', 'a@16', 0), ('ieq', 'b@16', 0)) => ('ieq', ('umax', 'a', 'b'), 0) */
   /* search717_0_0 -> 11 in the cache */
   /* search717_0_1 -> 856 in the cache */
   /* search717_0 -> 2159 in the cache */
   /* search717_1_0 -> 258 in the cache */
   /* search717_1_1 -> 856 in the cache */
   /* search717_1 -> 2160 in the cache */
   /* search717 -> 2161 in the cache */

   /* replace717_0_0 -> 11 in the cache */
   /* replace717_0_1 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_umax,
      1, 1,
      { 11, 258 },
      -1,
   } },
   /* replace717_1 -> 856 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 2168, 856 },
      -1,
   } },

   /* ('ior', ('ieq', 'a@16', 0), ('ieq', 'b@16', 0)) => ('ieq', ('umin', 'a', 'b'), 0) */
   /* search718_0_0 -> 11 in the cache */
   /* search718_0_1 -> 856 in the cache */
   /* search718_0 -> 2159 in the cache */
   /* search718_1_0 -> 258 in the cache */
   /* search718_1_1 -> 856 in the cache */
   /* search718_1 -> 2160 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 2159, 2160 },
      -1,
   } },

   /* replace718_0_0 -> 11 in the cache */
   /* replace718_0_1 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_umin,
      1, 1,
      { 11, 258 },
      -1,
   } },
   /* replace718_1 -> 856 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 2171, 856 },
      -1,
   } },

   /* ('iand', ('ine', 'a@16', 0), ('ine', 'b@16', 0)) => ('ine', ('umin', 'a', 'b'), 0) */
   /* search719_0_0 -> 11 in the cache */
   /* search719_0_1 -> 856 in the cache */
   /* search719_0 -> 2164 in the cache */
   /* search719_1_0 -> 258 in the cache */
   /* search719_1_1 -> 856 in the cache */
   /* search719_1 -> 2165 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 2164, 2165 },
      -1,
   } },

   /* replace719_0_0 -> 11 in the cache */
   /* replace719_0_1 -> 258 in the cache */
   /* replace719_0 -> 2171 in the cache */
   /* replace719_1 -> 856 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 2171, 856 },
      -1,
   } },

   /* ('ior', ('ine', 'a@16', 0), ('ine', 'b@16', 0)) => ('ine', ('umax', 'a', 'b'), 0) */
   /* search720_0_0 -> 11 in the cache */
   /* search720_0_1 -> 856 in the cache */
   /* search720_0 -> 2164 in the cache */
   /* search720_1_0 -> 258 in the cache */
   /* search720_1_1 -> 856 in the cache */
   /* search720_1 -> 2165 in the cache */
   /* search720 -> 2166 in the cache */

   /* replace720_0_0 -> 11 in the cache */
   /* replace720_0_1 -> 258 in the cache */
   /* replace720_0 -> 2168 in the cache */
   /* replace720_1 -> 856 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 2168, 856 },
      -1,
   } },

   /* ('ineg', ('b2i16', 'a@16')) => a */
   /* search721_0_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_b2i16,
      -1, 0,
      { 11 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 2176 },
      -1,
   } },

   /* replace721 -> 11 in the cache */

   /* ('ishl', 'a@16', ('iand', 15, 'b')) => ('ishl', 'a', 'b') */
   /* search722_0 -> 11 in the cache */
   /* search722_1_0 -> 14 in the cache */
   /* search722_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 14, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 11, 2178 },
      -1,
   } },

   /* replace722_0 -> 11 in the cache */
   /* replace722_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 11, 36 },
      -1,
   } },

   /* ('ishr', 'a@16', ('iand', 15, 'b')) => ('ishr', 'a', 'b') */
   /* search723_0 -> 11 in the cache */
   /* search723_1_0 -> 14 in the cache */
   /* search723_1_1 -> 36 in the cache */
   /* search723_1 -> 2178 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 1,
      { 11, 2178 },
      -1,
   } },

   /* replace723_0 -> 11 in the cache */
   /* replace723_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 11, 36 },
      -1,
   } },

   /* ('ushr', 'a@16', ('iand', 15, 'b')) => ('ushr', 'a', 'b') */
   /* search724_0 -> 11 in the cache */
   /* search724_1_0 -> 14 in the cache */
   /* search724_1_1 -> 36 in the cache */
   /* search724_1 -> 2178 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 11, 2178 },
      -1,
   } },

   /* replace724_0 -> 11 in the cache */
   /* replace724_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 11, 36 },
      -1,
   } },

   /* ('ushr', 'a@16', ('ishl(is_used_once)', ('iand', 'b', 1), 3)) => ('ushr', 'a', ('ishl', 'b', 3)) */
   /* search725_0 -> 11 in the cache */
   /* search725_1_0_0 -> 36 in the cache */
   /* search725_1_0_1 -> 396 in the cache */
   /* search725_1_0 -> 2154 in the cache */
   /* search725_1_1 -> 405 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 2154, 405 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 11, 2185 },
      -1,
   } },

   /* replace725_0 -> 11 in the cache */
   /* replace725_1_0 -> 36 in the cache */
   /* replace725_1_1 -> 405 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 36, 405 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 11, 2187 },
      -1,
   } },

   /* ('iand', ('ieq', 'a@32', 0), ('ieq', 'b@32', 0)) => ('ieq', ('ior', 'a', 'b'), 0) */
   /* search726_0_0 -> 16 in the cache */
   /* search726_0_1 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 16, 122 },
      -1,
   } },
   /* search726_1_0 -> 36 in the cache */
   /* search726_1_1 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 36, 122 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 2189, 2190 },
      -1,
   } },

   /* replace726_0_0 -> 16 in the cache */
   /* replace726_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 16, 36 },
      -1,
   } },
   /* replace726_1 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 2192, 122 },
      -1,
   } },

   /* ('ior', ('ine', 'a@32', 0), ('ine', 'b@32', 0)) => ('ine', ('ior', 'a', 'b'), 0) */
   /* search727_0_0 -> 16 in the cache */
   /* search727_0_1 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 16, 122 },
      -1,
   } },
   /* search727_1_0 -> 36 in the cache */
   /* search727_1_1 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 36, 122 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 2194, 2195 },
      -1,
   } },

   /* replace727_0_0 -> 16 in the cache */
   /* replace727_0_1 -> 36 in the cache */
   /* replace727_0 -> 2192 in the cache */
   /* replace727_1 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 2192, 122 },
      -1,
   } },

   /* ('iand', ('ieq', 'a@32', 0), ('ieq', 'b@32', 0)) => ('ieq', ('umax', 'a', 'b'), 0) */
   /* search728_0_0 -> 16 in the cache */
   /* search728_0_1 -> 122 in the cache */
   /* search728_0 -> 2189 in the cache */
   /* search728_1_0 -> 36 in the cache */
   /* search728_1_1 -> 122 in the cache */
   /* search728_1 -> 2190 in the cache */
   /* search728 -> 2191 in the cache */

   /* replace728_0_0 -> 16 in the cache */
   /* replace728_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_umax,
      1, 1,
      { 16, 36 },
      -1,
   } },
   /* replace728_1 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 2198, 122 },
      -1,
   } },

   /* ('ior', ('ieq', 'a@32', 0), ('ieq', 'b@32', 0)) => ('ieq', ('umin', 'a', 'b'), 0) */
   /* search729_0_0 -> 16 in the cache */
   /* search729_0_1 -> 122 in the cache */
   /* search729_0 -> 2189 in the cache */
   /* search729_1_0 -> 36 in the cache */
   /* search729_1_1 -> 122 in the cache */
   /* search729_1 -> 2190 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 2189, 2190 },
      -1,
   } },

   /* replace729_0_0 -> 16 in the cache */
   /* replace729_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_umin,
      1, 1,
      { 16, 36 },
      -1,
   } },
   /* replace729_1 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 2201, 122 },
      -1,
   } },

   /* ('iand', ('ine', 'a@32', 0), ('ine', 'b@32', 0)) => ('ine', ('umin', 'a', 'b'), 0) */
   /* search730_0_0 -> 16 in the cache */
   /* search730_0_1 -> 122 in the cache */
   /* search730_0 -> 2194 in the cache */
   /* search730_1_0 -> 36 in the cache */
   /* search730_1_1 -> 122 in the cache */
   /* search730_1 -> 2195 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 2194, 2195 },
      -1,
   } },

   /* replace730_0_0 -> 16 in the cache */
   /* replace730_0_1 -> 36 in the cache */
   /* replace730_0 -> 2201 in the cache */
   /* replace730_1 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 2201, 122 },
      -1,
   } },

   /* ('ior', ('ine', 'a@32', 0), ('ine', 'b@32', 0)) => ('ine', ('umax', 'a', 'b'), 0) */
   /* search731_0_0 -> 16 in the cache */
   /* search731_0_1 -> 122 in the cache */
   /* search731_0 -> 2194 in the cache */
   /* search731_1_0 -> 36 in the cache */
   /* search731_1_1 -> 122 in the cache */
   /* search731_1 -> 2195 in the cache */
   /* search731 -> 2196 in the cache */

   /* replace731_0_0 -> 16 in the cache */
   /* replace731_0_1 -> 36 in the cache */
   /* replace731_0 -> 2198 in the cache */
   /* replace731_1 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 2198, 122 },
      -1,
   } },

   /* ('ineg', ('b2i32', 'a@32')) => a */
   /* search732_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_b2i32,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 2206 },
      -1,
   } },

   /* replace732 -> 16 in the cache */

   /* ('ishl', 'a@32', ('iand', 31, 'b')) => ('ishl', 'a', 'b') */
   /* search733_0 -> 16 in the cache */
   /* search733_1_0 -> 19 in the cache */
   /* search733_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 19, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 16, 2208 },
      -1,
   } },

   /* replace733_0 -> 16 in the cache */
   /* replace733_1 -> 36 in the cache */
   /* replace733 -> 946 in the cache */

   /* ('ishr', 'a@32', ('iand', 31, 'b')) => ('ishr', 'a', 'b') */
   /* search734_0 -> 16 in the cache */
   /* search734_1_0 -> 19 in the cache */
   /* search734_1_1 -> 36 in the cache */
   /* search734_1 -> 2208 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 1,
      { 16, 2208 },
      -1,
   } },

   /* replace734_0 -> 16 in the cache */
   /* replace734_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 16, 36 },
      -1,
   } },

   /* ('ushr', 'a@32', ('iand', 31, 'b')) => ('ushr', 'a', 'b') */
   /* search735_0 -> 16 in the cache */
   /* search735_1_0 -> 19 in the cache */
   /* search735_1_1 -> 36 in the cache */
   /* search735_1 -> 2208 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 16, 2208 },
      -1,
   } },

   /* replace735_0 -> 16 in the cache */
   /* replace735_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 16, 36 },
      -1,
   } },

   /* ('ushr', 'a@32', ('ishl(is_used_once)', ('iand', 'b', 1), 4)) => ('ushr', 'a', ('ishl', 'b', 4)) */
   /* search736_0 -> 16 in the cache */
   /* search736_1_0_0 -> 36 in the cache */
   /* search736_1_0_1 -> 396 in the cache */
   /* search736_1_0 -> 2154 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x4 /* 4 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 2154, 2214 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 16, 2215 },
      -1,
   } },

   /* replace736_0 -> 16 in the cache */
   /* replace736_1_0 -> 36 in the cache */
   /* replace736_1_1 -> 2214 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 36, 2214 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 16, 2217 },
      -1,
   } },

   /* ('iand', ('ieq', 'a@64', 0), ('ieq', 'b@64', 0)) => ('ieq', ('ior', 'a', 'b'), 0) */
   /* search737_0_0 -> 21 in the cache */
   /* search737_0_1 -> 897 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 21, 897 },
      -1,
   } },
   /* search737_1_0 -> 41 in the cache */
   /* search737_1_1 -> 897 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 41, 897 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 2219, 2220 },
      -1,
   } },

   /* replace737_0_0 -> 21 in the cache */
   /* replace737_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 21, 41 },
      -1,
   } },
   /* replace737_1 -> 897 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 2222, 897 },
      -1,
   } },

   /* ('ior', ('ine', 'a@64', 0), ('ine', 'b@64', 0)) => ('ine', ('ior', 'a', 'b'), 0) */
   /* search738_0_0 -> 21 in the cache */
   /* search738_0_1 -> 897 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 21, 897 },
      -1,
   } },
   /* search738_1_0 -> 41 in the cache */
   /* search738_1_1 -> 897 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 41, 897 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 2224, 2225 },
      -1,
   } },

   /* replace738_0_0 -> 21 in the cache */
   /* replace738_0_1 -> 41 in the cache */
   /* replace738_0 -> 2222 in the cache */
   /* replace738_1 -> 897 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 2222, 897 },
      -1,
   } },

   /* ('iand', ('ieq', 'a@64', 0), ('ieq', 'b@64', 0)) => ('ieq', ('umax', 'a', 'b'), 0) */
   /* search739_0_0 -> 21 in the cache */
   /* search739_0_1 -> 897 in the cache */
   /* search739_0 -> 2219 in the cache */
   /* search739_1_0 -> 41 in the cache */
   /* search739_1_1 -> 897 in the cache */
   /* search739_1 -> 2220 in the cache */
   /* search739 -> 2221 in the cache */

   /* replace739_0_0 -> 21 in the cache */
   /* replace739_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_umax,
      1, 1,
      { 21, 41 },
      -1,
   } },
   /* replace739_1 -> 897 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 2228, 897 },
      -1,
   } },

   /* ('ior', ('ieq', 'a@64', 0), ('ieq', 'b@64', 0)) => ('ieq', ('umin', 'a', 'b'), 0) */
   /* search740_0_0 -> 21 in the cache */
   /* search740_0_1 -> 897 in the cache */
   /* search740_0 -> 2219 in the cache */
   /* search740_1_0 -> 41 in the cache */
   /* search740_1_1 -> 897 in the cache */
   /* search740_1 -> 2220 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 2219, 2220 },
      -1,
   } },

   /* replace740_0_0 -> 21 in the cache */
   /* replace740_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_umin,
      1, 1,
      { 21, 41 },
      -1,
   } },
   /* replace740_1 -> 897 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 2231, 897 },
      -1,
   } },

   /* ('iand', ('ine', 'a@64', 0), ('ine', 'b@64', 0)) => ('ine', ('umin', 'a', 'b'), 0) */
   /* search741_0_0 -> 21 in the cache */
   /* search741_0_1 -> 897 in the cache */
   /* search741_0 -> 2224 in the cache */
   /* search741_1_0 -> 41 in the cache */
   /* search741_1_1 -> 897 in the cache */
   /* search741_1 -> 2225 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 2224, 2225 },
      -1,
   } },

   /* replace741_0_0 -> 21 in the cache */
   /* replace741_0_1 -> 41 in the cache */
   /* replace741_0 -> 2231 in the cache */
   /* replace741_1 -> 897 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 2231, 897 },
      -1,
   } },

   /* ('ior', ('ine', 'a@64', 0), ('ine', 'b@64', 0)) => ('ine', ('umax', 'a', 'b'), 0) */
   /* search742_0_0 -> 21 in the cache */
   /* search742_0_1 -> 897 in the cache */
   /* search742_0 -> 2224 in the cache */
   /* search742_1_0 -> 41 in the cache */
   /* search742_1_1 -> 897 in the cache */
   /* search742_1 -> 2225 in the cache */
   /* search742 -> 2226 in the cache */

   /* replace742_0_0 -> 21 in the cache */
   /* replace742_0_1 -> 41 in the cache */
   /* replace742_0 -> 2228 in the cache */
   /* replace742_1 -> 897 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 2228, 897 },
      -1,
   } },

   /* ('ineg', ('b2i64', 'a@64')) => a */
   /* search743_0_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_b2i64,
      -1, 0,
      { 21 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 2236 },
      -1,
   } },

   /* replace743 -> 21 in the cache */

   /* ('ishl', 'a@64', ('iand', 63, 'b')) => ('ishl', 'a', 'b') */
   /* search744_0 -> 21 in the cache */
   /* search744_1_0 -> 24 in the cache */
   /* search744_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 24, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 21, 2238 },
      -1,
   } },

   /* replace744_0 -> 21 in the cache */
   /* replace744_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 21, 36 },
      -1,
   } },

   /* ('ishr', 'a@64', ('iand', 63, 'b')) => ('ishr', 'a', 'b') */
   /* search745_0 -> 21 in the cache */
   /* search745_1_0 -> 24 in the cache */
   /* search745_1_1 -> 36 in the cache */
   /* search745_1 -> 2238 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 1,
      { 21, 2238 },
      -1,
   } },

   /* replace745_0 -> 21 in the cache */
   /* replace745_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 21, 36 },
      -1,
   } },

   /* ('ushr', 'a@64', ('iand', 63, 'b')) => ('ushr', 'a', 'b') */
   /* search746_0 -> 21 in the cache */
   /* search746_1_0 -> 24 in the cache */
   /* search746_1_1 -> 36 in the cache */
   /* search746_1 -> 2238 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 21, 2238 },
      -1,
   } },

   /* replace746_0 -> 21 in the cache */
   /* replace746_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 21, 36 },
      -1,
   } },

   /* ('ushr', 'a@64', ('ishl(is_used_once)', ('iand', 'b', 1), 5)) => ('ushr', 'a', ('ishl', 'b', 5)) */
   /* search747_0 -> 21 in the cache */
   /* search747_1_0_0 -> 36 in the cache */
   /* search747_1_0_1 -> 396 in the cache */
   /* search747_1_0 -> 2154 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x5 /* 5 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 2154, 2245 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 21, 2246 },
      -1,
   } },

   /* replace747_0 -> 21 in the cache */
   /* replace747_1_0 -> 36 in the cache */
   /* replace747_1_1 -> 2245 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 36, 2245 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 21, 2248 },
      -1,
   } },

   /* ('ior', ('ieq', 'a', 0), ('ieq', 'a', 1)) => ('uge', 1, 'a') */
   /* search748_0_0 -> 32 in the cache */
   /* search748_0_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 32, 61 },
      -1,
   } },
   /* search748_1_0 -> 32 in the cache */
   /* search748_1_1 -> 35 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 32, 35 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 2250, 2251 },
      -1,
   } },

   /* replace748_0 -> 35 in the cache */
   /* replace748_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 35, 32 },
      -1,
   } },

   /* ('ior', ('uge', 1, 'a'), ('ieq', 'a', 2)) => ('uge', 2, 'a') */
   /* search749_0_0 -> 35 in the cache */
   /* search749_0_1 -> 32 in the cache */
   /* search749_0 -> 2253 in the cache */
   /* search749_1_0 -> 32 in the cache */
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_int, { 0x2 /* 2 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 32, 2254 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 2253, 2255 },
      -1,
   } },

   /* replace749_0 -> 2254 in the cache */
   /* replace749_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 2254, 32 },
      -1,
   } },

   /* ('ior', ('uge', 2, 'a'), ('ieq', 'a', 3)) => ('uge', 3, 'a') */
   /* search750_0_0 -> 2254 in the cache */
   /* search750_0_1 -> 32 in the cache */
   /* search750_0 -> 2257 in the cache */
   /* search750_1_0 -> 32 in the cache */
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_int, { 0x3 /* 3 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 32, 2258 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 2257, 2259 },
      -1,
   } },

   /* replace750_0 -> 2258 in the cache */
   /* replace750_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 2258, 32 },
      -1,
   } },

   /* ('ior', 'a', ('ieq', 'a', False)) => True */
   /* search751_0 -> 760 in the cache */
   /* search751_1_0 -> 760 in the cache */
   /* search751_1_1 -> 1077 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 760, 1077 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 760, 2262 },
      -1,
   } },

   /* replace751 -> 1235 in the cache */

   /* ('ine', ('ineg', ('b2i', 'a@1')), ('ineg', ('b2i', 'b@1'))) => ('ine', 'a', 'b') */
   /* search752_0_0_0 -> 760 in the cache */
   /* search752_0_0 -> 1228 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 1228 },
      -1,
   } },
   /* search752_1_0_0 -> 1134 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2i,
      -1, 0,
      { 1134 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 2265 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 2264, 2266 },
      -1,
   } },

   /* replace752_0 -> 760 in the cache */
   /* replace752_1 -> 1134 in the cache */
   /* replace752 -> 1391 in the cache */

   /* ('b2i', ('ine', 'a@1', 'b@1')) => ('b2i', ('ixor', 'a', 'b')) */
   /* search753_0_0 -> 760 in the cache */
   /* search753_0_1 -> 1134 in the cache */
   /* search753_0 -> 1391 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2i,
      -1, 1,
      { 1391 },
      -1,
   } },

   /* replace753_0_0 -> 760 in the cache */
   /* replace753_0_1 -> 1134 in the cache */
   /* replace753_0 -> 1151 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2i,
      -1, 1,
      { 1151 },
      -1,
   } },

   /* ('ishl', ('b2i32', ('ine', ('iand', 'a@32', '#b(is_pos_power_of_two)'), 0)), '#c') => ('bcsel', ('ige', ('iand', 'c', 31), ('find_lsb', 'b')), ('ishl', ('iand', 'a', 'b'), ('iadd', ('iand', 'c', 31), ('ineg', ('find_lsb', 'b')))), ('ushr', ('iand', 'a', 'b'), ('iadd', ('ineg', ('iand', 'c', 31)), ('find_lsb', 'b')))) */
   /* search754_0_0_0_0 -> 16 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      true,
      nir_type_invalid,
      0,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 16, 2270 },
      -1,
   } },
   /* search754_0_0_1 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 2271, 122 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_b2i32,
      -1, 2,
      { 2272 },
      -1,
   } },
   /* search754_1 -> 309 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 2,
      { 2273, 309 },
      -1,
   } },

   /* replace754_0_0_0 -> 135 in the cache */
   /* replace754_0_0_1 -> 19 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 135, 19 },
      -1,
   } },
   /* replace754_0_1_0 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_find_lsb,
      -1, 0,
      { 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 1,
      { 2275, 2276 },
      -1,
   } },
   /* replace754_1_0_0 -> 16 in the cache */
   /* replace754_1_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 16, 36 },
      -1,
   } },
   /* replace754_1_1_0_0 -> 135 in the cache */
   /* replace754_1_1_0_1 -> 19 in the cache */
   /* replace754_1_1_0 -> 885 in the cache */
   /* replace754_1_1_1_0_0 -> 36 in the cache */
   /* replace754_1_1_1_0 -> 2276 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 2276 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      2, 2,
      { 885, 2279 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 3,
      { 2278, 2280 },
      -1,
   } },
   /* replace754_2_0_0 -> 16 in the cache */
   /* replace754_2_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      4, 1,
      { 16, 36 },
      -1,
   } },
   /* replace754_2_1_0_0_0 -> 135 in the cache */
   /* replace754_2_1_0_0_1 -> 19 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      6, 1,
      { 135, 19 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 1,
      { 2283 },
      -1,
   } },
   /* replace754_2_1_1_0 -> 36 in the cache */
   /* replace754_2_1_1 -> 2276 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      5, 2,
      { 2284, 2276 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 3,
      { 2282, 2285 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 7,
      { 2277, 2281, 2286 },
      -1,
   } },

   /* ('b2i32', ('ine', ('iand', 'a@32', '#b(is_pos_power_of_two)'), 0)) => ('ushr', ('iand', 'a', 'b'), ('find_lsb', 'b')) */
   /* search755_0_0_0 -> 16 in the cache */
   /* search755_0_0_1 -> 2270 in the cache */
   /* search755_0_0 -> 2271 in the cache */
   /* search755_0_1 -> 122 in the cache */
   /* search755_0 -> 2272 in the cache */
   /* search755 -> 2273 in the cache */

   /* replace755_0_0 -> 16 in the cache */
   /* replace755_0_1 -> 36 in the cache */
   /* replace755_0 -> 2047 in the cache */
   /* replace755_1_0 -> 36 in the cache */
   /* replace755_1 -> 2276 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 2047, 2276 },
      -1,
   } },

   /* ('ior', ('b2i', 'a'), ('iand', 'b', 1)) => ('iand', ('ior', ('b2i', 'a'), 'b'), 1) */
   /* search756_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_search_op_b2i,
      -1, 0,
      { 32 },
      -1,
   } },
   /* search756_1_0 -> 3 in the cache */
   /* search756_1_1 -> 79 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 3, 79 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 2289, 2290 },
      -1,
   } },

   /* replace756_0_0_0 -> 32 in the cache */
   /* replace756_0_0 -> 2289 in the cache */
   /* replace756_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 2289, 3 },
      -1,
   } },
   /* replace756_1 -> 79 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 2292, 79 },
      -1,
   } },

   /* ('iand', ('b2i', 'a'), ('iand', 'b', 1)) => ('iand', ('b2i', 'a'), 'b') */
   /* search757_0_0 -> 32 in the cache */
   /* search757_0 -> 2289 in the cache */
   /* search757_1_0 -> 3 in the cache */
   /* search757_1_1 -> 79 in the cache */
   /* search757_1 -> 2290 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 2289, 2290 },
      -1,
   } },

   /* replace757_0_0 -> 32 in the cache */
   /* replace757_0 -> 2289 in the cache */
   /* replace757_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 2289, 3 },
      -1,
   } },

   /* ('iand', ('inot', ('iand', ('ior', ('ieq', 'a', 0), 'b'), 'c')), ('ilt', 'a', 0)) => ('iand', ('inot', ('iand', 'b', 'c')), ('ilt', 'a', 0)) */
   /* search758_0_0_0_0_0 -> 32 in the cache */
   /* search758_0_0_0_0_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      3, 1,
      { 32, 61 },
      -1,
   } },
   /* search758_0_0_0_1 -> 1134 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      2, 2,
      { 2296, 1134 },
      -1,
   } },
   /* search758_0_0_1 -> 464 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      1, 3,
      { 2297, 464 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 3,
      { 2298 },
      -1,
   } },
   /* search758_1_0 -> 32 in the cache */
   /* search758_1_1 -> 61 in the cache */
   /* search758_1 -> 1249 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 4,
      { 2299, 1249 },
      -1,
   } },

   /* replace758_0_0_0 -> 1134 in the cache */
   /* replace758_0_0_1 -> 464 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 1134, 464 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 1,
      { 2301 },
      -1,
   } },
   /* replace758_1_0 -> 32 in the cache */
   /* replace758_1_1 -> 61 in the cache */
   /* replace758_1 -> 1249 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 2302, 1249 },
      -1,
   } },

   /* ('iand', ('inot', ('iand', ('ieq', ('umin', 'a', 'b'), 0), 'c')), ('ilt', 'a', 0)) => ('iand', ('inot', ('iand', ('ieq', 'b', 0), 'c')), ('ilt', 'a', 0)) */
   /* search759_0_0_0_0_0 -> 0 in the cache */
   /* search759_0_0_0_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_umin,
      3, 1,
      { 0, 3 },
      -1,
   } },
   /* search759_0_0_0_1 -> 86 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 2,
      { 2304, 86 },
      -1,
   } },
   /* search759_0_0_1 -> 464 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      1, 3,
      { 2305, 464 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 3,
      { 2306 },
      -1,
   } },
   /* search759_1_0 -> 0 in the cache */
   /* search759_1_1 -> 86 in the cache */
   /* search759_1 -> 90 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 4,
      { 2307, 90 },
      -1,
   } },

   /* replace759_0_0_0_0 -> 3 in the cache */
   /* replace759_0_0_0_1 -> 86 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 3, 86 },
      -1,
   } },
   /* replace759_0_0_1 -> 464 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      1, 2,
      { 2309, 464 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 2,
      { 2310 },
      -1,
   } },
   /* replace759_1_0 -> 0 in the cache */
   /* replace759_1_1 -> 86 in the cache */
   /* replace759_1 -> 90 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 2311, 90 },
      -1,
   } },

   /* ('flt', 'a', ('fmax', 'b', 'a')) => ('flt', 'a', 'b') */
   /* search760_0 -> 32 in the cache */
   { .variable = {
      { nir_search_value_variable, -1 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search760_1_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 2313, 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 32, 2314 },
      -1,
   } },

   /* replace760_0 -> 32 in the cache */
   /* replace760_1 -> 2313 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 32, 2313 },
      -1,
   } },

   /* ('flt', ('fmin', 'a', 'b'), 'a') => ('flt', 'b', 'a') */
   /* search761_0_0 -> 0 in the cache */
   /* search761_0_1 -> 3 in the cache */
   /* search761_0 -> 1283 in the cache */
   /* search761_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 1283, 0 },
      -1,
   } },

   /* replace761_0 -> 3 in the cache */
   /* replace761_1 -> 0 in the cache */
   /* replace761 -> 1078 in the cache */

   /* ('~fge', 'a', ('fmin', 'b', 'a')) => True */
   /* search762_0 -> 32 in the cache */
   /* search762_1_0 -> 2313 in the cache */
   /* search762_1_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 2313, 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 32, 2318 },
      -1,
   } },

   /* replace762 -> 1235 in the cache */

   /* ('~fge', ('fmax', 'a', 'b'), 'a') => True */
   /* search763_0_0 -> 0 in the cache */
   /* search763_0_1 -> 3 in the cache */
   /* search763_0 -> 1281 in the cache */
   /* search763_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 1281, 0 },
      -1,
   } },

   /* replace763 -> 1235 in the cache */

   /* ('flt', 'a', ('fmin', 'b', 'a')) => False */
   /* search764_0 -> 32 in the cache */
   /* search764_1_0 -> 2313 in the cache */
   /* search764_1_1 -> 32 in the cache */
   /* search764_1 -> 2318 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 32, 2318 },
      -1,
   } },

   /* replace764 -> 1077 in the cache */

   /* ('flt', ('fmax', 'a', 'b'), 'a') => False */
   /* search765_0_0 -> 0 in the cache */
   /* search765_0_1 -> 3 in the cache */
   /* search765_0 -> 1281 in the cache */
   /* search765_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 1281, 0 },
      -1,
   } },

   /* replace765 -> 1077 in the cache */

   /* ('~fge', 'a', ('fmax', 'b', 'a')) => ('fge', 'a', 'b') */
   /* search766_0 -> 32 in the cache */
   /* search766_1_0 -> 2313 in the cache */
   /* search766_1_1 -> 32 in the cache */
   /* search766_1 -> 2314 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 32, 2314 },
      -1,
   } },

   /* replace766_0 -> 32 in the cache */
   /* replace766_1 -> 2313 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 32, 2313 },
      -1,
   } },

   /* ('~fge', ('fmin', 'a', 'b'), 'a') => ('fge', 'b', 'a') */
   /* search767_0_0 -> 0 in the cache */
   /* search767_0_1 -> 3 in the cache */
   /* search767_0 -> 1283 in the cache */
   /* search767_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 1283, 0 },
      -1,
   } },

   /* replace767_0 -> 3 in the cache */
   /* replace767_1 -> 0 in the cache */
   /* replace767 -> 1090 in the cache */

   /* ('ilt', 'a', ('imax', 'b', 'a')) => ('ilt', 'a', 'b') */
   /* search768_0 -> 32 in the cache */
   /* search768_1_0 -> 2313 in the cache */
   /* search768_1_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 2313, 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 32, 2326 },
      -1,
   } },

   /* replace768_0 -> 32 in the cache */
   /* replace768_1 -> 2313 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 32, 2313 },
      -1,
   } },

   /* ('ilt', ('imin', 'a', 'b'), 'a') => ('ilt', 'b', 'a') */
   /* search769_0_0 -> 0 in the cache */
   /* search769_0_1 -> 3 in the cache */
   /* search769_0 -> 1303 in the cache */
   /* search769_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 1303, 0 },
      -1,
   } },

   /* replace769_0 -> 3 in the cache */
   /* replace769_1 -> 0 in the cache */
   /* replace769 -> 1083 in the cache */

   /* ('ige', 'a', ('imin', 'b', 'a')) => True */
   /* search770_0 -> 32 in the cache */
   /* search770_1_0 -> 2313 in the cache */
   /* search770_1_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imin,
      0, 1,
      { 2313, 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 1,
      { 32, 2330 },
      -1,
   } },

   /* replace770 -> 1235 in the cache */

   /* ('ige', ('imax', 'a', 'b'), 'a') => True */
   /* search771_0_0 -> 0 in the cache */
   /* search771_0_1 -> 3 in the cache */
   /* search771_0 -> 1301 in the cache */
   /* search771_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 1,
      { 1301, 0 },
      -1,
   } },

   /* replace771 -> 1235 in the cache */

   /* ('ult', 'a', ('umax', 'b', 'a')) => ('ult', 'a', 'b') */
   /* search772_0 -> 32 in the cache */
   /* search772_1_0 -> 2313 in the cache */
   /* search772_1_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_umax,
      0, 1,
      { 2313, 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 1,
      { 32, 2333 },
      -1,
   } },

   /* replace772_0 -> 32 in the cache */
   /* replace772_1 -> 2313 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 32, 2313 },
      -1,
   } },

   /* ('ult', ('umin', 'a', 'b'), 'a') => ('ult', 'b', 'a') */
   /* search773_0_0 -> 0 in the cache */
   /* search773_0_1 -> 3 in the cache */
   /* search773_0 -> 1293 in the cache */
   /* search773_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 1,
      { 1293, 0 },
      -1,
   } },

   /* replace773_0 -> 3 in the cache */
   /* replace773_1 -> 0 in the cache */
   /* replace773 -> 1085 in the cache */

   /* ('uge', 'a', ('umin', 'b', 'a')) => True */
   /* search774_0 -> 32 in the cache */
   /* search774_1_0 -> 2313 in the cache */
   /* search774_1_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_umin,
      0, 1,
      { 2313, 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 1,
      { 32, 2337 },
      -1,
   } },

   /* replace774 -> 1235 in the cache */

   /* ('uge', ('umax', 'a', 'b'), 'a') => True */
   /* search775_0_0 -> 0 in the cache */
   /* search775_0_1 -> 3 in the cache */
   /* search775_0 -> 1291 in the cache */
   /* search775_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 1,
      { 1291, 0 },
      -1,
   } },

   /* replace775 -> 1235 in the cache */

   /* ('ilt', 'a', ('imin', 'b', 'a')) => False */
   /* search776_0 -> 32 in the cache */
   /* search776_1_0 -> 2313 in the cache */
   /* search776_1_1 -> 32 in the cache */
   /* search776_1 -> 2330 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 32, 2330 },
      -1,
   } },

   /* replace776 -> 1077 in the cache */

   /* ('ilt', ('imax', 'a', 'b'), 'a') => False */
   /* search777_0_0 -> 0 in the cache */
   /* search777_0_1 -> 3 in the cache */
   /* search777_0 -> 1301 in the cache */
   /* search777_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 1301, 0 },
      -1,
   } },

   /* replace777 -> 1077 in the cache */

   /* ('ige', 'a', ('imax', 'b', 'a')) => ('ige', 'a', 'b') */
   /* search778_0 -> 32 in the cache */
   /* search778_1_0 -> 2313 in the cache */
   /* search778_1_1 -> 32 in the cache */
   /* search778_1 -> 2326 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 1,
      { 32, 2326 },
      -1,
   } },

   /* replace778_0 -> 32 in the cache */
   /* replace778_1 -> 2313 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 32, 2313 },
      -1,
   } },

   /* ('ige', ('imin', 'a', 'b'), 'a') => ('ige', 'b', 'a') */
   /* search779_0_0 -> 0 in the cache */
   /* search779_0_1 -> 3 in the cache */
   /* search779_0 -> 1303 in the cache */
   /* search779_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 1,
      { 1303, 0 },
      -1,
   } },

   /* replace779_0 -> 3 in the cache */
   /* replace779_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 3, 0 },
      -1,
   } },

   /* ('ult', 'a', ('umin', 'b', 'a')) => False */
   /* search780_0 -> 32 in the cache */
   /* search780_1_0 -> 2313 in the cache */
   /* search780_1_1 -> 32 in the cache */
   /* search780_1 -> 2337 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 1,
      { 32, 2337 },
      -1,
   } },

   /* replace780 -> 1077 in the cache */

   /* ('ult', ('umax', 'a', 'b'), 'a') => False */
   /* search781_0_0 -> 0 in the cache */
   /* search781_0_1 -> 3 in the cache */
   /* search781_0 -> 1291 in the cache */
   /* search781_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 1,
      { 1291, 0 },
      -1,
   } },

   /* replace781 -> 1077 in the cache */

   /* ('uge', 'a', ('umax', 'b', 'a')) => ('uge', 'a', 'b') */
   /* search782_0 -> 32 in the cache */
   /* search782_1_0 -> 2313 in the cache */
   /* search782_1_1 -> 32 in the cache */
   /* search782_1 -> 2333 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 1,
      { 32, 2333 },
      -1,
   } },

   /* replace782_0 -> 32 in the cache */
   /* replace782_1 -> 2313 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 32, 2313 },
      -1,
   } },

   /* ('uge', ('umin', 'a', 'b'), 'a') => ('uge', 'b', 'a') */
   /* search783_0_0 -> 0 in the cache */
   /* search783_0_1 -> 3 in the cache */
   /* search783_0 -> 1293 in the cache */
   /* search783_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 1,
      { 1293, 0 },
      -1,
   } },

   /* replace783_0 -> 3 in the cache */
   /* replace783_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 3, 0 },
      -1,
   } },

   /* ('ult', 'a', ('iand', 'b', 'a')) => False */
   /* search784_0 -> 32 in the cache */
   /* search784_1_0 -> 2313 in the cache */
   /* search784_1_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 2313, 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 1,
      { 32, 2352 },
      -1,
   } },

   /* replace784 -> 1077 in the cache */

   /* ('ult', ('ior', 'a', 'b'), 'a') => False */
   /* search785_0_0 -> 0 in the cache */
   /* search785_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 0, 3 },
      -1,
   } },
   /* search785_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 1,
      { 2354, 0 },
      -1,
   } },

   /* replace785 -> 1077 in the cache */

   /* ('uge', 'a', ('iand', 'b', 'a')) => True */
   /* search786_0 -> 32 in the cache */
   /* search786_1_0 -> 2313 in the cache */
   /* search786_1_1 -> 32 in the cache */
   /* search786_1 -> 2352 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 1,
      { 32, 2352 },
      -1,
   } },

   /* replace786 -> 1235 in the cache */

   /* ('uge', ('ior', 'a', 'b'), 'a') => True */
   /* search787_0_0 -> 0 in the cache */
   /* search787_0_1 -> 3 in the cache */
   /* search787_0 -> 2354 in the cache */
   /* search787_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 1,
      { 2354, 0 },
      -1,
   } },

   /* replace787 -> 1235 in the cache */

   /* ('ilt', '#a', ('imax', '#b', 'c')) => ('ior', ('ilt', 'a', 'b'), ('ilt', 'a', 'c')) */
   /* search788_0 -> 282 in the cache */
   /* search788_1_0 -> 283 in the cache */
   /* search788_1_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 283, 129 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 282, 2358 },
      -1,
   } },

   /* replace788_0_0 -> 126 in the cache */
   /* replace788_0_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 126, 127 },
      -1,
   } },
   /* replace788_1_0 -> 126 in the cache */
   /* replace788_1_1 -> 129 in the cache */
   /* replace788_1 -> 1657 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 2360, 1657 },
      -1,
   } },

   /* ('ilt', ('imin', '#a', 'b'), '#c') => ('ior', ('ilt', 'a', 'c'), ('ilt', 'b', 'c')) */
   /* search789_0_0 -> 282 in the cache */
   /* search789_0_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imin,
      0, 1,
      { 282, 127 },
      -1,
   } },
   /* search789_1 -> 814 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 2362, 814 },
      -1,
   } },

   /* replace789_0_0 -> 126 in the cache */
   /* replace789_0_1 -> 129 in the cache */
   /* replace789_0 -> 1657 in the cache */
   /* replace789_1_0 -> 127 in the cache */
   /* replace789_1_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 127, 129 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1657, 2364 },
      -1,
   } },

   /* ('ige', '#a', ('imin', '#b', 'c')) => ('ior', ('ige', 'a', 'b'), ('ige', 'a', 'c')) */
   /* search790_0 -> 282 in the cache */
   /* search790_1_0 -> 283 in the cache */
   /* search790_1_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imin,
      0, 1,
      { 283, 129 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 1,
      { 282, 2366 },
      -1,
   } },

   /* replace790_0_0 -> 126 in the cache */
   /* replace790_0_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 126, 127 },
      -1,
   } },
   /* replace790_1_0 -> 126 in the cache */
   /* replace790_1_1 -> 129 in the cache */
   /* replace790_1 -> 1667 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 2368, 1667 },
      -1,
   } },

   /* ('ige', ('imax', '#a', 'b'), '#c') => ('ior', ('ige', 'a', 'c'), ('ige', 'b', 'c')) */
   /* search791_0_0 -> 282 in the cache */
   /* search791_0_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 282, 127 },
      -1,
   } },
   /* search791_1 -> 814 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 1,
      { 2370, 814 },
      -1,
   } },

   /* replace791_0_0 -> 126 in the cache */
   /* replace791_0_1 -> 129 in the cache */
   /* replace791_0 -> 1667 in the cache */
   /* replace791_1_0 -> 127 in the cache */
   /* replace791_1_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 127, 129 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1667, 2372 },
      -1,
   } },

   /* ('ult', '#a', ('umax', '#b', 'c')) => ('ior', ('ult', 'a', 'b'), ('ult', 'a', 'c')) */
   /* search792_0 -> 282 in the cache */
   /* search792_1_0 -> 283 in the cache */
   /* search792_1_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_umax,
      0, 1,
      { 283, 129 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 1,
      { 282, 2374 },
      -1,
   } },

   /* replace792_0_0 -> 126 in the cache */
   /* replace792_0_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 126, 127 },
      -1,
   } },
   /* replace792_1_0 -> 126 in the cache */
   /* replace792_1_1 -> 129 in the cache */
   /* replace792_1 -> 1677 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 2376, 1677 },
      -1,
   } },

   /* ('ult', ('umin', '#a', 'b'), '#c') => ('ior', ('ult', 'a', 'c'), ('ult', 'b', 'c')) */
   /* search793_0_0 -> 282 in the cache */
   /* search793_0_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_umin,
      0, 1,
      { 282, 127 },
      -1,
   } },
   /* search793_1 -> 814 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 1,
      { 2378, 814 },
      -1,
   } },

   /* replace793_0_0 -> 126 in the cache */
   /* replace793_0_1 -> 129 in the cache */
   /* replace793_0 -> 1677 in the cache */
   /* replace793_1_0 -> 127 in the cache */
   /* replace793_1_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 127, 129 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1677, 2380 },
      -1,
   } },

   /* ('uge', '#a', ('umin', '#b', 'c')) => ('ior', ('uge', 'a', 'b'), ('uge', 'a', 'c')) */
   /* search794_0 -> 282 in the cache */
   /* search794_1_0 -> 283 in the cache */
   /* search794_1_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_umin,
      0, 1,
      { 283, 129 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 1,
      { 282, 2382 },
      -1,
   } },

   /* replace794_0_0 -> 126 in the cache */
   /* replace794_0_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 126, 127 },
      -1,
   } },
   /* replace794_1_0 -> 126 in the cache */
   /* replace794_1_1 -> 129 in the cache */
   /* replace794_1 -> 1687 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 2384, 1687 },
      -1,
   } },

   /* ('uge', ('umax', '#a', 'b'), '#c') => ('ior', ('uge', 'a', 'c'), ('uge', 'b', 'c')) */
   /* search795_0_0 -> 282 in the cache */
   /* search795_0_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_umax,
      0, 1,
      { 282, 127 },
      -1,
   } },
   /* search795_1 -> 814 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 1,
      { 2386, 814 },
      -1,
   } },

   /* replace795_0_0 -> 126 in the cache */
   /* replace795_0_1 -> 129 in the cache */
   /* replace795_0 -> 1687 in the cache */
   /* replace795_1_0 -> 127 in the cache */
   /* replace795_1_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 127, 129 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1687, 2388 },
      -1,
   } },

   /* ('ilt', '#a', ('imin', '#b', 'c')) => ('iand', ('ilt', 'a', 'b'), ('ilt', 'a', 'c')) */
   /* search796_0 -> 282 in the cache */
   /* search796_1_0 -> 283 in the cache */
   /* search796_1_1 -> 129 in the cache */
   /* search796_1 -> 2366 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 282, 2366 },
      -1,
   } },

   /* replace796_0_0 -> 126 in the cache */
   /* replace796_0_1 -> 127 in the cache */
   /* replace796_0 -> 2360 in the cache */
   /* replace796_1_0 -> 126 in the cache */
   /* replace796_1_1 -> 129 in the cache */
   /* replace796_1 -> 1657 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 2360, 1657 },
      -1,
   } },

   /* ('ilt', ('imax', '#a', 'b'), '#c') => ('iand', ('ilt', 'a', 'c'), ('ilt', 'b', 'c')) */
   /* search797_0_0 -> 282 in the cache */
   /* search797_0_1 -> 127 in the cache */
   /* search797_0 -> 2370 in the cache */
   /* search797_1 -> 814 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 2370, 814 },
      -1,
   } },

   /* replace797_0_0 -> 126 in the cache */
   /* replace797_0_1 -> 129 in the cache */
   /* replace797_0 -> 1657 in the cache */
   /* replace797_1_0 -> 127 in the cache */
   /* replace797_1_1 -> 129 in the cache */
   /* replace797_1 -> 2364 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1657, 2364 },
      -1,
   } },

   /* ('ige', '#a', ('imax', '#b', 'c')) => ('iand', ('ige', 'a', 'b'), ('ige', 'a', 'c')) */
   /* search798_0 -> 282 in the cache */
   /* search798_1_0 -> 283 in the cache */
   /* search798_1_1 -> 129 in the cache */
   /* search798_1 -> 2358 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 1,
      { 282, 2358 },
      -1,
   } },

   /* replace798_0_0 -> 126 in the cache */
   /* replace798_0_1 -> 127 in the cache */
   /* replace798_0 -> 2368 in the cache */
   /* replace798_1_0 -> 126 in the cache */
   /* replace798_1_1 -> 129 in the cache */
   /* replace798_1 -> 1667 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 2368, 1667 },
      -1,
   } },

   /* ('ige', ('imin', '#a', 'b'), '#c') => ('iand', ('ige', 'a', 'c'), ('ige', 'b', 'c')) */
   /* search799_0_0 -> 282 in the cache */
   /* search799_0_1 -> 127 in the cache */
   /* search799_0 -> 2362 in the cache */
   /* search799_1 -> 814 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 1,
      { 2362, 814 },
      -1,
   } },

   /* replace799_0_0 -> 126 in the cache */
   /* replace799_0_1 -> 129 in the cache */
   /* replace799_0 -> 1667 in the cache */
   /* replace799_1_0 -> 127 in the cache */
   /* replace799_1_1 -> 129 in the cache */
   /* replace799_1 -> 2372 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1667, 2372 },
      -1,
   } },

   /* ('ult', '#a', ('umin', '#b', 'c')) => ('iand', ('ult', 'a', 'b'), ('ult', 'a', 'c')) */
   /* search800_0 -> 282 in the cache */
   /* search800_1_0 -> 283 in the cache */
   /* search800_1_1 -> 129 in the cache */
   /* search800_1 -> 2382 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 1,
      { 282, 2382 },
      -1,
   } },

   /* replace800_0_0 -> 126 in the cache */
   /* replace800_0_1 -> 127 in the cache */
   /* replace800_0 -> 2376 in the cache */
   /* replace800_1_0 -> 126 in the cache */
   /* replace800_1_1 -> 129 in the cache */
   /* replace800_1 -> 1677 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 2376, 1677 },
      -1,
   } },

   /* ('ult', ('umax', '#a', 'b'), '#c') => ('iand', ('ult', 'a', 'c'), ('ult', 'b', 'c')) */
   /* search801_0_0 -> 282 in the cache */
   /* search801_0_1 -> 127 in the cache */
   /* search801_0 -> 2386 in the cache */
   /* search801_1 -> 814 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 1,
      { 2386, 814 },
      -1,
   } },

   /* replace801_0_0 -> 126 in the cache */
   /* replace801_0_1 -> 129 in the cache */
   /* replace801_0 -> 1677 in the cache */
   /* replace801_1_0 -> 127 in the cache */
   /* replace801_1_1 -> 129 in the cache */
   /* replace801_1 -> 2380 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1677, 2380 },
      -1,
   } },

   /* ('uge', '#a', ('umax', '#b', 'c')) => ('iand', ('uge', 'a', 'b'), ('uge', 'a', 'c')) */
   /* search802_0 -> 282 in the cache */
   /* search802_1_0 -> 283 in the cache */
   /* search802_1_1 -> 129 in the cache */
   /* search802_1 -> 2374 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 1,
      { 282, 2374 },
      -1,
   } },

   /* replace802_0_0 -> 126 in the cache */
   /* replace802_0_1 -> 127 in the cache */
   /* replace802_0 -> 2384 in the cache */
   /* replace802_1_0 -> 126 in the cache */
   /* replace802_1_1 -> 129 in the cache */
   /* replace802_1 -> 1687 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 2384, 1687 },
      -1,
   } },

   /* ('uge', ('umin', '#a', 'b'), '#c') => ('iand', ('uge', 'a', 'c'), ('uge', 'b', 'c')) */
   /* search803_0_0 -> 282 in the cache */
   /* search803_0_1 -> 127 in the cache */
   /* search803_0 -> 2378 in the cache */
   /* search803_1 -> 814 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 1,
      { 2378, 814 },
      -1,
   } },

   /* replace803_0_0 -> 126 in the cache */
   /* replace803_0_1 -> 129 in the cache */
   /* replace803_0 -> 1687 in the cache */
   /* replace803_1_0 -> 127 in the cache */
   /* replace803_1_1 -> 129 in the cache */
   /* replace803_1 -> 2388 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1687, 2388 },
      -1,
   } },

   /* ('bcsel', ('ilt', 'a', 0), ('ineg', ('ishr', 'a', 'b')), ('ishr', 'a', 'b')) => ('iabs', ('ishr', 'a', 'b')) */
   /* search804_0_0 -> 32 in the cache */
   /* search804_0_1 -> 61 in the cache */
   /* search804_0 -> 1249 in the cache */
   /* search804_1_0_0 -> 32 in the cache */
   /* search804_1_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 32, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 2406 },
      -1,
   } },
   /* search804_2_0 -> 32 in the cache */
   /* search804_2_1 -> 36 in the cache */
   /* search804_2 -> 2406 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1249, 2407, 2406 },
      -1,
   } },

   /* replace804_0_0 -> 32 in the cache */
   /* replace804_0_1 -> 36 in the cache */
   /* replace804_0 -> 2406 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_iabs,
      -1, 0,
      { 2406 },
      -1,
   } },

   /* ('iabs', ('ishr', ('iabs', 'a'), 'b')) => ('ishr', ('iabs', 'a'), 'b') */
   /* search805_0_0_0 -> 32 in the cache */
   /* search805_0_0 -> 106 in the cache */
   /* search805_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 106, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_iabs,
      -1, 0,
      { 2410 },
      -1,
   } },

   /* replace805_0_0 -> 32 in the cache */
   /* replace805_0 -> 106 in the cache */
   /* replace805_1 -> 36 in the cache */
   /* replace805 -> 2410 in the cache */

   /* ('fabs', ('slt', 'a', 'b')) => ('slt', 'a', 'b') */
   /* search806_0_0 -> 0 in the cache */
   /* search806_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_slt,
      -1, 0,
      { 0, 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 2412 },
      -1,
   } },

   /* replace806_0 -> 0 in the cache */
   /* replace806_1 -> 3 in the cache */
   /* replace806 -> 2412 in the cache */

   /* ('fabs', ('sge', 'a', 'b')) => ('sge', 'a', 'b') */
   /* search807_0_0 -> 0 in the cache */
   /* search807_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_sge,
      -1, 0,
      { 0, 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 2414 },
      -1,
   } },

   /* replace807_0 -> 0 in the cache */
   /* replace807_1 -> 3 in the cache */
   /* replace807 -> 2414 in the cache */

   /* ('fabs', ('seq', 'a', 'b')) => ('seq', 'a', 'b') */
   /* search808_0_0 -> 0 in the cache */
   /* search808_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_seq,
      0, 1,
      { 0, 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 1,
      { 2416 },
      -1,
   } },

   /* replace808_0 -> 0 in the cache */
   /* replace808_1 -> 3 in the cache */
   /* replace808 -> 2416 in the cache */

   /* ('fabs', ('sne', 'a', 'b')) => ('sne', 'a', 'b') */
   /* search809_0_0 -> 0 in the cache */
   /* search809_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_sne,
      0, 1,
      { 0, 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 1,
      { 2418 },
      -1,
   } },

   /* replace809_0 -> 0 in the cache */
   /* replace809_1 -> 3 in the cache */
   /* replace809 -> 2418 in the cache */

   /* ('slt', 'a', 'b') => ('b2f', ('flt', 'a', 'b')) */
   /* search810_0 -> 0 in the cache */
   /* search810_1 -> 3 in the cache */
   /* search810 -> 2412 in the cache */

   /* replace810_0_0 -> 0 in the cache */
   /* replace810_0_1 -> 3 in the cache */
   /* replace810_0 -> 1049 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 1049 },
      -1,
   } },

   /* ('sge', 'a', 'b') => ('b2f', ('fge', 'a', 'b')) */
   /* search811_0 -> 0 in the cache */
   /* search811_1 -> 3 in the cache */
   /* search811 -> 2414 in the cache */

   /* replace811_0_0 -> 0 in the cache */
   /* replace811_0_1 -> 3 in the cache */
   /* replace811_0 -> 1046 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 1046 },
      -1,
   } },

   /* ('seq', 'a', 'b') => ('b2f', ('feq', 'a', 'b')) */
   /* search812_0 -> 0 in the cache */
   /* search812_1 -> 3 in the cache */
   /* search812 -> 2416 in the cache */

   /* replace812_0_0 -> 0 in the cache */
   /* replace812_0_1 -> 3 in the cache */
   /* replace812_0 -> 1055 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 1,
      { 1055 },
      -1,
   } },

   /* ('sne', 'a', 'b') => ('b2f', ('fneu', 'a', 'b')) */
   /* search813_0 -> 0 in the cache */
   /* search813_1 -> 3 in the cache */
   /* search813 -> 2418 in the cache */

   /* replace813_0_0 -> 0 in the cache */
   /* replace813_0_1 -> 3 in the cache */
   /* replace813_0 -> 1052 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 1,
      { 1052 },
      -1,
   } },

   /* ('seq', ('seq', 'a', 'b'), 1.0) => ('seq', 'a', 'b') */
   /* search814_0_0 -> 0 in the cache */
   /* search814_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_seq,
      1, 1,
      { 0, 3 },
      -1,
   } },
   /* search814_1 -> 270 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_seq,
      0, 2,
      { 2424, 270 },
      -1,
   } },

   /* replace814_0 -> 0 in the cache */
   /* replace814_1 -> 3 in the cache */
   /* replace814 -> 2416 in the cache */

   /* ('seq', ('sne', 'a', 'b'), 1.0) => ('sne', 'a', 'b') */
   /* search815_0_0 -> 0 in the cache */
   /* search815_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_sne,
      1, 1,
      { 0, 3 },
      -1,
   } },
   /* search815_1 -> 270 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_seq,
      0, 2,
      { 2426, 270 },
      -1,
   } },

   /* replace815_0 -> 0 in the cache */
   /* replace815_1 -> 3 in the cache */
   /* replace815 -> 2418 in the cache */

   /* ('seq', ('slt', 'a', 'b'), 1.0) => ('slt', 'a', 'b') */
   /* search816_0_0 -> 0 in the cache */
   /* search816_0_1 -> 3 in the cache */
   /* search816_0 -> 2412 in the cache */
   /* search816_1 -> 270 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_seq,
      0, 1,
      { 2412, 270 },
      -1,
   } },

   /* replace816_0 -> 0 in the cache */
   /* replace816_1 -> 3 in the cache */
   /* replace816 -> 2412 in the cache */

   /* ('seq', ('sge', 'a', 'b'), 1.0) => ('sge', 'a', 'b') */
   /* search817_0_0 -> 0 in the cache */
   /* search817_0_1 -> 3 in the cache */
   /* search817_0 -> 2414 in the cache */
   /* search817_1 -> 270 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_seq,
      0, 1,
      { 2414, 270 },
      -1,
   } },

   /* replace817_0 -> 0 in the cache */
   /* replace817_1 -> 3 in the cache */
   /* replace817 -> 2414 in the cache */

   /* ('sne', ('seq', 'a', 'b'), 0.0) => ('seq', 'a', 'b') */
   /* search818_0_0 -> 0 in the cache */
   /* search818_0_1 -> 3 in the cache */
   /* search818_0 -> 2424 in the cache */
   /* search818_1 -> 256 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_sne,
      0, 2,
      { 2424, 256 },
      -1,
   } },

   /* replace818_0 -> 0 in the cache */
   /* replace818_1 -> 3 in the cache */
   /* replace818 -> 2416 in the cache */

   /* ('sne', ('sne', 'a', 'b'), 0.0) => ('sne', 'a', 'b') */
   /* search819_0_0 -> 0 in the cache */
   /* search819_0_1 -> 3 in the cache */
   /* search819_0 -> 2426 in the cache */
   /* search819_1 -> 256 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_sne,
      0, 2,
      { 2426, 256 },
      -1,
   } },

   /* replace819_0 -> 0 in the cache */
   /* replace819_1 -> 3 in the cache */
   /* replace819 -> 2418 in the cache */

   /* ('sne', ('slt', 'a', 'b'), 0.0) => ('slt', 'a', 'b') */
   /* search820_0_0 -> 0 in the cache */
   /* search820_0_1 -> 3 in the cache */
   /* search820_0 -> 2412 in the cache */
   /* search820_1 -> 256 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_sne,
      0, 1,
      { 2412, 256 },
      -1,
   } },

   /* replace820_0 -> 0 in the cache */
   /* replace820_1 -> 3 in the cache */
   /* replace820 -> 2412 in the cache */

   /* ('sne', ('sge', 'a', 'b'), 0.0) => ('sge', 'a', 'b') */
   /* search821_0_0 -> 0 in the cache */
   /* search821_0_1 -> 3 in the cache */
   /* search821_0 -> 2414 in the cache */
   /* search821_1 -> 256 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_sne,
      0, 1,
      { 2414, 256 },
      -1,
   } },

   /* replace821_0 -> 0 in the cache */
   /* replace821_1 -> 3 in the cache */
   /* replace821 -> 2414 in the cache */

   /* ('seq', ('seq', 'a', 'b'), 0.0) => ('sne', 'a', 'b') */
   /* search822_0_0 -> 0 in the cache */
   /* search822_0_1 -> 3 in the cache */
   /* search822_0 -> 2424 in the cache */
   /* search822_1 -> 256 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_seq,
      0, 2,
      { 2424, 256 },
      -1,
   } },

   /* replace822_0 -> 0 in the cache */
   /* replace822_1 -> 3 in the cache */
   /* replace822 -> 2418 in the cache */

   /* ('seq', ('sne', 'a', 'b'), 0.0) => ('seq', 'a', 'b') */
   /* search823_0_0 -> 0 in the cache */
   /* search823_0_1 -> 3 in the cache */
   /* search823_0 -> 2426 in the cache */
   /* search823_1 -> 256 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_seq,
      0, 2,
      { 2426, 256 },
      -1,
   } },

   /* replace823_0 -> 0 in the cache */
   /* replace823_1 -> 3 in the cache */
   /* replace823 -> 2416 in the cache */

   /* ('seq', ('slt', 'a', 'b'), 0.0) => ('sge', 'a', 'b') */
   /* search824_0_0 -> 0 in the cache */
   /* search824_0_1 -> 3 in the cache */
   /* search824_0 -> 2412 in the cache */
   /* search824_1 -> 256 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_seq,
      0, 1,
      { 2412, 256 },
      -1,
   } },

   /* replace824_0 -> 0 in the cache */
   /* replace824_1 -> 3 in the cache */
   /* replace824 -> 2414 in the cache */

   /* ('seq', ('sge', 'a', 'b'), 0.0) => ('slt', 'a', 'b') */
   /* search825_0_0 -> 0 in the cache */
   /* search825_0_1 -> 3 in the cache */
   /* search825_0 -> 2414 in the cache */
   /* search825_1 -> 256 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_seq,
      0, 1,
      { 2414, 256 },
      -1,
   } },

   /* replace825_0 -> 0 in the cache */
   /* replace825_1 -> 3 in the cache */
   /* replace825 -> 2412 in the cache */

   /* ('sne', ('seq', 'a', 'b'), 1.0) => ('sne', 'a', 'b') */
   /* search826_0_0 -> 0 in the cache */
   /* search826_0_1 -> 3 in the cache */
   /* search826_0 -> 2424 in the cache */
   /* search826_1 -> 270 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_sne,
      0, 2,
      { 2424, 270 },
      -1,
   } },

   /* replace826_0 -> 0 in the cache */
   /* replace826_1 -> 3 in the cache */
   /* replace826 -> 2418 in the cache */

   /* ('sne', ('sne', 'a', 'b'), 1.0) => ('seq', 'a', 'b') */
   /* search827_0_0 -> 0 in the cache */
   /* search827_0_1 -> 3 in the cache */
   /* search827_0 -> 2426 in the cache */
   /* search827_1 -> 270 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_sne,
      0, 2,
      { 2426, 270 },
      -1,
   } },

   /* replace827_0 -> 0 in the cache */
   /* replace827_1 -> 3 in the cache */
   /* replace827 -> 2416 in the cache */

   /* ('sne', ('slt', 'a', 'b'), 1.0) => ('sge', 'a', 'b') */
   /* search828_0_0 -> 0 in the cache */
   /* search828_0_1 -> 3 in the cache */
   /* search828_0 -> 2412 in the cache */
   /* search828_1 -> 270 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_sne,
      0, 1,
      { 2412, 270 },
      -1,
   } },

   /* replace828_0 -> 0 in the cache */
   /* replace828_1 -> 3 in the cache */
   /* replace828 -> 2414 in the cache */

   /* ('sne', ('sge', 'a', 'b'), 1.0) => ('slt', 'a', 'b') */
   /* search829_0_0 -> 0 in the cache */
   /* search829_0_1 -> 3 in the cache */
   /* search829_0 -> 2414 in the cache */
   /* search829_1 -> 270 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_sne,
      0, 1,
      { 2414, 270 },
      -1,
   } },

   /* replace829_0 -> 0 in the cache */
   /* replace829_1 -> 3 in the cache */
   /* replace829 -> 2412 in the cache */

   /* ('fall_equal2', 'a', 'b') => ('fmin', ('seq', 'a.x', 'b.x'), ('seq', 'a.y', 'b.y')) */
   /* search830_0 -> 16 in the cache */
   /* search830_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fall_equal2,
      0, 1,
      { 16, 36 },
      -1,
   } },

   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_seq,
      0, 1,
      { 2443, 2444 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {1},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {1},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_seq,
      1, 1,
      { 2446, 2447 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmin,
      -1, 2,
      { 2445, 2448 },
      -1,
   } },

   /* ('fall_equal3', 'a', 'b') => ('seq', ('fany_nequal3', 'a', 'b'), 0.0) */
   /* search831_0 -> 16 in the cache */
   /* search831_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fall_equal3,
      0, 1,
      { 16, 36 },
      -1,
   } },

   /* replace831_0_0 -> 16 in the cache */
   /* replace831_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fany_nequal3,
      1, 1,
      { 16, 36 },
      -1,
   } },
   /* replace831_1 -> 115 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_seq,
      0, 2,
      { 2451, 115 },
      -1,
   } },

   /* ('fall_equal4', 'a', 'b') => ('seq', ('fany_nequal4', 'a', 'b'), 0.0) */
   /* search832_0 -> 16 in the cache */
   /* search832_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fall_equal4,
      0, 1,
      { 16, 36 },
      -1,
   } },

   /* replace832_0_0 -> 16 in the cache */
   /* replace832_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fany_nequal4,
      1, 1,
      { 16, 36 },
      -1,
   } },
   /* replace832_1 -> 115 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_seq,
      0, 2,
      { 2454, 115 },
      -1,
   } },

   /* ('fall_equal8', 'a', 'b') => ('seq', ('fany_nequal8', 'a', 'b'), 0.0) */
   /* search833_0 -> 16 in the cache */
   /* search833_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fall_equal8,
      0, 1,
      { 16, 36 },
      -1,
   } },

   /* replace833_0_0 -> 16 in the cache */
   /* replace833_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fany_nequal8,
      1, 1,
      { 16, 36 },
      -1,
   } },
   /* replace833_1 -> 115 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_seq,
      0, 2,
      { 2457, 115 },
      -1,
   } },

   /* ('fall_equal16', 'a', 'b') => ('seq', ('fany_nequal16', 'a', 'b'), 0.0) */
   /* search834_0 -> 16 in the cache */
   /* search834_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fall_equal16,
      0, 1,
      { 16, 36 },
      -1,
   } },

   /* replace834_0_0 -> 16 in the cache */
   /* replace834_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fany_nequal16,
      1, 1,
      { 16, 36 },
      -1,
   } },
   /* replace834_1 -> 115 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_seq,
      0, 2,
      { 2460, 115 },
      -1,
   } },

   /* ('fany_nequal2', 'a', 'b') => ('fmax', ('sne', 'a.x', 'b.x'), ('sne', 'a.y', 'b.y')) */
   /* search835_0 -> 16 in the cache */
   /* search835_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fany_nequal2,
      0, 1,
      { 16, 36 },
      -1,
   } },

   /* replace835_0_0 -> 2443 in the cache */
   /* replace835_0_1 -> 2444 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sne,
      0, 1,
      { 2443, 2444 },
      -1,
   } },
   /* replace835_1_0 -> 2446 in the cache */
   /* replace835_1_1 -> 2447 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sne,
      1, 1,
      { 2446, 2447 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmax,
      -1, 2,
      { 2463, 2464 },
      -1,
   } },

   /* ('fany_nequal3', 'a', 'b') => ('fsat', ('fdot3', ('sne', 'a', 'b'), ('sne', 'a', 'b'))) */
   /* search836_0 -> 16 in the cache */
   /* search836_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fany_nequal3,
      0, 1,
      { 16, 36 },
      -1,
   } },

   /* replace836_0_0_0 -> 16 in the cache */
   /* replace836_0_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sne,
      0, 1,
      { 16, 36 },
      -1,
   } },
   /* replace836_0_1_0 -> 16 in the cache */
   /* replace836_0_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sne,
      1, 1,
      { 16, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fdot3,
      -1, 2,
      { 2467, 2468 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 2,
      { 2469 },
      -1,
   } },

   /* ('fany_nequal4', 'a', 'b') => ('fsat', ('fdot4', ('sne', 'a', 'b'), ('sne', 'a', 'b'))) */
   /* search837_0 -> 16 in the cache */
   /* search837_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fany_nequal4,
      0, 1,
      { 16, 36 },
      -1,
   } },

   /* replace837_0_0_0 -> 16 in the cache */
   /* replace837_0_0_1 -> 36 in the cache */
   /* replace837_0_0 -> 2467 in the cache */
   /* replace837_0_1_0 -> 16 in the cache */
   /* replace837_0_1_1 -> 36 in the cache */
   /* replace837_0_1 -> 2468 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fdot4,
      -1, 2,
      { 2467, 2468 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 2,
      { 2472 },
      -1,
   } },

   /* ('fany_nequal8', 'a', 'b') => ('fsat', ('fdot8', ('sne', 'a', 'b'), ('sne', 'a', 'b'))) */
   /* search838_0 -> 16 in the cache */
   /* search838_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fany_nequal8,
      0, 1,
      { 16, 36 },
      -1,
   } },

   /* replace838_0_0_0 -> 16 in the cache */
   /* replace838_0_0_1 -> 36 in the cache */
   /* replace838_0_0 -> 2467 in the cache */
   /* replace838_0_1_0 -> 16 in the cache */
   /* replace838_0_1_1 -> 36 in the cache */
   /* replace838_0_1 -> 2468 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fdot8,
      -1, 2,
      { 2467, 2468 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 2,
      { 2475 },
      -1,
   } },

   /* ('fany_nequal16', 'a', 'b') => ('fsat', ('fdot16', ('sne', 'a', 'b'), ('sne', 'a', 'b'))) */
   /* search839_0 -> 16 in the cache */
   /* search839_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fany_nequal16,
      0, 1,
      { 16, 36 },
      -1,
   } },

   /* replace839_0_0_0 -> 16 in the cache */
   /* replace839_0_0_1 -> 36 in the cache */
   /* replace839_0_0 -> 2467 in the cache */
   /* replace839_0_1_0 -> 16 in the cache */
   /* replace839_0_1_1 -> 36 in the cache */
   /* replace839_0_1 -> 2468 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fdot16,
      -1, 2,
      { 2467, 2468 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 2,
      { 2478 },
      -1,
   } },

   /* ('ball_iequal2', 'a', 'b') => ('iand', ('ieq', 'a.x', 'b.x'), ('ieq', 'a.y', 'b.y')) */
   /* search840_0 -> 0 in the cache */
   /* search840_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ball_iequal2,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace840_0_0 -> 769 in the cache */
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 769, 2481 },
      -1,
   } },
   /* replace840_1_0 -> 770 in the cache */
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {1},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 770, 2483 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      -1, 2,
      { 2482, 2484 },
      -1,
   } },

   /* ('ball_iequal3', 'a', 'b') => ('iand', ('ieq', 'a.x', 'b.x'), ('iand', ('ieq', 'a.y', 'b.y'), ('ieq', 'a.z', 'b.z'))) */
   /* search841_0 -> 0 in the cache */
   /* search841_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ball_iequal3,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace841_0_0 -> 769 in the cache */
   /* replace841_0_1 -> 2481 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 769, 2481 },
      -1,
   } },
   /* replace841_1_0_0 -> 770 in the cache */
   /* replace841_1_0_1 -> 2483 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 770, 2483 },
      -1,
   } },
   /* replace841_1_1_0 -> 771 in the cache */
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {2},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      3, 1,
      { 771, 2489 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      -1, 2,
      { 2488, 2490 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 4,
      { 2487, 2491 },
      -1,
   } },

   /* ('ball_iequal4', 'a', 'b') => ('iand', ('iand', ('ieq', 'a.x', 'b.x'), ('ieq', 'a.y', 'b.y')), ('iand', ('ieq', 'a.z', 'b.z'), ('ieq', 'a.w', 'b.w'))) */
   /* search842_0 -> 0 in the cache */
   /* search842_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ball_iequal4,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace842_0_0_0 -> 769 in the cache */
   /* replace842_0_0_1 -> 2481 in the cache */
   /* replace842_0_0 -> 2482 in the cache */
   /* replace842_0_1_0 -> 770 in the cache */
   /* replace842_0_1_1 -> 2483 in the cache */
   /* replace842_0_1 -> 2484 in the cache */
   /* replace842_0 -> 2485 in the cache */
   /* replace842_1_0_0 -> 771 in the cache */
   /* replace842_1_0_1 -> 2489 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 771, 2489 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {3},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {3},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      3, 1,
      { 2495, 2496 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      -1, 2,
      { 2494, 2497 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      -1, 4,
      { 2485, 2498 },
      -1,
   } },

   /* ('ball_iequal8', 'a', 'b') => ('iand', ('iand', ('iand', ('ieq', 'a.a', 'b.a'), ('ieq', 'a.b', 'b.b')), ('iand', ('ieq', 'a.c', 'b.c'), ('ieq', 'a.d', 'b.d'))), ('iand', ('iand', ('ieq', 'a.e', 'b.e'), ('ieq', 'a.f', 'b.f')), ('iand', ('ieq', 'a.g', 'b.g'), ('ieq', 'a.h', 'b.h')))) */
   /* search843_0 -> 0 in the cache */
   /* search843_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ball_iequal8,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace843_0_0_0_0 -> 769 in the cache */
   /* replace843_0_0_0_1 -> 2481 in the cache */
   /* replace843_0_0_0 -> 2482 in the cache */
   /* replace843_0_0_1_0 -> 770 in the cache */
   /* replace843_0_0_1_1 -> 2483 in the cache */
   /* replace843_0_0_1 -> 2484 in the cache */
   /* replace843_0_0 -> 2485 in the cache */
   /* replace843_0_1_0_0 -> 771 in the cache */
   /* replace843_0_1_0_1 -> 2489 in the cache */
   /* replace843_0_1_0 -> 2494 in the cache */
   /* replace843_0_1_1_0 -> 2495 in the cache */
   /* replace843_0_1_1_1 -> 2496 in the cache */
   /* replace843_0_1_1 -> 2497 in the cache */
   /* replace843_0_1 -> 2498 in the cache */
   /* replace843_0 -> 2499 in the cache */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {4},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {4},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      4, 1,
      { 2501, 2502 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {5},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {5},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      5, 1,
      { 2504, 2505 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      -1, 2,
      { 2503, 2506 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {6},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {6},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      6, 1,
      { 2508, 2509 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {7},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {7},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      7, 1,
      { 2511, 2512 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      -1, 2,
      { 2510, 2513 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      -1, 4,
      { 2507, 2514 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      -1, 8,
      { 2499, 2515 },
      -1,
   } },

   /* ('ball_iequal16', 'a', 'b') => ('iand', ('iand', ('iand', ('iand', ('ieq', 'a.a', 'b.a'), ('ieq', 'a.b', 'b.b')), ('iand', ('ieq', 'a.c', 'b.c'), ('ieq', 'a.d', 'b.d'))), ('iand', ('iand', ('ieq', 'a.e', 'b.e'), ('ieq', 'a.f', 'b.f')), ('iand', ('ieq', 'a.g', 'b.g'), ('ieq', 'a.h', 'b.h')))), ('iand', ('iand', ('iand', ('ieq', 'a.i', 'b.i'), ('ieq', 'a.j', 'b.j')), ('iand', ('ieq', 'a.k', 'b.k'), ('ieq', 'a.l', 'b.l'))), ('iand', ('iand', ('ieq', 'a.m', 'b.m'), ('ieq', 'a.n', 'b.n')), ('iand', ('ieq', 'a.o', 'b.o'), ('ieq', 'a.p', 'b.p'))))) */
   /* search844_0 -> 0 in the cache */
   /* search844_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ball_iequal16,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace844_0_0_0_0_0 -> 769 in the cache */
   /* replace844_0_0_0_0_1 -> 2481 in the cache */
   /* replace844_0_0_0_0 -> 2482 in the cache */
   /* replace844_0_0_0_1_0 -> 770 in the cache */
   /* replace844_0_0_0_1_1 -> 2483 in the cache */
   /* replace844_0_0_0_1 -> 2484 in the cache */
   /* replace844_0_0_0 -> 2485 in the cache */
   /* replace844_0_0_1_0_0 -> 771 in the cache */
   /* replace844_0_0_1_0_1 -> 2489 in the cache */
   /* replace844_0_0_1_0 -> 2494 in the cache */
   /* replace844_0_0_1_1_0 -> 2495 in the cache */
   /* replace844_0_0_1_1_1 -> 2496 in the cache */
   /* replace844_0_0_1_1 -> 2497 in the cache */
   /* replace844_0_0_1 -> 2498 in the cache */
   /* replace844_0_0 -> 2499 in the cache */
   /* replace844_0_1_0_0_0 -> 2501 in the cache */
   /* replace844_0_1_0_0_1 -> 2502 in the cache */
   /* replace844_0_1_0_0 -> 2503 in the cache */
   /* replace844_0_1_0_1_0 -> 2504 in the cache */
   /* replace844_0_1_0_1_1 -> 2505 in the cache */
   /* replace844_0_1_0_1 -> 2506 in the cache */
   /* replace844_0_1_0 -> 2507 in the cache */
   /* replace844_0_1_1_0_0 -> 2508 in the cache */
   /* replace844_0_1_1_0_1 -> 2509 in the cache */
   /* replace844_0_1_1_0 -> 2510 in the cache */
   /* replace844_0_1_1_1_0 -> 2511 in the cache */
   /* replace844_0_1_1_1_1 -> 2512 in the cache */
   /* replace844_0_1_1_1 -> 2513 in the cache */
   /* replace844_0_1_1 -> 2514 in the cache */
   /* replace844_0_1 -> 2515 in the cache */
   /* replace844_0 -> 2516 in the cache */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {8},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {8},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      8, 1,
      { 2518, 2519 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {9},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {9},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      9, 1,
      { 2521, 2522 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      -1, 2,
      { 2520, 2523 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {10},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {10},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      10, 1,
      { 2525, 2526 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {11},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {11},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      11, 1,
      { 2528, 2529 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      -1, 2,
      { 2527, 2530 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      -1, 4,
      { 2524, 2531 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {12},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {12},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      12, 1,
      { 2533, 2534 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {13},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {13},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      13, 1,
      { 2536, 2537 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      -1, 2,
      { 2535, 2538 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {14},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {14},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      14, 1,
      { 2540, 2541 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {15},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      15, 1,
      { 2543, 2544 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      -1, 2,
      { 2542, 2545 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      -1, 4,
      { 2539, 2546 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      -1, 8,
      { 2532, 2547 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      -1, 16,
      { 2516, 2548 },
      -1,
   } },

   /* ('ball_fequal2', 'a', 'b') => ('iand', ('feq', 'a.x', 'b.x'), ('feq', 'a.y', 'b.y')) */
   /* search845_0 -> 0 in the cache */
   /* search845_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ball_fequal2,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace845_0_0 -> 769 in the cache */
   /* replace845_0_1 -> 2481 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 769, 2481 },
      -1,
   } },
   /* replace845_1_0 -> 770 in the cache */
   /* replace845_1_1 -> 2483 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      1, 1,
      { 770, 2483 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      -1, 2,
      { 2551, 2552 },
      -1,
   } },

   /* ('ball_fequal3', 'a', 'b') => ('iand', ('feq', 'a.x', 'b.x'), ('iand', ('feq', 'a.y', 'b.y'), ('feq', 'a.z', 'b.z'))) */
   /* search846_0 -> 0 in the cache */
   /* search846_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ball_fequal3,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace846_0_0 -> 769 in the cache */
   /* replace846_0_1 -> 2481 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      1, 1,
      { 769, 2481 },
      -1,
   } },
   /* replace846_1_0_0 -> 770 in the cache */
   /* replace846_1_0_1 -> 2483 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      2, 1,
      { 770, 2483 },
      -1,
   } },
   /* replace846_1_1_0 -> 771 in the cache */
   /* replace846_1_1_1 -> 2489 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      3, 1,
      { 771, 2489 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      -1, 2,
      { 2556, 2557 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 4,
      { 2555, 2558 },
      -1,
   } },

   /* ('ball_fequal4', 'a', 'b') => ('iand', ('iand', ('feq', 'a.x', 'b.x'), ('feq', 'a.y', 'b.y')), ('iand', ('feq', 'a.z', 'b.z'), ('feq', 'a.w', 'b.w'))) */
   /* search847_0 -> 0 in the cache */
   /* search847_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ball_fequal4,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace847_0_0_0 -> 769 in the cache */
   /* replace847_0_0_1 -> 2481 in the cache */
   /* replace847_0_0 -> 2551 in the cache */
   /* replace847_0_1_0 -> 770 in the cache */
   /* replace847_0_1_1 -> 2483 in the cache */
   /* replace847_0_1 -> 2552 in the cache */
   /* replace847_0 -> 2553 in the cache */
   /* replace847_1_0_0 -> 771 in the cache */
   /* replace847_1_0_1 -> 2489 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      2, 1,
      { 771, 2489 },
      -1,
   } },
   /* replace847_1_1_0 -> 2495 in the cache */
   /* replace847_1_1_1 -> 2496 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      3, 1,
      { 2495, 2496 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      -1, 2,
      { 2561, 2562 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      -1, 4,
      { 2553, 2563 },
      -1,
   } },

   /* ('ball_fequal8', 'a', 'b') => ('iand', ('iand', ('iand', ('feq', 'a.a', 'b.a'), ('feq', 'a.b', 'b.b')), ('iand', ('feq', 'a.c', 'b.c'), ('feq', 'a.d', 'b.d'))), ('iand', ('iand', ('feq', 'a.e', 'b.e'), ('feq', 'a.f', 'b.f')), ('iand', ('feq', 'a.g', 'b.g'), ('feq', 'a.h', 'b.h')))) */
   /* search848_0 -> 0 in the cache */
   /* search848_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ball_fequal8,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace848_0_0_0_0 -> 769 in the cache */
   /* replace848_0_0_0_1 -> 2481 in the cache */
   /* replace848_0_0_0 -> 2551 in the cache */
   /* replace848_0_0_1_0 -> 770 in the cache */
   /* replace848_0_0_1_1 -> 2483 in the cache */
   /* replace848_0_0_1 -> 2552 in the cache */
   /* replace848_0_0 -> 2553 in the cache */
   /* replace848_0_1_0_0 -> 771 in the cache */
   /* replace848_0_1_0_1 -> 2489 in the cache */
   /* replace848_0_1_0 -> 2561 in the cache */
   /* replace848_0_1_1_0 -> 2495 in the cache */
   /* replace848_0_1_1_1 -> 2496 in the cache */
   /* replace848_0_1_1 -> 2562 in the cache */
   /* replace848_0_1 -> 2563 in the cache */
   /* replace848_0 -> 2564 in the cache */
   /* replace848_1_0_0_0 -> 2501 in the cache */
   /* replace848_1_0_0_1 -> 2502 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      4, 1,
      { 2501, 2502 },
      -1,
   } },
   /* replace848_1_0_1_0 -> 2504 in the cache */
   /* replace848_1_0_1_1 -> 2505 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      5, 1,
      { 2504, 2505 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      -1, 2,
      { 2566, 2567 },
      -1,
   } },
   /* replace848_1_1_0_0 -> 2508 in the cache */
   /* replace848_1_1_0_1 -> 2509 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      6, 1,
      { 2508, 2509 },
      -1,
   } },
   /* replace848_1_1_1_0 -> 2511 in the cache */
   /* replace848_1_1_1_1 -> 2512 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      7, 1,
      { 2511, 2512 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      -1, 2,
      { 2569, 2570 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      -1, 4,
      { 2568, 2571 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      -1, 8,
      { 2564, 2572 },
      -1,
   } },

   /* ('ball_fequal16', 'a', 'b') => ('iand', ('iand', ('iand', ('iand', ('feq', 'a.a', 'b.a'), ('feq', 'a.b', 'b.b')), ('iand', ('feq', 'a.c', 'b.c'), ('feq', 'a.d', 'b.d'))), ('iand', ('iand', ('feq', 'a.e', 'b.e'), ('feq', 'a.f', 'b.f')), ('iand', ('feq', 'a.g', 'b.g'), ('feq', 'a.h', 'b.h')))), ('iand', ('iand', ('iand', ('feq', 'a.i', 'b.i'), ('feq', 'a.j', 'b.j')), ('iand', ('feq', 'a.k', 'b.k'), ('feq', 'a.l', 'b.l'))), ('iand', ('iand', ('feq', 'a.m', 'b.m'), ('feq', 'a.n', 'b.n')), ('iand', ('feq', 'a.o', 'b.o'), ('feq', 'a.p', 'b.p'))))) */
   /* search849_0 -> 0 in the cache */
   /* search849_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ball_fequal16,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace849_0_0_0_0_0 -> 769 in the cache */
   /* replace849_0_0_0_0_1 -> 2481 in the cache */
   /* replace849_0_0_0_0 -> 2551 in the cache */
   /* replace849_0_0_0_1_0 -> 770 in the cache */
   /* replace849_0_0_0_1_1 -> 2483 in the cache */
   /* replace849_0_0_0_1 -> 2552 in the cache */
   /* replace849_0_0_0 -> 2553 in the cache */
   /* replace849_0_0_1_0_0 -> 771 in the cache */
   /* replace849_0_0_1_0_1 -> 2489 in the cache */
   /* replace849_0_0_1_0 -> 2561 in the cache */
   /* replace849_0_0_1_1_0 -> 2495 in the cache */
   /* replace849_0_0_1_1_1 -> 2496 in the cache */
   /* replace849_0_0_1_1 -> 2562 in the cache */
   /* replace849_0_0_1 -> 2563 in the cache */
   /* replace849_0_0 -> 2564 in the cache */
   /* replace849_0_1_0_0_0 -> 2501 in the cache */
   /* replace849_0_1_0_0_1 -> 2502 in the cache */
   /* replace849_0_1_0_0 -> 2566 in the cache */
   /* replace849_0_1_0_1_0 -> 2504 in the cache */
   /* replace849_0_1_0_1_1 -> 2505 in the cache */
   /* replace849_0_1_0_1 -> 2567 in the cache */
   /* replace849_0_1_0 -> 2568 in the cache */
   /* replace849_0_1_1_0_0 -> 2508 in the cache */
   /* replace849_0_1_1_0_1 -> 2509 in the cache */
   /* replace849_0_1_1_0 -> 2569 in the cache */
   /* replace849_0_1_1_1_0 -> 2511 in the cache */
   /* replace849_0_1_1_1_1 -> 2512 in the cache */
   /* replace849_0_1_1_1 -> 2570 in the cache */
   /* replace849_0_1_1 -> 2571 in the cache */
   /* replace849_0_1 -> 2572 in the cache */
   /* replace849_0 -> 2573 in the cache */
   /* replace849_1_0_0_0_0 -> 2518 in the cache */
   /* replace849_1_0_0_0_1 -> 2519 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      8, 1,
      { 2518, 2519 },
      -1,
   } },
   /* replace849_1_0_0_1_0 -> 2521 in the cache */
   /* replace849_1_0_0_1_1 -> 2522 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      9, 1,
      { 2521, 2522 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      -1, 2,
      { 2575, 2576 },
      -1,
   } },
   /* replace849_1_0_1_0_0 -> 2525 in the cache */
   /* replace849_1_0_1_0_1 -> 2526 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      10, 1,
      { 2525, 2526 },
      -1,
   } },
   /* replace849_1_0_1_1_0 -> 2528 in the cache */
   /* replace849_1_0_1_1_1 -> 2529 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      11, 1,
      { 2528, 2529 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      -1, 2,
      { 2578, 2579 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      -1, 4,
      { 2577, 2580 },
      -1,
   } },
   /* replace849_1_1_0_0_0 -> 2533 in the cache */
   /* replace849_1_1_0_0_1 -> 2534 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      12, 1,
      { 2533, 2534 },
      -1,
   } },
   /* replace849_1_1_0_1_0 -> 2536 in the cache */
   /* replace849_1_1_0_1_1 -> 2537 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      13, 1,
      { 2536, 2537 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      -1, 2,
      { 2582, 2583 },
      -1,
   } },
   /* replace849_1_1_1_0_0 -> 2540 in the cache */
   /* replace849_1_1_1_0_1 -> 2541 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      14, 1,
      { 2540, 2541 },
      -1,
   } },
   /* replace849_1_1_1_1_0 -> 2543 in the cache */
   /* replace849_1_1_1_1_1 -> 2544 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      15, 1,
      { 2543, 2544 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      -1, 2,
      { 2585, 2586 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      -1, 4,
      { 2584, 2587 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      -1, 8,
      { 2581, 2588 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      -1, 16,
      { 2573, 2589 },
      -1,
   } },

   /* ('bany_inequal2', 'a', 'b') => ('ior', ('ine', 'a.x', 'b.x'), ('ine', 'a.y', 'b.y')) */
   /* search850_0 -> 0 in the cache */
   /* search850_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bany_inequal2,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace850_0_0 -> 769 in the cache */
   /* replace850_0_1 -> 2481 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 769, 2481 },
      -1,
   } },
   /* replace850_1_0 -> 770 in the cache */
   /* replace850_1_1 -> 2483 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 770, 2483 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      -1, 2,
      { 2592, 2593 },
      -1,
   } },

   /* ('bany_inequal3', 'a', 'b') => ('ior', ('ine', 'a.x', 'b.x'), ('ior', ('ine', 'a.y', 'b.y'), ('ine', 'a.z', 'b.z'))) */
   /* search851_0 -> 0 in the cache */
   /* search851_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bany_inequal3,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace851_0_0 -> 769 in the cache */
   /* replace851_0_1 -> 2481 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 769, 2481 },
      -1,
   } },
   /* replace851_1_0_0 -> 770 in the cache */
   /* replace851_1_0_1 -> 2483 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 770, 2483 },
      -1,
   } },
   /* replace851_1_1_0 -> 771 in the cache */
   /* replace851_1_1_1 -> 2489 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      3, 1,
      { 771, 2489 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      -1, 2,
      { 2597, 2598 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 4,
      { 2596, 2599 },
      -1,
   } },

   /* ('bany_inequal4', 'a', 'b') => ('ior', ('ior', ('ine', 'a.x', 'b.x'), ('ine', 'a.y', 'b.y')), ('ior', ('ine', 'a.z', 'b.z'), ('ine', 'a.w', 'b.w'))) */
   /* search852_0 -> 0 in the cache */
   /* search852_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bany_inequal4,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace852_0_0_0 -> 769 in the cache */
   /* replace852_0_0_1 -> 2481 in the cache */
   /* replace852_0_0 -> 2592 in the cache */
   /* replace852_0_1_0 -> 770 in the cache */
   /* replace852_0_1_1 -> 2483 in the cache */
   /* replace852_0_1 -> 2593 in the cache */
   /* replace852_0 -> 2594 in the cache */
   /* replace852_1_0_0 -> 771 in the cache */
   /* replace852_1_0_1 -> 2489 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 771, 2489 },
      -1,
   } },
   /* replace852_1_1_0 -> 2495 in the cache */
   /* replace852_1_1_1 -> 2496 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      3, 1,
      { 2495, 2496 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      -1, 2,
      { 2602, 2603 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      -1, 4,
      { 2594, 2604 },
      -1,
   } },

   /* ('bany_inequal8', 'a', 'b') => ('ior', ('ior', ('ior', ('ine', 'a.a', 'b.a'), ('ine', 'a.b', 'b.b')), ('ior', ('ine', 'a.c', 'b.c'), ('ine', 'a.d', 'b.d'))), ('ior', ('ior', ('ine', 'a.e', 'b.e'), ('ine', 'a.f', 'b.f')), ('ior', ('ine', 'a.g', 'b.g'), ('ine', 'a.h', 'b.h')))) */
   /* search853_0 -> 0 in the cache */
   /* search853_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bany_inequal8,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace853_0_0_0_0 -> 769 in the cache */
   /* replace853_0_0_0_1 -> 2481 in the cache */
   /* replace853_0_0_0 -> 2592 in the cache */
   /* replace853_0_0_1_0 -> 770 in the cache */
   /* replace853_0_0_1_1 -> 2483 in the cache */
   /* replace853_0_0_1 -> 2593 in the cache */
   /* replace853_0_0 -> 2594 in the cache */
   /* replace853_0_1_0_0 -> 771 in the cache */
   /* replace853_0_1_0_1 -> 2489 in the cache */
   /* replace853_0_1_0 -> 2602 in the cache */
   /* replace853_0_1_1_0 -> 2495 in the cache */
   /* replace853_0_1_1_1 -> 2496 in the cache */
   /* replace853_0_1_1 -> 2603 in the cache */
   /* replace853_0_1 -> 2604 in the cache */
   /* replace853_0 -> 2605 in the cache */
   /* replace853_1_0_0_0 -> 2501 in the cache */
   /* replace853_1_0_0_1 -> 2502 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      4, 1,
      { 2501, 2502 },
      -1,
   } },
   /* replace853_1_0_1_0 -> 2504 in the cache */
   /* replace853_1_0_1_1 -> 2505 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      5, 1,
      { 2504, 2505 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      -1, 2,
      { 2607, 2608 },
      -1,
   } },
   /* replace853_1_1_0_0 -> 2508 in the cache */
   /* replace853_1_1_0_1 -> 2509 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      6, 1,
      { 2508, 2509 },
      -1,
   } },
   /* replace853_1_1_1_0 -> 2511 in the cache */
   /* replace853_1_1_1_1 -> 2512 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      7, 1,
      { 2511, 2512 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      -1, 2,
      { 2610, 2611 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      -1, 4,
      { 2609, 2612 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      -1, 8,
      { 2605, 2613 },
      -1,
   } },

   /* ('bany_inequal16', 'a', 'b') => ('ior', ('ior', ('ior', ('ior', ('ine', 'a.a', 'b.a'), ('ine', 'a.b', 'b.b')), ('ior', ('ine', 'a.c', 'b.c'), ('ine', 'a.d', 'b.d'))), ('ior', ('ior', ('ine', 'a.e', 'b.e'), ('ine', 'a.f', 'b.f')), ('ior', ('ine', 'a.g', 'b.g'), ('ine', 'a.h', 'b.h')))), ('ior', ('ior', ('ior', ('ine', 'a.i', 'b.i'), ('ine', 'a.j', 'b.j')), ('ior', ('ine', 'a.k', 'b.k'), ('ine', 'a.l', 'b.l'))), ('ior', ('ior', ('ine', 'a.m', 'b.m'), ('ine', 'a.n', 'b.n')), ('ior', ('ine', 'a.o', 'b.o'), ('ine', 'a.p', 'b.p'))))) */
   /* search854_0 -> 0 in the cache */
   /* search854_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bany_inequal16,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace854_0_0_0_0_0 -> 769 in the cache */
   /* replace854_0_0_0_0_1 -> 2481 in the cache */
   /* replace854_0_0_0_0 -> 2592 in the cache */
   /* replace854_0_0_0_1_0 -> 770 in the cache */
   /* replace854_0_0_0_1_1 -> 2483 in the cache */
   /* replace854_0_0_0_1 -> 2593 in the cache */
   /* replace854_0_0_0 -> 2594 in the cache */
   /* replace854_0_0_1_0_0 -> 771 in the cache */
   /* replace854_0_0_1_0_1 -> 2489 in the cache */
   /* replace854_0_0_1_0 -> 2602 in the cache */
   /* replace854_0_0_1_1_0 -> 2495 in the cache */
   /* replace854_0_0_1_1_1 -> 2496 in the cache */
   /* replace854_0_0_1_1 -> 2603 in the cache */
   /* replace854_0_0_1 -> 2604 in the cache */
   /* replace854_0_0 -> 2605 in the cache */
   /* replace854_0_1_0_0_0 -> 2501 in the cache */
   /* replace854_0_1_0_0_1 -> 2502 in the cache */
   /* replace854_0_1_0_0 -> 2607 in the cache */
   /* replace854_0_1_0_1_0 -> 2504 in the cache */
   /* replace854_0_1_0_1_1 -> 2505 in the cache */
   /* replace854_0_1_0_1 -> 2608 in the cache */
   /* replace854_0_1_0 -> 2609 in the cache */
   /* replace854_0_1_1_0_0 -> 2508 in the cache */
   /* replace854_0_1_1_0_1 -> 2509 in the cache */
   /* replace854_0_1_1_0 -> 2610 in the cache */
   /* replace854_0_1_1_1_0 -> 2511 in the cache */
   /* replace854_0_1_1_1_1 -> 2512 in the cache */
   /* replace854_0_1_1_1 -> 2611 in the cache */
   /* replace854_0_1_1 -> 2612 in the cache */
   /* replace854_0_1 -> 2613 in the cache */
   /* replace854_0 -> 2614 in the cache */
   /* replace854_1_0_0_0_0 -> 2518 in the cache */
   /* replace854_1_0_0_0_1 -> 2519 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      8, 1,
      { 2518, 2519 },
      -1,
   } },
   /* replace854_1_0_0_1_0 -> 2521 in the cache */
   /* replace854_1_0_0_1_1 -> 2522 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      9, 1,
      { 2521, 2522 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      -1, 2,
      { 2616, 2617 },
      -1,
   } },
   /* replace854_1_0_1_0_0 -> 2525 in the cache */
   /* replace854_1_0_1_0_1 -> 2526 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      10, 1,
      { 2525, 2526 },
      -1,
   } },
   /* replace854_1_0_1_1_0 -> 2528 in the cache */
   /* replace854_1_0_1_1_1 -> 2529 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      11, 1,
      { 2528, 2529 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      -1, 2,
      { 2619, 2620 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      -1, 4,
      { 2618, 2621 },
      -1,
   } },
   /* replace854_1_1_0_0_0 -> 2533 in the cache */
   /* replace854_1_1_0_0_1 -> 2534 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      12, 1,
      { 2533, 2534 },
      -1,
   } },
   /* replace854_1_1_0_1_0 -> 2536 in the cache */
   /* replace854_1_1_0_1_1 -> 2537 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      13, 1,
      { 2536, 2537 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      -1, 2,
      { 2623, 2624 },
      -1,
   } },
   /* replace854_1_1_1_0_0 -> 2540 in the cache */
   /* replace854_1_1_1_0_1 -> 2541 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      14, 1,
      { 2540, 2541 },
      -1,
   } },
   /* replace854_1_1_1_1_0 -> 2543 in the cache */
   /* replace854_1_1_1_1_1 -> 2544 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      15, 1,
      { 2543, 2544 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      -1, 2,
      { 2626, 2627 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      -1, 4,
      { 2625, 2628 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      -1, 8,
      { 2622, 2629 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      -1, 16,
      { 2614, 2630 },
      -1,
   } },

   /* ('bany_fnequal2', 'a', 'b') => ('ior', ('fneu', 'a.x', 'b.x'), ('fneu', 'a.y', 'b.y')) */
   /* search855_0 -> 0 in the cache */
   /* search855_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bany_fnequal2,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace855_0_0 -> 769 in the cache */
   /* replace855_0_1 -> 2481 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 769, 2481 },
      -1,
   } },
   /* replace855_1_0 -> 770 in the cache */
   /* replace855_1_1 -> 2483 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      1, 1,
      { 770, 2483 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      -1, 2,
      { 2633, 2634 },
      -1,
   } },

   /* ('bany_fnequal3', 'a', 'b') => ('ior', ('fneu', 'a.x', 'b.x'), ('ior', ('fneu', 'a.y', 'b.y'), ('fneu', 'a.z', 'b.z'))) */
   /* search856_0 -> 0 in the cache */
   /* search856_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bany_fnequal3,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace856_0_0 -> 769 in the cache */
   /* replace856_0_1 -> 2481 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      1, 1,
      { 769, 2481 },
      -1,
   } },
   /* replace856_1_0_0 -> 770 in the cache */
   /* replace856_1_0_1 -> 2483 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      2, 1,
      { 770, 2483 },
      -1,
   } },
   /* replace856_1_1_0 -> 771 in the cache */
   /* replace856_1_1_1 -> 2489 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      3, 1,
      { 771, 2489 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      -1, 2,
      { 2638, 2639 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 4,
      { 2637, 2640 },
      -1,
   } },

   /* ('bany_fnequal4', 'a', 'b') => ('ior', ('ior', ('fneu', 'a.x', 'b.x'), ('fneu', 'a.y', 'b.y')), ('ior', ('fneu', 'a.z', 'b.z'), ('fneu', 'a.w', 'b.w'))) */
   /* search857_0 -> 0 in the cache */
   /* search857_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bany_fnequal4,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace857_0_0_0 -> 769 in the cache */
   /* replace857_0_0_1 -> 2481 in the cache */
   /* replace857_0_0 -> 2633 in the cache */
   /* replace857_0_1_0 -> 770 in the cache */
   /* replace857_0_1_1 -> 2483 in the cache */
   /* replace857_0_1 -> 2634 in the cache */
   /* replace857_0 -> 2635 in the cache */
   /* replace857_1_0_0 -> 771 in the cache */
   /* replace857_1_0_1 -> 2489 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      2, 1,
      { 771, 2489 },
      -1,
   } },
   /* replace857_1_1_0 -> 2495 in the cache */
   /* replace857_1_1_1 -> 2496 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      3, 1,
      { 2495, 2496 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      -1, 2,
      { 2643, 2644 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      -1, 4,
      { 2635, 2645 },
      -1,
   } },

   /* ('bany_fnequal8', 'a', 'b') => ('ior', ('ior', ('ior', ('fneu', 'a.a', 'b.a'), ('fneu', 'a.b', 'b.b')), ('ior', ('fneu', 'a.c', 'b.c'), ('fneu', 'a.d', 'b.d'))), ('ior', ('ior', ('fneu', 'a.e', 'b.e'), ('fneu', 'a.f', 'b.f')), ('ior', ('fneu', 'a.g', 'b.g'), ('fneu', 'a.h', 'b.h')))) */
   /* search858_0 -> 0 in the cache */
   /* search858_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bany_fnequal8,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace858_0_0_0_0 -> 769 in the cache */
   /* replace858_0_0_0_1 -> 2481 in the cache */
   /* replace858_0_0_0 -> 2633 in the cache */
   /* replace858_0_0_1_0 -> 770 in the cache */
   /* replace858_0_0_1_1 -> 2483 in the cache */
   /* replace858_0_0_1 -> 2634 in the cache */
   /* replace858_0_0 -> 2635 in the cache */
   /* replace858_0_1_0_0 -> 771 in the cache */
   /* replace858_0_1_0_1 -> 2489 in the cache */
   /* replace858_0_1_0 -> 2643 in the cache */
   /* replace858_0_1_1_0 -> 2495 in the cache */
   /* replace858_0_1_1_1 -> 2496 in the cache */
   /* replace858_0_1_1 -> 2644 in the cache */
   /* replace858_0_1 -> 2645 in the cache */
   /* replace858_0 -> 2646 in the cache */
   /* replace858_1_0_0_0 -> 2501 in the cache */
   /* replace858_1_0_0_1 -> 2502 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      4, 1,
      { 2501, 2502 },
      -1,
   } },
   /* replace858_1_0_1_0 -> 2504 in the cache */
   /* replace858_1_0_1_1 -> 2505 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      5, 1,
      { 2504, 2505 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      -1, 2,
      { 2648, 2649 },
      -1,
   } },
   /* replace858_1_1_0_0 -> 2508 in the cache */
   /* replace858_1_1_0_1 -> 2509 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      6, 1,
      { 2508, 2509 },
      -1,
   } },
   /* replace858_1_1_1_0 -> 2511 in the cache */
   /* replace858_1_1_1_1 -> 2512 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      7, 1,
      { 2511, 2512 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      -1, 2,
      { 2651, 2652 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      -1, 4,
      { 2650, 2653 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      -1, 8,
      { 2646, 2654 },
      -1,
   } },

   /* ('bany_fnequal16', 'a', 'b') => ('ior', ('ior', ('ior', ('ior', ('fneu', 'a.a', 'b.a'), ('fneu', 'a.b', 'b.b')), ('ior', ('fneu', 'a.c', 'b.c'), ('fneu', 'a.d', 'b.d'))), ('ior', ('ior', ('fneu', 'a.e', 'b.e'), ('fneu', 'a.f', 'b.f')), ('ior', ('fneu', 'a.g', 'b.g'), ('fneu', 'a.h', 'b.h')))), ('ior', ('ior', ('ior', ('fneu', 'a.i', 'b.i'), ('fneu', 'a.j', 'b.j')), ('ior', ('fneu', 'a.k', 'b.k'), ('fneu', 'a.l', 'b.l'))), ('ior', ('ior', ('fneu', 'a.m', 'b.m'), ('fneu', 'a.n', 'b.n')), ('ior', ('fneu', 'a.o', 'b.o'), ('fneu', 'a.p', 'b.p'))))) */
   /* search859_0 -> 0 in the cache */
   /* search859_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bany_fnequal16,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace859_0_0_0_0_0 -> 769 in the cache */
   /* replace859_0_0_0_0_1 -> 2481 in the cache */
   /* replace859_0_0_0_0 -> 2633 in the cache */
   /* replace859_0_0_0_1_0 -> 770 in the cache */
   /* replace859_0_0_0_1_1 -> 2483 in the cache */
   /* replace859_0_0_0_1 -> 2634 in the cache */
   /* replace859_0_0_0 -> 2635 in the cache */
   /* replace859_0_0_1_0_0 -> 771 in the cache */
   /* replace859_0_0_1_0_1 -> 2489 in the cache */
   /* replace859_0_0_1_0 -> 2643 in the cache */
   /* replace859_0_0_1_1_0 -> 2495 in the cache */
   /* replace859_0_0_1_1_1 -> 2496 in the cache */
   /* replace859_0_0_1_1 -> 2644 in the cache */
   /* replace859_0_0_1 -> 2645 in the cache */
   /* replace859_0_0 -> 2646 in the cache */
   /* replace859_0_1_0_0_0 -> 2501 in the cache */
   /* replace859_0_1_0_0_1 -> 2502 in the cache */
   /* replace859_0_1_0_0 -> 2648 in the cache */
   /* replace859_0_1_0_1_0 -> 2504 in the cache */
   /* replace859_0_1_0_1_1 -> 2505 in the cache */
   /* replace859_0_1_0_1 -> 2649 in the cache */
   /* replace859_0_1_0 -> 2650 in the cache */
   /* replace859_0_1_1_0_0 -> 2508 in the cache */
   /* replace859_0_1_1_0_1 -> 2509 in the cache */
   /* replace859_0_1_1_0 -> 2651 in the cache */
   /* replace859_0_1_1_1_0 -> 2511 in the cache */
   /* replace859_0_1_1_1_1 -> 2512 in the cache */
   /* replace859_0_1_1_1 -> 2652 in the cache */
   /* replace859_0_1_1 -> 2653 in the cache */
   /* replace859_0_1 -> 2654 in the cache */
   /* replace859_0 -> 2655 in the cache */
   /* replace859_1_0_0_0_0 -> 2518 in the cache */
   /* replace859_1_0_0_0_1 -> 2519 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      8, 1,
      { 2518, 2519 },
      -1,
   } },
   /* replace859_1_0_0_1_0 -> 2521 in the cache */
   /* replace859_1_0_0_1_1 -> 2522 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      9, 1,
      { 2521, 2522 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      -1, 2,
      { 2657, 2658 },
      -1,
   } },
   /* replace859_1_0_1_0_0 -> 2525 in the cache */
   /* replace859_1_0_1_0_1 -> 2526 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      10, 1,
      { 2525, 2526 },
      -1,
   } },
   /* replace859_1_0_1_1_0 -> 2528 in the cache */
   /* replace859_1_0_1_1_1 -> 2529 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      11, 1,
      { 2528, 2529 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      -1, 2,
      { 2660, 2661 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      -1, 4,
      { 2659, 2662 },
      -1,
   } },
   /* replace859_1_1_0_0_0 -> 2533 in the cache */
   /* replace859_1_1_0_0_1 -> 2534 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      12, 1,
      { 2533, 2534 },
      -1,
   } },
   /* replace859_1_1_0_1_0 -> 2536 in the cache */
   /* replace859_1_1_0_1_1 -> 2537 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      13, 1,
      { 2536, 2537 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      -1, 2,
      { 2664, 2665 },
      -1,
   } },
   /* replace859_1_1_1_0_0 -> 2540 in the cache */
   /* replace859_1_1_1_0_1 -> 2541 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      14, 1,
      { 2540, 2541 },
      -1,
   } },
   /* replace859_1_1_1_1_0 -> 2543 in the cache */
   /* replace859_1_1_1_1_1 -> 2544 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      15, 1,
      { 2543, 2544 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      -1, 2,
      { 2667, 2668 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      -1, 4,
      { 2666, 2669 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      -1, 8,
      { 2663, 2670 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      -1, 16,
      { 2655, 2671 },
      -1,
   } },

   /* ('feq', ('seq', 'a', 'b'), 1.0) => ('feq', 'a', 'b') */
   /* search860_0_0 -> 0 in the cache */
   /* search860_0_1 -> 3 in the cache */
   /* search860_0 -> 2424 in the cache */
   /* search860_1 -> 270 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 2,
      { 2424, 270 },
      -1,
   } },

   /* replace860_0 -> 0 in the cache */
   /* replace860_1 -> 3 in the cache */
   /* replace860 -> 1055 in the cache */

   /* ('feq', ('sne', 'a', 'b'), 1.0) => ('fneu', 'a', 'b') */
   /* search861_0_0 -> 0 in the cache */
   /* search861_0_1 -> 3 in the cache */
   /* search861_0 -> 2426 in the cache */
   /* search861_1 -> 270 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 2,
      { 2426, 270 },
      -1,
   } },

   /* replace861_0 -> 0 in the cache */
   /* replace861_1 -> 3 in the cache */
   /* replace861 -> 1052 in the cache */

   /* ('feq', ('slt', 'a', 'b'), 1.0) => ('flt', 'a', 'b') */
   /* search862_0_0 -> 0 in the cache */
   /* search862_0_1 -> 3 in the cache */
   /* search862_0 -> 2412 in the cache */
   /* search862_1 -> 270 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 2412, 270 },
      -1,
   } },

   /* replace862_0 -> 0 in the cache */
   /* replace862_1 -> 3 in the cache */
   /* replace862 -> 1049 in the cache */

   /* ('feq', ('sge', 'a', 'b'), 1.0) => ('fge', 'a', 'b') */
   /* search863_0_0 -> 0 in the cache */
   /* search863_0_1 -> 3 in the cache */
   /* search863_0 -> 2414 in the cache */
   /* search863_1 -> 270 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 2414, 270 },
      -1,
   } },

   /* replace863_0 -> 0 in the cache */
   /* replace863_1 -> 3 in the cache */
   /* replace863 -> 1046 in the cache */

   /* ('fneu', ('seq', 'a', 'b'), 0.0) => ('feq', 'a', 'b') */
   /* search864_0_0 -> 0 in the cache */
   /* search864_0_1 -> 3 in the cache */
   /* search864_0 -> 2424 in the cache */
   /* search864_1 -> 256 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 2,
      { 2424, 256 },
      -1,
   } },

   /* replace864_0 -> 0 in the cache */
   /* replace864_1 -> 3 in the cache */
   /* replace864 -> 1055 in the cache */

   /* ('fneu', ('sne', 'a', 'b'), 0.0) => ('fneu', 'a', 'b') */
   /* search865_0_0 -> 0 in the cache */
   /* search865_0_1 -> 3 in the cache */
   /* search865_0 -> 2426 in the cache */
   /* search865_1 -> 256 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 2,
      { 2426, 256 },
      -1,
   } },

   /* replace865_0 -> 0 in the cache */
   /* replace865_1 -> 3 in the cache */
   /* replace865 -> 1052 in the cache */

   /* ('fneu', ('slt', 'a', 'b'), 0.0) => ('flt', 'a', 'b') */
   /* search866_0_0 -> 0 in the cache */
   /* search866_0_1 -> 3 in the cache */
   /* search866_0 -> 2412 in the cache */
   /* search866_1 -> 256 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 2412, 256 },
      -1,
   } },

   /* replace866_0 -> 0 in the cache */
   /* replace866_1 -> 3 in the cache */
   /* replace866 -> 1049 in the cache */

   /* ('fneu', ('sge', 'a', 'b'), 0.0) => ('fge', 'a', 'b') */
   /* search867_0_0 -> 0 in the cache */
   /* search867_0_1 -> 3 in the cache */
   /* search867_0 -> 2414 in the cache */
   /* search867_1 -> 256 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 2414, 256 },
      -1,
   } },

   /* replace867_0 -> 0 in the cache */
   /* replace867_1 -> 3 in the cache */
   /* replace867 -> 1046 in the cache */

   /* ('feq', ('seq', 'a', 'b'), 0.0) => ('fneu', 'a', 'b') */
   /* search868_0_0 -> 0 in the cache */
   /* search868_0_1 -> 3 in the cache */
   /* search868_0 -> 2424 in the cache */
   /* search868_1 -> 256 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 2,
      { 2424, 256 },
      -1,
   } },

   /* replace868_0 -> 0 in the cache */
   /* replace868_1 -> 3 in the cache */
   /* replace868 -> 1052 in the cache */

   /* ('feq', ('sne', 'a', 'b'), 0.0) => ('feq', 'a', 'b') */
   /* search869_0_0 -> 0 in the cache */
   /* search869_0_1 -> 3 in the cache */
   /* search869_0 -> 2426 in the cache */
   /* search869_1 -> 256 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 2,
      { 2426, 256 },
      -1,
   } },

   /* replace869_0 -> 0 in the cache */
   /* replace869_1 -> 3 in the cache */
   /* replace869 -> 1055 in the cache */

   /* ('feq', ('slt', 'a', 'b'), 0.0) => ('fge', 'a', 'b') */
   /* search870_0_0 -> 0 in the cache */
   /* search870_0_1 -> 3 in the cache */
   /* search870_0 -> 2412 in the cache */
   /* search870_1 -> 256 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 2412, 256 },
      -1,
   } },

   /* replace870_0 -> 0 in the cache */
   /* replace870_1 -> 3 in the cache */
   /* replace870 -> 1046 in the cache */

   /* ('feq', ('sge', 'a', 'b'), 0.0) => ('flt', 'a', 'b') */
   /* search871_0_0 -> 0 in the cache */
   /* search871_0_1 -> 3 in the cache */
   /* search871_0 -> 2414 in the cache */
   /* search871_1 -> 256 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 2414, 256 },
      -1,
   } },

   /* replace871_0 -> 0 in the cache */
   /* replace871_1 -> 3 in the cache */
   /* replace871 -> 1049 in the cache */

   /* ('fneu', ('seq', 'a', 'b'), 1.0) => ('fneu', 'a', 'b') */
   /* search872_0_0 -> 0 in the cache */
   /* search872_0_1 -> 3 in the cache */
   /* search872_0 -> 2424 in the cache */
   /* search872_1 -> 270 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 2,
      { 2424, 270 },
      -1,
   } },

   /* replace872_0 -> 0 in the cache */
   /* replace872_1 -> 3 in the cache */
   /* replace872 -> 1052 in the cache */

   /* ('fneu', ('sne', 'a', 'b'), 1.0) => ('feq', 'a', 'b') */
   /* search873_0_0 -> 0 in the cache */
   /* search873_0_1 -> 3 in the cache */
   /* search873_0 -> 2426 in the cache */
   /* search873_1 -> 270 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 2,
      { 2426, 270 },
      -1,
   } },

   /* replace873_0 -> 0 in the cache */
   /* replace873_1 -> 3 in the cache */
   /* replace873 -> 1055 in the cache */

   /* ('fneu', ('slt', 'a', 'b'), 1.0) => ('fge', 'a', 'b') */
   /* search874_0_0 -> 0 in the cache */
   /* search874_0_1 -> 3 in the cache */
   /* search874_0 -> 2412 in the cache */
   /* search874_1 -> 270 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 2412, 270 },
      -1,
   } },

   /* replace874_0 -> 0 in the cache */
   /* replace874_1 -> 3 in the cache */
   /* replace874 -> 1046 in the cache */

   /* ('fneu', ('sge', 'a', 'b'), 1.0) => ('flt', 'a', 'b') */
   /* search875_0_0 -> 0 in the cache */
   /* search875_0_1 -> 3 in the cache */
   /* search875_0 -> 2414 in the cache */
   /* search875_1 -> 270 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 2414, 270 },
      -1,
   } },

   /* replace875_0 -> 0 in the cache */
   /* replace875_1 -> 3 in the cache */
   /* replace875 -> 1049 in the cache */

   /* ('fneu', ('fneg', 'a'), 'a') => ('fneu', 'a', 0.0) */
   /* search876_0_0 -> 32 in the cache */
   /* search876_0 -> 98 in the cache */
   /* search876_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 98, 32 },
      -1,
   } },

   /* replace876_0 -> 32 in the cache */
   /* replace876_1 -> 111 in the cache */
   /* replace876 -> 1253 in the cache */

   /* ('feq', ('fneg', 'a'), 'a') => ('feq', 'a', 0.0) */
   /* search877_0_0 -> 32 in the cache */
   /* search877_0 -> 98 in the cache */
   /* search877_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 98, 32 },
      -1,
   } },

   /* replace877_0 -> 32 in the cache */
   /* replace877_1 -> 111 in the cache */
   /* replace877 -> 1257 in the cache */

   /* ('imul', ('b2i', 'a@1'), ('b2i', 'b@1')) => ('b2i', ('iand', 'a', 'b')) */
   /* search878_0_0 -> 760 in the cache */
   /* search878_0 -> 1228 in the cache */
   /* search878_1_0 -> 1134 in the cache */
   /* search878_1 -> 2265 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 1228, 2265 },
      -1,
   } },

   /* replace878_0_0 -> 760 in the cache */
   /* replace878_0_1 -> 1134 in the cache */
   /* replace878_0 -> 1146 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2i,
      -1, 1,
      { 1146 },
      -1,
   } },

   /* ('iand', ('b2i', 'a@1'), ('b2i', 'b@1')) => ('b2i', ('iand', 'a', 'b')) */
   /* search879_0_0 -> 760 in the cache */
   /* search879_0 -> 1228 in the cache */
   /* search879_1_0 -> 1134 in the cache */
   /* search879_1 -> 2265 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1228, 2265 },
      -1,
   } },

   /* replace879_0_0 -> 760 in the cache */
   /* replace879_0_1 -> 1134 in the cache */
   /* replace879_0 -> 1146 in the cache */
   /* replace879 -> 2692 in the cache */

   /* ('ior', ('b2i', 'a@1'), ('b2i', 'b@1')) => ('b2i', ('ior', 'a', 'b')) */
   /* search880_0_0 -> 760 in the cache */
   /* search880_0 -> 1228 in the cache */
   /* search880_1_0 -> 1134 in the cache */
   /* search880_1 -> 2265 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1228, 2265 },
      -1,
   } },

   /* replace880_0_0 -> 760 in the cache */
   /* replace880_0_1 -> 1134 in the cache */
   /* replace880_0 -> 1138 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2i,
      -1, 1,
      { 1138 },
      -1,
   } },

   /* ('fmul', ('b2f', 'a@1'), ('b2f', 'b@1')) => ('b2f', ('iand', 'a', 'b')) */
   /* search881_0_0 -> 760 in the cache */
   /* search881_0 -> 1129 in the cache */
   /* search881_1_0 -> 1134 in the cache */
   /* search881_1 -> 1135 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 1129, 1135 },
      -1,
   } },

   /* replace881_0_0 -> 760 in the cache */
   /* replace881_0_1 -> 1134 in the cache */
   /* replace881_0 -> 1146 in the cache */
   /* replace881 -> 1266 in the cache */

   /* ('fsat', ('fadd', ('b2f', 'a@1'), ('b2f', 'b@1'))) => ('b2f', ('ior', 'a', 'b')) */
   /* search882_0_0_0 -> 760 in the cache */
   /* search882_0_0 -> 1129 in the cache */
   /* search882_0_1_0 -> 1134 in the cache */
   /* search882_0_1 -> 1135 in the cache */
   /* search882_0 -> 1165 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 1,
      { 1165 },
      -1,
   } },

   /* replace882_0_0 -> 760 in the cache */
   /* replace882_0_1 -> 1134 in the cache */
   /* replace882_0 -> 1138 in the cache */
   /* replace882 -> 1263 in the cache */

   /* ('iand', 'a@bool16', 1.0) => ('b2f', 'a') */
   { .variable = {
      { nir_search_value_variable, 16 },
      0, /* a */
      false,
      nir_type_bool,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search883_1 -> 481 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 2698, 481 },
      -1,
   } },

   /* replace883_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 11 },
      -1,
   } },

   /* ('iand', 'a@bool32', 1.0) => ('b2f', 'a') */
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* a */
      false,
      nir_type_bool,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search884_1 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 2701, 243 },
      -1,
   } },

   /* replace884_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('flt', ('fneg', ('b2f', 'a@1')), 0) => a */
   /* search885_0_0_0 -> 760 in the cache */
   /* search885_0_0 -> 1129 in the cache */
   /* search885_0 -> 1132 in the cache */
   /* search885_1 -> 1229 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1132, 1229 },
      -1,
   } },

   /* replace885 -> 760 in the cache */

   /* ('ilt', 'a', 'a') => False */
   /* search886_0 -> 32 in the cache */
   /* search886_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 32, 32 },
      -1,
   } },

   /* replace886 -> 1077 in the cache */

   /* ('ige', 'a', 'a') => True */
   /* search887_0 -> 32 in the cache */
   /* search887_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 32, 32 },
      -1,
   } },

   /* replace887 -> 1235 in the cache */

   /* ('ieq', 'a', 'a') => True */
   /* search888_0 -> 32 in the cache */
   /* search888_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      -1, 0,
      { 32, 32 },
      -1,
   } },

   /* replace888 -> 1235 in the cache */

   /* ('ine', 'a', 'a') => False */
   /* search889_0 -> 32 in the cache */
   /* search889_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      -1, 0,
      { 32, 32 },
      -1,
   } },

   /* replace889 -> 1077 in the cache */

   /* ('ult', 'a', 'a') => False */
   /* search890_0 -> 32 in the cache */
   /* search890_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 32, 32 },
      -1,
   } },

   /* replace890 -> 1077 in the cache */

   /* ('uge', 'a', 'a') => True */
   /* search891_0 -> 32 in the cache */
   /* search891_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 32, 32 },
      -1,
   } },

   /* replace891 -> 1235 in the cache */

   /* ('flt', 'a', 'a') => False */
   /* search892_0 -> 32 in the cache */
   /* search892_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 32, 32 },
      -1,
   } },

   /* replace892 -> 1077 in the cache */

   /* ('fge', 'a(is_a_number)', 'a') => True */
   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* a */
      false,
      nir_type_invalid,
      16,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search893_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 2712, 32 },
      -1,
   } },

   /* replace893 -> 1235 in the cache */

   /* ('feq', 'a(is_a_number)', 'a') => True */
   /* search894_0 -> 2712 in the cache */
   /* search894_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      -1, 0,
      { 2712, 32 },
      -1,
   } },

   /* replace894 -> 1235 in the cache */

   /* ('fneu', 'a(is_a_number)', 'a') => False */
   /* search895_0 -> 2712 in the cache */
   /* search895_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      -1, 0,
      { 2712, 32 },
      -1,
   } },

   /* replace895 -> 1077 in the cache */

   /* ('iand', 'a', 'a') => a */
   /* search896_0 -> 32 in the cache */
   /* search896_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_iand,
      -1, 0,
      { 32, 32 },
      -1,
   } },

   /* replace896 -> 32 in the cache */

   /* ('iand', 'a', 0) => 0 */
   /* search897_0 -> 32 in the cache */
   /* search897_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 32, 61 },
      -1,
   } },

   /* replace897 -> 61 in the cache */

   /* ('iand', 'a', -1) => a */
   /* search898_0 -> 32 in the cache */
   /* search898_1 -> 63 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 32, 63 },
      -1,
   } },

   /* replace898 -> 32 in the cache */

   /* ('iand', 'a', ('inot', 'a')) => 0 */
   /* search899_0 -> 32 in the cache */
   /* search899_1_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 32, 2719 },
      -1,
   } },

   /* replace899 -> 61 in the cache */

   /* ('ior', 'a', 'a') => a */
   /* search900_0 -> 32 in the cache */
   /* search900_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ior,
      -1, 0,
      { 32, 32 },
      -1,
   } },

   /* replace900 -> 32 in the cache */

   /* ('ior', 'a', 0) => a */
   /* search901_0 -> 32 in the cache */
   /* search901_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 32, 61 },
      -1,
   } },

   /* replace901 -> 32 in the cache */

   /* ('ior', 'a', -1) => -1 */
   /* search902_0 -> 32 in the cache */
   /* search902_1 -> 63 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 32, 63 },
      -1,
   } },

   /* replace902 -> 63 in the cache */

   /* ('ior', 'a', ('inot', 'a')) => -1 */
   /* search903_0 -> 32 in the cache */
   /* search903_1_0 -> 32 in the cache */
   /* search903_1 -> 2719 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 32, 2719 },
      -1,
   } },

   /* replace903 -> 63 in the cache */

   /* ('ixor', 'a', 'a') => 0 */
   /* search904_0 -> 32 in the cache */
   /* search904_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ixor,
      -1, 0,
      { 32, 32 },
      -1,
   } },

   /* replace904 -> 61 in the cache */

   /* ('ixor', 'a', 0) => a */
   /* search905_0 -> 32 in the cache */
   /* search905_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 32, 61 },
      -1,
   } },

   /* replace905 -> 32 in the cache */

   /* ('ixor', 'a', ('ixor', 'a', 'b')) => b */
   /* search906_0 -> 0 in the cache */
   /* search906_1_0 -> 0 in the cache */
   /* search906_1_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ixor,
      1, 1,
      { 0, 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 2,
      { 0, 2727 },
      -1,
   } },

   /* replace906 -> 3 in the cache */

   /* ('ixor', 'a', -1) => ('inot', 'a') */
   /* search907_0 -> 32 in the cache */
   /* search907_1 -> 63 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 32, 63 },
      -1,
   } },

   /* replace907_0 -> 32 in the cache */
   /* replace907 -> 2719 in the cache */

   /* ('inot', ('inot', 'a')) => a */
   /* search908_0_0 -> 32 in the cache */
   /* search908_0 -> 2719 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 2719 },
      -1,
   } },

   /* replace908 -> 32 in the cache */

   /* ('ior', ('iand', 'a', 'b'), 'b') => b */
   /* search909_0_0 -> 0 in the cache */
   /* search909_0_1 -> 3 in the cache */
   /* search909_0 -> 201 in the cache */
   /* search909_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 201, 3 },
      -1,
   } },

   /* replace909 -> 3 in the cache */

   /* ('ior', ('ior', 'a', 'b'), 'b') => ('ior', 'a', 'b') */
   /* search910_0_0 -> 0 in the cache */
   /* search910_0_1 -> 3 in the cache */
   /* search910_0 -> 84 in the cache */
   /* search910_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 84, 3 },
      -1,
   } },

   /* replace910_0 -> 0 in the cache */
   /* replace910_1 -> 3 in the cache */
   /* replace910 -> 2354 in the cache */

   /* ('iand', ('ior', 'a', 'b'), 'b') => b */
   /* search911_0_0 -> 0 in the cache */
   /* search911_0_1 -> 3 in the cache */
   /* search911_0 -> 84 in the cache */
   /* search911_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 84, 3 },
      -1,
   } },

   /* replace911 -> 3 in the cache */

   /* ('iand', ('iand', 'a', 'b'), 'b') => ('iand', 'a', 'b') */
   /* search912_0_0 -> 0 in the cache */
   /* search912_0_1 -> 3 in the cache */
   /* search912_0 -> 201 in the cache */
   /* search912_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 201, 3 },
      -1,
   } },

   /* replace912_0 -> 0 in the cache */
   /* replace912_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* ('iand', ('iand(is_used_once)', 'a', 'b'), ('iand(is_used_once)', 'a', 'c')) => ('iand', 'a', ('iand', 'b', 'c')) */
   /* search913_0_0 -> 126 in the cache */
   /* search913_0_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 126, 127 },
      0,
   } },
   /* search913_1_0 -> 126 in the cache */
   /* search913_1_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iand,
      2, 1,
      { 126, 129 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 2736, 2737 },
      -1,
   } },

   /* replace913_0 -> 126 in the cache */
   /* replace913_1_0 -> 127 in the cache */
   /* replace913_1_1 -> 129 in the cache */
   /* replace913_1 -> 192 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 126, 192 },
      -1,
   } },

   /* ('iand@64', 'a', '#b(is_lower_half_zero)') => ('pack_64_2x32_split', 0, ('iand', ('unpack_64_2x32_split_y', 'a'), ('unpack_64_2x32_split_y', 'b'))) */
   /* search914_0 -> 21 in the cache */
   { .variable = {
      { nir_search_value_variable, 64 },
      1, /* b */
      true,
      nir_type_invalid,
      20,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 21, 2740 },
      -1,
   } },

   /* replace914_0 -> 122 in the cache */
   /* replace914_1_0_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_64_2x32_split_y,
      -1, 0,
      { 21 },
      -1,
   } },
   /* replace914_1_1_0 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_64_2x32_split_y,
      -1, 0,
      { 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 2742, 2743 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_pack_64_2x32_split,
      -1, 1,
      { 122, 2744 },
      -1,
   } },

   /* ('iand@64', 'a', '#b(is_upper_half_zero)') => ('pack_64_2x32_split', ('iand', ('unpack_64_2x32_split_x', 'a'), ('unpack_64_2x32_split_x', 'b')), 0) */
   /* search915_0 -> 21 in the cache */
   { .variable = {
      { nir_search_value_variable, 64 },
      1, /* b */
      true,
      nir_type_invalid,
      21,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 21, 2746 },
      -1,
   } },

   /* replace915_0_0_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_64_2x32_split_x,
      -1, 0,
      { 21 },
      -1,
   } },
   /* replace915_0_1_0 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_64_2x32_split_x,
      -1, 0,
      { 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 2748, 2749 },
      -1,
   } },
   /* replace915_1 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_pack_64_2x32_split,
      -1, 1,
      { 2750, 122 },
      -1,
   } },

   /* ('iand@64', 'a', '#b(is_lower_half_negative_one)') => ('pack_64_2x32_split', ('unpack_64_2x32_split_x', 'a'), ('iand', ('unpack_64_2x32_split_y', 'a'), ('unpack_64_2x32_split_y', 'b'))) */
   /* search916_0 -> 21 in the cache */
   { .variable = {
      { nir_search_value_variable, 64 },
      1, /* b */
      true,
      nir_type_invalid,
      22,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 21, 2752 },
      -1,
   } },

   /* replace916_0_0 -> 21 in the cache */
   /* replace916_0 -> 2748 in the cache */
   /* replace916_1_0_0 -> 21 in the cache */
   /* replace916_1_0 -> 2742 in the cache */
   /* replace916_1_1_0 -> 41 in the cache */
   /* replace916_1_1 -> 2743 in the cache */
   /* replace916_1 -> 2744 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_pack_64_2x32_split,
      -1, 1,
      { 2748, 2744 },
      -1,
   } },

   /* ('iand@64', 'a', '#b(is_upper_half_negative_one)') => ('pack_64_2x32_split', ('iand', ('unpack_64_2x32_split_x', 'a'), ('unpack_64_2x32_split_x', 'b')), ('unpack_64_2x32_split_y', 'a')) */
   /* search917_0 -> 21 in the cache */
   { .variable = {
      { nir_search_value_variable, 64 },
      1, /* b */
      true,
      nir_type_invalid,
      23,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 21, 2755 },
      -1,
   } },

   /* replace917_0_0_0 -> 21 in the cache */
   /* replace917_0_0 -> 2748 in the cache */
   /* replace917_0_1_0 -> 41 in the cache */
   /* replace917_0_1 -> 2749 in the cache */
   /* replace917_0 -> 2750 in the cache */
   /* replace917_1_0 -> 21 in the cache */
   /* replace917_1 -> 2742 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_pack_64_2x32_split,
      -1, 1,
      { 2750, 2742 },
      -1,
   } },

   /* ('ior@64', 'a', '#b(is_lower_half_zero)') => ('pack_64_2x32_split', ('unpack_64_2x32_split_x', 'a'), ('ior', ('unpack_64_2x32_split_y', 'a'), ('unpack_64_2x32_split_y', 'b'))) */
   /* search918_0 -> 21 in the cache */
   /* search918_1 -> 2740 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 21, 2740 },
      -1,
   } },

   /* replace918_0_0 -> 21 in the cache */
   /* replace918_0 -> 2748 in the cache */
   /* replace918_1_0_0 -> 21 in the cache */
   /* replace918_1_0 -> 2742 in the cache */
   /* replace918_1_1_0 -> 41 in the cache */
   /* replace918_1_1 -> 2743 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 2742, 2743 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_pack_64_2x32_split,
      -1, 1,
      { 2748, 2759 },
      -1,
   } },

   /* ('ior@64', 'a', '#b(is_upper_half_zero)') => ('pack_64_2x32_split', ('ior', ('unpack_64_2x32_split_x', 'a'), ('unpack_64_2x32_split_x', 'b')), ('unpack_64_2x32_split_y', 'a')) */
   /* search919_0 -> 21 in the cache */
   /* search919_1 -> 2746 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 21, 2746 },
      -1,
   } },

   /* replace919_0_0_0 -> 21 in the cache */
   /* replace919_0_0 -> 2748 in the cache */
   /* replace919_0_1_0 -> 41 in the cache */
   /* replace919_0_1 -> 2749 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 2748, 2749 },
      -1,
   } },
   /* replace919_1_0 -> 21 in the cache */
   /* replace919_1 -> 2742 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_pack_64_2x32_split,
      -1, 1,
      { 2762, 2742 },
      -1,
   } },

   /* ('ior@64', 'a', '#b(is_lower_half_negative_one)') => ('pack_64_2x32_split', -1, ('ior', ('unpack_64_2x32_split_y', 'a'), ('unpack_64_2x32_split_y', 'b'))) */
   /* search920_0 -> 21 in the cache */
   /* search920_1 -> 2752 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 21, 2752 },
      -1,
   } },

   /* replace920_0 -> 124 in the cache */
   /* replace920_1_0_0 -> 21 in the cache */
   /* replace920_1_0 -> 2742 in the cache */
   /* replace920_1_1_0 -> 41 in the cache */
   /* replace920_1_1 -> 2743 in the cache */
   /* replace920_1 -> 2759 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_pack_64_2x32_split,
      -1, 1,
      { 124, 2759 },
      -1,
   } },

   /* ('ior@64', 'a', '#b(is_upper_half_negative_one)') => ('pack_64_2x32_split', ('ior', ('unpack_64_2x32_split_x', 'a'), ('unpack_64_2x32_split_x', 'b')), -1) */
   /* search921_0 -> 21 in the cache */
   /* search921_1 -> 2755 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 21, 2755 },
      -1,
   } },

   /* replace921_0_0_0 -> 21 in the cache */
   /* replace921_0_0 -> 2748 in the cache */
   /* replace921_0_1_0 -> 41 in the cache */
   /* replace921_0_1 -> 2749 in the cache */
   /* replace921_0 -> 2762 in the cache */
   /* replace921_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_pack_64_2x32_split,
      -1, 1,
      { 2762, 124 },
      -1,
   } },

   /* ('ixor@64', 'a', '#b(is_lower_half_zero)') => ('pack_64_2x32_split', ('unpack_64_2x32_split_x', 'a'), ('ixor', ('unpack_64_2x32_split_y', 'a'), ('unpack_64_2x32_split_y', 'b'))) */
   /* search922_0 -> 21 in the cache */
   /* search922_1 -> 2740 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 21, 2740 },
      -1,
   } },

   /* replace922_0_0 -> 21 in the cache */
   /* replace922_0 -> 2748 in the cache */
   /* replace922_1_0_0 -> 21 in the cache */
   /* replace922_1_0 -> 2742 in the cache */
   /* replace922_1_1_0 -> 41 in the cache */
   /* replace922_1_1 -> 2743 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 2742, 2743 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_pack_64_2x32_split,
      -1, 1,
      { 2748, 2769 },
      -1,
   } },

   /* ('ixor@64', 'a', '#b(is_upper_half_zero)') => ('pack_64_2x32_split', ('ixor', ('unpack_64_2x32_split_x', 'a'), ('unpack_64_2x32_split_x', 'b')), ('unpack_64_2x32_split_y', 'a')) */
   /* search923_0 -> 21 in the cache */
   /* search923_1 -> 2746 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 21, 2746 },
      -1,
   } },

   /* replace923_0_0_0 -> 21 in the cache */
   /* replace923_0_0 -> 2748 in the cache */
   /* replace923_0_1_0 -> 41 in the cache */
   /* replace923_0_1 -> 2749 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 2748, 2749 },
      -1,
   } },
   /* replace923_1_0 -> 21 in the cache */
   /* replace923_1 -> 2742 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_pack_64_2x32_split,
      -1, 1,
      { 2772, 2742 },
      -1,
   } },

   /* ('iand', ('inot', 'a'), ('inot', 'b')) => ('inot', ('ior', 'a', 'b')) */
   /* search924_0_0 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 0 },
      -1,
   } },
   /* search924_1_0 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 2774, 2775 },
      -1,
   } },

   /* replace924_0_0 -> 0 in the cache */
   /* replace924_0_1 -> 3 in the cache */
   /* replace924_0 -> 2354 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 1,
      { 2354 },
      -1,
   } },

   /* ('ior', ('inot', 'a'), ('inot', 'b')) => ('inot', ('iand', 'a', 'b')) */
   /* search925_0_0 -> 0 in the cache */
   /* search925_0 -> 2774 in the cache */
   /* search925_1_0 -> 3 in the cache */
   /* search925_1 -> 2775 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 2774, 2775 },
      -1,
   } },

   /* replace925_0_0 -> 0 in the cache */
   /* replace925_0_1 -> 3 in the cache */
   /* replace925_0 -> 2735 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 1,
      { 2735 },
      -1,
   } },

   /* ('ishl', 0, 'a') => 0 */
   /* search926_0 -> 1229 in the cache */
   /* search926_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 1229, 16 },
      -1,
   } },

   /* replace926 -> 1229 in the cache */

   /* ('ishl', 'a', 0) => a */
   /* search927_0 -> 32 in the cache */
   /* search927_1 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 32, 122 },
      -1,
   } },

   /* replace927 -> 32 in the cache */

   /* ('ishr', 0, 'a') => 0 */
   /* search928_0 -> 1229 in the cache */
   /* search928_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 1229, 16 },
      -1,
   } },

   /* replace928 -> 1229 in the cache */

   /* ('ishr', -1, 'a') => -1 */
   { .constant = {
      { nir_search_value_constant, 0 },
      nir_type_int, { -0x1 /* -1 */ },
   } },
   /* search929_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 2783, 16 },
      -1,
   } },

   /* replace929 -> 2783 in the cache */

   /* ('ishr', 'a', 0) => a */
   /* search930_0 -> 32 in the cache */
   /* search930_1 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 32, 122 },
      -1,
   } },

   /* replace930 -> 32 in the cache */

   /* ('ushr', 0, 'a') => 0 */
   /* search931_0 -> 1229 in the cache */
   /* search931_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 1229, 16 },
      -1,
   } },

   /* replace931 -> 1229 in the cache */

   /* ('ushr', 'a', 0) => a */
   /* search932_0 -> 32 in the cache */
   /* search932_1 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 32, 122 },
      -1,
   } },

   /* replace932 -> 32 in the cache */

   /* ('ior', ('ishl@16', 'a', 'b'), ('ushr@16', 'a', ('iadd', 16, ('ineg', 'b')))) => ('urol', 'a', 'b') */
   /* search933_0_0 -> 11 in the cache */
   /* search933_0_1 -> 36 in the cache */
   /* search933_0 -> 2180 in the cache */
   /* search933_1_0 -> 11 in the cache */
   /* search933_1_1_0 -> 853 in the cache */
   /* search933_1_1_1_0 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 853, 2788 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 11, 2789 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 2180, 2790 },
      -1,
   } },

   /* replace933_0 -> 11 in the cache */
   /* replace933_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_urol,
      -1, 0,
      { 11, 36 },
      -1,
   } },

   /* ('ior', ('ishl@16', 'a', 'b'), ('ushr@16', 'a', ('isub', 16, 'b'))) => ('urol', 'a', 'b') */
   /* search934_0_0 -> 11 in the cache */
   /* search934_0_1 -> 36 in the cache */
   /* search934_0 -> 2180 in the cache */
   /* search934_1_0 -> 11 in the cache */
   /* search934_1_1_0 -> 853 in the cache */
   /* search934_1_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 853, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 11, 2793 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 2180, 2794 },
      -1,
   } },

   /* replace934_0 -> 11 in the cache */
   /* replace934_1 -> 36 in the cache */
   /* replace934 -> 2792 in the cache */

   /* ('ior', ('ishl@32', 'a', 'b'), ('ushr@32', 'a', ('iadd', 32, ('ineg', 'b')))) => ('urol', 'a', 'b') */
   /* search935_0_0 -> 16 in the cache */
   /* search935_0_1 -> 36 in the cache */
   /* search935_0 -> 946 in the cache */
   /* search935_1_0 -> 16 in the cache */
   /* search935_1_1_0 -> 874 in the cache */
   /* search935_1_1_1_0 -> 36 in the cache */
   /* search935_1_1_1 -> 2788 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 874, 2788 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 16, 2796 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 946, 2797 },
      -1,
   } },

   /* replace935_0 -> 16 in the cache */
   /* replace935_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_urol,
      -1, 0,
      { 16, 36 },
      -1,
   } },

   /* ('ior', ('ishl@32', 'a', 'b'), ('ushr@32', 'a', ('isub', 32, 'b'))) => ('urol', 'a', 'b') */
   /* search936_0_0 -> 16 in the cache */
   /* search936_0_1 -> 36 in the cache */
   /* search936_0 -> 946 in the cache */
   /* search936_1_0 -> 16 in the cache */
   /* search936_1_1_0 -> 874 in the cache */
   /* search936_1_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 874, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 16, 2800 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 946, 2801 },
      -1,
   } },

   /* replace936_0 -> 16 in the cache */
   /* replace936_1 -> 36 in the cache */
   /* replace936 -> 2799 in the cache */

   /* ('ior', ('ushr@16', 'a', 'b'), ('ishl@16', 'a', ('iadd', 16, ('ineg', 'b')))) => ('uror', 'a', 'b') */
   /* search937_0_0 -> 11 in the cache */
   /* search937_0_1 -> 36 in the cache */
   /* search937_0 -> 2184 in the cache */
   /* search937_1_0 -> 11 in the cache */
   /* search937_1_1_0 -> 853 in the cache */
   /* search937_1_1_1_0 -> 36 in the cache */
   /* search937_1_1_1 -> 2788 in the cache */
   /* search937_1_1 -> 2789 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 11, 2789 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 2184, 2803 },
      -1,
   } },

   /* replace937_0 -> 11 in the cache */
   /* replace937_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_uror,
      -1, 0,
      { 11, 36 },
      -1,
   } },

   /* ('ior', ('ushr@16', 'a', 'b'), ('ishl@16', 'a', ('isub', 16, 'b'))) => ('uror', 'a', 'b') */
   /* search938_0_0 -> 11 in the cache */
   /* search938_0_1 -> 36 in the cache */
   /* search938_0 -> 2184 in the cache */
   /* search938_1_0 -> 11 in the cache */
   /* search938_1_1_0 -> 853 in the cache */
   /* search938_1_1_1 -> 36 in the cache */
   /* search938_1_1 -> 2793 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 11, 2793 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 2184, 2806 },
      -1,
   } },

   /* replace938_0 -> 11 in the cache */
   /* replace938_1 -> 36 in the cache */
   /* replace938 -> 2805 in the cache */

   /* ('ior', ('ushr@32', 'a', 'b'), ('ishl@32', 'a', ('iadd', 32, ('ineg', 'b')))) => ('uror', 'a', 'b') */
   /* search939_0_0 -> 16 in the cache */
   /* search939_0_1 -> 36 in the cache */
   /* search939_0 -> 2213 in the cache */
   /* search939_1_0 -> 16 in the cache */
   /* search939_1_1_0 -> 874 in the cache */
   /* search939_1_1_1_0 -> 36 in the cache */
   /* search939_1_1_1 -> 2788 in the cache */
   /* search939_1_1 -> 2796 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 16, 2796 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 2213, 2808 },
      -1,
   } },

   /* replace939_0 -> 16 in the cache */
   /* replace939_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_uror,
      -1, 0,
      { 16, 36 },
      -1,
   } },

   /* ('ior', ('ushr@32', 'a', 'b'), ('ishl@32', 'a', ('isub', 32, 'b'))) => ('uror', 'a', 'b') */
   /* search940_0_0 -> 16 in the cache */
   /* search940_0_1 -> 36 in the cache */
   /* search940_0 -> 2213 in the cache */
   /* search940_1_0 -> 16 in the cache */
   /* search940_1_1_0 -> 874 in the cache */
   /* search940_1_1_1 -> 36 in the cache */
   /* search940_1_1 -> 2800 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 16, 2800 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 2213, 2811 },
      -1,
   } },

   /* replace940_0 -> 16 in the cache */
   /* replace940_1 -> 36 in the cache */
   /* replace940 -> 2810 in the cache */

   /* ('urol@8', 'a', 'b') => ('ior', ('ishl', 'a', 'b'), ('ushr', 'a', ('isub', 8, 'b'))) */
   /* search941_0 -> 6 in the cache */
   /* search941_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_urol,
      -1, 0,
      { 6, 36 },
      -1,
   } },

   /* replace941_0_0 -> 6 in the cache */
   /* replace941_0_1 -> 36 in the cache */
   /* replace941_0 -> 2149 in the cache */
   /* replace941_1_0 -> 6 in the cache */
   /* replace941_1_1_0 -> 831 in the cache */
   /* replace941_1_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 831, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 6, 2814 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 2149, 2815 },
      -1,
   } },

   /* ('urol@16', 'a', 'b') => ('ior', ('ishl', 'a', 'b'), ('ushr', 'a', ('isub', 16, 'b'))) */
   /* search942_0 -> 11 in the cache */
   /* search942_1 -> 36 in the cache */
   /* search942 -> 2792 in the cache */

   /* replace942_0_0 -> 11 in the cache */
   /* replace942_0_1 -> 36 in the cache */
   /* replace942_0 -> 2180 in the cache */
   /* replace942_1_0 -> 11 in the cache */
   /* replace942_1_1_0 -> 853 in the cache */
   /* replace942_1_1_1 -> 36 in the cache */
   /* replace942_1_1 -> 2793 in the cache */
   /* replace942_1 -> 2794 in the cache */
   /* replace942 -> 2795 in the cache */

   /* ('urol@32', 'a', 'b') => ('ior', ('ishl', 'a', 'b'), ('ushr', 'a', ('isub', 32, 'b'))) */
   /* search943_0 -> 16 in the cache */
   /* search943_1 -> 36 in the cache */
   /* search943 -> 2799 in the cache */

   /* replace943_0_0 -> 16 in the cache */
   /* replace943_0_1 -> 36 in the cache */
   /* replace943_0 -> 946 in the cache */
   /* replace943_1_0 -> 16 in the cache */
   /* replace943_1_1_0 -> 874 in the cache */
   /* replace943_1_1_1 -> 36 in the cache */
   /* replace943_1_1 -> 2800 in the cache */
   /* replace943_1 -> 2801 in the cache */
   /* replace943 -> 2802 in the cache */

   /* ('urol@64', 'a', 'b') => ('ior', ('ishl', 'a', 'b'), ('ushr', 'a', ('isub', 64, 'b'))) */
   /* search944_0 -> 21 in the cache */
   /* search944_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_urol,
      -1, 0,
      { 21, 36 },
      -1,
   } },

   /* replace944_0_0 -> 21 in the cache */
   /* replace944_0_1 -> 36 in the cache */
   /* replace944_0 -> 2240 in the cache */
   /* replace944_1_0 -> 21 in the cache */
   /* replace944_1_1_0 -> 894 in the cache */
   /* replace944_1_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 894, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 21, 2818 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 2240, 2819 },
      -1,
   } },

   /* ('uror@8', 'a', 'b') => ('ior', ('ushr', 'a', 'b'), ('ishl', 'a', ('isub', 8, 'b'))) */
   /* search945_0 -> 6 in the cache */
   /* search945_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_uror,
      -1, 0,
      { 6, 36 },
      -1,
   } },

   /* replace945_0_0 -> 6 in the cache */
   /* replace945_0_1 -> 36 in the cache */
   /* replace945_0 -> 2153 in the cache */
   /* replace945_1_0 -> 6 in the cache */
   /* replace945_1_1_0 -> 831 in the cache */
   /* replace945_1_1_1 -> 36 in the cache */
   /* replace945_1_1 -> 2814 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 6, 2814 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 2153, 2822 },
      -1,
   } },

   /* ('uror@16', 'a', 'b') => ('ior', ('ushr', 'a', 'b'), ('ishl', 'a', ('isub', 16, 'b'))) */
   /* search946_0 -> 11 in the cache */
   /* search946_1 -> 36 in the cache */
   /* search946 -> 2805 in the cache */

   /* replace946_0_0 -> 11 in the cache */
   /* replace946_0_1 -> 36 in the cache */
   /* replace946_0 -> 2184 in the cache */
   /* replace946_1_0 -> 11 in the cache */
   /* replace946_1_1_0 -> 853 in the cache */
   /* replace946_1_1_1 -> 36 in the cache */
   /* replace946_1_1 -> 2793 in the cache */
   /* replace946_1 -> 2806 in the cache */
   /* replace946 -> 2807 in the cache */

   /* ('uror@32', 'a', 'b') => ('ior', ('ushr', 'a', 'b'), ('ishl', 'a', ('isub', 32, 'b'))) */
   /* search947_0 -> 16 in the cache */
   /* search947_1 -> 36 in the cache */
   /* search947 -> 2810 in the cache */

   /* replace947_0_0 -> 16 in the cache */
   /* replace947_0_1 -> 36 in the cache */
   /* replace947_0 -> 2213 in the cache */
   /* replace947_1_0 -> 16 in the cache */
   /* replace947_1_1_0 -> 874 in the cache */
   /* replace947_1_1_1 -> 36 in the cache */
   /* replace947_1_1 -> 2800 in the cache */
   /* replace947_1 -> 2811 in the cache */
   /* replace947 -> 2812 in the cache */

   /* ('uror@64', 'a', 'b') => ('ior', ('ushr', 'a', 'b'), ('ishl', 'a', ('isub', 64, 'b'))) */
   /* search948_0 -> 21 in the cache */
   /* search948_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_uror,
      -1, 0,
      { 21, 36 },
      -1,
   } },

   /* replace948_0_0 -> 21 in the cache */
   /* replace948_0_1 -> 36 in the cache */
   /* replace948_0 -> 2244 in the cache */
   /* replace948_1_0 -> 21 in the cache */
   /* replace948_1_1_0 -> 894 in the cache */
   /* replace948_1_1_1 -> 36 in the cache */
   /* replace948_1_1 -> 2818 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 21, 2818 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 2244, 2825 },
      -1,
   } },

   /* ('~fexp2', ('flog2', 'a')) => a */
   /* search949_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_flog2,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fexp2,
      -1, 0,
      { 2827 },
      -1,
   } },

   /* replace949 -> 32 in the cache */

   /* ('~flog2', ('fexp2', 'a')) => a */
   /* search950_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fexp2,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_flog2,
      -1, 0,
      { 2829 },
      -1,
   } },

   /* replace950 -> 32 in the cache */

   /* ('fpow', 'a', 'b') => ('fexp2', ('fmul', ('flog2', 'a'), 'b')) */
   /* search951_0 -> 0 in the cache */
   /* search951_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* replace951_0_0_0 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_flog2,
      -1, 0,
      { 0 },
      -1,
   } },
   /* replace951_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 2832, 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fexp2,
      -1, 1,
      { 2833 },
      -1,
   } },

   /* ('~fexp2', ('fmul', ('flog2', 'a'), 'b')) => ('fpow', 'a', 'b') */
   /* search952_0_0_0 -> 0 in the cache */
   /* search952_0_0 -> 2832 in the cache */
   /* search952_0_1 -> 3 in the cache */
   /* search952_0 -> 2833 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_fexp2,
      -1, 1,
      { 2833 },
      -1,
   } },

   /* replace952_0 -> 0 in the cache */
   /* replace952_1 -> 3 in the cache */
   /* replace952 -> 2831 in the cache */

   /* ('~fexp2', ('fadd', ('fmul', ('flog2', 'a'), 'b'), ('fmul', ('flog2', 'c'), 'd'))) => ('~fmul', ('fpow', 'a', 'b'), ('fpow', 'c', 'd')) */
   /* search953_0_0_0_0 -> 149 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_flog2,
      -1, 0,
      { 149 },
      -1,
   } },
   /* search953_0_0_1 -> 150 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 2836, 150 },
      -1,
   } },
   /* search953_0_1_0_0 -> 152 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_flog2,
      -1, 0,
      { 152 },
      -1,
   } },
   /* search953_0_1_1 -> 153 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      2, 1,
      { 2838, 153 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 2837, 2839 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      true,
      false,
      false,
      nir_op_fexp2,
      -1, 3,
      { 2840 },
      -1,
   } },

   /* replace953_0_0 -> 149 in the cache */
   /* replace953_0_1 -> 150 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 149, 150 },
      -1,
   } },
   /* replace953_1_0 -> 152 in the cache */
   /* replace953_1_1 -> 153 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 152, 153 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      true,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 2842, 2843 },
      -1,
   } },

   /* ('~fexp2', ('fmul', ('flog2', 'a'), 0.5)) => ('fsqrt', 'a') */
   /* search954_0_0_0 -> 32 in the cache */
   /* search954_0_0 -> 2827 in the cache */
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0x3fe0000000000000 /* 0.5 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 2827, 2845 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fexp2,
      -1, 1,
      { 2846 },
      -1,
   } },

   /* replace954_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsqrt,
      -1, 0,
      { 32 },
      -1,
   } },

   /* ('~fexp2', ('fmul', ('flog2', 'a'), 2.0)) => ('fmul', 'a', 'a') */
   /* search955_0_0_0 -> 32 in the cache */
   /* search955_0_0 -> 2827 in the cache */
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0x4000000000000000 /* 2.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 2827, 2849 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fexp2,
      -1, 1,
      { 2850 },
      -1,
   } },

   /* replace955_0 -> 32 in the cache */
   /* replace955_1 -> 32 in the cache */
   /* replace955 -> 251 in the cache */

   /* ('~fexp2', ('fmul', ('flog2', 'a'), 4.0)) => ('fmul', ('fmul', 'a', 'a'), ('fmul', 'a', 'a')) */
   /* search956_0_0_0 -> 32 in the cache */
   /* search956_0_0 -> 2827 in the cache */
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0x4010000000000000 /* 4.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 2827, 2852 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fexp2,
      -1, 1,
      { 2853 },
      -1,
   } },

   /* replace956_0_0 -> 32 in the cache */
   /* replace956_0_1 -> 32 in the cache */
   /* replace956_0 -> 251 in the cache */
   /* replace956_1_0 -> 32 in the cache */
   /* replace956_1_1 -> 32 in the cache */
   /* replace956_1 -> 251 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      -1, 0,
      { 251, 251 },
      -1,
   } },

   /* ('~fpow', 'a', 1.0) => a */
   /* search957_0 -> 32 in the cache */
   /* search957_1 -> 241 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 32, 241 },
      -1,
   } },

   /* replace957 -> 32 in the cache */

   /* ('~fpow', 'a', 2.0) => ('fmul', 'a', 'a') */
   /* search958_0 -> 32 in the cache */
   /* search958_1 -> 2849 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 32, 2849 },
      -1,
   } },

   /* replace958_0 -> 32 in the cache */
   /* replace958_1 -> 32 in the cache */
   /* replace958 -> 251 in the cache */

   /* ('~fpow', 'a', 4.0) => ('fmul', ('fmul', 'a', 'a'), ('fmul', 'a', 'a')) */
   /* search959_0 -> 32 in the cache */
   /* search959_1 -> 2852 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 32, 2852 },
      -1,
   } },

   /* replace959_0_0 -> 32 in the cache */
   /* replace959_0_1 -> 32 in the cache */
   /* replace959_0 -> 251 in the cache */
   /* replace959_1_0 -> 32 in the cache */
   /* replace959_1_1 -> 32 in the cache */
   /* replace959_1 -> 251 in the cache */
   /* replace959 -> 2855 in the cache */

   /* ('~fpow', 2.0, 'a') => ('fexp2', 'a') */
   /* search960_0 -> 2849 in the cache */
   /* search960_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 2849, 32 },
      -1,
   } },

   /* replace960_0 -> 32 in the cache */
   /* replace960 -> 2829 in the cache */

   /* ('~fpow', ('fpow', 'a', 2.2), 0.454545) => a */
   /* search961_0_0 -> 32 in the cache */
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0x400199999999999a /* 2.2 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 32, 2860 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0x3fdd1743e963dc48 /* 0.454545 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 2861, 2862 },
      -1,
   } },

   /* replace961 -> 32 in the cache */

   /* ('~fpow', ('fabs', ('fpow', 'a', 2.2)), 0.454545) => ('fabs', 'a') */
   /* search962_0_0_0 -> 32 in the cache */
   /* search962_0_0_1 -> 2860 in the cache */
   /* search962_0_0 -> 2861 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 2861 },
      -1,
   } },
   /* search962_1 -> 2862 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 2864, 2862 },
      -1,
   } },

   /* replace962_0 -> 32 in the cache */
   /* replace962 -> 103 in the cache */

   /* ('~fsqrt', ('fexp2', 'a')) => ('fexp2', ('fmul', 0.5, 'a')) */
   /* search963_0_0 -> 32 in the cache */
   /* search963_0 -> 2829 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fsqrt,
      -1, 0,
      { 2829 },
      -1,
   } },

   /* replace963_0_0 -> 2845 in the cache */
   /* replace963_0_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 2845, 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fexp2,
      -1, 1,
      { 2867 },
      -1,
   } },

   /* ('~frcp', ('fexp2', 'a')) => ('fexp2', ('fneg', 'a')) */
   /* search964_0_0 -> 32 in the cache */
   /* search964_0 -> 2829 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_frcp,
      -1, 0,
      { 2829 },
      -1,
   } },

   /* replace964_0_0 -> 32 in the cache */
   /* replace964_0 -> 98 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fexp2,
      -1, 0,
      { 98 },
      -1,
   } },

   /* ('~frsq', ('fexp2', 'a')) => ('fexp2', ('fmul', -0.5, 'a')) */
   /* search965_0_0 -> 32 in the cache */
   /* search965_0 -> 2829 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_frsq,
      -1, 0,
      { 2829 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0xbfe0000000000000 /* -0.5 */ },
   } },
   /* replace965_0_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 2872, 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fexp2,
      -1, 1,
      { 2873 },
      -1,
   } },

   /* ('~flog2', ('fsqrt', 'a')) => ('fmul', 0.5, ('flog2', 'a')) */
   /* search966_0_0 -> 32 in the cache */
   /* search966_0 -> 2848 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_flog2,
      -1, 0,
      { 2848 },
      -1,
   } },

   /* replace966_0 -> 2845 in the cache */
   /* replace966_1_0 -> 32 in the cache */
   /* replace966_1 -> 2827 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 2845, 2827 },
      -1,
   } },

   /* ('~flog2', ('frcp', 'a')) => ('fneg', ('flog2', 'a')) */
   /* search967_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_frcp,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_flog2,
      -1, 0,
      { 2877 },
      -1,
   } },

   /* replace967_0_0 -> 32 in the cache */
   /* replace967_0 -> 2827 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 2827 },
      -1,
   } },

   /* ('~flog2', ('frsq', 'a')) => ('fmul', -0.5, ('flog2', 'a')) */
   /* search968_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_frsq,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_flog2,
      -1, 0,
      { 2880 },
      -1,
   } },

   /* replace968_0 -> 2872 in the cache */
   /* replace968_1_0 -> 32 in the cache */
   /* replace968_1 -> 2827 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 2872, 2827 },
      -1,
   } },

   /* ('~flog2', ('fpow', 'a', 'b')) => ('fmul', 'b', ('flog2', 'a')) */
   /* search969_0_0 -> 0 in the cache */
   /* search969_0_1 -> 3 in the cache */
   /* search969_0 -> 2831 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_flog2,
      -1, 0,
      { 2831 },
      -1,
   } },

   /* replace969_0 -> 3 in the cache */
   /* replace969_1_0 -> 0 in the cache */
   /* replace969_1 -> 2832 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 3, 2832 },
      -1,
   } },

   /* ('~fmul', ('fexp2(is_used_once)', 'a'), ('fexp2(is_used_once)', 'b')) => ('fexp2', ('fadd', 'a', 'b')) */
   /* search970_0_0 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fexp2,
      -1, 0,
      { 0 },
      0,
   } },
   /* search970_1_0 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fexp2,
      -1, 0,
      { 3 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 2885, 2886 },
      -1,
   } },

   /* replace970_0_0 -> 0 in the cache */
   /* replace970_0_1 -> 3 in the cache */
   /* replace970_0 -> 272 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fexp2,
      -1, 1,
      { 272 },
      -1,
   } },

   /* ('bcsel', ('flt', 'a', 0.0), 0.0, ('fsqrt', 'a')) => ('fsqrt', ('fmax', 'a', 0.0)) */
   /* search971_0_0 -> 32 in the cache */
   /* search971_0_1 -> 111 in the cache */
   /* search971_0 -> 1172 in the cache */
   /* search971_1 -> 111 in the cache */
   /* search971_2_0 -> 32 in the cache */
   /* search971_2 -> 2848 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1172, 111, 2848 },
      -1,
   } },

   /* replace971_0_0 -> 32 in the cache */
   /* replace971_0_1 -> 111 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 32, 111 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsqrt,
      -1, 1,
      { 2890 },
      -1,
   } },

   /* ('~fmul', ('fsqrt', 'a'), ('fsqrt', 'a')) => ('fabs', 'a') */
   /* search972_0_0 -> 32 in the cache */
   /* search972_0 -> 2848 in the cache */
   /* search972_1_0 -> 32 in the cache */
   /* search972_1 -> 2848 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fmul,
      -1, 0,
      { 2848, 2848 },
      -1,
   } },

   /* replace972_0 -> 32 in the cache */
   /* replace972 -> 103 in the cache */

   /* ('~fmulz', ('fsqrt', 'a'), ('fsqrt', 'a')) => ('fabs', 'a') */
   /* search973_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fsqrt,
      -1, 0,
      { 16 },
      -1,
   } },
   /* search973_1_0 -> 16 in the cache */
   /* search973_1 -> 2893 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fmulz,
      -1, 0,
      { 2893, 2893 },
      -1,
   } },

   /* replace973_0 -> 16 in the cache */
   /* replace973 -> 696 in the cache */

   /* ('~fdiv', 1.0, 'a') => ('frcp', 'a') */
   /* search974_0 -> 241 in the cache */
   /* search974_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fdiv,
      -1, 0,
      { 241, 32 },
      -1,
   } },

   /* replace974_0 -> 32 in the cache */
   /* replace974 -> 2877 in the cache */

   /* ('fdiv', 'a', 'b') => ('fmul', 'a', ('frcp', 'b')) */
   /* search975_0 -> 0 in the cache */
   /* search975_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdiv,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* replace975_0 -> 0 in the cache */
   /* replace975_1_0 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_frcp,
      -1, 0,
      { 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 0, 2897 },
      -1,
   } },

   /* ('~frcp', ('frcp', 'a')) => a */
   /* search976_0_0 -> 32 in the cache */
   /* search976_0 -> 2877 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_frcp,
      -1, 0,
      { 2877 },
      -1,
   } },

   /* replace976 -> 32 in the cache */

   /* ('~frcp', ('fsqrt', 'a')) => ('frsq', 'a') */
   /* search977_0_0 -> 32 in the cache */
   /* search977_0 -> 2848 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_frcp,
      -1, 0,
      { 2848 },
      -1,
   } },

   /* replace977_0 -> 32 in the cache */
   /* replace977 -> 2880 in the cache */

   /* ('fsqrt', 'a') => ('frcp', ('frsq', 'a')) */
   /* search978_0 -> 32 in the cache */
   /* search978 -> 2848 in the cache */

   /* replace978_0_0 -> 32 in the cache */
   /* replace978_0 -> 2880 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_frcp,
      -1, 0,
      { 2880 },
      -1,
   } },

   /* ('~frcp', ('frsq', 'a')) => ('fsqrt', 'a') */
   /* search979_0_0 -> 32 in the cache */
   /* search979_0 -> 2880 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_frcp,
      -1, 0,
      { 2880 },
      -1,
   } },

   /* replace979_0 -> 32 in the cache */
   /* replace979 -> 2848 in the cache */

   /* ('fsin', 'a') => ('ffma', ('ffma', ('fmul', ('fsub', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0), ('fmul', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0), ('fabs', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0)))), 4.0), ('fabs', ('fmul', ('fsub', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0), ('fmul', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0), ('fabs', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0)))), 4.0)), ('fneg', ('fmul', ('fsub', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0), ('fmul', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0), ('fabs', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0)))), 4.0))), 0.225, ('fmul', ('fsub', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0), ('fmul', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0), ('fabs', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.5))), 1.0)))), 4.0)) */
   /* search980_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsin,
      -1, 0,
      { 32 },
      -1,
   } },

   /* replace980_0_0_0_0_0_0 -> 2849 in the cache */
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0x3fc45f306dc9c883 /* 0.15915494309189535 */ },
   } },
   /* replace980_0_0_0_0_0_1_0_0_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      5, 1,
      { 2904, 32 },
      -1,
   } },
   /* replace980_0_0_0_0_0_1_0_1 -> 2845 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      4, 2,
      { 2905, 2845 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 2906 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      3, 3,
      { 2849, 2907 },
      -1,
   } },
   /* replace980_0_0_0_0_1 -> 241 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 2908, 241 },
      -1,
   } },
   /* replace980_0_0_0_1_0_0_0 -> 2849 in the cache */
   /* replace980_0_0_0_1_0_0_1_0_0_0 -> 2904 in the cache */
   /* replace980_0_0_0_1_0_0_1_0_0_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      9, 1,
      { 2904, 32 },
      -1,
   } },
   /* replace980_0_0_0_1_0_0_1_0_1 -> 2845 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      8, 2,
      { 2910, 2845 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 2911 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      7, 3,
      { 2849, 2912 },
      -1,
   } },
   /* replace980_0_0_0_1_0_1 -> 241 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 2913, 241 },
      -1,
   } },
   /* replace980_0_0_0_1_1_0_0_0 -> 2849 in the cache */
   /* replace980_0_0_0_1_1_0_0_1_0_0_0 -> 2904 in the cache */
   /* replace980_0_0_0_1_1_0_0_1_0_0_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      12, 1,
      { 2904, 32 },
      -1,
   } },
   /* replace980_0_0_0_1_1_0_0_1_0_1 -> 2845 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      11, 2,
      { 2915, 2845 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 2916 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      10, 3,
      { 2849, 2917 },
      -1,
   } },
   /* replace980_0_0_0_1_1_0_1 -> 241 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 2918, 241 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 3,
      { 2919 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      6, 7,
      { 2914, 2920 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 10,
      { 2909, 2921 },
      -1,
   } },
   /* replace980_0_0_1 -> 2852 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      2, 11,
      { 2922, 2852 },
      -1,
   } },
   /* replace980_0_1_0_0_0_0_0 -> 2849 in the cache */
   /* replace980_0_1_0_0_0_0_1_0_0_0 -> 2904 in the cache */
   /* replace980_0_1_0_0_0_0_1_0_0_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      16, 1,
      { 2904, 32 },
      -1,
   } },
   /* replace980_0_1_0_0_0_0_1_0_1 -> 2845 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      15, 2,
      { 2924, 2845 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 2925 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      14, 3,
      { 2849, 2926 },
      -1,
   } },
   /* replace980_0_1_0_0_0_1 -> 241 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 2927, 241 },
      -1,
   } },
   /* replace980_0_1_0_0_1_0_0_0 -> 2849 in the cache */
   /* replace980_0_1_0_0_1_0_0_1_0_0_0 -> 2904 in the cache */
   /* replace980_0_1_0_0_1_0_0_1_0_0_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      20, 1,
      { 2904, 32 },
      -1,
   } },
   /* replace980_0_1_0_0_1_0_0_1_0_1 -> 2845 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      19, 2,
      { 2929, 2845 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 2930 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      18, 3,
      { 2849, 2931 },
      -1,
   } },
   /* replace980_0_1_0_0_1_0_1 -> 241 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 2932, 241 },
      -1,
   } },
   /* replace980_0_1_0_0_1_1_0_0_0 -> 2849 in the cache */
   /* replace980_0_1_0_0_1_1_0_0_1_0_0_0 -> 2904 in the cache */
   /* replace980_0_1_0_0_1_1_0_0_1_0_0_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      23, 1,
      { 2904, 32 },
      -1,
   } },
   /* replace980_0_1_0_0_1_1_0_0_1_0_1 -> 2845 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      22, 2,
      { 2934, 2845 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 2935 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      21, 3,
      { 2849, 2936 },
      -1,
   } },
   /* replace980_0_1_0_0_1_1_0_1 -> 241 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 2937, 241 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 3,
      { 2938 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      17, 7,
      { 2933, 2939 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 10,
      { 2928, 2940 },
      -1,
   } },
   /* replace980_0_1_0_1 -> 2852 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      13, 11,
      { 2941, 2852 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 11,
      { 2942 },
      -1,
   } },
   /* replace980_0_2_0_0_0_0_0 -> 2849 in the cache */
   /* replace980_0_2_0_0_0_0_1_0_0_0 -> 2904 in the cache */
   /* replace980_0_2_0_0_0_0_1_0_0_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      27, 1,
      { 2904, 32 },
      -1,
   } },
   /* replace980_0_2_0_0_0_0_1_0_1 -> 2845 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      26, 2,
      { 2944, 2845 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 2945 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      25, 3,
      { 2849, 2946 },
      -1,
   } },
   /* replace980_0_2_0_0_0_1 -> 241 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 2947, 241 },
      -1,
   } },
   /* replace980_0_2_0_0_1_0_0_0 -> 2849 in the cache */
   /* replace980_0_2_0_0_1_0_0_1_0_0_0 -> 2904 in the cache */
   /* replace980_0_2_0_0_1_0_0_1_0_0_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      31, 1,
      { 2904, 32 },
      -1,
   } },
   /* replace980_0_2_0_0_1_0_0_1_0_1 -> 2845 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      30, 2,
      { 2949, 2845 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 2950 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      29, 3,
      { 2849, 2951 },
      -1,
   } },
   /* replace980_0_2_0_0_1_0_1 -> 241 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 2952, 241 },
      -1,
   } },
   /* replace980_0_2_0_0_1_1_0_0_0 -> 2849 in the cache */
   /* replace980_0_2_0_0_1_1_0_0_1_0_0_0 -> 2904 in the cache */
   /* replace980_0_2_0_0_1_1_0_0_1_0_0_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      34, 1,
      { 2904, 32 },
      -1,
   } },
   /* replace980_0_2_0_0_1_1_0_0_1_0_1 -> 2845 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      33, 2,
      { 2954, 2845 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 2955 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      32, 3,
      { 2849, 2956 },
      -1,
   } },
   /* replace980_0_2_0_0_1_1_0_1 -> 241 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 2957, 241 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 3,
      { 2958 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      28, 7,
      { 2953, 2959 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 10,
      { 2948, 2960 },
      -1,
   } },
   /* replace980_0_2_0_1 -> 2852 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      24, 11,
      { 2961, 2852 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 11,
      { 2962 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffma,
      1, 34,
      { 2923, 2943, 2963 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0x3fcccccccccccccd /* 0.225 */ },
   } },
   /* replace980_2_0_0_0_0 -> 2849 in the cache */
   /* replace980_2_0_0_0_1_0_0_0 -> 2904 in the cache */
   /* replace980_2_0_0_0_1_0_0_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      38, 1,
      { 2904, 32 },
      -1,
   } },
   /* replace980_2_0_0_0_1_0_1 -> 2845 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      37, 2,
      { 2966, 2845 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 2967 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      36, 3,
      { 2849, 2968 },
      -1,
   } },
   /* replace980_2_0_0_1 -> 241 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 2969, 241 },
      -1,
   } },
   /* replace980_2_0_1_0_0_0 -> 2849 in the cache */
   /* replace980_2_0_1_0_0_1_0_0_0 -> 2904 in the cache */
   /* replace980_2_0_1_0_0_1_0_0_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      42, 1,
      { 2904, 32 },
      -1,
   } },
   /* replace980_2_0_1_0_0_1_0_1 -> 2845 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      41, 2,
      { 2971, 2845 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 2972 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      40, 3,
      { 2849, 2973 },
      -1,
   } },
   /* replace980_2_0_1_0_1 -> 241 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 2974, 241 },
      -1,
   } },
   /* replace980_2_0_1_1_0_0_0 -> 2849 in the cache */
   /* replace980_2_0_1_1_0_0_1_0_0_0 -> 2904 in the cache */
   /* replace980_2_0_1_1_0_0_1_0_0_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      45, 1,
      { 2904, 32 },
      -1,
   } },
   /* replace980_2_0_1_1_0_0_1_0_1 -> 2845 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      44, 2,
      { 2976, 2845 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 2977 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      43, 3,
      { 2849, 2978 },
      -1,
   } },
   /* replace980_2_0_1_1_0_1 -> 241 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 2979, 241 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 3,
      { 2980 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      39, 7,
      { 2975, 2981 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 10,
      { 2970, 2982 },
      -1,
   } },
   /* replace980_2_1 -> 2852 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      35, 11,
      { 2983, 2852 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 46,
      { 2964, 2965, 2984 },
      -1,
   } },

   /* ('fcos', 'a') => ('ffma', ('ffma', ('fmul', ('fsub', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0), ('fmul', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0), ('fabs', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0)))), 4.0), ('fabs', ('fmul', ('fsub', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0), ('fmul', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0), ('fabs', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0)))), 4.0)), ('fneg', ('fmul', ('fsub', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0), ('fmul', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0), ('fabs', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0)))), 4.0))), 0.225, ('fmul', ('fsub', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0), ('fmul', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0), ('fabs', ('fsub', ('fmul', 2.0, ('ffract', ('fadd', ('fmul', 0.15915494309189535, 'a'), 0.75))), 1.0)))), 4.0)) */
   /* search981_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fcos,
      -1, 0,
      { 32 },
      -1,
   } },

   /* replace981_0_0_0_0_0_0 -> 2849 in the cache */
   /* replace981_0_0_0_0_0_1_0_0_0 -> 2904 in the cache */
   /* replace981_0_0_0_0_0_1_0_0_1 -> 32 in the cache */
   /* replace981_0_0_0_0_0_1_0_0 -> 2905 in the cache */
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0x3fe8000000000000 /* 0.75 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      4, 2,
      { 2905, 2987 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 2988 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      3, 3,
      { 2849, 2989 },
      -1,
   } },
   /* replace981_0_0_0_0_1 -> 241 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 2990, 241 },
      -1,
   } },
   /* replace981_0_0_0_1_0_0_0 -> 2849 in the cache */
   /* replace981_0_0_0_1_0_0_1_0_0_0 -> 2904 in the cache */
   /* replace981_0_0_0_1_0_0_1_0_0_1 -> 32 in the cache */
   /* replace981_0_0_0_1_0_0_1_0_0 -> 2910 in the cache */
   /* replace981_0_0_0_1_0_0_1_0_1 -> 2987 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      8, 2,
      { 2910, 2987 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 2992 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      7, 3,
      { 2849, 2993 },
      -1,
   } },
   /* replace981_0_0_0_1_0_1 -> 241 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 2994, 241 },
      -1,
   } },
   /* replace981_0_0_0_1_1_0_0_0 -> 2849 in the cache */
   /* replace981_0_0_0_1_1_0_0_1_0_0_0 -> 2904 in the cache */
   /* replace981_0_0_0_1_1_0_0_1_0_0_1 -> 32 in the cache */
   /* replace981_0_0_0_1_1_0_0_1_0_0 -> 2915 in the cache */
   /* replace981_0_0_0_1_1_0_0_1_0_1 -> 2987 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      11, 2,
      { 2915, 2987 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 2996 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      10, 3,
      { 2849, 2997 },
      -1,
   } },
   /* replace981_0_0_0_1_1_0_1 -> 241 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 2998, 241 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 3,
      { 2999 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      6, 7,
      { 2995, 3000 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 10,
      { 2991, 3001 },
      -1,
   } },
   /* replace981_0_0_1 -> 2852 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      2, 11,
      { 3002, 2852 },
      -1,
   } },
   /* replace981_0_1_0_0_0_0_0 -> 2849 in the cache */
   /* replace981_0_1_0_0_0_0_1_0_0_0 -> 2904 in the cache */
   /* replace981_0_1_0_0_0_0_1_0_0_1 -> 32 in the cache */
   /* replace981_0_1_0_0_0_0_1_0_0 -> 2924 in the cache */
   /* replace981_0_1_0_0_0_0_1_0_1 -> 2987 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      15, 2,
      { 2924, 2987 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 3004 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      14, 3,
      { 2849, 3005 },
      -1,
   } },
   /* replace981_0_1_0_0_0_1 -> 241 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 3006, 241 },
      -1,
   } },
   /* replace981_0_1_0_0_1_0_0_0 -> 2849 in the cache */
   /* replace981_0_1_0_0_1_0_0_1_0_0_0 -> 2904 in the cache */
   /* replace981_0_1_0_0_1_0_0_1_0_0_1 -> 32 in the cache */
   /* replace981_0_1_0_0_1_0_0_1_0_0 -> 2929 in the cache */
   /* replace981_0_1_0_0_1_0_0_1_0_1 -> 2987 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      19, 2,
      { 2929, 2987 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 3008 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      18, 3,
      { 2849, 3009 },
      -1,
   } },
   /* replace981_0_1_0_0_1_0_1 -> 241 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 3010, 241 },
      -1,
   } },
   /* replace981_0_1_0_0_1_1_0_0_0 -> 2849 in the cache */
   /* replace981_0_1_0_0_1_1_0_0_1_0_0_0 -> 2904 in the cache */
   /* replace981_0_1_0_0_1_1_0_0_1_0_0_1 -> 32 in the cache */
   /* replace981_0_1_0_0_1_1_0_0_1_0_0 -> 2934 in the cache */
   /* replace981_0_1_0_0_1_1_0_0_1_0_1 -> 2987 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      22, 2,
      { 2934, 2987 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 3012 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      21, 3,
      { 2849, 3013 },
      -1,
   } },
   /* replace981_0_1_0_0_1_1_0_1 -> 241 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 3014, 241 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 3,
      { 3015 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      17, 7,
      { 3011, 3016 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 10,
      { 3007, 3017 },
      -1,
   } },
   /* replace981_0_1_0_1 -> 2852 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      13, 11,
      { 3018, 2852 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 11,
      { 3019 },
      -1,
   } },
   /* replace981_0_2_0_0_0_0_0 -> 2849 in the cache */
   /* replace981_0_2_0_0_0_0_1_0_0_0 -> 2904 in the cache */
   /* replace981_0_2_0_0_0_0_1_0_0_1 -> 32 in the cache */
   /* replace981_0_2_0_0_0_0_1_0_0 -> 2944 in the cache */
   /* replace981_0_2_0_0_0_0_1_0_1 -> 2987 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      26, 2,
      { 2944, 2987 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 3021 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      25, 3,
      { 2849, 3022 },
      -1,
   } },
   /* replace981_0_2_0_0_0_1 -> 241 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 3023, 241 },
      -1,
   } },
   /* replace981_0_2_0_0_1_0_0_0 -> 2849 in the cache */
   /* replace981_0_2_0_0_1_0_0_1_0_0_0 -> 2904 in the cache */
   /* replace981_0_2_0_0_1_0_0_1_0_0_1 -> 32 in the cache */
   /* replace981_0_2_0_0_1_0_0_1_0_0 -> 2949 in the cache */
   /* replace981_0_2_0_0_1_0_0_1_0_1 -> 2987 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      30, 2,
      { 2949, 2987 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 3025 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      29, 3,
      { 2849, 3026 },
      -1,
   } },
   /* replace981_0_2_0_0_1_0_1 -> 241 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 3027, 241 },
      -1,
   } },
   /* replace981_0_2_0_0_1_1_0_0_0 -> 2849 in the cache */
   /* replace981_0_2_0_0_1_1_0_0_1_0_0_0 -> 2904 in the cache */
   /* replace981_0_2_0_0_1_1_0_0_1_0_0_1 -> 32 in the cache */
   /* replace981_0_2_0_0_1_1_0_0_1_0_0 -> 2954 in the cache */
   /* replace981_0_2_0_0_1_1_0_0_1_0_1 -> 2987 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      33, 2,
      { 2954, 2987 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 3029 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      32, 3,
      { 2849, 3030 },
      -1,
   } },
   /* replace981_0_2_0_0_1_1_0_1 -> 241 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 3031, 241 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 3,
      { 3032 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      28, 7,
      { 3028, 3033 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 10,
      { 3024, 3034 },
      -1,
   } },
   /* replace981_0_2_0_1 -> 2852 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      24, 11,
      { 3035, 2852 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 11,
      { 3036 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffma,
      1, 34,
      { 3003, 3020, 3037 },
      -1,
   } },
   /* replace981_1 -> 2965 in the cache */
   /* replace981_2_0_0_0_0 -> 2849 in the cache */
   /* replace981_2_0_0_0_1_0_0_0 -> 2904 in the cache */
   /* replace981_2_0_0_0_1_0_0_1 -> 32 in the cache */
   /* replace981_2_0_0_0_1_0_0 -> 2966 in the cache */
   /* replace981_2_0_0_0_1_0_1 -> 2987 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      37, 2,
      { 2966, 2987 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 3039 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      36, 3,
      { 2849, 3040 },
      -1,
   } },
   /* replace981_2_0_0_1 -> 241 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 3041, 241 },
      -1,
   } },
   /* replace981_2_0_1_0_0_0 -> 2849 in the cache */
   /* replace981_2_0_1_0_0_1_0_0_0 -> 2904 in the cache */
   /* replace981_2_0_1_0_0_1_0_0_1 -> 32 in the cache */
   /* replace981_2_0_1_0_0_1_0_0 -> 2971 in the cache */
   /* replace981_2_0_1_0_0_1_0_1 -> 2987 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      41, 2,
      { 2971, 2987 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 3043 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      40, 3,
      { 2849, 3044 },
      -1,
   } },
   /* replace981_2_0_1_0_1 -> 241 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 3045, 241 },
      -1,
   } },
   /* replace981_2_0_1_1_0_0_0 -> 2849 in the cache */
   /* replace981_2_0_1_1_0_0_1_0_0_0 -> 2904 in the cache */
   /* replace981_2_0_1_1_0_0_1_0_0_1 -> 32 in the cache */
   /* replace981_2_0_1_1_0_0_1_0_0 -> 2976 in the cache */
   /* replace981_2_0_1_1_0_0_1_0_1 -> 2987 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      44, 2,
      { 2976, 2987 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 2,
      { 3047 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      43, 3,
      { 2849, 3048 },
      -1,
   } },
   /* replace981_2_0_1_1_0_1 -> 241 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 3,
      { 3049, 241 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 3,
      { 3050 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      39, 7,
      { 3046, 3051 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 10,
      { 3042, 3052 },
      -1,
   } },
   /* replace981_2_1 -> 2852 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      35, 11,
      { 3053, 2852 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 46,
      { 3038, 2965, 3054 },
      -1,
   } },

   /* ('ieq', 'a', True) => a */
   /* search982_0 -> 760 in the cache */
   /* search982_1 -> 1235 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 760, 1235 },
      -1,
   } },

   /* replace982 -> 760 in the cache */

   /* ('ine(is_not_used_by_if)', 'a', True) => ('inot', 'a') */
   /* search983_0 -> 760 in the cache */
   /* search983_1 -> 1235 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 760, 1235 },
      2,
   } },

   /* replace983_0 -> 760 in the cache */
   /* replace983 -> 1131 in the cache */

   /* ('ine', 'a', False) => a */
   /* search984_0 -> 760 in the cache */
   /* search984_1 -> 1077 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 760, 1077 },
      -1,
   } },

   /* replace984 -> 760 in the cache */

   /* ('ieq(is_not_used_by_if)', 'a', False) => ('inot', 'a') */
   /* search985_0 -> 760 in the cache */
   /* search985_1 -> 1077 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 760, 1077 },
      2,
   } },

   /* replace985_0 -> 760 in the cache */
   /* replace985 -> 1131 in the cache */

   /* ('bcsel', 'a', True, False) => a */
   /* search986_0 -> 760 in the cache */
   /* search986_1 -> 1235 in the cache */
   /* search986_2 -> 1077 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 760, 1235, 1077 },
      -1,
   } },

   /* replace986 -> 760 in the cache */

   /* ('bcsel', 'a', False, True) => ('inot', 'a') */
   /* search987_0 -> 760 in the cache */
   /* search987_1 -> 1077 in the cache */
   /* search987_2 -> 1235 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 760, 1077, 1235 },
      -1,
   } },

   /* replace987_0 -> 760 in the cache */
   /* replace987 -> 1131 in the cache */

   /* ('bcsel', True, 'b', 'c') => b */
   /* search988_0 -> 1235 in the cache */
   /* search988_1 -> 1117 in the cache */
   /* search988_2 -> 684 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1235, 1117, 684 },
      -1,
   } },

   /* replace988 -> 1117 in the cache */

   /* ('bcsel', False, 'b', 'c') => c */
   /* search989_0 -> 1077 in the cache */
   /* search989_1 -> 1117 in the cache */
   /* search989_2 -> 684 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1077, 1117, 684 },
      -1,
   } },

   /* replace989 -> 684 in the cache */

   /* ('bcsel@16', 'a', 1.0, 0.0) => ('b2f', 'a') */
   /* search990_0 -> 760 in the cache */
   /* search990_1 -> 481 in the cache */
   /* search990_2 -> 113 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 760, 481, 113 },
      -1,
   } },

   /* replace990_0 -> 760 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 760 },
      -1,
   } },

   /* ('bcsel@16', 'a', 0.0, 1.0) => ('b2f', ('inot', 'a')) */
   /* search991_0 -> 760 in the cache */
   /* search991_1 -> 113 in the cache */
   /* search991_2 -> 481 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 760, 113, 481 },
      -1,
   } },

   /* replace991_0_0 -> 760 in the cache */
   /* replace991_0 -> 1131 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 1131 },
      -1,
   } },

   /* ('bcsel@16', 'a', -1.0, -0.0) => ('fneg', ('b2f', 'a')) */
   /* search992_0 -> 760 in the cache */
   { .constant = {
      { nir_search_value_constant, 16 },
      nir_type_float, { 0xbff0000000000000 /* -1.0 */ },
   } },
   { .constant = {
      { nir_search_value_constant, 16 },
      nir_type_float, { 0x8000000000000000 /* -0.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 760, 3068, 3069 },
      -1,
   } },

   /* replace992_0_0 -> 760 in the cache */
   /* replace992_0 -> 3065 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 3065 },
      -1,
   } },

   /* ('bcsel@16', 'a', -0.0, -1.0) => ('fneg', ('b2f', ('inot', 'a'))) */
   /* search993_0 -> 760 in the cache */
   /* search993_1 -> 3069 in the cache */
   /* search993_2 -> 3068 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 760, 3069, 3068 },
      -1,
   } },

   /* replace993_0_0_0 -> 760 in the cache */
   /* replace993_0_0 -> 1131 in the cache */
   /* replace993_0 -> 3067 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 3067 },
      -1,
   } },

   /* ('bcsel@32', 'a', 1.0, 0.0) => ('b2f', 'a') */
   /* search994_0 -> 760 in the cache */
   /* search994_1 -> 243 in the cache */
   /* search994_2 -> 115 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 760, 243, 115 },
      -1,
   } },

   /* replace994_0 -> 760 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 760 },
      -1,
   } },

   /* ('bcsel@32', 'a', 0.0, 1.0) => ('b2f', ('inot', 'a')) */
   /* search995_0 -> 760 in the cache */
   /* search995_1 -> 115 in the cache */
   /* search995_2 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 760, 115, 243 },
      -1,
   } },

   /* replace995_0_0 -> 760 in the cache */
   /* replace995_0 -> 1131 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 1131 },
      -1,
   } },

   /* ('bcsel@32', 'a', -1.0, -0.0) => ('fneg', ('b2f', 'a')) */
   /* search996_0 -> 760 in the cache */
   /* search996_1 -> 278 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_float, { 0x8000000000000000 /* -0.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 760, 278, 3078 },
      -1,
   } },

   /* replace996_0_0 -> 760 in the cache */
   /* replace996_0 -> 3075 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 3075 },
      -1,
   } },

   /* ('bcsel@32', 'a', -0.0, -1.0) => ('fneg', ('b2f', ('inot', 'a'))) */
   /* search997_0 -> 760 in the cache */
   /* search997_1 -> 3078 in the cache */
   /* search997_2 -> 278 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 760, 3078, 278 },
      -1,
   } },

   /* replace997_0_0_0 -> 760 in the cache */
   /* replace997_0_0 -> 1131 in the cache */
   /* replace997_0 -> 3077 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 3077 },
      -1,
   } },

   /* ('bcsel@64', 'a', 1.0, 0.0) => ('b2f', 'a') */
   /* search998_0 -> 760 in the cache */
   /* search998_1 -> 622 in the cache */
   /* search998_2 -> 701 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 760, 622, 701 },
      -1,
   } },

   /* replace998_0 -> 760 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 760 },
      -1,
   } },

   /* ('bcsel@64', 'a', 0.0, 1.0) => ('b2f', ('inot', 'a')) */
   /* search999_0 -> 760 in the cache */
   /* search999_1 -> 701 in the cache */
   /* search999_2 -> 622 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 760, 701, 622 },
      -1,
   } },

   /* replace999_0_0 -> 760 in the cache */
   /* replace999_0 -> 1131 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 1131 },
      -1,
   } },

   /* ('bcsel@64', 'a', -1.0, -0.0) => ('fneg', ('b2f', 'a')) */
   /* search1000_0 -> 760 in the cache */
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_float, { 0xbff0000000000000 /* -1.0 */ },
   } },
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_float, { 0x8000000000000000 /* -0.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 760, 3087, 3088 },
      -1,
   } },

   /* replace1000_0_0 -> 760 in the cache */
   /* replace1000_0 -> 3084 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 3084 },
      -1,
   } },

   /* ('bcsel@64', 'a', -0.0, -1.0) => ('fneg', ('b2f', ('inot', 'a'))) */
   /* search1001_0 -> 760 in the cache */
   /* search1001_1 -> 3088 in the cache */
   /* search1001_2 -> 3087 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 760, 3088, 3087 },
      -1,
   } },

   /* replace1001_0_0_0 -> 760 in the cache */
   /* replace1001_0_0 -> 1131 in the cache */
   /* replace1001_0 -> 3086 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 3086 },
      -1,
   } },

   /* ('bcsel', 'a', 'b', 'b') => b */
   /* search1002_0 -> 760 in the cache */
   /* search1002_1 -> 3 in the cache */
   /* search1002_2 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 760, 3, 3 },
      -1,
   } },

   /* replace1002 -> 3 in the cache */

   /* ('~fcsel', 'a', 'b', 'b') => b */
   /* search1003_0 -> 16 in the cache */
   /* search1003_1 -> 36 in the cache */
   /* search1003_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fcsel,
      -1, 0,
      { 16, 36, 36 },
      -1,
   } },

   /* replace1003 -> 36 in the cache */

   /* ('bcsel', 'a', -1, 0) => ('ineg', ('b2i', 'a@1')) */
   /* search1004_0 -> 760 in the cache */
   /* search1004_1 -> 2783 in the cache */
   /* search1004_2 -> 1229 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 760, 2783, 1229 },
      -1,
   } },

   /* replace1004_0_0 -> 760 in the cache */
   /* replace1004_0 -> 1228 in the cache */
   /* replace1004 -> 2264 in the cache */

   /* ('bcsel', 'a', 0, -1) => ('ineg', ('b2i', ('inot', 'a'))) */
   /* search1005_0 -> 760 in the cache */
   /* search1005_1 -> 1229 in the cache */
   /* search1005_2 -> 2783 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 760, 1229, 2783 },
      -1,
   } },

   /* replace1005_0_0_0 -> 760 in the cache */
   /* replace1005_0_0 -> 1131 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2i,
      -1, 0,
      { 1131 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 3097 },
      -1,
   } },

   /* ('bcsel', 'a', 1, 0) => ('b2i', 'a@1') */
   /* search1006_0 -> 760 in the cache */
   { .constant = {
      { nir_search_value_constant, 0 },
      nir_type_int, { 0x1 /* 1 */ },
   } },
   /* search1006_2 -> 1229 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 760, 3099, 1229 },
      -1,
   } },

   /* replace1006_0 -> 760 in the cache */
   /* replace1006 -> 1228 in the cache */

   /* ('bcsel', 'a', 0, 1) => ('b2i', ('inot', 'a')) */
   /* search1007_0 -> 760 in the cache */
   /* search1007_1 -> 1229 in the cache */
   /* search1007_2 -> 3099 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 760, 1229, 3099 },
      -1,
   } },

   /* replace1007_0_0 -> 760 in the cache */
   /* replace1007_0 -> 1131 in the cache */
   /* replace1007 -> 3097 in the cache */

   /* ('iand', ('ineg', ('b2i', 'a@1')), ('ineg', ('b2i', 'b@1'))) => ('ineg', ('b2i', ('iand', 'a', 'b'))) */
   /* search1008_0_0_0 -> 760 in the cache */
   /* search1008_0_0 -> 1228 in the cache */
   /* search1008_0 -> 2264 in the cache */
   /* search1008_1_0_0 -> 1134 in the cache */
   /* search1008_1_0 -> 2265 in the cache */
   /* search1008_1 -> 2266 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 2264, 2266 },
      -1,
   } },

   /* replace1008_0_0_0 -> 760 in the cache */
   /* replace1008_0_0_1 -> 1134 in the cache */
   /* replace1008_0_0 -> 1146 in the cache */
   /* replace1008_0 -> 2692 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 1,
      { 2692 },
      -1,
   } },

   /* ('ior', ('ineg', ('b2i', 'a@1')), ('ineg', ('b2i', 'b@1'))) => ('ineg', ('b2i', ('ior', 'a', 'b'))) */
   /* search1009_0_0_0 -> 760 in the cache */
   /* search1009_0_0 -> 1228 in the cache */
   /* search1009_0 -> 2264 in the cache */
   /* search1009_1_0_0 -> 1134 in the cache */
   /* search1009_1_0 -> 2265 in the cache */
   /* search1009_1 -> 2266 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 2264, 2266 },
      -1,
   } },

   /* replace1009_0_0_0 -> 760 in the cache */
   /* replace1009_0_0_1 -> 1134 in the cache */
   /* replace1009_0_0 -> 1138 in the cache */
   /* replace1009_0 -> 2695 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 1,
      { 2695 },
      -1,
   } },

   /* ('ieq', ('ineg', ('b2i', 'a@1')), -1) => a */
   /* search1010_0_0_0 -> 760 in the cache */
   /* search1010_0_0 -> 1228 in the cache */
   /* search1010_0 -> 2264 in the cache */
   /* search1010_1 -> 2783 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 2264, 2783 },
      -1,
   } },

   /* replace1010 -> 760 in the cache */

   /* ('ine', ('ineg', ('b2i', 'a@1')), -1) => ('inot', 'a') */
   /* search1011_0_0_0 -> 760 in the cache */
   /* search1011_0_0 -> 1228 in the cache */
   /* search1011_0 -> 2264 in the cache */
   /* search1011_1 -> 2783 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 2264, 2783 },
      -1,
   } },

   /* replace1011_0 -> 760 in the cache */
   /* replace1011 -> 1131 in the cache */

   /* ('ige', ('ineg', ('b2i', 'a@1')), 0) => ('inot', 'a') */
   /* search1012_0_0_0 -> 760 in the cache */
   /* search1012_0_0 -> 1228 in the cache */
   /* search1012_0 -> 2264 in the cache */
   /* search1012_1 -> 1229 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 2264, 1229 },
      -1,
   } },

   /* replace1012_0 -> 760 in the cache */
   /* replace1012 -> 1131 in the cache */

   /* ('ilt', ('ineg', ('b2i', 'a@1')), 0) => a */
   /* search1013_0_0_0 -> 760 in the cache */
   /* search1013_0_0 -> 1228 in the cache */
   /* search1013_0 -> 2264 in the cache */
   /* search1013_1 -> 1229 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 2264, 1229 },
      -1,
   } },

   /* replace1013 -> 760 in the cache */

   /* ('ult', 0, ('ineg', ('b2i', 'a@1'))) => a */
   /* search1014_0 -> 1229 in the cache */
   /* search1014_1_0_0 -> 760 in the cache */
   /* search1014_1_0 -> 1228 in the cache */
   /* search1014_1 -> 2264 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 1229, 2264 },
      -1,
   } },

   /* replace1014 -> 760 in the cache */

   /* ('iand', ('ineg', ('b2i', 'a')), 1.0) => ('b2f', 'a') */
   /* search1015_0_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2i,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 3111 },
      -1,
   } },
   /* search1015_1 -> 1139 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 3112, 1139 },
      -1,
   } },

   /* replace1015_0 -> 32 in the cache */
   /* replace1015 -> 1528 in the cache */

   /* ('iand', ('ineg', ('b2i', 'a')), 1) => ('b2i', 'a') */
   /* search1016_0_0_0 -> 32 in the cache */
   /* search1016_0_0 -> 3111 in the cache */
   /* search1016_0 -> 3112 in the cache */
   /* search1016_1 -> 3099 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 3112, 3099 },
      -1,
   } },

   /* replace1016_0 -> 32 in the cache */
   /* replace1016 -> 3111 in the cache */

   /* ('imax', ('ineg', ('b2i', 'a@1')), ('ineg', ('b2i', 'b@1'))) => ('ineg', ('b2i', ('iand', 'a', 'b'))) */
   /* search1017_0_0_0 -> 760 in the cache */
   /* search1017_0_0 -> 1228 in the cache */
   /* search1017_0 -> 2264 in the cache */
   /* search1017_1_0_0 -> 1134 in the cache */
   /* search1017_1_0 -> 2265 in the cache */
   /* search1017_1 -> 2266 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 2264, 2266 },
      -1,
   } },

   /* replace1017_0_0_0 -> 760 in the cache */
   /* replace1017_0_0_1 -> 1134 in the cache */
   /* replace1017_0_0 -> 1146 in the cache */
   /* replace1017_0 -> 2692 in the cache */
   /* replace1017 -> 3103 in the cache */

   /* ('imin', ('ineg', ('b2i', 'a@1')), ('ineg', ('b2i', 'b@1'))) => ('ineg', ('b2i', ('ior', 'a', 'b'))) */
   /* search1018_0_0_0 -> 760 in the cache */
   /* search1018_0_0 -> 1228 in the cache */
   /* search1018_0 -> 2264 in the cache */
   /* search1018_1_0_0 -> 1134 in the cache */
   /* search1018_1_0 -> 2265 in the cache */
   /* search1018_1 -> 2266 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_imin,
      0, 1,
      { 2264, 2266 },
      -1,
   } },

   /* replace1018_0_0_0 -> 760 in the cache */
   /* replace1018_0_0_1 -> 1134 in the cache */
   /* replace1018_0_0 -> 1138 in the cache */
   /* replace1018_0 -> 2695 in the cache */
   /* replace1018 -> 3105 in the cache */

   /* ('umax', ('ineg', ('b2i', 'a@1')), ('ineg', ('b2i', 'b@1'))) => ('ineg', ('b2i', ('ior', 'a', 'b'))) */
   /* search1019_0_0_0 -> 760 in the cache */
   /* search1019_0_0 -> 1228 in the cache */
   /* search1019_0 -> 2264 in the cache */
   /* search1019_1_0_0 -> 1134 in the cache */
   /* search1019_1_0 -> 2265 in the cache */
   /* search1019_1 -> 2266 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_umax,
      0, 1,
      { 2264, 2266 },
      -1,
   } },

   /* replace1019_0_0_0 -> 760 in the cache */
   /* replace1019_0_0_1 -> 1134 in the cache */
   /* replace1019_0_0 -> 1138 in the cache */
   /* replace1019_0 -> 2695 in the cache */
   /* replace1019 -> 3105 in the cache */

   /* ('umin', ('ineg', ('b2i', 'a@1')), ('ineg', ('b2i', 'b@1'))) => ('ineg', ('b2i', ('iand', 'a', 'b'))) */
   /* search1020_0_0_0 -> 760 in the cache */
   /* search1020_0_0 -> 1228 in the cache */
   /* search1020_0 -> 2264 in the cache */
   /* search1020_1_0_0 -> 1134 in the cache */
   /* search1020_1_0 -> 2265 in the cache */
   /* search1020_1 -> 2266 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_umin,
      0, 1,
      { 2264, 2266 },
      -1,
   } },

   /* replace1020_0_0_0 -> 760 in the cache */
   /* replace1020_0_0_1 -> 1134 in the cache */
   /* replace1020_0_0 -> 1146 in the cache */
   /* replace1020_0 -> 2692 in the cache */
   /* replace1020 -> 3103 in the cache */

   /* ('umax', ('b2i', 'a@1'), ('b2i', 'b@1')) => ('b2i', ('ior', 'a', 'b')) */
   /* search1021_0_0 -> 760 in the cache */
   /* search1021_0 -> 1228 in the cache */
   /* search1021_1_0 -> 1134 in the cache */
   /* search1021_1 -> 2265 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_umax,
      0, 1,
      { 1228, 2265 },
      -1,
   } },

   /* replace1021_0_0 -> 760 in the cache */
   /* replace1021_0_1 -> 1134 in the cache */
   /* replace1021_0 -> 1138 in the cache */
   /* replace1021 -> 2695 in the cache */

   /* ('umin', ('b2i', 'a@1'), ('b2i', 'b@1')) => ('b2i', ('iand', 'a', 'b')) */
   /* search1022_0_0 -> 760 in the cache */
   /* search1022_0 -> 1228 in the cache */
   /* search1022_1_0 -> 1134 in the cache */
   /* search1022_1 -> 2265 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_op_umin,
      0, 1,
      { 1228, 2265 },
      -1,
   } },

   /* replace1022_0_0 -> 760 in the cache */
   /* replace1022_0_1 -> 1134 in the cache */
   /* replace1022_0 -> 1146 in the cache */
   /* replace1022 -> 2692 in the cache */

   /* ('ine', ('umin', ('ineg', ('b2i', 'a@1')), 'b'), 0) => ('iand', 'a', ('ine', 'b', 0)) */
   /* search1023_0_0_0_0 -> 760 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_search_op_b2i,
      -1, 0,
      { 760 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 3121 },
      -1,
   } },
   /* search1023_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_umin,
      1, 1,
      { 3122, 3 },
      -1,
   } },
   /* search1023_1 -> 86 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 3123, 86 },
      -1,
   } },

   /* replace1023_0 -> 760 in the cache */
   /* replace1023_1_0 -> 3 in the cache */
   /* replace1023_1_1 -> 86 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 3, 86 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 760, 3125 },
      -1,
   } },

   /* ('ine', ('umax', ('ineg', ('b2i', 'a@1')), 'b'), 0) => ('ior', 'a', ('ine', 'b', 0)) */
   /* search1024_0_0_0_0 -> 760 in the cache */
   /* search1024_0_0_0 -> 3121 in the cache */
   /* search1024_0_0 -> 3122 in the cache */
   /* search1024_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_umax,
      1, 1,
      { 3122, 3 },
      -1,
   } },
   /* search1024_1 -> 86 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 3127, 86 },
      -1,
   } },

   /* replace1024_0 -> 760 in the cache */
   /* replace1024_1_0 -> 3 in the cache */
   /* replace1024_1_1 -> 86 in the cache */
   /* replace1024_1 -> 3125 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 760, 3125 },
      -1,
   } },

   /* ('f2i', ('ftrunc', 'a')) => ('f2i', 'a') */
   /* search1025_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ftrunc,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_f2i,
      -1, 0,
      { 3130 },
      -1,
   } },

   /* replace1025_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_f2i,
      -1, 0,
      { 32 },
      -1,
   } },

   /* ('f2u', ('ftrunc', 'a')) => ('f2u', 'a') */
   /* search1026_0_0 -> 32 in the cache */
   /* search1026_0 -> 3130 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_f2u,
      -1, 0,
      { 3130 },
      -1,
   } },

   /* replace1026_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_f2u,
      -1, 0,
      { 32 },
      -1,
   } },

   /* ('inot', ('f2b1', 'a')) => ('feq', 'a', 0.0) */
   /* search1027_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_f2b1,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 3135 },
      -1,
   } },

   /* replace1027_0 -> 32 in the cache */
   /* replace1027_1 -> 111 in the cache */
   /* replace1027 -> 1257 in the cache */

   /* ('f2fmp', ('f2f32', 'a@16')) => a */
   /* search1028_0_0 -> 11 in the cache */
   /* search1028_0 -> 1813 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2fmp,
      -1, 0,
      { 1813 },
      -1,
   } },

   /* replace1028 -> 11 in the cache */

   /* ('i2imp', ('i2i32', 'a@16')) => a */
   /* search1029_0_0 -> 11 in the cache */
   /* search1029_0 -> 1815 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2imp,
      -1, 0,
      { 1815 },
      -1,
   } },

   /* replace1029 -> 11 in the cache */

   /* ('i2imp', ('u2u32', 'a@16')) => a */
   /* search1030_0_0 -> 11 in the cache */
   /* search1030_0 -> 1817 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2imp,
      -1, 0,
      { 1817 },
      -1,
   } },

   /* replace1030 -> 11 in the cache */

   /* ('f2imp', ('f2f32', 'a@16')) => ('f2i16', 'a') */
   /* search1031_0_0 -> 11 in the cache */
   /* search1031_0 -> 1813 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2imp,
      -1, 0,
      { 1813 },
      -1,
   } },

   /* replace1031_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2i16,
      -1, 0,
      { 11 },
      -1,
   } },

   /* ('f2ump', ('f2f32', 'a@16')) => ('f2u16', 'a') */
   /* search1032_0_0 -> 11 in the cache */
   /* search1032_0 -> 1813 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2ump,
      -1, 0,
      { 1813 },
      -1,
   } },

   /* replace1032_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2u16,
      -1, 0,
      { 11 },
      -1,
   } },

   /* ('i2fmp', ('i2i32', 'a@16')) => ('i2f16', 'a') */
   /* search1033_0_0 -> 11 in the cache */
   /* search1033_0 -> 1815 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2fmp,
      -1, 0,
      { 1815 },
      -1,
   } },

   /* replace1033_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2f16,
      -1, 0,
      { 11 },
      -1,
   } },

   /* ('u2fmp', ('u2u32', 'a@16')) => ('u2f16', 'a') */
   /* search1034_0_0 -> 11 in the cache */
   /* search1034_0 -> 1817 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2fmp,
      -1, 0,
      { 1817 },
      -1,
   } },

   /* replace1034_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2f16,
      -1, 0,
      { 11 },
      -1,
   } },

   /* ('f2fmp', ('b2f32', 'a@1')) => ('b2f16', 'a') */
   /* search1035_0_0 -> 760 in the cache */
   /* search1035_0 -> 1408 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2fmp,
      -1, 0,
      { 1408 },
      -1,
   } },

   /* replace1035_0 -> 760 in the cache */
   /* replace1035 -> 1404 in the cache */

   /* ('i2imp', ('b2i32', 'a@1')) => ('b2i16', 'a') */
   /* search1036_0_0 -> 760 in the cache */
   /* search1036_0 -> 1396 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2imp,
      -1, 0,
      { 1396 },
      -1,
   } },

   /* replace1036_0 -> 760 in the cache */
   /* replace1036 -> 1392 in the cache */

   /* ('i2imp', ('b2i32', 'a@1')) => ('b2i16', 'a') */
   /* search1037_0_0 -> 760 in the cache */
   /* search1037_0 -> 1396 in the cache */
   /* search1037 -> 3149 in the cache */

   /* replace1037_0 -> 760 in the cache */
   /* replace1037 -> 1392 in the cache */

   /* ('f2imp', ('b2f32', 'a@1')) => ('b2i16', 'a') */
   /* search1038_0_0 -> 760 in the cache */
   /* search1038_0 -> 1408 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2imp,
      -1, 0,
      { 1408 },
      -1,
   } },

   /* replace1038_0 -> 760 in the cache */
   /* replace1038 -> 1392 in the cache */

   /* ('f2ump', ('b2f32', 'a@1')) => ('b2i16', 'a') */
   /* search1039_0_0 -> 760 in the cache */
   /* search1039_0 -> 1408 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2ump,
      -1, 0,
      { 1408 },
      -1,
   } },

   /* replace1039_0 -> 760 in the cache */
   /* replace1039 -> 1392 in the cache */

   /* ('i2fmp', ('b2i32', 'a@1')) => ('b2f16', 'a') */
   /* search1040_0_0 -> 760 in the cache */
   /* search1040_0 -> 1396 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2fmp,
      -1, 0,
      { 1396 },
      -1,
   } },

   /* replace1040_0 -> 760 in the cache */
   /* replace1040 -> 1404 in the cache */

   /* ('u2fmp', ('b2i32', 'a@1')) => ('b2f16', 'a') */
   /* search1041_0_0 -> 760 in the cache */
   /* search1041_0 -> 1396 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2fmp,
      -1, 0,
      { 1396 },
      -1,
   } },

   /* replace1041_0 -> 760 in the cache */
   /* replace1041 -> 1404 in the cache */

   /* ('f2f32', ('f2fmp', 'a@32')) => a */
   /* search1042_0_0 -> 16 in the cache */
   /* search1042_0 -> 2009 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 2009 },
      -1,
   } },

   /* replace1042 -> 16 in the cache */

   /* ('i2i32', ('i2imp', 'a@32')) => a */
   /* search1043_0_0 -> 16 in the cache */
   /* search1043_0 -> 2020 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 2020 },
      -1,
   } },

   /* replace1043 -> 16 in the cache */

   /* ('u2u32', ('i2imp', 'a@32')) => a */
   /* search1044_0_0 -> 16 in the cache */
   /* search1044_0 -> 2020 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 2020 },
      -1,
   } },

   /* replace1044 -> 16 in the cache */

   /* ('i2i32', ('f2imp', 'a@32')) => ('f2i32', 'a') */
   /* search1045_0_0 -> 16 in the cache */
   /* search1045_0 -> 2019 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 2019 },
      -1,
   } },

   /* replace1045_0 -> 16 in the cache */
   /* replace1045 -> 2017 in the cache */

   /* ('u2u32', ('f2ump', 'a@32')) => ('f2u32', 'a') */
   /* search1046_0_0 -> 16 in the cache */
   /* search1046_0 -> 2016 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 2016 },
      -1,
   } },

   /* replace1046_0 -> 16 in the cache */
   /* replace1046 -> 2014 in the cache */

   /* ('f2f32', ('i2fmp', 'a@32')) => ('i2f32', 'a') */
   /* search1047_0_0 -> 16 in the cache */
   /* search1047_0 -> 2008 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 2008 },
      -1,
   } },

   /* replace1047_0 -> 16 in the cache */
   /* replace1047 -> 2006 in the cache */

   /* ('f2f32', ('u2fmp', 'a@32')) => ('u2f32', 'a') */
   /* search1048_0_0 -> 16 in the cache */
   /* search1048_0 -> 2005 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 2005 },
      -1,
   } },

   /* replace1048_0 -> 16 in the cache */
   /* replace1048 -> 2003 in the cache */

   /* ('~f2f32', ('f2f64', 'a@32')) => a */
   /* search1049_0_0 -> 16 in the cache */
   /* search1049_0 -> 1918 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 1918 },
      -1,
   } },

   /* replace1049 -> 16 in the cache */

   /* ('ffloor', 'a(is_integral)') => a */
   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* a */
      false,
      nir_type_invalid,
      24,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffloor,
      -1, 0,
      { 3162 },
      -1,
   } },

   /* replace1050 -> 32 in the cache */

   /* ('fceil', 'a(is_integral)') => a */
   /* search1051_0 -> 3162 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fceil,
      -1, 0,
      { 3162 },
      -1,
   } },

   /* replace1051 -> 32 in the cache */

   /* ('ftrunc', 'a(is_integral)') => a */
   /* search1052_0 -> 3162 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ftrunc,
      -1, 0,
      { 3162 },
      -1,
   } },

   /* replace1052 -> 32 in the cache */

   /* ('fround_even', 'a(is_integral)') => a */
   /* search1053_0 -> 3162 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fround_even,
      -1, 0,
      { 3162 },
      -1,
   } },

   /* replace1053 -> 32 in the cache */

   /* ('~ffract', 'a(is_integral)') => 0.0 */
   /* search1054_0 -> 3162 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_ffract,
      -1, 0,
      { 3162 },
      -1,
   } },

   /* replace1054 -> 111 in the cache */

   /* ('fabs', 'a(is_not_negative)') => a */
   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* a */
      false,
      nir_type_invalid,
      19,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 3168 },
      -1,
   } },

   /* replace1055 -> 32 in the cache */

   /* ('iabs', 'a(is_not_negative)') => a */
   /* search1056_0 -> 3168 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_iabs,
      -1, 0,
      { 3168 },
      -1,
   } },

   /* replace1056 -> 32 in the cache */

   /* ('fsat', 'a(is_not_positive)') => 0.0 */
   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* a */
      false,
      nir_type_invalid,
      25,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 3171 },
      -1,
   } },

   /* replace1057 -> 111 in the cache */

   /* ('~fmin', 'a(is_not_negative)', 1.0) => ('fsat', 'a') */
   /* search1058_0 -> 3168 in the cache */
   /* search1058_1 -> 241 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 3168, 241 },
      -1,
   } },

   /* replace1058_0 -> 32 in the cache */
   /* replace1058 -> 217 in the cache */

   /* ('flt', ('fadd', ('fmul', ('fsat', 'a'), ('fneg', ('fsat', 'a'))), 1.0), 0.0) => False */
   /* search1059_0_0_0_0 -> 32 in the cache */
   /* search1059_0_0_0 -> 217 in the cache */
   /* search1059_0_0_1_0_0 -> 32 in the cache */
   /* search1059_0_0_1_0 -> 217 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 217 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 217, 3174 },
      -1,
   } },
   /* search1059_0_1 -> 241 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 3175, 241 },
      -1,
   } },
   /* search1059_1 -> 111 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 2,
      { 3176, 111 },
      -1,
   } },

   /* replace1059 -> 1077 in the cache */

   /* ('flt', ('fadd', ('fneg', ('fmul', ('fsat', 'a'), ('fsat', 'a'))), 1.0), 0.0) => False */
   /* search1060_0_0_0_0_0 -> 32 in the cache */
   /* search1060_0_0_0_0 -> 217 in the cache */
   /* search1060_0_0_0_1_0 -> 32 in the cache */
   /* search1060_0_0_0_1 -> 217 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      -1, 0,
      { 217, 217 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 3178 },
      -1,
   } },
   /* search1060_0_1 -> 241 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 3179, 241 },
      -1,
   } },
   /* search1060_1 -> 111 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 3180, 111 },
      -1,
   } },

   /* replace1060 -> 1077 in the cache */

   /* ('fmax', ('fadd', ('fmul', ('fsat', 'a'), ('fneg', ('fsat', 'a'))), 1.0), 0.0) => ('fadd', ('fmul', ('fsat', 'a'), ('fneg', ('fsat', 'a'))), 1.0) */
   /* search1061_0_0_0_0 -> 32 in the cache */
   /* search1061_0_0_0 -> 217 in the cache */
   /* search1061_0_0_1_0_0 -> 32 in the cache */
   /* search1061_0_0_1_0 -> 217 in the cache */
   /* search1061_0_0_1 -> 3174 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      2, 1,
      { 217, 3174 },
      -1,
   } },
   /* search1061_0_1 -> 241 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 2,
      { 3182, 241 },
      -1,
   } },
   /* search1061_1 -> 111 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 3,
      { 3183, 111 },
      -1,
   } },

   /* replace1061_0_0_0 -> 32 in the cache */
   /* replace1061_0_0 -> 217 in the cache */
   /* replace1061_0_1_0_0 -> 32 in the cache */
   /* replace1061_0_1_0 -> 217 in the cache */
   /* replace1061_0_1 -> 3174 in the cache */
   /* replace1061_0 -> 3175 in the cache */
   /* replace1061_1 -> 241 in the cache */
   /* replace1061 -> 3176 in the cache */

   /* ('fmax', ('fadd', ('fneg', ('fmul', ('fsat', 'a'), ('fsat', 'a'))), 1.0), 0.0) => ('fadd', ('fneg', ('fmul', ('fsat', 'a'), ('fsat', 'a'))), 1.0) */
   /* search1062_0_0_0_0_0 -> 32 in the cache */
   /* search1062_0_0_0_0 -> 217 in the cache */
   /* search1062_0_0_0_1_0 -> 32 in the cache */
   /* search1062_0_0_0_1 -> 217 in the cache */
   /* search1062_0_0_0 -> 3178 in the cache */
   /* search1062_0_0 -> 3179 in the cache */
   /* search1062_0_1 -> 241 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 3179, 241 },
      -1,
   } },
   /* search1062_1 -> 111 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 2,
      { 3185, 111 },
      -1,
   } },

   /* replace1062_0_0_0_0 -> 32 in the cache */
   /* replace1062_0_0_0 -> 217 in the cache */
   /* replace1062_0_0_1_0 -> 32 in the cache */
   /* replace1062_0_0_1 -> 217 in the cache */
   /* replace1062_0_0 -> 3178 in the cache */
   /* replace1062_0 -> 3179 in the cache */
   /* replace1062_1 -> 241 in the cache */
   /* replace1062 -> 3180 in the cache */

   /* ('fneu', 'a(is_not_zero)', 0.0) => True */
   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* a */
      false,
      nir_type_invalid,
      26,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search1063_1 -> 111 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 3187, 111 },
      -1,
   } },

   /* replace1063 -> 1235 in the cache */

   /* ('feq', 'a(is_not_zero)', 0.0) => False */
   /* search1064_0 -> 3187 in the cache */
   /* search1064_1 -> 111 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 3187, 111 },
      -1,
   } },

   /* replace1064 -> 1077 in the cache */

   /* ('fge', 'a(is_a_number_not_negative)', 'b(is_a_number_not_positive)') => True */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      27,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      28,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 3190, 3191 },
      -1,
   } },

   /* replace1065 -> 1235 in the cache */

   /* ('fge', 'a(is_not_positive)', 'b(is_gt_zero)') => False */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      25,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      29,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 3193, 3194 },
      -1,
   } },

   /* replace1066 -> 1077 in the cache */

   /* ('fge', 'a(is_lt_zero)', 'b(is_not_negative)') => False */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      30,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      19,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 3196, 3197 },
      -1,
   } },

   /* replace1067 -> 1077 in the cache */

   /* ('flt', 'a(is_not_negative)', 'b(is_not_positive)') => False */
   /* search1068_0 -> 1584 in the cache */
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      25,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1584, 3199 },
      -1,
   } },

   /* replace1068 -> 1077 in the cache */

   /* ('flt', 'a(is_a_number_not_positive)', 'b(is_a_number_gt_zero)') => True */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      28,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      31,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 3201, 3202 },
      -1,
   } },

   /* replace1069 -> 1235 in the cache */

   /* ('flt', 'a(is_a_number_lt_zero)', 'b(is_a_number_not_negative)') => True */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      32,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      27,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 3204, 3205 },
      -1,
   } },

   /* replace1070 -> 1235 in the cache */

   /* ('ine', 'a(is_not_zero)', 0) => True */
   /* search1071_0 -> 3187 in the cache */
   /* search1071_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 3187, 61 },
      -1,
   } },

   /* replace1071 -> 1235 in the cache */

   /* ('ieq', 'a(is_not_zero)', 0) => False */
   /* search1072_0 -> 3187 in the cache */
   /* search1072_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 3187, 61 },
      -1,
   } },

   /* replace1072 -> 1077 in the cache */

   /* ('ige', 'a(is_not_negative)', 'b(is_not_positive)') => True */
   /* search1073_0 -> 1584 in the cache */
   /* search1073_1 -> 3199 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 1584, 3199 },
      -1,
   } },

   /* replace1073 -> 1235 in the cache */

   /* ('ige', 'a(is_not_positive)', 'b(is_gt_zero)') => False */
   /* search1074_0 -> 3193 in the cache */
   /* search1074_1 -> 3194 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 3193, 3194 },
      -1,
   } },

   /* replace1074 -> 1077 in the cache */

   /* ('ige', 'a(is_lt_zero)', 'b(is_not_negative)') => False */
   /* search1075_0 -> 3196 in the cache */
   /* search1075_1 -> 3197 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 3196, 3197 },
      -1,
   } },

   /* replace1075 -> 1077 in the cache */

   /* ('ilt', 'a(is_not_negative)', 'b(is_not_positive)') => False */
   /* search1076_0 -> 1584 in the cache */
   /* search1076_1 -> 3199 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 1584, 3199 },
      -1,
   } },

   /* replace1076 -> 1077 in the cache */

   /* ('ilt', 'a(is_not_positive)', 'b(is_gt_zero)') => True */
   /* search1077_0 -> 3193 in the cache */
   /* search1077_1 -> 3194 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 3193, 3194 },
      -1,
   } },

   /* replace1077 -> 1235 in the cache */

   /* ('ilt', 'a(is_lt_zero)', 'b(is_not_negative)') => True */
   /* search1078_0 -> 3196 in the cache */
   /* search1078_1 -> 3197 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 3196, 3197 },
      -1,
   } },

   /* replace1078 -> 1235 in the cache */

   /* ('ult', 0, 'a(is_gt_zero)') => True */
   /* search1079_0 -> 61 in the cache */
   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* a */
      false,
      nir_type_invalid,
      29,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 61, 3215 },
      -1,
   } },

   /* replace1079 -> 1235 in the cache */

   /* ('ult', 'a', 0) => False */
   /* search1080_0 -> 32 in the cache */
   /* search1080_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 32, 61 },
      -1,
   } },

   /* replace1080 -> 1077 in the cache */

   /* ('unpack_64_2x32_split_x', ('pack_64_2x32_split', 'a', 'b')) => a */
   /* search1081_0_0 -> 16 in the cache */
   /* search1081_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_pack_64_2x32_split,
      -1, 0,
      { 16, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_64_2x32_split_x,
      -1, 0,
      { 3218 },
      -1,
   } },

   /* replace1081 -> 16 in the cache */

   /* ('unpack_64_2x32_split_y', ('pack_64_2x32_split', 'a', 'b')) => b */
   /* search1082_0_0 -> 16 in the cache */
   /* search1082_0_1 -> 36 in the cache */
   /* search1082_0 -> 3218 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_64_2x32_split_y,
      -1, 0,
      { 3218 },
      -1,
   } },

   /* replace1082 -> 36 in the cache */

   /* ('unpack_64_2x32_split_x', ('pack_64_2x32', 'a')) => a.x */
   /* search1083_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_pack_64_2x32,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_64_2x32_split_x,
      -1, 0,
      { 3221 },
      -1,
   } },

   /* replace1083 -> 2443 in the cache */

   /* ('unpack_64_2x32_split_y', ('pack_64_2x32', 'a')) => a.y */
   /* search1084_0_0 -> 16 in the cache */
   /* search1084_0 -> 3221 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_64_2x32_split_y,
      -1, 0,
      { 3221 },
      -1,
   } },

   /* replace1084 -> 2446 in the cache */

   /* ('unpack_64_2x32_split_x', ('u2u64', 'a@32')) => a */
   /* search1085_0_0 -> 16 in the cache */
   /* search1085_0 -> 1922 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_64_2x32_split_x,
      -1, 0,
      { 1922 },
      -1,
   } },

   /* replace1085 -> 16 in the cache */

   /* ('unpack_64_2x32_split_y', ('u2u64', 'a')) => 0 */
   /* search1086_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_64_2x32_split_y,
      -1, 0,
      { 3225 },
      -1,
   } },

   /* replace1086 -> 122 in the cache */

   /* ('unpack_64_2x32_split_x', ('i2i64', 'a@32')) => a */
   /* search1087_0_0 -> 16 in the cache */
   /* search1087_0 -> 1920 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_64_2x32_split_x,
      -1, 0,
      { 1920 },
      -1,
   } },

   /* replace1087 -> 16 in the cache */

   /* ('unpack_64_2x32_split_y', ('i2i64(is_used_once)', 'a@32')) => ('ishr', 'a', 31) */
   /* search1088_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 16 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_64_2x32_split_y,
      -1, 0,
      { 3228 },
      -1,
   } },

   /* replace1088_0 -> 16 in the cache */
   /* replace1088_1 -> 19 in the cache */
   /* replace1088 -> 1460 in the cache */

   /* ('unpack_64_2x32', ('pack_64_2x32_split', 'a', 'b')) => ('vec2', 'a', 'b') */
   /* search1089_0_0 -> 16 in the cache */
   /* search1089_0_1 -> 36 in the cache */
   /* search1089_0 -> 3218 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_64_2x32,
      -1, 0,
      { 3218 },
      -1,
   } },

   /* replace1089_0 -> 16 in the cache */
   /* replace1089_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_vec2,
      -1, 0,
      { 16, 36 },
      -1,
   } },

   /* ('unpack_64_2x32', ('pack_64_2x32', 'a')) => a */
   /* search1090_0_0 -> 16 in the cache */
   /* search1090_0 -> 3221 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_64_2x32,
      -1, 0,
      { 3221 },
      -1,
   } },

   /* replace1090 -> 16 in the cache */

   /* ('unpack_double_2x32_dxil', ('pack_double_2x32_dxil', 'a')) => a */
   /* search1091_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_pack_double_2x32_dxil,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_double_2x32_dxil,
      -1, 0,
      { 3233 },
      -1,
   } },

   /* replace1091 -> 16 in the cache */

   /* ('pack_64_2x32_split', ('unpack_64_2x32_split_x', 'a'), ('unpack_64_2x32_split_y', 'a')) => a */
   /* search1092_0_0 -> 21 in the cache */
   /* search1092_0 -> 2748 in the cache */
   /* search1092_1_0 -> 21 in the cache */
   /* search1092_1 -> 2742 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_pack_64_2x32_split,
      -1, 0,
      { 2748, 2742 },
      -1,
   } },

   /* replace1092 -> 21 in the cache */

   /* ('pack_64_2x32', ('vec2', ('unpack_64_2x32_split_x', 'a'), ('unpack_64_2x32_split_y', 'a'))) => a */
   /* search1093_0_0_0 -> 21 in the cache */
   /* search1093_0_0 -> 2748 in the cache */
   /* search1093_0_1_0 -> 21 in the cache */
   /* search1093_0_1 -> 2742 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_vec2,
      -1, 0,
      { 2748, 2742 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_pack_64_2x32,
      -1, 0,
      { 3236 },
      -1,
   } },

   /* replace1093 -> 21 in the cache */

   /* ('pack_64_2x32', ('unpack_64_2x32', 'a')) => a */
   /* search1094_0_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_64_2x32,
      -1, 0,
      { 21 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_pack_64_2x32,
      -1, 0,
      { 3238 },
      -1,
   } },

   /* replace1094 -> 21 in the cache */

   /* ('pack_double_2x32_dxil', ('unpack_double_2x32_dxil', 'a')) => a */
   /* search1095_0_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_double_2x32_dxil,
      -1, 0,
      { 21 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_pack_double_2x32_dxil,
      -1, 0,
      { 3240 },
      -1,
   } },

   /* replace1095 -> 21 in the cache */

   /* ('iand', ('ieq', ('unpack_32_2x16_split_x', 'a'), '#b'), ('ieq', ('unpack_32_2x16_split_y', 'a'), '#c')) => ('ieq', 'a', ('pack_32_2x16_split', 'b', 'c')) */
   /* search1096_0_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_unpack_32_2x16_split_x,
      -1, 0,
      { 16 },
      -1,
   } },
   /* search1096_0_1 -> 2027 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 3242, 2027 },
      -1,
   } },
   /* search1096_1_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_unpack_32_2x16_split_y,
      -1, 0,
      { 16 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, 16 },
      2, /* c */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 3244, 3245 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 3243, 3246 },
      -1,
   } },

   /* replace1096_0 -> 16 in the cache */
   /* replace1096_1_0 -> 258 in the cache */
   /* replace1096_1_1 -> 469 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_pack_32_2x16_split,
      -1, 0,
      { 258, 469 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 16, 3248 },
      -1,
   } },

   /* ('ushr', 'a@16', 8) => ('extract_u8', 'a', 1) */
   /* search1097_0 -> 11 in the cache */
   /* search1097_1 -> 831 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 11, 831 },
      -1,
   } },

   /* replace1097_0 -> 11 in the cache */
   /* replace1097_1 -> 1452 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 11, 1452 },
      -1,
   } },

   /* ('ushr', 'a@32', 24) => ('extract_u8', 'a', 3) */
   /* search1098_0 -> 16 in the cache */
   /* search1098_1 -> 1012 in the cache */
   /* search1098 -> 1017 in the cache */

   /* replace1098_0 -> 16 in the cache */
   /* replace1098_1 -> 405 in the cache */
   /* replace1098 -> 422 in the cache */

   /* ('ushr', 'a@64', 56) => ('extract_u8', 'a', 7) */
   /* search1099_0 -> 21 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x38 /* 56 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 21, 3252 },
      -1,
   } },

   /* replace1099_0 -> 21 in the cache */
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0x7 /* 7 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 21, 3254 },
      -1,
   } },

   /* ('ishr', 'a@16', 8) => ('extract_i8', 'a', 1) */
   /* search1100_0 -> 11 in the cache */
   /* search1100_1 -> 831 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 11, 831 },
      -1,
   } },

   /* replace1100_0 -> 11 in the cache */
   /* replace1100_1 -> 1452 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 11, 1452 },
      -1,
   } },

   /* ('ishr', 'a@32', 24) => ('extract_i8', 'a', 3) */
   /* search1101_0 -> 16 in the cache */
   /* search1101_1 -> 1012 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 16, 1012 },
      -1,
   } },

   /* replace1101_0 -> 16 in the cache */
   /* replace1101_1 -> 405 in the cache */
   /* replace1101 -> 406 in the cache */

   /* ('ishr', 'a@64', 56) => ('extract_i8', 'a', 7) */
   /* search1102_0 -> 21 in the cache */
   /* search1102_1 -> 3252 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 21, 3252 },
      -1,
   } },

   /* replace1102_0 -> 21 in the cache */
   /* replace1102_1 -> 3254 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 21, 3254 },
      -1,
   } },

   /* ('iand', 255, 'a') => ('extract_u8', 'a', 0) */
   /* search1103_0 -> 1590 in the cache */
   /* search1103_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 1590, 32 },
      -1,
   } },

   /* replace1103_0 -> 32 in the cache */
   /* replace1103_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 32, 61 },
      -1,
   } },

   /* ('u2u8', ('extract_u16', 'a', 1)) => ('u2u8', ('extract_u8', 'a', 2)) */
   /* search1104_0_0 -> 32 in the cache */
   /* search1104_0_1 -> 35 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 0,
      { 32, 35 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 3263 },
      -1,
   } },

   /* replace1104_0_0 -> 32 in the cache */
   /* replace1104_0_1 -> 2254 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 32, 2254 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 3265 },
      -1,
   } },

   /* ('u2u8', ('ushr', 'a', 8)) => ('u2u8', ('extract_u8', 'a', 1)) */
   /* search1105_0_0 -> 32 in the cache */
   /* search1105_0_1 -> 831 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 32, 831 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 3267 },
      -1,
   } },

   /* replace1105_0_0 -> 32 in the cache */
   /* replace1105_0_1 -> 35 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 32, 35 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 3269 },
      -1,
   } },

   /* ('i2i16', ('u2u8', ('extract_u8', 'a', 'b'))) => ('i2i16', ('extract_i8', 'a', 'b')) */
   /* search1106_0_0_0 -> 0 in the cache */
   /* search1106_0_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 0, 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 3271 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 3272 },
      -1,
   } },

   /* replace1106_0_0 -> 0 in the cache */
   /* replace1106_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 0, 3 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 3274 },
      -1,
   } },

   /* ('u2u16', ('u2u8', ('extract_u8', 'a', 'b'))) => ('u2u16', ('extract_u8', 'a', 'b')) */
   /* search1107_0_0_0 -> 0 in the cache */
   /* search1107_0_0_1 -> 3 in the cache */
   /* search1107_0_0 -> 3271 in the cache */
   /* search1107_0 -> 3272 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 3272 },
      -1,
   } },

   /* replace1107_0_0 -> 0 in the cache */
   /* replace1107_0_1 -> 3 in the cache */
   /* replace1107_0 -> 3271 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 3271 },
      -1,
   } },

   /* ('ubfe', 'a', 0, 8) => ('extract_u8', 'a', 0) */
   /* search1108_0 -> 16 in the cache */
   /* search1108_1 -> 122 in the cache */
   /* search1108_2 -> 831 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ubfe,
      -1, 0,
      { 16, 122, 831 },
      -1,
   } },

   /* replace1108_0 -> 16 in the cache */
   /* replace1108_1 -> 122 in the cache */
   /* replace1108 -> 412 in the cache */

   /* ('ubfe', 'a', 8, 8) => ('extract_u8', 'a', 1) */
   /* search1109_0 -> 16 in the cache */
   /* search1109_1 -> 831 in the cache */
   /* search1109_2 -> 831 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ubfe,
      -1, 0,
      { 16, 831, 831 },
      -1,
   } },

   /* replace1109_0 -> 16 in the cache */
   /* replace1109_1 -> 396 in the cache */
   /* replace1109 -> 415 in the cache */

   /* ('ubfe', 'a', 16, 8) => ('extract_u8', 'a', 2) */
   /* search1110_0 -> 16 in the cache */
   /* search1110_1 -> 853 in the cache */
   /* search1110_2 -> 831 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ubfe,
      -1, 0,
      { 16, 853, 831 },
      -1,
   } },

   /* replace1110_0 -> 16 in the cache */
   /* replace1110_1 -> 401 in the cache */
   /* replace1110 -> 419 in the cache */

   /* ('ubfe', 'a', 24, 8) => ('extract_u8', 'a', 3) */
   /* search1111_0 -> 16 in the cache */
   /* search1111_1 -> 1012 in the cache */
   /* search1111_2 -> 831 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ubfe,
      -1, 0,
      { 16, 1012, 831 },
      -1,
   } },

   /* replace1111_0 -> 16 in the cache */
   /* replace1111_1 -> 405 in the cache */
   /* replace1111 -> 422 in the cache */

   /* ('ibfe', 'a', 0, 8) => ('extract_i8', 'a', 0) */
   /* search1112_0 -> 16 in the cache */
   /* search1112_1 -> 122 in the cache */
   /* search1112_2 -> 831 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ibfe,
      -1, 0,
      { 16, 122, 831 },
      -1,
   } },

   /* replace1112_0 -> 16 in the cache */
   /* replace1112_1 -> 122 in the cache */
   /* replace1112 -> 393 in the cache */

   /* ('ibfe', 'a', 8, 8) => ('extract_i8', 'a', 1) */
   /* search1113_0 -> 16 in the cache */
   /* search1113_1 -> 831 in the cache */
   /* search1113_2 -> 831 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ibfe,
      -1, 0,
      { 16, 831, 831 },
      -1,
   } },

   /* replace1113_0 -> 16 in the cache */
   /* replace1113_1 -> 396 in the cache */
   /* replace1113 -> 397 in the cache */

   /* ('ibfe', 'a', 16, 8) => ('extract_i8', 'a', 2) */
   /* search1114_0 -> 16 in the cache */
   /* search1114_1 -> 853 in the cache */
   /* search1114_2 -> 831 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ibfe,
      -1, 0,
      { 16, 853, 831 },
      -1,
   } },

   /* replace1114_0 -> 16 in the cache */
   /* replace1114_1 -> 401 in the cache */
   /* replace1114 -> 402 in the cache */

   /* ('ibfe', 'a', 24, 8) => ('extract_i8', 'a', 3) */
   /* search1115_0 -> 16 in the cache */
   /* search1115_1 -> 1012 in the cache */
   /* search1115_2 -> 831 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ibfe,
      -1, 0,
      { 16, 1012, 831 },
      -1,
   } },

   /* replace1115_0 -> 16 in the cache */
   /* replace1115_1 -> 405 in the cache */
   /* replace1115 -> 406 in the cache */

   /* ('extract_u8', ('extract_i8', 'a', 'b'), 0) => ('extract_u8', 'a', 'b') */
   /* search1116_0_0 -> 0 in the cache */
   /* search1116_0_1 -> 3 in the cache */
   /* search1116_0 -> 3274 in the cache */
   /* search1116_1 -> 86 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3274, 86 },
      -1,
   } },

   /* replace1116_0 -> 0 in the cache */
   /* replace1116_1 -> 3 in the cache */
   /* replace1116 -> 3271 in the cache */

   /* ('extract_u8', ('extract_u8', 'a', 'b'), 0) => ('extract_u8', 'a', 'b') */
   /* search1117_0_0 -> 0 in the cache */
   /* search1117_0_1 -> 3 in the cache */
   /* search1117_0 -> 3271 in the cache */
   /* search1117_1 -> 86 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3271, 86 },
      -1,
   } },

   /* replace1117_0 -> 0 in the cache */
   /* replace1117_1 -> 3 in the cache */
   /* replace1117 -> 3271 in the cache */

   /* ('ushr', ('ishl', 'a@32', 16), 16) => ('extract_u16', 'a', 0) */
   /* search1118_0_0 -> 16 in the cache */
   /* search1118_0_1 -> 853 in the cache */
   /* search1118_0 -> 1005 in the cache */
   /* search1118_1 -> 853 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 1005, 853 },
      -1,
   } },

   /* replace1118_0 -> 16 in the cache */
   /* replace1118_1 -> 122 in the cache */
   /* replace1118 -> 444 in the cache */

   /* ('ushr', 'a@32', 16) => ('extract_u16', 'a', 1) */
   /* search1119_0 -> 16 in the cache */
   /* search1119_1 -> 853 in the cache */
   /* search1119 -> 1008 in the cache */

   /* replace1119_0 -> 16 in the cache */
   /* replace1119_1 -> 396 in the cache */
   /* replace1119 -> 447 in the cache */

   /* ('ishr', ('ishl', 'a@32', 16), 16) => ('extract_i16', 'a', 0) */
   /* search1120_0_0 -> 16 in the cache */
   /* search1120_0_1 -> 853 in the cache */
   /* search1120_0 -> 1005 in the cache */
   /* search1120_1 -> 853 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 1005, 853 },
      -1,
   } },

   /* replace1120_0 -> 16 in the cache */
   /* replace1120_1 -> 122 in the cache */
   /* replace1120 -> 436 in the cache */

   /* ('ishr', 'a@32', 16) => ('extract_i16', 'a', 1) */
   /* search1121_0 -> 16 in the cache */
   /* search1121_1 -> 853 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 16, 853 },
      -1,
   } },

   /* replace1121_0 -> 16 in the cache */
   /* replace1121_1 -> 396 in the cache */
   /* replace1121 -> 439 in the cache */

   /* ('iand', 65535, 'a') => ('extract_u16', 'a', 0) */
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_int, { 0xffff /* 65535 */ },
   } },
   /* search1122_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 3291, 32 },
      -1,
   } },

   /* replace1122_0 -> 32 in the cache */
   /* replace1122_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 0,
      { 32, 61 },
      -1,
   } },

   /* ('ubfe', 'a', 0, 16) => ('extract_u16', 'a', 0) */
   /* search1123_0 -> 16 in the cache */
   /* search1123_1 -> 122 in the cache */
   /* search1123_2 -> 853 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ubfe,
      -1, 0,
      { 16, 122, 853 },
      -1,
   } },

   /* replace1123_0 -> 16 in the cache */
   /* replace1123_1 -> 122 in the cache */
   /* replace1123 -> 444 in the cache */

   /* ('ubfe', 'a', 16, 16) => ('extract_u16', 'a', 1) */
   /* search1124_0 -> 16 in the cache */
   /* search1124_1 -> 853 in the cache */
   /* search1124_2 -> 853 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ubfe,
      -1, 0,
      { 16, 853, 853 },
      -1,
   } },

   /* replace1124_0 -> 16 in the cache */
   /* replace1124_1 -> 396 in the cache */
   /* replace1124 -> 447 in the cache */

   /* ('ibfe', 'a', 0, 16) => ('extract_i16', 'a', 0) */
   /* search1125_0 -> 16 in the cache */
   /* search1125_1 -> 122 in the cache */
   /* search1125_2 -> 853 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ibfe,
      -1, 0,
      { 16, 122, 853 },
      -1,
   } },

   /* replace1125_0 -> 16 in the cache */
   /* replace1125_1 -> 122 in the cache */
   /* replace1125 -> 436 in the cache */

   /* ('ibfe', 'a', 16, 16) => ('extract_i16', 'a', 1) */
   /* search1126_0 -> 16 in the cache */
   /* search1126_1 -> 853 in the cache */
   /* search1126_2 -> 853 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ibfe,
      -1, 0,
      { 16, 853, 853 },
      -1,
   } },

   /* replace1126_0 -> 16 in the cache */
   /* replace1126_1 -> 396 in the cache */
   /* replace1126 -> 439 in the cache */

   /* ('ior', ('ishl', ('u2u32', 'a@8'), 24), ('ior', ('ishl', ('u2u32', 'b@8'), 16), ('ior', ('ishl', ('u2u32', 'c@8'), 8), ('u2u32', 'd@8')))) => ('pack_32_4x8', ('vec4', 'd', 'c', 'b', 'a')) */
   /* search1127_0_0_0 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 6 },
      -1,
   } },
   /* search1127_0_1 -> 1012 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 3298, 1012 },
      -1,
   } },
   /* search1127_1_0_0_0 -> 2128 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 2128 },
      -1,
   } },
   /* search1127_1_0_1 -> 853 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 3300, 853 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, 8 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 3302 },
      -1,
   } },
   /* search1127_1_1_0_1 -> 831 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 3303, 831 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, 8 },
      3, /* d */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 3305 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      2, 1,
      { 3304, 3306 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      1, 2,
      { 3301, 3307 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 3299, 3308 },
      -1,
   } },

   /* replace1127_0_0 -> 3305 in the cache */
   /* replace1127_0_1 -> 3302 in the cache */
   /* replace1127_0_2 -> 2128 in the cache */
   /* replace1127_0_3 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_vec4,
      -1, 0,
      { 3305, 3302, 2128, 6 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_pack_32_4x8,
      -1, 0,
      { 3310 },
      -1,
   } },

   /* ('extract_u16', ('extract_i16', 'a', 'b'), 0) => ('extract_u16', 'a', 'b') */
   /* search1128_0_0 -> 0 in the cache */
   /* search1128_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_i16,
      -1, 0,
      { 0, 3 },
      -1,
   } },
   /* search1128_1 -> 86 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 0,
      { 3312, 86 },
      -1,
   } },

   /* replace1128_0 -> 0 in the cache */
   /* replace1128_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* ('extract_u16', ('extract_u16', 'a', 'b'), 0) => ('extract_u16', 'a', 'b') */
   /* search1129_0_0 -> 0 in the cache */
   /* search1129_0_1 -> 3 in the cache */
   /* search1129_0 -> 3314 in the cache */
   /* search1129_1 -> 86 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 0,
      { 3314, 86 },
      -1,
   } },

   /* replace1129_0 -> 0 in the cache */
   /* replace1129_1 -> 3 in the cache */
   /* replace1129 -> 3314 in the cache */

   /* ('pack_64_2x32_split', 'a', 'b') => ('ior', ('u2u64', 'a'), ('ishl', ('u2u64', 'b'), 32)) */
   /* search1130_0 -> 16 in the cache */
   /* search1130_1 -> 36 in the cache */
   /* search1130 -> 3218 in the cache */

   /* replace1130_0_0 -> 16 in the cache */
   /* replace1130_0 -> 1922 in the cache */
   /* replace1130_1_0_0 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 36 },
      -1,
   } },
   /* replace1130_1_1 -> 874 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 3316, 874 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1922, 3317 },
      -1,
   } },

   /* ('pack_32_2x16_split', 'a', 'b') => ('ior', ('u2u32', 'a'), ('ishl', ('u2u32', 'b'), 16)) */
   /* search1131_0 -> 11 in the cache */
   /* search1131_1 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_pack_32_2x16_split,
      -1, 0,
      { 11, 258 },
      -1,
   } },

   /* replace1131_0_0 -> 11 in the cache */
   /* replace1131_0 -> 1817 in the cache */
   /* replace1131_1_0_0 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 258 },
      -1,
   } },
   /* replace1131_1_1 -> 853 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 3320, 853 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 1817, 3321 },
      -1,
   } },

   /* ('unpack_64_2x32_split_x', 'a') => ('u2u32', 'a') */
   /* search1132_0 -> 21 in the cache */
   /* search1132 -> 2748 in the cache */

   /* replace1132_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 21 },
      -1,
   } },

   /* ('unpack_64_2x32_split_y', 'a') => ('u2u32', ('ushr', 'a', 32)) */
   /* search1133_0 -> 21 in the cache */
   /* search1133 -> 2742 in the cache */

   /* replace1133_0_0 -> 21 in the cache */
   /* replace1133_0_1 -> 874 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 21, 874 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 3324 },
      -1,
   } },

   /* ('unpack_32_2x16_split_x', 'a') => ('u2u16', 'a') */
   /* search1134_0 -> 16 in the cache */
   /* search1134 -> 3242 in the cache */

   /* replace1134_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('unpack_32_2x16_split_y', 'a') => ('u2u16', ('ushr', 'a', 16)) */
   /* search1135_0 -> 16 in the cache */
   /* search1135 -> 3244 in the cache */

   /* replace1135_0_0 -> 16 in the cache */
   /* replace1135_0_1 -> 853 in the cache */
   /* replace1135_0 -> 1008 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 1008 },
      -1,
   } },

   /* ('unpack_half_2x16_split_x', ('iand', 'a', 65535)) => ('unpack_half_2x16_split_x', 'a') */
   /* search1136_0_0 -> 16 in the cache */
   /* search1136_0_1 -> 1002 in the cache */
   /* search1136_0 -> 1003 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_half_2x16_split_x,
      -1, 1,
      { 1003 },
      -1,
   } },

   /* replace1136_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_half_2x16_split_x,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('unpack_32_2x16_split_x', ('iand', 'a', 65535)) => ('unpack_32_2x16_split_x', 'a') */
   /* search1137_0_0 -> 16 in the cache */
   /* search1137_0_1 -> 1002 in the cache */
   /* search1137_0 -> 1003 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_unpack_32_2x16_split_x,
      -1, 1,
      { 1003 },
      -1,
   } },

   /* replace1137_0 -> 16 in the cache */
   /* replace1137 -> 3242 in the cache */

   /* ('unpack_64_2x32_split_x', ('iand', 'a', 4294967295)) => ('unpack_64_2x32_split_x', 'a') */
   /* search1138_0_0 -> 21 in the cache */
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0xffffffff /* 4294967295 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 21, 3331 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_64_2x32_split_x,
      -1, 1,
      { 3332 },
      -1,
   } },

   /* replace1138_0 -> 21 in the cache */
   /* replace1138 -> 2748 in the cache */

   /* ('unpack_half_2x16_split_y', ('iand', 'a', 4294901760)) => ('unpack_half_2x16_split_y', 'a') */
   /* search1139_0_0 -> 16 in the cache */
   /* search1139_0_1 -> 1006 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 16, 1006 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_half_2x16_split_y,
      -1, 1,
      { 3334 },
      -1,
   } },

   /* replace1139_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_half_2x16_split_y,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('unpack_32_2x16_split_y', ('iand', 'a', 4294901760)) => ('unpack_32_2x16_split_y', 'a') */
   /* search1140_0_0 -> 16 in the cache */
   /* search1140_0_1 -> 1006 in the cache */
   /* search1140_0 -> 3334 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_unpack_32_2x16_split_y,
      -1, 1,
      { 3334 },
      -1,
   } },

   /* replace1140_0 -> 16 in the cache */
   /* replace1140 -> 3244 in the cache */

   /* ('unpack_64_2x32_split_y', ('iand', 'a', 18446744069414584320)) => ('unpack_64_2x32_split_y', 'a') */
   /* search1141_0_0 -> 21 in the cache */
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0xffffffff00000000 /* 18446744069414584320 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 21, 3338 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_64_2x32_split_y,
      -1, 1,
      { 3339 },
      -1,
   } },

   /* replace1141_0 -> 21 in the cache */
   /* replace1141 -> 2742 in the cache */

   /* ('unpack_half_2x16_split_x', ('extract_u16', 'a', 0)) => ('unpack_half_2x16_split_x', 'a') */
   /* search1142_0_0 -> 16 in the cache */
   /* search1142_0_1 -> 122 in the cache */
   /* search1142_0 -> 444 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_half_2x16_split_x,
      -1, 0,
      { 444 },
      -1,
   } },

   /* replace1142_0 -> 16 in the cache */
   /* replace1142 -> 3329 in the cache */

   /* ('unpack_half_2x16_split_x', ('extract_u16', 'a', 1)) => ('unpack_half_2x16_split_y', 'a') */
   /* search1143_0_0 -> 16 in the cache */
   /* search1143_0_1 -> 396 in the cache */
   /* search1143_0 -> 447 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_half_2x16_split_x,
      -1, 0,
      { 447 },
      -1,
   } },

   /* replace1143_0 -> 16 in the cache */
   /* replace1143 -> 3336 in the cache */

   /* ('unpack_half_2x16_split_x', ('ushr', 'a', 16)) => ('unpack_half_2x16_split_y', 'a') */
   /* search1144_0_0 -> 16 in the cache */
   /* search1144_0_1 -> 853 in the cache */
   /* search1144_0 -> 1008 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_half_2x16_split_x,
      -1, 0,
      { 1008 },
      -1,
   } },

   /* replace1144_0 -> 16 in the cache */
   /* replace1144 -> 3336 in the cache */

   /* ('unpack_32_2x16_split_x', ('extract_u16', 'a', 0)) => ('unpack_32_2x16_split_x', 'a') */
   /* search1145_0_0 -> 16 in the cache */
   /* search1145_0_1 -> 122 in the cache */
   /* search1145_0 -> 444 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_unpack_32_2x16_split_x,
      -1, 0,
      { 444 },
      -1,
   } },

   /* replace1145_0 -> 16 in the cache */
   /* replace1145 -> 3242 in the cache */

   /* ('unpack_32_2x16_split_x', ('extract_u16', 'a', 1)) => ('unpack_32_2x16_split_y', 'a') */
   /* search1146_0_0 -> 16 in the cache */
   /* search1146_0_1 -> 396 in the cache */
   /* search1146_0 -> 447 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_unpack_32_2x16_split_x,
      -1, 0,
      { 447 },
      -1,
   } },

   /* replace1146_0 -> 16 in the cache */
   /* replace1146 -> 3244 in the cache */

   /* ('ishl', ('pack_half_2x16', ('vec2', 'a', 0)), 16) => ('pack_half_2x16', ('vec2', 0, 'a')) */
   /* search1147_0_0_0 -> 16 in the cache */
   /* search1147_0_0_1 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_vec2,
      -1, 0,
      { 16, 122 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_pack_half_2x16,
      -1, 0,
      { 3346 },
      -1,
   } },
   /* search1147_1 -> 853 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 3347, 853 },
      -1,
   } },

   /* replace1147_0_0 -> 122 in the cache */
   /* replace1147_0_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_vec2,
      -1, 0,
      { 122, 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_pack_half_2x16,
      -1, 0,
      { 3349 },
      -1,
   } },

   /* ('ushr', ('pack_half_2x16', ('vec2', 0, 'a')), 16) => ('pack_half_2x16', ('vec2', 'a', 0)) */
   /* search1148_0_0_0 -> 122 in the cache */
   /* search1148_0_0_1 -> 16 in the cache */
   /* search1148_0_0 -> 3349 in the cache */
   /* search1148_0 -> 3350 in the cache */
   /* search1148_1 -> 853 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 3350, 853 },
      -1,
   } },

   /* replace1148_0_0 -> 16 in the cache */
   /* replace1148_0_1 -> 122 in the cache */
   /* replace1148_0 -> 3346 in the cache */
   /* replace1148 -> 3347 in the cache */

   /* ('iadd', ('pack_half_2x16', ('vec2', 'a', 0)), ('pack_half_2x16', ('vec2', 0, 'b'))) => ('pack_half_2x16', ('vec2', 'a', 'b')) */
   /* search1149_0_0_0 -> 16 in the cache */
   /* search1149_0_0_1 -> 122 in the cache */
   /* search1149_0_0 -> 3346 in the cache */
   /* search1149_0 -> 3347 in the cache */
   /* search1149_1_0_0 -> 122 in the cache */
   /* search1149_1_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_vec2,
      -1, 0,
      { 122, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_pack_half_2x16,
      -1, 0,
      { 3352 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 3347, 3353 },
      -1,
   } },

   /* replace1149_0_0 -> 16 in the cache */
   /* replace1149_0_1 -> 36 in the cache */
   /* replace1149_0 -> 3231 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_pack_half_2x16,
      -1, 0,
      { 3231 },
      -1,
   } },

   /* ('ior', ('pack_half_2x16', ('vec2', 'a', 0)), ('pack_half_2x16', ('vec2', 0, 'b'))) => ('pack_half_2x16', ('vec2', 'a', 'b')) */
   /* search1150_0_0_0 -> 16 in the cache */
   /* search1150_0_0_1 -> 122 in the cache */
   /* search1150_0_0 -> 3346 in the cache */
   /* search1150_0 -> 3347 in the cache */
   /* search1150_1_0_0 -> 122 in the cache */
   /* search1150_1_0_1 -> 36 in the cache */
   /* search1150_1_0 -> 3352 in the cache */
   /* search1150_1 -> 3353 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 3347, 3353 },
      -1,
   } },

   /* replace1150_0_0 -> 16 in the cache */
   /* replace1150_0_1 -> 36 in the cache */
   /* replace1150_0 -> 3231 in the cache */
   /* replace1150 -> 3355 in the cache */

   /* ('ishl', ('pack_half_2x16_split', 'a', 0), 16) => ('pack_half_2x16_split', 0, 'a') */
   /* search1151_0_0 -> 16 in the cache */
   /* search1151_0_1 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_pack_half_2x16_split,
      -1, 0,
      { 16, 122 },
      -1,
   } },
   /* search1151_1 -> 853 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 3357, 853 },
      -1,
   } },

   /* replace1151_0 -> 122 in the cache */
   /* replace1151_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_pack_half_2x16_split,
      -1, 0,
      { 122, 16 },
      -1,
   } },

   /* ('ushr', ('pack_half_2x16_split', 0, 'a'), 16) => ('pack_half_2x16_split', 'a', 0) */
   /* search1152_0_0 -> 122 in the cache */
   /* search1152_0_1 -> 16 in the cache */
   /* search1152_0 -> 3359 in the cache */
   /* search1152_1 -> 853 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 3359, 853 },
      -1,
   } },

   /* replace1152_0 -> 16 in the cache */
   /* replace1152_1 -> 122 in the cache */
   /* replace1152 -> 3357 in the cache */

   /* ('extract_u16', ('pack_half_2x16_split', 0, 'a'), 1) => ('pack_half_2x16_split', 'a', 0) */
   /* search1153_0_0 -> 122 in the cache */
   /* search1153_0_1 -> 16 in the cache */
   /* search1153_0 -> 3359 in the cache */
   /* search1153_1 -> 396 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 0,
      { 3359, 396 },
      -1,
   } },

   /* replace1153_0 -> 16 in the cache */
   /* replace1153_1 -> 122 in the cache */
   /* replace1153 -> 3357 in the cache */

   /* ('iadd', ('pack_half_2x16_split', 'a', 0), ('pack_half_2x16_split', 0, 'b')) => ('pack_half_2x16_split', 'a', 'b') */
   /* search1154_0_0 -> 16 in the cache */
   /* search1154_0_1 -> 122 in the cache */
   /* search1154_0 -> 3357 in the cache */
   /* search1154_1_0 -> 122 in the cache */
   /* search1154_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_pack_half_2x16_split,
      -1, 0,
      { 122, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 3357, 3362 },
      -1,
   } },

   /* replace1154_0 -> 16 in the cache */
   /* replace1154_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_pack_half_2x16_split,
      -1, 0,
      { 16, 36 },
      -1,
   } },

   /* ('ior', ('pack_half_2x16_split', 'a', 0), ('pack_half_2x16_split', 0, 'b')) => ('pack_half_2x16_split', 'a', 'b') */
   /* search1155_0_0 -> 16 in the cache */
   /* search1155_0_1 -> 122 in the cache */
   /* search1155_0 -> 3357 in the cache */
   /* search1155_1_0 -> 122 in the cache */
   /* search1155_1_1 -> 36 in the cache */
   /* search1155_1 -> 3362 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 3357, 3362 },
      -1,
   } },

   /* replace1155_0 -> 16 in the cache */
   /* replace1155_1 -> 36 in the cache */
   /* replace1155 -> 3364 in the cache */

   /* ('extract_i8', ('pack_32_4x8_split', 'a', 'b', 'c', 'd'), 0) => ('i2i', 'a') */
   /* search1156_0_0 -> 6 in the cache */
   /* search1156_0_1 -> 2128 in the cache */
   /* search1156_0_2 -> 3302 in the cache */
   /* search1156_0_3 -> 3305 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_pack_32_4x8_split,
      -1, 0,
      { 6, 2128, 3302, 3305 },
      -1,
   } },
   /* search1156_1 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 3366, 122 },
      -1,
   } },

   /* replace1156_0 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_search_op_i2i,
      -1, 0,
      { 6 },
      -1,
   } },

   /* ('extract_i8', ('pack_32_4x8_split', 'a', 'b', 'c', 'd'), 1) => ('i2i', 'b') */
   /* search1157_0_0 -> 6 in the cache */
   /* search1157_0_1 -> 2128 in the cache */
   /* search1157_0_2 -> 3302 in the cache */
   /* search1157_0_3 -> 3305 in the cache */
   /* search1157_0 -> 3366 in the cache */
   /* search1157_1 -> 396 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 3366, 396 },
      -1,
   } },

   /* replace1157_0 -> 2128 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_search_op_i2i,
      -1, 0,
      { 2128 },
      -1,
   } },

   /* ('extract_i8', ('pack_32_4x8_split', 'a', 'b', 'c', 'd'), 2) => ('i2i', 'c') */
   /* search1158_0_0 -> 6 in the cache */
   /* search1158_0_1 -> 2128 in the cache */
   /* search1158_0_2 -> 3302 in the cache */
   /* search1158_0_3 -> 3305 in the cache */
   /* search1158_0 -> 3366 in the cache */
   /* search1158_1 -> 401 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 3366, 401 },
      -1,
   } },

   /* replace1158_0 -> 3302 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_search_op_i2i,
      -1, 0,
      { 3302 },
      -1,
   } },

   /* ('extract_i8', ('pack_32_4x8_split', 'a', 'b', 'c', 'd'), 3) => ('i2i', 'd') */
   /* search1159_0_0 -> 6 in the cache */
   /* search1159_0_1 -> 2128 in the cache */
   /* search1159_0_2 -> 3302 in the cache */
   /* search1159_0_3 -> 3305 in the cache */
   /* search1159_0 -> 3366 in the cache */
   /* search1159_1 -> 405 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 3366, 405 },
      -1,
   } },

   /* replace1159_0 -> 3305 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_search_op_i2i,
      -1, 0,
      { 3305 },
      -1,
   } },

   /* ('extract_u8', ('pack_32_4x8_split', 'a', 'b', 'c', 'd'), 0) => ('u2u', 'a') */
   /* search1160_0_0 -> 6 in the cache */
   /* search1160_0_1 -> 2128 in the cache */
   /* search1160_0_2 -> 3302 in the cache */
   /* search1160_0_3 -> 3305 in the cache */
   /* search1160_0 -> 3366 in the cache */
   /* search1160_1 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3366, 122 },
      -1,
   } },

   /* replace1160_0 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_search_op_u2u,
      -1, 0,
      { 6 },
      -1,
   } },

   /* ('extract_u8', ('pack_32_4x8_split', 'a', 'b', 'c', 'd'), 1) => ('u2u', 'b') */
   /* search1161_0_0 -> 6 in the cache */
   /* search1161_0_1 -> 2128 in the cache */
   /* search1161_0_2 -> 3302 in the cache */
   /* search1161_0_3 -> 3305 in the cache */
   /* search1161_0 -> 3366 in the cache */
   /* search1161_1 -> 396 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3366, 396 },
      -1,
   } },

   /* replace1161_0 -> 2128 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_search_op_u2u,
      -1, 0,
      { 2128 },
      -1,
   } },

   /* ('extract_u8', ('pack_32_4x8_split', 'a', 'b', 'c', 'd'), 2) => ('u2u', 'c') */
   /* search1162_0_0 -> 6 in the cache */
   /* search1162_0_1 -> 2128 in the cache */
   /* search1162_0_2 -> 3302 in the cache */
   /* search1162_0_3 -> 3305 in the cache */
   /* search1162_0 -> 3366 in the cache */
   /* search1162_1 -> 401 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3366, 401 },
      -1,
   } },

   /* replace1162_0 -> 3302 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_search_op_u2u,
      -1, 0,
      { 3302 },
      -1,
   } },

   /* ('extract_u8', ('pack_32_4x8_split', 'a', 'b', 'c', 'd'), 3) => ('u2u', 'd') */
   /* search1163_0_0 -> 6 in the cache */
   /* search1163_0_1 -> 2128 in the cache */
   /* search1163_0_2 -> 3302 in the cache */
   /* search1163_0_3 -> 3305 in the cache */
   /* search1163_0 -> 3366 in the cache */
   /* search1163_1 -> 405 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3366, 405 },
      -1,
   } },

   /* replace1163_0 -> 3305 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_search_op_u2u,
      -1, 0,
      { 3305 },
      -1,
   } },

   /* ('extract_u8', ('ushr', 'a@16', 8), 0) => ('extract_u8', 'a', 1) */
   /* search1164_0_0 -> 11 in the cache */
   /* search1164_0_1 -> 831 in the cache */
   /* search1164_0 -> 3250 in the cache */
   /* search1164_1 -> 856 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3250, 856 },
      -1,
   } },

   /* replace1164_0 -> 11 in the cache */
   /* replace1164_1 -> 1452 in the cache */
   /* replace1164 -> 3251 in the cache */

   /* ('extract_u8', ('ushr', 'a@32', 8), 0) => ('extract_u8', 'a', 1) */
   /* search1165_0_0 -> 16 in the cache */
   /* search1165_0_1 -> 831 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 16, 831 },
      -1,
   } },
   /* search1165_1 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3384, 122 },
      -1,
   } },

   /* replace1165_0 -> 16 in the cache */
   /* replace1165_1 -> 396 in the cache */
   /* replace1165 -> 415 in the cache */

   /* ('extract_u8', ('ushr', 'a@32', 16), 0) => ('extract_u8', 'a', 2) */
   /* search1166_0_0 -> 16 in the cache */
   /* search1166_0_1 -> 853 in the cache */
   /* search1166_0 -> 1008 in the cache */
   /* search1166_1 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 1008, 122 },
      -1,
   } },

   /* replace1166_0 -> 16 in the cache */
   /* replace1166_1 -> 401 in the cache */
   /* replace1166 -> 419 in the cache */

   /* ('extract_u8', ('ushr', 'a@32', 24), 0) => ('extract_u8', 'a', 3) */
   /* search1167_0_0 -> 16 in the cache */
   /* search1167_0_1 -> 1012 in the cache */
   /* search1167_0 -> 1017 in the cache */
   /* search1167_1 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 1017, 122 },
      -1,
   } },

   /* replace1167_0 -> 16 in the cache */
   /* replace1167_1 -> 405 in the cache */
   /* replace1167 -> 422 in the cache */

   /* ('extract_u8', ('ushr', 'a@64', 8), 0) => ('extract_u8', 'a', 1) */
   /* search1168_0_0 -> 21 in the cache */
   /* search1168_0_1 -> 831 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 21, 831 },
      -1,
   } },
   /* search1168_1 -> 897 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3388, 897 },
      -1,
   } },

   /* replace1168_0 -> 21 in the cache */
   /* replace1168_1 -> 1494 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 21, 1494 },
      -1,
   } },

   /* ('extract_u8', ('ushr', 'a@64', 16), 0) => ('extract_u8', 'a', 2) */
   /* search1169_0_0 -> 21 in the cache */
   /* search1169_0_1 -> 853 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 21, 853 },
      -1,
   } },
   /* search1169_1 -> 897 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3391, 897 },
      -1,
   } },

   /* replace1169_0 -> 21 in the cache */
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0x2 /* 2 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 21, 3393 },
      -1,
   } },

   /* ('extract_u8', ('ushr', 'a@64', 24), 0) => ('extract_u8', 'a', 3) */
   /* search1170_0_0 -> 21 in the cache */
   /* search1170_0_1 -> 1012 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 21, 1012 },
      -1,
   } },
   /* search1170_1 -> 897 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3395, 897 },
      -1,
   } },

   /* replace1170_0 -> 21 in the cache */
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0x3 /* 3 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 21, 3397 },
      -1,
   } },

   /* ('extract_u8', ('ushr', 'a@64', 32), 0) => ('extract_u8', 'a', 4) */
   /* search1171_0_0 -> 21 in the cache */
   /* search1171_0_1 -> 874 in the cache */
   /* search1171_0 -> 3324 in the cache */
   /* search1171_1 -> 897 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3324, 897 },
      -1,
   } },

   /* replace1171_0 -> 21 in the cache */
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0x4 /* 4 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 21, 3400 },
      -1,
   } },

   /* ('extract_u8', ('ushr', 'a@64', 40), 0) => ('extract_u8', 'a', 5) */
   /* search1172_0_0 -> 21 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x28 /* 40 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 21, 3402 },
      -1,
   } },
   /* search1172_1 -> 897 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3403, 897 },
      -1,
   } },

   /* replace1172_0 -> 21 in the cache */
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0x5 /* 5 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 21, 3405 },
      -1,
   } },

   /* ('extract_u8', ('ushr', 'a@64', 48), 0) => ('extract_u8', 'a', 6) */
   /* search1173_0_0 -> 21 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x30 /* 48 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 21, 3407 },
      -1,
   } },
   /* search1173_1 -> 897 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3408, 897 },
      -1,
   } },

   /* replace1173_0 -> 21 in the cache */
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0x6 /* 6 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 21, 3410 },
      -1,
   } },

   /* ('extract_u8', ('ushr', 'a@64', 56), 0) => ('extract_u8', 'a', 7) */
   /* search1174_0_0 -> 21 in the cache */
   /* search1174_0_1 -> 3252 in the cache */
   /* search1174_0 -> 3253 in the cache */
   /* search1174_1 -> 897 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3253, 897 },
      -1,
   } },

   /* replace1174_0 -> 21 in the cache */
   /* replace1174_1 -> 3254 in the cache */
   /* replace1174 -> 3255 in the cache */

   /* ('extract_u8', ('ishr', 'a@16', 8), 0) => ('extract_u8', 'a', 1) */
   /* search1175_0_0 -> 11 in the cache */
   /* search1175_0_1 -> 831 in the cache */
   /* search1175_0 -> 3256 in the cache */
   /* search1175_1 -> 856 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3256, 856 },
      -1,
   } },

   /* replace1175_0 -> 11 in the cache */
   /* replace1175_1 -> 1452 in the cache */
   /* replace1175 -> 3251 in the cache */

   /* ('extract_u8', ('ishr', 'a@32', 8), 0) => ('extract_u8', 'a', 1) */
   /* search1176_0_0 -> 16 in the cache */
   /* search1176_0_1 -> 831 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 16, 831 },
      -1,
   } },
   /* search1176_1 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3414, 122 },
      -1,
   } },

   /* replace1176_0 -> 16 in the cache */
   /* replace1176_1 -> 396 in the cache */
   /* replace1176 -> 415 in the cache */

   /* ('extract_u8', ('ishr', 'a@32', 16), 0) => ('extract_u8', 'a', 2) */
   /* search1177_0_0 -> 16 in the cache */
   /* search1177_0_1 -> 853 in the cache */
   /* search1177_0 -> 3290 in the cache */
   /* search1177_1 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3290, 122 },
      -1,
   } },

   /* replace1177_0 -> 16 in the cache */
   /* replace1177_1 -> 401 in the cache */
   /* replace1177 -> 419 in the cache */

   /* ('extract_u8', ('ishr', 'a@32', 24), 0) => ('extract_u8', 'a', 3) */
   /* search1178_0_0 -> 16 in the cache */
   /* search1178_0_1 -> 1012 in the cache */
   /* search1178_0 -> 3258 in the cache */
   /* search1178_1 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3258, 122 },
      -1,
   } },

   /* replace1178_0 -> 16 in the cache */
   /* replace1178_1 -> 405 in the cache */
   /* replace1178 -> 422 in the cache */

   /* ('extract_u8', ('ishr', 'a@64', 8), 0) => ('extract_u8', 'a', 1) */
   /* search1179_0_0 -> 21 in the cache */
   /* search1179_0_1 -> 831 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 21, 831 },
      -1,
   } },
   /* search1179_1 -> 897 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3418, 897 },
      -1,
   } },

   /* replace1179_0 -> 21 in the cache */
   /* replace1179_1 -> 1494 in the cache */
   /* replace1179 -> 3390 in the cache */

   /* ('extract_u8', ('ishr', 'a@64', 16), 0) => ('extract_u8', 'a', 2) */
   /* search1180_0_0 -> 21 in the cache */
   /* search1180_0_1 -> 853 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 21, 853 },
      -1,
   } },
   /* search1180_1 -> 897 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3420, 897 },
      -1,
   } },

   /* replace1180_0 -> 21 in the cache */
   /* replace1180_1 -> 3393 in the cache */
   /* replace1180 -> 3394 in the cache */

   /* ('extract_u8', ('ishr', 'a@64', 24), 0) => ('extract_u8', 'a', 3) */
   /* search1181_0_0 -> 21 in the cache */
   /* search1181_0_1 -> 1012 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 21, 1012 },
      -1,
   } },
   /* search1181_1 -> 897 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3422, 897 },
      -1,
   } },

   /* replace1181_0 -> 21 in the cache */
   /* replace1181_1 -> 3397 in the cache */
   /* replace1181 -> 3398 in the cache */

   /* ('extract_u8', ('ishr', 'a@64', 32), 0) => ('extract_u8', 'a', 4) */
   /* search1182_0_0 -> 21 in the cache */
   /* search1182_0_1 -> 874 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 21, 874 },
      -1,
   } },
   /* search1182_1 -> 897 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3424, 897 },
      -1,
   } },

   /* replace1182_0 -> 21 in the cache */
   /* replace1182_1 -> 3400 in the cache */
   /* replace1182 -> 3401 in the cache */

   /* ('extract_u8', ('ishr', 'a@64', 40), 0) => ('extract_u8', 'a', 5) */
   /* search1183_0_0 -> 21 in the cache */
   /* search1183_0_1 -> 3402 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 21, 3402 },
      -1,
   } },
   /* search1183_1 -> 897 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3426, 897 },
      -1,
   } },

   /* replace1183_0 -> 21 in the cache */
   /* replace1183_1 -> 3405 in the cache */
   /* replace1183 -> 3406 in the cache */

   /* ('extract_u8', ('ishr', 'a@64', 48), 0) => ('extract_u8', 'a', 6) */
   /* search1184_0_0 -> 21 in the cache */
   /* search1184_0_1 -> 3407 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 21, 3407 },
      -1,
   } },
   /* search1184_1 -> 897 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3428, 897 },
      -1,
   } },

   /* replace1184_0 -> 21 in the cache */
   /* replace1184_1 -> 3410 in the cache */
   /* replace1184 -> 3411 in the cache */

   /* ('extract_u8', ('ishr', 'a@64', 56), 0) => ('extract_u8', 'a', 7) */
   /* search1185_0_0 -> 21 in the cache */
   /* search1185_0_1 -> 3252 in the cache */
   /* search1185_0 -> 3259 in the cache */
   /* search1185_1 -> 897 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3259, 897 },
      -1,
   } },

   /* replace1185_0 -> 21 in the cache */
   /* replace1185_1 -> 3254 in the cache */
   /* replace1185 -> 3255 in the cache */

   /* ('extract_u8', ('extract_u16', 'a', 1), 0) => ('extract_u8', 'a', 2) */
   /* search1186_0_0 -> 32 in the cache */
   /* search1186_0_1 -> 35 in the cache */
   /* search1186_0 -> 3263 in the cache */
   /* search1186_1 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3263, 61 },
      -1,
   } },

   /* replace1186_0 -> 32 in the cache */
   /* replace1186_1 -> 2254 in the cache */
   /* replace1186 -> 3265 in the cache */

   /* ('extract_u8', ('ishl', 'a@16', 8), 1) => ('extract_u8', 'a', 0) */
   /* search1187_0_0 -> 11 in the cache */
   /* search1187_0_1 -> 831 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 11, 831 },
      -1,
   } },
   /* search1187_1 -> 1452 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3432, 1452 },
      -1,
   } },

   /* replace1187_0 -> 11 in the cache */
   /* replace1187_1 -> 856 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 11, 856 },
      -1,
   } },

   /* ('extract_u8', ('ishl', 'a@32', 8), 3) => ('extract_u8', 'a', 2) */
   /* search1188_0_0 -> 16 in the cache */
   /* search1188_0_1 -> 831 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 16, 831 },
      -1,
   } },
   /* search1188_1 -> 405 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3435, 405 },
      -1,
   } },

   /* replace1188_0 -> 16 in the cache */
   /* replace1188_1 -> 401 in the cache */
   /* replace1188 -> 419 in the cache */

   /* ('extract_u8', ('ishl', 'a@32', 16), 3) => ('extract_u8', 'a', 1) */
   /* search1189_0_0 -> 16 in the cache */
   /* search1189_0_1 -> 853 in the cache */
   /* search1189_0 -> 1005 in the cache */
   /* search1189_1 -> 405 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 1005, 405 },
      -1,
   } },

   /* replace1189_0 -> 16 in the cache */
   /* replace1189_1 -> 396 in the cache */
   /* replace1189 -> 415 in the cache */

   /* ('extract_u8', ('ishl', 'a@32', 24), 3) => ('extract_u8', 'a', 0) */
   /* search1190_0_0 -> 16 in the cache */
   /* search1190_0_1 -> 1012 in the cache */
   /* search1190_0 -> 1014 in the cache */
   /* search1190_1 -> 405 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 1014, 405 },
      -1,
   } },

   /* replace1190_0 -> 16 in the cache */
   /* replace1190_1 -> 122 in the cache */
   /* replace1190 -> 412 in the cache */

   /* ('extract_u8', ('ishl', 'a@64', 8), 7) => ('extract_u8', 'a', 6) */
   /* search1191_0_0 -> 21 in the cache */
   /* search1191_0_1 -> 831 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 21, 831 },
      -1,
   } },
   /* search1191_1 -> 3254 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3439, 3254 },
      -1,
   } },

   /* replace1191_0 -> 21 in the cache */
   /* replace1191_1 -> 3410 in the cache */
   /* replace1191 -> 3411 in the cache */

   /* ('extract_u8', ('ishl', 'a@64', 16), 7) => ('extract_u8', 'a', 5) */
   /* search1192_0_0 -> 21 in the cache */
   /* search1192_0_1 -> 853 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 21, 853 },
      -1,
   } },
   /* search1192_1 -> 3254 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3441, 3254 },
      -1,
   } },

   /* replace1192_0 -> 21 in the cache */
   /* replace1192_1 -> 3405 in the cache */
   /* replace1192 -> 3406 in the cache */

   /* ('extract_u8', ('ishl', 'a@64', 24), 7) => ('extract_u8', 'a', 4) */
   /* search1193_0_0 -> 21 in the cache */
   /* search1193_0_1 -> 1012 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 21, 1012 },
      -1,
   } },
   /* search1193_1 -> 3254 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3443, 3254 },
      -1,
   } },

   /* replace1193_0 -> 21 in the cache */
   /* replace1193_1 -> 3400 in the cache */
   /* replace1193 -> 3401 in the cache */

   /* ('extract_u8', ('ishl', 'a@64', 32), 7) => ('extract_u8', 'a', 3) */
   /* search1194_0_0 -> 21 in the cache */
   /* search1194_0_1 -> 874 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 21, 874 },
      -1,
   } },
   /* search1194_1 -> 3254 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3445, 3254 },
      -1,
   } },

   /* replace1194_0 -> 21 in the cache */
   /* replace1194_1 -> 3397 in the cache */
   /* replace1194 -> 3398 in the cache */

   /* ('extract_u8', ('ishl', 'a@64', 40), 7) => ('extract_u8', 'a', 2) */
   /* search1195_0_0 -> 21 in the cache */
   /* search1195_0_1 -> 3402 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 21, 3402 },
      -1,
   } },
   /* search1195_1 -> 3254 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3447, 3254 },
      -1,
   } },

   /* replace1195_0 -> 21 in the cache */
   /* replace1195_1 -> 3393 in the cache */
   /* replace1195 -> 3394 in the cache */

   /* ('extract_u8', ('ishl', 'a@64', 48), 7) => ('extract_u8', 'a', 1) */
   /* search1196_0_0 -> 21 in the cache */
   /* search1196_0_1 -> 3407 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 21, 3407 },
      -1,
   } },
   /* search1196_1 -> 3254 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3449, 3254 },
      -1,
   } },

   /* replace1196_0 -> 21 in the cache */
   /* replace1196_1 -> 1494 in the cache */
   /* replace1196 -> 3390 in the cache */

   /* ('extract_u8', ('ishl', 'a@64', 56), 7) => ('extract_u8', 'a', 0) */
   /* search1197_0_0 -> 21 in the cache */
   /* search1197_0_1 -> 3252 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 21, 3252 },
      -1,
   } },
   /* search1197_1 -> 3254 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3451, 3254 },
      -1,
   } },

   /* replace1197_0 -> 21 in the cache */
   /* replace1197_1 -> 897 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 21, 897 },
      -1,
   } },

   /* ('extract_i8', ('ishl', 'a@16', 8), 1) => ('extract_i8', 'a', 0) */
   /* search1198_0_0 -> 11 in the cache */
   /* search1198_0_1 -> 831 in the cache */
   /* search1198_0 -> 3432 in the cache */
   /* search1198_1 -> 1452 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 3432, 1452 },
      -1,
   } },

   /* replace1198_0 -> 11 in the cache */
   /* replace1198_1 -> 856 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 11, 856 },
      -1,
   } },

   /* ('extract_i8', ('ishl', 'a@32', 8), 3) => ('extract_i8', 'a', 2) */
   /* search1199_0_0 -> 16 in the cache */
   /* search1199_0_1 -> 831 in the cache */
   /* search1199_0 -> 3435 in the cache */
   /* search1199_1 -> 405 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 3435, 405 },
      -1,
   } },

   /* replace1199_0 -> 16 in the cache */
   /* replace1199_1 -> 401 in the cache */
   /* replace1199 -> 402 in the cache */

   /* ('extract_i8', ('ishl', 'a@32', 16), 3) => ('extract_i8', 'a', 1) */
   /* search1200_0_0 -> 16 in the cache */
   /* search1200_0_1 -> 853 in the cache */
   /* search1200_0 -> 1005 in the cache */
   /* search1200_1 -> 405 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 1005, 405 },
      -1,
   } },

   /* replace1200_0 -> 16 in the cache */
   /* replace1200_1 -> 396 in the cache */
   /* replace1200 -> 397 in the cache */

   /* ('extract_i8', ('ishl', 'a@32', 24), 3) => ('extract_i8', 'a', 0) */
   /* search1201_0_0 -> 16 in the cache */
   /* search1201_0_1 -> 1012 in the cache */
   /* search1201_0 -> 1014 in the cache */
   /* search1201_1 -> 405 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 1014, 405 },
      -1,
   } },

   /* replace1201_0 -> 16 in the cache */
   /* replace1201_1 -> 122 in the cache */
   /* replace1201 -> 393 in the cache */

   /* ('extract_i8', ('ishl', 'a@64', 8), 7) => ('extract_i8', 'a', 6) */
   /* search1202_0_0 -> 21 in the cache */
   /* search1202_0_1 -> 831 in the cache */
   /* search1202_0 -> 3439 in the cache */
   /* search1202_1 -> 3254 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 3439, 3254 },
      -1,
   } },

   /* replace1202_0 -> 21 in the cache */
   /* replace1202_1 -> 3410 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 21, 3410 },
      -1,
   } },

   /* ('extract_i8', ('ishl', 'a@64', 16), 7) => ('extract_i8', 'a', 5) */
   /* search1203_0_0 -> 21 in the cache */
   /* search1203_0_1 -> 853 in the cache */
   /* search1203_0 -> 3441 in the cache */
   /* search1203_1 -> 3254 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 3441, 3254 },
      -1,
   } },

   /* replace1203_0 -> 21 in the cache */
   /* replace1203_1 -> 3405 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 21, 3405 },
      -1,
   } },

   /* ('extract_i8', ('ishl', 'a@64', 24), 7) => ('extract_i8', 'a', 4) */
   /* search1204_0_0 -> 21 in the cache */
   /* search1204_0_1 -> 1012 in the cache */
   /* search1204_0 -> 3443 in the cache */
   /* search1204_1 -> 3254 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 3443, 3254 },
      -1,
   } },

   /* replace1204_0 -> 21 in the cache */
   /* replace1204_1 -> 3400 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 21, 3400 },
      -1,
   } },

   /* ('extract_i8', ('ishl', 'a@64', 32), 7) => ('extract_i8', 'a', 3) */
   /* search1205_0_0 -> 21 in the cache */
   /* search1205_0_1 -> 874 in the cache */
   /* search1205_0 -> 3445 in the cache */
   /* search1205_1 -> 3254 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 3445, 3254 },
      -1,
   } },

   /* replace1205_0 -> 21 in the cache */
   /* replace1205_1 -> 3397 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 21, 3397 },
      -1,
   } },

   /* ('extract_i8', ('ishl', 'a@64', 40), 7) => ('extract_i8', 'a', 2) */
   /* search1206_0_0 -> 21 in the cache */
   /* search1206_0_1 -> 3402 in the cache */
   /* search1206_0 -> 3447 in the cache */
   /* search1206_1 -> 3254 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 3447, 3254 },
      -1,
   } },

   /* replace1206_0 -> 21 in the cache */
   /* replace1206_1 -> 3393 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 21, 3393 },
      -1,
   } },

   /* ('extract_i8', ('ishl', 'a@64', 48), 7) => ('extract_i8', 'a', 1) */
   /* search1207_0_0 -> 21 in the cache */
   /* search1207_0_1 -> 3407 in the cache */
   /* search1207_0 -> 3449 in the cache */
   /* search1207_1 -> 3254 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 3449, 3254 },
      -1,
   } },

   /* replace1207_0 -> 21 in the cache */
   /* replace1207_1 -> 1494 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 21, 1494 },
      -1,
   } },

   /* ('extract_i8', ('ishl', 'a@64', 56), 7) => ('extract_i8', 'a', 0) */
   /* search1208_0_0 -> 21 in the cache */
   /* search1208_0_1 -> 3252 in the cache */
   /* search1208_0 -> 3451 in the cache */
   /* search1208_1 -> 3254 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 3451, 3254 },
      -1,
   } },

   /* replace1208_0 -> 21 in the cache */
   /* replace1208_1 -> 897 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 21, 897 },
      -1,
   } },

   /* ('ussub_4x8_vc4', 'a', 0) => a */
   /* search1209_0 -> 16 in the cache */
   /* search1209_1 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ussub_4x8_vc4,
      -1, 0,
      { 16, 122 },
      -1,
   } },

   /* replace1209 -> 16 in the cache */

   /* ('ussub_4x8_vc4', 'a', -1) => 0 */
   /* search1210_0 -> 16 in the cache */
   /* search1210_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ussub_4x8_vc4,
      -1, 0,
      { 16, 124 },
      -1,
   } },

   /* replace1210 -> 122 in the cache */

   /* ('fsub', 'a', 'b') => ('fadd', 'a', ('fneg', 'b')) */
   /* search1211_0 -> 0 in the cache */
   /* search1211_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* replace1211_0 -> 0 in the cache */
   /* replace1211_1_0 -> 3 in the cache */
   /* replace1211_1 -> 1087 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 0, 1087 },
      -1,
   } },

   /* ('isub', 'a', 'b') => ('iadd', 'a', ('ineg', 'b')) */
   /* search1212_0 -> 0 in the cache */
   /* search1212_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* replace1212_0 -> 0 in the cache */
   /* replace1212_1_0 -> 3 in the cache */
   /* replace1212_1 -> 93 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 0, 93 },
      -1,
   } },

   /* ('uabs_usub', 'a', 'b') => ('bcsel', ('ult', 'a', 'b'), ('ineg', ('isub', 'a', 'b')), ('isub', 'a', 'b')) */
   /* search1213_0 -> 0 in the cache */
   /* search1213_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_uabs_usub,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* replace1213_0_0 -> 0 in the cache */
   /* replace1213_0_1 -> 3 in the cache */
   /* replace1213_0 -> 1067 in the cache */
   /* replace1213_1_0_0 -> 0 in the cache */
   /* replace1213_1_0_1 -> 3 in the cache */
   /* replace1213_1_0 -> 3477 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 3477 },
      -1,
   } },
   /* replace1213_2_0 -> 0 in the cache */
   /* replace1213_2_1 -> 3 in the cache */
   /* replace1213_2 -> 3477 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1067, 3480, 3477 },
      -1,
   } },

   /* ('uabs_isub', 'a', 'b') => ('bcsel', ('ilt', 'a', 'b'), ('ineg', ('isub', 'a', 'b')), ('isub', 'a', 'b')) */
   /* search1214_0 -> 0 in the cache */
   /* search1214_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_uabs_isub,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* replace1214_0_0 -> 0 in the cache */
   /* replace1214_0_1 -> 3 in the cache */
   /* replace1214_0 -> 1064 in the cache */
   /* replace1214_1_0_0 -> 0 in the cache */
   /* replace1214_1_0_1 -> 3 in the cache */
   /* replace1214_1_0 -> 3477 in the cache */
   /* replace1214_1 -> 3480 in the cache */
   /* replace1214_2_0 -> 0 in the cache */
   /* replace1214_2_1 -> 3 in the cache */
   /* replace1214_2 -> 3477 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1064, 3480, 3477 },
      -1,
   } },

   /* ('fmul(is_used_by_non_fsat)', ('fneg', 'a'), 'b') => ('fneg', ('fmul', 'a', 'b')) */
   /* search1215_0_0 -> 0 in the cache */
   /* search1215_0 -> 212 in the cache */
   /* search1215_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 212, 3 },
      3,
   } },

   /* replace1215_0_0 -> 0 in the cache */
   /* replace1215_0_1 -> 3 in the cache */
   /* replace1215_0 -> 264 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 264 },
      -1,
   } },

   /* ('fmulz(is_used_by_non_fsat)', ('fneg', 'a'), 'b') => ('fneg', ('fmulz', 'a', 'b')) */
   /* search1216_0_0 -> 16 in the cache */
   /* search1216_0 -> 280 in the cache */
   /* search1216_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 280, 36 },
      3,
   } },

   /* replace1216_0_0 -> 16 in the cache */
   /* replace1216_0_1 -> 36 in the cache */
   /* replace1216_0 -> 269 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 269 },
      -1,
   } },

   /* ('ffma', ('fneg', 'a'), ('fneg', 'b'), 'c') => ('ffma', 'a', 'b', 'c') */
   /* search1217_0_0 -> 126 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 126 },
      -1,
   } },
   /* search1217_1_0 -> 127 in the cache */
   /* search1217_1 -> 1197 in the cache */
   /* search1217_2 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 3488, 1197, 129 },
      -1,
   } },

   /* replace1217_0 -> 126 in the cache */
   /* replace1217_1 -> 127 in the cache */
   /* replace1217_2 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 126, 127, 129 },
      -1,
   } },

   /* ('ffmaz', ('fneg', 'a'), ('fneg', 'b'), 'c') => ('ffmaz', 'a', 'b', 'c') */
   /* search1218_0_0 -> 16 in the cache */
   /* search1218_0 -> 280 in the cache */
   /* search1218_1_0 -> 36 in the cache */
   /* search1218_1 -> 600 in the cache */
   /* search1218_2 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 1,
      { 280, 600, 135 },
      -1,
   } },

   /* replace1218_0 -> 16 in the cache */
   /* replace1218_1 -> 36 in the cache */
   /* replace1218_2 -> 135 in the cache */
   /* replace1218 -> 387 in the cache */

   /* ('imul', ('ineg', 'a'), 'b') => ('ineg', ('imul', 'a', 'b')) */
   /* search1219_0_0 -> 0 in the cache */
   /* search1219_0 -> 207 in the cache */
   /* search1219_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 207, 3 },
      -1,
   } },

   /* replace1219_0_0 -> 0 in the cache */
   /* replace1219_0_1 -> 3 in the cache */
   /* replace1219_0 -> 951 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 1,
      { 951 },
      -1,
   } },

   /* ('~fmul(is_used_once)', ('fmul(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c') => ('fmul', ('fmul', 'a', 'c'), 'b') */
   { .variable = {
      { nir_search_value_variable, -3 },
      0, /* a */
      false,
      nir_type_invalid,
      5,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      1, /* b */
      false,
      nir_type_invalid,
      5,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 3494, 3495 },
      0,
   } },
   /* search1220_1 -> 814 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      true,
      false,
      false,
      nir_op_fmul,
      0, 2,
      { 3496, 814 },
      0,
   } },

   /* replace1220_0_0 -> 126 in the cache */
   /* replace1220_0_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 126, 129 },
      -1,
   } },
   /* replace1220_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 2,
      { 3498, 127 },
      -1,
   } },

   /* ('~fmulz(is_used_once)', ('fmulz(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c') => ('fmulz', ('fmulz', 'a', 'c'), 'b') */
   /* search1221_0_0 -> 328 in the cache */
   /* search1221_0_1 -> 338 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      1, 1,
      { 328, 338 },
      0,
   } },
   /* search1221_1 -> 309 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fmulz,
      0, 2,
      { 3500, 309 },
      0,
   } },

   /* replace1221_0_0 -> 16 in the cache */
   /* replace1221_0_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      1, 1,
      { 16, 135 },
      -1,
   } },
   /* replace1221_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      0, 2,
      { 3502, 36 },
      -1,
   } },

   /* ('~fmul(is_used_once)', ('fmulz(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c(is_finite_not_zero)') => ('fmulz', ('fmul', 'a', 'c'), 'b') */
   /* search1222_0_0 -> 328 in the cache */
   /* search1222_0_1 -> 338 in the cache */
   /* search1222_0 -> 3500 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      2, /* c */
      true,
      nir_type_invalid,
      3,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fmul,
      0, 2,
      { 3500, 3504 },
      0,
   } },

   /* replace1222_0_0 -> 16 in the cache */
   /* replace1222_0_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 16, 135 },
      -1,
   } },
   /* replace1222_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      0, 2,
      { 3506, 36 },
      -1,
   } },

   /* ('imul(is_used_once)', ('imul(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c') => ('imul', ('imul', 'a', 'c'), 'b') */
   /* search1223_0_0 -> 3494 in the cache */
   /* search1223_0_1 -> 3495 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imul,
      1, 1,
      { 3494, 3495 },
      0,
   } },
   /* search1223_1 -> 814 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imul,
      0, 2,
      { 3508, 814 },
      0,
   } },

   /* replace1223_0_0 -> 126 in the cache */
   /* replace1223_0_1 -> 129 in the cache */
   /* replace1223_0 -> 1025 in the cache */
   /* replace1223_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imul,
      0, 2,
      { 1025, 127 },
      -1,
   } },

   /* ('~ffma', ('fmul(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c', 'd') => ('ffma', ('fmul', 'a', 'c'), 'b', 'd') */
   { .variable = {
      { nir_search_value_variable, -4 },
      0, /* a */
      false,
      nir_type_invalid,
      5,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -4 },
      1, /* b */
      false,
      nir_type_invalid,
      5,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 3511, 3512 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, -4 },
      2, /* c */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search1224_2 -> 153 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 3513, 3514, 153 },
      -1,
   } },

   /* replace1224_0_0 -> 149 in the cache */
   /* replace1224_0_1 -> 152 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 149, 152 },
      -1,
   } },
   /* replace1224_1 -> 150 in the cache */
   /* replace1224_2 -> 153 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 3516, 150, 153 },
      -1,
   } },

   /* ('~ffmaz', ('fmulz(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c', 'd') => ('ffmaz', ('fmulz', 'a', 'c'), 'b', 'd') */
   /* search1225_0_0 -> 328 in the cache */
   /* search1225_0_1 -> 338 in the cache */
   /* search1225_0 -> 3500 in the cache */
   /* search1225_1 -> 309 in the cache */
   /* search1225_2 -> 163 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_ffmaz,
      0, 2,
      { 3500, 309, 163 },
      -1,
   } },

   /* replace1225_0_0 -> 16 in the cache */
   /* replace1225_0_1 -> 135 in the cache */
   /* replace1225_0 -> 3502 in the cache */
   /* replace1225_1 -> 36 in the cache */
   /* replace1225_2 -> 163 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 2,
      { 3502, 36, 163 },
      -1,
   } },

   /* ('~ffma', ('fmulz(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c(is_finite_not_zero)', 'd') => ('ffmaz', ('fmul', 'a', 'c'), 'b', 'd') */
   /* search1226_0_0 -> 328 in the cache */
   /* search1226_0_1 -> 338 in the cache */
   /* search1226_0 -> 3500 in the cache */
   /* search1226_1 -> 3504 in the cache */
   /* search1226_2 -> 163 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 3500, 3504, 163 },
      -1,
   } },

   /* replace1226_0_0 -> 16 in the cache */
   /* replace1226_0_1 -> 135 in the cache */
   /* replace1226_0 -> 3506 in the cache */
   /* replace1226_1 -> 36 in the cache */
   /* replace1226_2 -> 163 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 2,
      { 3506, 36, 163 },
      -1,
   } },

   /* ('~fadd(is_used_once)', ('fadd(is_used_once)', 'a(is_not_const)', 'b(is_fmul)'), '#c') => ('fadd', ('fadd', 'a', 'c'), 'b') */
   /* search1227_0_0 -> 3494 in the cache */
   { .variable = {
      { nir_search_value_variable, -3 },
      1, /* b */
      false,
      nir_type_invalid,
      33,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 3494, 3522 },
      0,
   } },
   /* search1227_1 -> 814 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 3523, 814 },
      0,
   } },

   /* replace1227_0_0 -> 126 in the cache */
   /* replace1227_0_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 126, 129 },
      -1,
   } },
   /* replace1227_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 3525, 127 },
      -1,
   } },

   /* ('~fadd(is_used_once)', ('fadd(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c') => ('fadd', ('fadd', 'a', 'c'), 'b') */
   /* search1228_0_0 -> 3494 in the cache */
   /* search1228_0_1 -> 3495 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 3494, 3495 },
      0,
   } },
   /* search1228_1 -> 814 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 3527, 814 },
      0,
   } },

   /* replace1228_0_0 -> 126 in the cache */
   /* replace1228_0_1 -> 129 in the cache */
   /* replace1228_0 -> 3525 in the cache */
   /* replace1228_1 -> 127 in the cache */
   /* replace1228 -> 3526 in the cache */

   /* ('~fadd(is_used_once)', ('ffma(is_used_once)', 'a(is_not_const)', 'b', 'c(is_not_const)'), '#d') => ('fadd', ('ffma', 'a', 'b', 'd'), 'c') */
   /* search1229_0_0 -> 3511 in the cache */
   /* search1229_0_1 -> 150 in the cache */
   { .variable = {
      { nir_search_value_variable, -4 },
      2, /* c */
      false,
      nir_type_invalid,
      5,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ffma,
      1, 1,
      { 3511, 150, 3529 },
      0,
   } },
   /* search1229_1 -> 1031 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 3530, 1031 },
      0,
   } },

   /* replace1229_0_0 -> 149 in the cache */
   /* replace1229_0_1 -> 150 in the cache */
   /* replace1229_0_2 -> 153 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ffma,
      1, 1,
      { 149, 150, 153 },
      -1,
   } },
   /* replace1229_1 -> 152 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 3532, 152 },
      -1,
   } },

   /* ('~fadd(is_used_once)', ('ffmaz(is_used_once)', 'a(is_not_const)', 'b', 'c(is_not_const)'), '#d') => ('fadd', ('ffmaz', 'a', 'b', 'd'), 'c') */
   /* search1230_0_0 -> 328 in the cache */
   /* search1230_0_1 -> 36 in the cache */
   /* search1230_0_2 -> 347 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      1, 1,
      { 328, 36, 347 },
      0,
   } },
   /* search1230_1 -> 311 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 3534, 311 },
      0,
   } },

   /* replace1230_0_0 -> 16 in the cache */
   /* replace1230_0_1 -> 36 in the cache */
   /* replace1230_0_2 -> 163 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      1, 1,
      { 16, 36, 163 },
      -1,
   } },
   /* replace1230_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 3536, 135 },
      -1,
   } },

   /* ('iadd(is_used_once)', ('iadd(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), '#c') => ('iadd', ('iadd', 'a', 'c'), 'b') */
   /* search1231_0_0 -> 3494 in the cache */
   /* search1231_0_1 -> 3495 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 3494, 3495 },
      0,
   } },
   /* search1231_1 -> 814 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 3538, 814 },
      0,
   } },

   /* replace1231_0_0 -> 126 in the cache */
   /* replace1231_0_1 -> 129 in the cache */
   /* replace1231_0 -> 1039 in the cache */
   /* replace1231_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 1039, 127 },
      -1,
   } },

   /* ('~fmul', '#a', ('fmul', 'b(is_not_const)', '#c')) => ('fmul', ('fmul', 'a', 'c'), 'b') */
   /* search1232_0 -> 282 in the cache */
   /* search1232_1_0 -> 3495 in the cache */
   /* search1232_1_1 -> 814 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 3495, 814 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      true,
      false,
      false,
      nir_op_fmul,
      0, 2,
      { 282, 3541 },
      -1,
   } },

   /* replace1232_0_0 -> 126 in the cache */
   /* replace1232_0_1 -> 129 in the cache */
   /* replace1232_0 -> 3498 in the cache */
   /* replace1232_1 -> 127 in the cache */
   /* replace1232 -> 3499 in the cache */

   /* ('~fmulz', '#a', ('fmulz', 'b(is_not_const)', '#c')) => ('fmulz', ('fmulz', 'a', 'c'), 'b') */
   /* search1233_0 -> 286 in the cache */
   /* search1233_1_0 -> 338 in the cache */
   /* search1233_1_1 -> 309 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      1, 1,
      { 338, 309 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fmulz,
      0, 2,
      { 286, 3543 },
      -1,
   } },

   /* replace1233_0_0 -> 16 in the cache */
   /* replace1233_0_1 -> 135 in the cache */
   /* replace1233_0 -> 3502 in the cache */
   /* replace1233_1 -> 36 in the cache */
   /* replace1233 -> 3503 in the cache */

   /* ('~fmul', '#a(is_finite_not_zero)', ('fmulz', 'b(is_not_const)', '#c')) => ('fmulz', ('fmul', 'a', 'c'), 'b') */
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* a */
      true,
      nir_type_invalid,
      3,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search1234_1_0 -> 338 in the cache */
   /* search1234_1_1 -> 309 in the cache */
   /* search1234_1 -> 3543 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fmul,
      0, 2,
      { 3545, 3543 },
      -1,
   } },

   /* replace1234_0_0 -> 16 in the cache */
   /* replace1234_0_1 -> 135 in the cache */
   /* replace1234_0 -> 3506 in the cache */
   /* replace1234_1 -> 36 in the cache */
   /* replace1234 -> 3507 in the cache */

   /* ('~ffma', '#a', ('fmul', 'b(is_not_const)', '#c'), 'd') => ('ffma', ('fmul', 'a', 'c'), 'b', 'd') */
   { .variable = {
      { nir_search_value_variable, -4 },
      0, /* a */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search1235_1_0 -> 3512 in the cache */
   /* search1235_1_1 -> 3514 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 3512, 3514 },
      -1,
   } },
   /* search1235_2 -> 153 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 3547, 3548, 153 },
      -1,
   } },

   /* replace1235_0_0 -> 149 in the cache */
   /* replace1235_0_1 -> 152 in the cache */
   /* replace1235_0 -> 3516 in the cache */
   /* replace1235_1 -> 150 in the cache */
   /* replace1235_2 -> 153 in the cache */
   /* replace1235 -> 3517 in the cache */

   /* ('~ffmaz', '#a', ('fmulz', 'b(is_not_const)', '#c'), 'd') => ('ffmaz', ('fmulz', 'a', 'c'), 'b', 'd') */
   /* search1236_0 -> 286 in the cache */
   /* search1236_1_0 -> 338 in the cache */
   /* search1236_1_1 -> 309 in the cache */
   /* search1236_1 -> 3543 in the cache */
   /* search1236_2 -> 163 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_ffmaz,
      0, 2,
      { 286, 3543, 163 },
      -1,
   } },

   /* replace1236_0_0 -> 16 in the cache */
   /* replace1236_0_1 -> 135 in the cache */
   /* replace1236_0 -> 3502 in the cache */
   /* replace1236_1 -> 36 in the cache */
   /* replace1236_2 -> 163 in the cache */
   /* replace1236 -> 3519 in the cache */

   /* ('~ffmaz', '#a(is_finite_not_zero)', ('fmulz', 'b(is_not_const)', '#c'), 'd') => ('ffmaz', ('fmul', 'a', 'c'), 'b', 'd') */
   /* search1237_0 -> 3545 in the cache */
   /* search1237_1_0 -> 338 in the cache */
   /* search1237_1_1 -> 309 in the cache */
   /* search1237_1 -> 3543 in the cache */
   /* search1237_2 -> 163 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_ffmaz,
      0, 2,
      { 3545, 3543, 163 },
      -1,
   } },

   /* replace1237_0_0 -> 16 in the cache */
   /* replace1237_0_1 -> 135 in the cache */
   /* replace1237_0 -> 3506 in the cache */
   /* replace1237_1 -> 36 in the cache */
   /* replace1237_2 -> 163 in the cache */
   /* replace1237 -> 3521 in the cache */

   /* ('imul', '#a', ('imul', 'b(is_not_const)', '#c')) => ('imul', ('imul', 'a', 'c'), 'b') */
   /* search1238_0 -> 282 in the cache */
   /* search1238_1_0 -> 3495 in the cache */
   /* search1238_1_1 -> 814 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imul,
      1, 1,
      { 3495, 814 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imul,
      0, 2,
      { 282, 3552 },
      -1,
   } },

   /* replace1238_0_0 -> 126 in the cache */
   /* replace1238_0_1 -> 129 in the cache */
   /* replace1238_0 -> 1025 in the cache */
   /* replace1238_1 -> 127 in the cache */
   /* replace1238 -> 3510 in the cache */

   /* ('~fadd', '#a', ('fadd', 'b(is_not_const)', '#c')) => ('fadd', ('fadd', 'a', 'c'), 'b') */
   /* search1239_0 -> 282 in the cache */
   /* search1239_1_0 -> 3495 in the cache */
   /* search1239_1_1 -> 814 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 3495, 814 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 282, 3554 },
      -1,
   } },

   /* replace1239_0_0 -> 126 in the cache */
   /* replace1239_0_1 -> 129 in the cache */
   /* replace1239_0 -> 3525 in the cache */
   /* replace1239_1 -> 127 in the cache */
   /* replace1239 -> 3526 in the cache */

   /* ('~fadd', '#a', ('fneg', ('fadd', 'b(is_not_const)', '#c'))) => ('fadd', ('fadd', 'a', ('fneg', 'c')), ('fneg', 'b')) */
   /* search1240_0 -> 282 in the cache */
   /* search1240_1_0_0 -> 3495 in the cache */
   /* search1240_1_0_1 -> 814 in the cache */
   /* search1240_1_0 -> 3554 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 3554 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 282, 3556 },
      -1,
   } },

   /* replace1240_0_0 -> 126 in the cache */
   /* replace1240_0_1_0 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 129 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 126, 3558 },
      -1,
   } },
   /* replace1240_1_0 -> 127 in the cache */
   /* replace1240_1 -> 1197 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 3559, 1197 },
      -1,
   } },

   /* ('~fadd', '#a', ('ffma', 'b(is_not_const)', 'c(is_not_const)', '#d')) => ('ffma', 'b', 'c', ('fadd', 'a', 'd')) */
   /* search1241_0 -> 3547 in the cache */
   /* search1241_1_0 -> 3512 in the cache */
   /* search1241_1_1 -> 3529 in the cache */
   /* search1241_1_2 -> 1031 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ffma,
      1, 1,
      { 3512, 3529, 1031 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 3547, 3561 },
      -1,
   } },

   /* replace1241_0 -> 150 in the cache */
   /* replace1241_1 -> 152 in the cache */
   /* replace1241_2_0 -> 149 in the cache */
   /* replace1241_2_1 -> 153 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 149, 153 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 150, 152, 3563 },
      -1,
   } },

   /* ('~fadd', '#a', ('fneg', ('ffma', 'b(is_not_const)', 'c(is_not_const)', '#d'))) => ('ffma', ('fneg', 'b'), 'c', ('fadd', 'a', ('fneg', 'd'))) */
   /* search1242_0 -> 3547 in the cache */
   /* search1242_1_0_0 -> 3512 in the cache */
   /* search1242_1_0_1 -> 3529 in the cache */
   /* search1242_1_0_2 -> 1031 in the cache */
   /* search1242_1_0 -> 3561 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 3561 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 3547, 3565 },
      -1,
   } },

   /* replace1242_0_0 -> 150 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 150 },
      -1,
   } },
   /* replace1242_1 -> 152 in the cache */
   /* replace1242_2_0 -> 149 in the cache */
   /* replace1242_2_1_0 -> 153 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 153 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 149, 3568 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 3567, 152, 3569 },
      -1,
   } },

   /* ('~fadd', '#a', ('ffmaz', 'b(is_not_const)', 'c(is_not_const)', '#d')) => ('ffmaz', 'b', 'c', ('fadd', 'a', 'd')) */
   /* search1243_0 -> 286 in the cache */
   /* search1243_1_0 -> 338 in the cache */
   /* search1243_1_1 -> 347 in the cache */
   /* search1243_1_2 -> 311 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      1, 1,
      { 338, 347, 311 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 286, 3571 },
      -1,
   } },

   /* replace1243_0 -> 36 in the cache */
   /* replace1243_1 -> 135 in the cache */
   /* replace1243_2_0 -> 16 in the cache */
   /* replace1243_2_1 -> 163 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 16, 163 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 2,
      { 36, 135, 3573 },
      -1,
   } },

   /* ('~fadd', '#a', ('fneg', ('ffmaz', 'b(is_not_const)', 'c(is_not_const)', '#d'))) => ('ffmaz', ('fneg', 'b'), 'c', ('fadd', 'a', ('fneg', 'd'))) */
   /* search1244_0 -> 286 in the cache */
   /* search1244_1_0_0 -> 338 in the cache */
   /* search1244_1_0_1 -> 347 in the cache */
   /* search1244_1_0_2 -> 311 in the cache */
   /* search1244_1_0 -> 3571 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 3571 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 286, 3575 },
      -1,
   } },

   /* replace1244_0_0 -> 36 in the cache */
   /* replace1244_0 -> 600 in the cache */
   /* replace1244_1 -> 135 in the cache */
   /* replace1244_2_0 -> 16 in the cache */
   /* replace1244_2_1_0 -> 163 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 163 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 16, 3577 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 2,
      { 600, 135, 3578 },
      -1,
   } },

   /* ('iadd', '#a', ('iadd', 'b(is_not_const)', '#c')) => ('iadd', ('iadd', 'a', 'c'), 'b') */
   /* search1245_0 -> 282 in the cache */
   /* search1245_1_0 -> 3495 in the cache */
   /* search1245_1_1 -> 814 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 3495, 814 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 282, 3580 },
      -1,
   } },

   /* replace1245_0_0 -> 126 in the cache */
   /* replace1245_0_1 -> 129 in the cache */
   /* replace1245_0 -> 1039 in the cache */
   /* replace1245_1 -> 127 in the cache */
   /* replace1245 -> 3540 in the cache */

   /* ('iand', '#a', ('iand', 'b(is_not_const)', '#c')) => ('iand', ('iand', 'a', 'c'), 'b') */
   /* search1246_0 -> 282 in the cache */
   /* search1246_1_0 -> 3495 in the cache */
   /* search1246_1_1 -> 814 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 3495, 814 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 282, 3582 },
      -1,
   } },

   /* replace1246_0_0 -> 126 in the cache */
   /* replace1246_0_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 126, 129 },
      -1,
   } },
   /* replace1246_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 3584, 127 },
      -1,
   } },

   /* ('ior', '#a', ('ior', 'b(is_not_const)', '#c')) => ('ior', ('ior', 'a', 'c'), 'b') */
   /* search1247_0 -> 282 in the cache */
   /* search1247_1_0 -> 3495 in the cache */
   /* search1247_1_1 -> 814 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 3495, 814 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 282, 3586 },
      -1,
   } },

   /* replace1247_0_0 -> 126 in the cache */
   /* replace1247_0_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 126, 129 },
      -1,
   } },
   /* replace1247_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 3588, 127 },
      -1,
   } },

   /* ('ixor', '#a', ('ixor', 'b(is_not_const)', '#c')) => ('ixor', ('ixor', 'a', 'c'), 'b') */
   /* search1248_0 -> 282 in the cache */
   /* search1248_1_0 -> 3495 in the cache */
   /* search1248_1_1 -> 814 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ixor,
      1, 1,
      { 3495, 814 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 2,
      { 282, 3590 },
      -1,
   } },

   /* replace1248_0_0 -> 126 in the cache */
   /* replace1248_0_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ixor,
      1, 1,
      { 126, 129 },
      -1,
   } },
   /* replace1248_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 2,
      { 3592, 127 },
      -1,
   } },

   /* ('~fadd', ('fadd(is_used_once)', 'a(is_fmul)', 'b(is_fmul)'), 'c(is_not_fmul)') => ('fadd', ('fadd', 'a', 'c'), 'b') */
   { .variable = {
      { nir_search_value_variable, -3 },
      0, /* a */
      false,
      nir_type_invalid,
      33,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search1249_0_1 -> 3522 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 3594, 3522 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      2, /* c */
      false,
      nir_type_invalid,
      8,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 3595, 3596 },
      -1,
   } },

   /* replace1249_0_0 -> 126 in the cache */
   /* replace1249_0_1 -> 129 in the cache */
   /* replace1249_0 -> 3525 in the cache */
   /* replace1249_1 -> 127 in the cache */
   /* replace1249 -> 3526 in the cache */

   /* ('idiv', ('imul(no_signed_wrap)', 'a', 'b'), 'b') => a */
   /* search1250_0_0 -> 0 in the cache */
   /* search1250_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 0, 3 },
      4,
   } },
   /* search1250_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_idiv,
      -1, 1,
      { 3598, 3 },
      -1,
   } },

   /* replace1250 -> 0 in the cache */

   /* ('bcsel', ('ige', ('find_lsb', 'a'), 0), ('find_lsb', 'a'), -1) => ('find_lsb', 'a') */
   /* search1251_0_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_find_lsb,
      -1, 0,
      { 32 },
      -1,
   } },
   /* search1251_0_1 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 3600, 122 },
      -1,
   } },
   /* search1251_1_0 -> 32 in the cache */
   /* search1251_1 -> 3600 in the cache */
   /* search1251_2 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3601, 3600, 124 },
      -1,
   } },

   /* replace1251_0 -> 32 in the cache */
   /* replace1251 -> 3600 in the cache */

   /* ('bcsel', ('ige', ('ifind_msb', 'a'), 0), ('ifind_msb', 'a'), -1) => ('ifind_msb', 'a') */
   /* search1252_0_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ifind_msb,
      -1, 0,
      { 16 },
      -1,
   } },
   /* search1252_0_1 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 3603, 122 },
      -1,
   } },
   /* search1252_1_0 -> 16 in the cache */
   /* search1252_1 -> 3603 in the cache */
   /* search1252_2 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3604, 3603, 124 },
      -1,
   } },

   /* replace1252_0 -> 16 in the cache */
   /* replace1252 -> 3603 in the cache */

   /* ('bcsel', ('ige', ('ufind_msb', 'a'), 0), ('ufind_msb', 'a'), -1) => ('ufind_msb', 'a') */
   /* search1253_0_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ufind_msb,
      -1, 0,
      { 32 },
      -1,
   } },
   /* search1253_0_1 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 3606, 122 },
      -1,
   } },
   /* search1253_1_0 -> 32 in the cache */
   /* search1253_1 -> 3606 in the cache */
   /* search1253_2 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3607, 3606, 124 },
      -1,
   } },

   /* replace1253_0 -> 32 in the cache */
   /* replace1253 -> 3606 in the cache */

   /* ('bcsel', ('ige', ('ifind_msb_rev', 'a'), 0), ('ifind_msb_rev', 'a'), -1) => ('ifind_msb_rev', 'a') */
   /* search1254_0_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ifind_msb_rev,
      -1, 0,
      { 32 },
      -1,
   } },
   /* search1254_0_1 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 3609, 122 },
      -1,
   } },
   /* search1254_1_0 -> 32 in the cache */
   /* search1254_1 -> 3609 in the cache */
   /* search1254_2 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3610, 3609, 124 },
      -1,
   } },

   /* replace1254_0 -> 32 in the cache */
   /* replace1254 -> 3609 in the cache */

   /* ('bcsel', ('ige', ('ufind_msb_rev', 'a'), 0), ('ufind_msb_rev', 'a'), -1) => ('ufind_msb_rev', 'a') */
   /* search1255_0_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ufind_msb_rev,
      -1, 0,
      { 32 },
      -1,
   } },
   /* search1255_0_1 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 3612, 122 },
      -1,
   } },
   /* search1255_1_0 -> 32 in the cache */
   /* search1255_1 -> 3612 in the cache */
   /* search1255_2 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3613, 3612, 124 },
      -1,
   } },

   /* replace1255_0 -> 32 in the cache */
   /* replace1255 -> 3612 in the cache */

   /* ('bcsel', ('ine', 'a', 0), ('find_lsb', 'a'), -1) => ('find_lsb', 'a') */
   /* search1256_0_0 -> 32 in the cache */
   /* search1256_0_1 -> 61 in the cache */
   /* search1256_0 -> 1110 in the cache */
   /* search1256_1_0 -> 32 in the cache */
   /* search1256_1 -> 3600 in the cache */
   /* search1256_2 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 1110, 3600, 124 },
      -1,
   } },

   /* replace1256_0 -> 32 in the cache */
   /* replace1256 -> 3600 in the cache */

   /* ('bcsel', ('ine', 'a', 0), ('ifind_msb', 'a'), -1) => ('ifind_msb', 'a') */
   /* search1257_0_0 -> 16 in the cache */
   /* search1257_0_1 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 16, 122 },
      -1,
   } },
   /* search1257_1_0 -> 16 in the cache */
   /* search1257_1 -> 3603 in the cache */
   /* search1257_2 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 3616, 3603, 124 },
      -1,
   } },

   /* replace1257_0 -> 16 in the cache */
   /* replace1257 -> 3603 in the cache */

   /* ('bcsel', ('ine', 'a', 0), ('ufind_msb', 'a'), -1) => ('ufind_msb', 'a') */
   /* search1258_0_0 -> 32 in the cache */
   /* search1258_0_1 -> 61 in the cache */
   /* search1258_0 -> 1110 in the cache */
   /* search1258_1_0 -> 32 in the cache */
   /* search1258_1 -> 3606 in the cache */
   /* search1258_2 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 1110, 3606, 124 },
      -1,
   } },

   /* replace1258_0 -> 32 in the cache */
   /* replace1258 -> 3606 in the cache */

   /* ('bcsel', ('ine', 'a', 0), ('ifind_msb_rev', 'a'), -1) => ('ifind_msb_rev', 'a') */
   /* search1259_0_0 -> 32 in the cache */
   /* search1259_0_1 -> 61 in the cache */
   /* search1259_0 -> 1110 in the cache */
   /* search1259_1_0 -> 32 in the cache */
   /* search1259_1 -> 3609 in the cache */
   /* search1259_2 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 1110, 3609, 124 },
      -1,
   } },

   /* replace1259_0 -> 32 in the cache */
   /* replace1259 -> 3609 in the cache */

   /* ('bcsel', ('ine', 'a', 0), ('ufind_msb_rev', 'a'), -1) => ('ufind_msb_rev', 'a') */
   /* search1260_0_0 -> 32 in the cache */
   /* search1260_0_1 -> 61 in the cache */
   /* search1260_0 -> 1110 in the cache */
   /* search1260_1_0 -> 32 in the cache */
   /* search1260_1 -> 3612 in the cache */
   /* search1260_2 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 1110, 3612, 124 },
      -1,
   } },

   /* replace1260_0 -> 32 in the cache */
   /* replace1260 -> 3612 in the cache */

   /* ('bcsel', ('ine', 'a', -1), ('ifind_msb', 'a'), -1) => ('ifind_msb', 'a') */
   /* search1261_0_0 -> 16 in the cache */
   /* search1261_0_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 16, 124 },
      -1,
   } },
   /* search1261_1_0 -> 16 in the cache */
   /* search1261_1 -> 3603 in the cache */
   /* search1261_2 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 3621, 3603, 124 },
      -1,
   } },

   /* replace1261_0 -> 16 in the cache */
   /* replace1261 -> 3603 in the cache */

   /* ('bcsel', ('ine', 'a', -1), ('ifind_msb_rev', 'a'), -1) => ('ifind_msb_rev', 'a') */
   /* search1262_0_0 -> 32 in the cache */
   /* search1262_0_1 -> 63 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 32, 63 },
      -1,
   } },
   /* search1262_1_0 -> 32 in the cache */
   /* search1262_1 -> 3609 in the cache */
   /* search1262_2 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 3623, 3609, 124 },
      -1,
   } },

   /* replace1262_0 -> 32 in the cache */
   /* replace1262 -> 3609 in the cache */

   /* ('bcsel', ('ine', ('ifind_msb', 'a@32'), -1), ('iadd', 31, ('ineg', ('ifind_msb', 'a'))), -1) => ('ifind_msb_rev', 'a') */
   /* search1263_0_0_0 -> 16 in the cache */
   /* search1263_0_0 -> 3603 in the cache */
   /* search1263_0_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 3603, 124 },
      -1,
   } },
   /* search1263_1_0 -> 19 in the cache */
   /* search1263_1_1_0_0 -> 16 in the cache */
   /* search1263_1_1_0 -> 3603 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 3603 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 19, 3626 },
      -1,
   } },
   /* search1263_2 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 3625, 3627, 124 },
      -1,
   } },

   /* replace1263_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ifind_msb_rev,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('bcsel', ('ine', ('ufind_msb', 'a@32'), -1), ('iadd', 31, ('ineg', ('ufind_msb', 'a'))), -1) => ('ufind_msb_rev', 'a') */
   /* search1264_0_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ufind_msb,
      -1, 0,
      { 16 },
      -1,
   } },
   /* search1264_0_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 3630, 124 },
      -1,
   } },
   /* search1264_1_0 -> 19 in the cache */
   /* search1264_1_1_0_0 -> 16 in the cache */
   /* search1264_1_1_0 -> 3630 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 3630 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 19, 3632 },
      -1,
   } },
   /* search1264_2 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 3631, 3633, 124 },
      -1,
   } },

   /* replace1264_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ufind_msb_rev,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('bcsel', ('ieq', ('ifind_msb', 'a@32'), -1), -1, ('iadd', 31, ('ineg', ('ifind_msb', 'a')))) => ('ifind_msb_rev', 'a') */
   /* search1265_0_0_0 -> 16 in the cache */
   /* search1265_0_0 -> 3603 in the cache */
   /* search1265_0_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 3603, 124 },
      -1,
   } },
   /* search1265_1 -> 124 in the cache */
   /* search1265_2_0 -> 19 in the cache */
   /* search1265_2_1_0_0 -> 16 in the cache */
   /* search1265_2_1_0 -> 3603 in the cache */
   /* search1265_2_1 -> 3626 in the cache */
   /* search1265_2 -> 3627 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 3636, 124, 3627 },
      -1,
   } },

   /* replace1265_0 -> 16 in the cache */
   /* replace1265 -> 3629 in the cache */

   /* ('bcsel', ('ieq', ('ufind_msb', 'a@32'), -1), -1, ('iadd', 31, ('ineg', ('ufind_msb', 'a')))) => ('ufind_msb_rev', 'a') */
   /* search1266_0_0_0 -> 16 in the cache */
   /* search1266_0_0 -> 3630 in the cache */
   /* search1266_0_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 3630, 124 },
      -1,
   } },
   /* search1266_1 -> 124 in the cache */
   /* search1266_2_0 -> 19 in the cache */
   /* search1266_2_1_0_0 -> 16 in the cache */
   /* search1266_2_1_0 -> 3630 in the cache */
   /* search1266_2_1 -> 3632 in the cache */
   /* search1266_2 -> 3633 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 3638, 124, 3633 },
      -1,
   } },

   /* replace1266_0 -> 16 in the cache */
   /* replace1266 -> 3635 in the cache */

   /* ('bcsel', ('ine', ('ifind_msb', 'a@32'), -1), ('iadd', 31, ('ineg', ('ifind_msb', 'a'))), ('ifind_msb', 'a')) => ('ifind_msb_rev', 'a') */
   /* search1267_0_0_0 -> 16 in the cache */
   /* search1267_0_0 -> 3603 in the cache */
   /* search1267_0_1 -> 124 in the cache */
   /* search1267_0 -> 3625 in the cache */
   /* search1267_1_0 -> 19 in the cache */
   /* search1267_1_1_0_0 -> 16 in the cache */
   /* search1267_1_1_0 -> 3603 in the cache */
   /* search1267_1_1 -> 3626 in the cache */
   /* search1267_1 -> 3627 in the cache */
   /* search1267_2_0 -> 16 in the cache */
   /* search1267_2 -> 3603 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 3625, 3627, 3603 },
      -1,
   } },

   /* replace1267_0 -> 16 in the cache */
   /* replace1267 -> 3629 in the cache */

   /* ('bcsel', ('ine', ('ufind_msb', 'a@32'), -1), ('iadd', 31, ('ineg', ('ufind_msb', 'a'))), ('ufind_msb', 'a')) => ('ufind_msb_rev', 'a') */
   /* search1268_0_0_0 -> 16 in the cache */
   /* search1268_0_0 -> 3630 in the cache */
   /* search1268_0_1 -> 124 in the cache */
   /* search1268_0 -> 3631 in the cache */
   /* search1268_1_0 -> 19 in the cache */
   /* search1268_1_1_0_0 -> 16 in the cache */
   /* search1268_1_1_0 -> 3630 in the cache */
   /* search1268_1_1 -> 3632 in the cache */
   /* search1268_1 -> 3633 in the cache */
   /* search1268_2_0 -> 16 in the cache */
   /* search1268_2 -> 3630 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 3631, 3633, 3630 },
      -1,
   } },

   /* replace1268_0 -> 16 in the cache */
   /* replace1268 -> 3635 in the cache */

   /* ('bcsel', ('ieq', ('ifind_msb', 'a@32'), -1), ('ifind_msb', 'a'), ('iadd', 31, ('ineg', ('ifind_msb', 'a')))) => ('ifind_msb_rev', 'a') */
   /* search1269_0_0_0 -> 16 in the cache */
   /* search1269_0_0 -> 3603 in the cache */
   /* search1269_0_1 -> 124 in the cache */
   /* search1269_0 -> 3636 in the cache */
   /* search1269_1_0 -> 16 in the cache */
   /* search1269_1 -> 3603 in the cache */
   /* search1269_2_0 -> 19 in the cache */
   /* search1269_2_1_0_0 -> 16 in the cache */
   /* search1269_2_1_0 -> 3603 in the cache */
   /* search1269_2_1 -> 3626 in the cache */
   /* search1269_2 -> 3627 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 3636, 3603, 3627 },
      -1,
   } },

   /* replace1269_0 -> 16 in the cache */
   /* replace1269 -> 3629 in the cache */

   /* ('bcsel', ('ieq', ('ufind_msb', 'a@32'), -1), ('ufind_msb', 'a'), ('iadd', 31, ('ineg', ('ufind_msb', 'a')))) => ('ufind_msb_rev', 'a') */
   /* search1270_0_0_0 -> 16 in the cache */
   /* search1270_0_0 -> 3630 in the cache */
   /* search1270_0_1 -> 124 in the cache */
   /* search1270_0 -> 3638 in the cache */
   /* search1270_1_0 -> 16 in the cache */
   /* search1270_1 -> 3630 in the cache */
   /* search1270_2_0 -> 19 in the cache */
   /* search1270_2_1_0_0 -> 16 in the cache */
   /* search1270_2_1_0 -> 3630 in the cache */
   /* search1270_2_1 -> 3632 in the cache */
   /* search1270_2 -> 3633 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 3638, 3630, 3633 },
      -1,
   } },

   /* replace1270_0 -> 16 in the cache */
   /* replace1270 -> 3635 in the cache */

   /* ('bcsel', ('ine', 'a@32', 0), ('iadd', 31, ('ineg', ('ufind_msb', 'a'))), -1) => ('ufind_msb_rev', 'a') */
   /* search1271_0_0 -> 16 in the cache */
   /* search1271_0_1 -> 122 in the cache */
   /* search1271_0 -> 3616 in the cache */
   /* search1271_1_0 -> 19 in the cache */
   /* search1271_1_1_0_0 -> 16 in the cache */
   /* search1271_1_1_0 -> 3630 in the cache */
   /* search1271_1_1 -> 3632 in the cache */
   /* search1271_1 -> 3633 in the cache */
   /* search1271_2 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 3616, 3633, 124 },
      -1,
   } },

   /* replace1271_0 -> 16 in the cache */
   /* replace1271 -> 3635 in the cache */

   /* ('bcsel', ('ieq', 'a@32', 0), -1, ('iadd', 31, ('ineg', ('ufind_msb', 'a')))) => ('ufind_msb_rev', 'a') */
   /* search1272_0_0 -> 16 in the cache */
   /* search1272_0_1 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 16, 122 },
      -1,
   } },
   /* search1272_1 -> 124 in the cache */
   /* search1272_2_0 -> 19 in the cache */
   /* search1272_2_1_0_0 -> 16 in the cache */
   /* search1272_2_1_0 -> 3630 in the cache */
   /* search1272_2_1 -> 3632 in the cache */
   /* search1272_2 -> 3633 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 3645, 124, 3633 },
      -1,
   } },

   /* replace1272_0 -> 16 in the cache */
   /* replace1272 -> 3635 in the cache */

   /* ('bcsel', ('ine', 'a@32', 0), ('iadd', 31, ('ineg', ('ufind_msb', 'a'))), ('ufind_msb', 'a')) => ('ufind_msb_rev', 'a') */
   /* search1273_0_0 -> 16 in the cache */
   /* search1273_0_1 -> 122 in the cache */
   /* search1273_0 -> 3616 in the cache */
   /* search1273_1_0 -> 19 in the cache */
   /* search1273_1_1_0_0 -> 16 in the cache */
   /* search1273_1_1_0 -> 3630 in the cache */
   /* search1273_1_1 -> 3632 in the cache */
   /* search1273_1 -> 3633 in the cache */
   /* search1273_2_0 -> 16 in the cache */
   /* search1273_2 -> 3630 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 3616, 3633, 3630 },
      -1,
   } },

   /* replace1273_0 -> 16 in the cache */
   /* replace1273 -> 3635 in the cache */

   /* ('bcsel', ('ieq', 'a@32', 0), ('ufind_msb', 'a'), ('iadd', 31, ('ineg', ('ufind_msb', 'a')))) => ('ufind_msb_rev', 'a') */
   /* search1274_0_0 -> 16 in the cache */
   /* search1274_0_1 -> 122 in the cache */
   /* search1274_0 -> 3645 in the cache */
   /* search1274_1_0 -> 16 in the cache */
   /* search1274_1 -> 3630 in the cache */
   /* search1274_2_0 -> 19 in the cache */
   /* search1274_2_1_0_0 -> 16 in the cache */
   /* search1274_2_1_0 -> 3630 in the cache */
   /* search1274_2_1 -> 3632 in the cache */
   /* search1274_2 -> 3633 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 3645, 3630, 3633 },
      -1,
   } },

   /* replace1274_0 -> 16 in the cache */
   /* replace1274 -> 3635 in the cache */

   /* ('bcsel', ('ine', ('ifind_msb_rev', 'a@32'), -1), ('iadd', 31, ('ineg', ('ifind_msb_rev', 'a'))), -1) => ('ifind_msb', 'a') */
   /* search1275_0_0_0 -> 16 in the cache */
   /* search1275_0_0 -> 3629 in the cache */
   /* search1275_0_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 3629, 124 },
      -1,
   } },
   /* search1275_1_0 -> 19 in the cache */
   /* search1275_1_1_0_0 -> 16 in the cache */
   /* search1275_1_1_0 -> 3629 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 3629 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 19, 3650 },
      -1,
   } },
   /* search1275_2 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 3649, 3651, 124 },
      -1,
   } },

   /* replace1275_0 -> 16 in the cache */
   /* replace1275 -> 3603 in the cache */

   /* ('bcsel', ('ine', ('ufind_msb_rev', 'a@32'), -1), ('iadd', 31, ('ineg', ('ufind_msb_rev', 'a'))), -1) => ('ufind_msb', 'a') */
   /* search1276_0_0_0 -> 16 in the cache */
   /* search1276_0_0 -> 3635 in the cache */
   /* search1276_0_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 3635, 124 },
      -1,
   } },
   /* search1276_1_0 -> 19 in the cache */
   /* search1276_1_1_0_0 -> 16 in the cache */
   /* search1276_1_1_0 -> 3635 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 3635 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 19, 3654 },
      -1,
   } },
   /* search1276_2 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 3653, 3655, 124 },
      -1,
   } },

   /* replace1276_0 -> 16 in the cache */
   /* replace1276 -> 3630 in the cache */

   /* ('bcsel', ('ieq', ('ifind_msb_rev', 'a@32'), -1), -1, ('iadd', 31, ('ineg', ('ifind_msb_rev', 'a')))) => ('ifind_msb', 'a') */
   /* search1277_0_0_0 -> 16 in the cache */
   /* search1277_0_0 -> 3629 in the cache */
   /* search1277_0_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 3629, 124 },
      -1,
   } },
   /* search1277_1 -> 124 in the cache */
   /* search1277_2_0 -> 19 in the cache */
   /* search1277_2_1_0_0 -> 16 in the cache */
   /* search1277_2_1_0 -> 3629 in the cache */
   /* search1277_2_1 -> 3650 in the cache */
   /* search1277_2 -> 3651 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 3657, 124, 3651 },
      -1,
   } },

   /* replace1277_0 -> 16 in the cache */
   /* replace1277 -> 3603 in the cache */

   /* ('bcsel', ('ieq', ('ufind_msb_rev', 'a@32'), -1), -1, ('iadd', 31, ('ineg', ('ufind_msb_rev', 'a')))) => ('ufind_msb', 'a') */
   /* search1278_0_0_0 -> 16 in the cache */
   /* search1278_0_0 -> 3635 in the cache */
   /* search1278_0_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 3635, 124 },
      -1,
   } },
   /* search1278_1 -> 124 in the cache */
   /* search1278_2_0 -> 19 in the cache */
   /* search1278_2_1_0_0 -> 16 in the cache */
   /* search1278_2_1_0 -> 3635 in the cache */
   /* search1278_2_1 -> 3654 in the cache */
   /* search1278_2 -> 3655 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 3659, 124, 3655 },
      -1,
   } },

   /* replace1278_0 -> 16 in the cache */
   /* replace1278 -> 3630 in the cache */

   /* ('bcsel', ('ine', ('ifind_msb_rev', 'a@32'), -1), ('iadd', 31, ('ineg', ('ifind_msb_rev', 'a'))), ('ifind_msb_rev', 'a')) => ('ifind_msb', 'a') */
   /* search1279_0_0_0 -> 16 in the cache */
   /* search1279_0_0 -> 3629 in the cache */
   /* search1279_0_1 -> 124 in the cache */
   /* search1279_0 -> 3649 in the cache */
   /* search1279_1_0 -> 19 in the cache */
   /* search1279_1_1_0_0 -> 16 in the cache */
   /* search1279_1_1_0 -> 3629 in the cache */
   /* search1279_1_1 -> 3650 in the cache */
   /* search1279_1 -> 3651 in the cache */
   /* search1279_2_0 -> 16 in the cache */
   /* search1279_2 -> 3629 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 3649, 3651, 3629 },
      -1,
   } },

   /* replace1279_0 -> 16 in the cache */
   /* replace1279 -> 3603 in the cache */

   /* ('bcsel', ('ine', ('ufind_msb_rev', 'a@32'), -1), ('iadd', 31, ('ineg', ('ufind_msb_rev', 'a'))), ('ufind_msb_rev', 'a')) => ('ufind_msb', 'a') */
   /* search1280_0_0_0 -> 16 in the cache */
   /* search1280_0_0 -> 3635 in the cache */
   /* search1280_0_1 -> 124 in the cache */
   /* search1280_0 -> 3653 in the cache */
   /* search1280_1_0 -> 19 in the cache */
   /* search1280_1_1_0_0 -> 16 in the cache */
   /* search1280_1_1_0 -> 3635 in the cache */
   /* search1280_1_1 -> 3654 in the cache */
   /* search1280_1 -> 3655 in the cache */
   /* search1280_2_0 -> 16 in the cache */
   /* search1280_2 -> 3635 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 3653, 3655, 3635 },
      -1,
   } },

   /* replace1280_0 -> 16 in the cache */
   /* replace1280 -> 3630 in the cache */

   /* ('bcsel', ('ieq', ('ifind_msb_rev', 'a@32'), -1), ('ifind_msb_rev', 'a'), ('iadd', 31, ('ineg', ('ifind_msb_rev', 'a')))) => ('ifind_msb', 'a') */
   /* search1281_0_0_0 -> 16 in the cache */
   /* search1281_0_0 -> 3629 in the cache */
   /* search1281_0_1 -> 124 in the cache */
   /* search1281_0 -> 3657 in the cache */
   /* search1281_1_0 -> 16 in the cache */
   /* search1281_1 -> 3629 in the cache */
   /* search1281_2_0 -> 19 in the cache */
   /* search1281_2_1_0_0 -> 16 in the cache */
   /* search1281_2_1_0 -> 3629 in the cache */
   /* search1281_2_1 -> 3650 in the cache */
   /* search1281_2 -> 3651 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 3657, 3629, 3651 },
      -1,
   } },

   /* replace1281_0 -> 16 in the cache */
   /* replace1281 -> 3603 in the cache */

   /* ('bcsel', ('ieq', ('ufind_msb_rev', 'a@32'), -1), ('ufind_msb_rev', 'a'), ('iadd', 31, ('ineg', ('ufind_msb_rev', 'a')))) => ('ufind_msb', 'a') */
   /* search1282_0_0_0 -> 16 in the cache */
   /* search1282_0_0 -> 3635 in the cache */
   /* search1282_0_1 -> 124 in the cache */
   /* search1282_0 -> 3659 in the cache */
   /* search1282_1_0 -> 16 in the cache */
   /* search1282_1 -> 3635 in the cache */
   /* search1282_2_0 -> 19 in the cache */
   /* search1282_2_1_0_0 -> 16 in the cache */
   /* search1282_2_1_0 -> 3635 in the cache */
   /* search1282_2_1 -> 3654 in the cache */
   /* search1282_2 -> 3655 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 3659, 3635, 3655 },
      -1,
   } },

   /* replace1282_0 -> 16 in the cache */
   /* replace1282 -> 3630 in the cache */

   /* ('bcsel', ('ine', 'a@32', 0), ('iadd', 31, ('ineg', ('ufind_msb_rev', 'a'))), -1) => ('ufind_msb', 'a') */
   /* search1283_0_0 -> 16 in the cache */
   /* search1283_0_1 -> 122 in the cache */
   /* search1283_0 -> 3616 in the cache */
   /* search1283_1_0 -> 19 in the cache */
   /* search1283_1_1_0_0 -> 16 in the cache */
   /* search1283_1_1_0 -> 3635 in the cache */
   /* search1283_1_1 -> 3654 in the cache */
   /* search1283_1 -> 3655 in the cache */
   /* search1283_2 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 3616, 3655, 124 },
      -1,
   } },

   /* replace1283_0 -> 16 in the cache */
   /* replace1283 -> 3630 in the cache */

   /* ('bcsel', ('ieq', 'a@32', 0), -1, ('iadd', 31, ('ineg', ('ufind_msb_rev', 'a')))) => ('ufind_msb', 'a') */
   /* search1284_0_0 -> 16 in the cache */
   /* search1284_0_1 -> 122 in the cache */
   /* search1284_0 -> 3645 in the cache */
   /* search1284_1 -> 124 in the cache */
   /* search1284_2_0 -> 19 in the cache */
   /* search1284_2_1_0_0 -> 16 in the cache */
   /* search1284_2_1_0 -> 3635 in the cache */
   /* search1284_2_1 -> 3654 in the cache */
   /* search1284_2 -> 3655 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 3645, 124, 3655 },
      -1,
   } },

   /* replace1284_0 -> 16 in the cache */
   /* replace1284 -> 3630 in the cache */

   /* ('bcsel', ('ine', 'a@32', 0), ('iadd', 31, ('ineg', ('ufind_msb_rev', 'a'))), ('ufind_msb_rev', 'a')) => ('ufind_msb', 'a') */
   /* search1285_0_0 -> 16 in the cache */
   /* search1285_0_1 -> 122 in the cache */
   /* search1285_0 -> 3616 in the cache */
   /* search1285_1_0 -> 19 in the cache */
   /* search1285_1_1_0_0 -> 16 in the cache */
   /* search1285_1_1_0 -> 3635 in the cache */
   /* search1285_1_1 -> 3654 in the cache */
   /* search1285_1 -> 3655 in the cache */
   /* search1285_2_0 -> 16 in the cache */
   /* search1285_2 -> 3635 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 3616, 3655, 3635 },
      -1,
   } },

   /* replace1285_0 -> 16 in the cache */
   /* replace1285 -> 3630 in the cache */

   /* ('bcsel', ('ieq', 'a@32', 0), ('ufind_msb_rev', 'a'), ('iadd', 31, ('ineg', ('ufind_msb_rev', 'a')))) => ('ufind_msb', 'a') */
   /* search1286_0_0 -> 16 in the cache */
   /* search1286_0_1 -> 122 in the cache */
   /* search1286_0 -> 3645 in the cache */
   /* search1286_1_0 -> 16 in the cache */
   /* search1286_1 -> 3635 in the cache */
   /* search1286_2_0 -> 19 in the cache */
   /* search1286_2_1_0_0 -> 16 in the cache */
   /* search1286_2_1_0 -> 3635 in the cache */
   /* search1286_2_1 -> 3654 in the cache */
   /* search1286_2 -> 3655 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 3645, 3635, 3655 },
      -1,
   } },

   /* replace1286_0 -> 16 in the cache */
   /* replace1286 -> 3630 in the cache */

   /* ('find_lsb', ('bitfield_reverse', 'a')) => ('ufind_msb_rev', 'a') */
   /* search1287_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bitfield_reverse,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_find_lsb,
      -1, 0,
      { 3669 },
      -1,
   } },

   /* replace1287_0 -> 16 in the cache */
   /* replace1287 -> 3635 in the cache */

   /* ('ufind_msb_rev', ('bitfield_reverse', 'a')) => ('find_lsb', 'a') */
   /* search1288_0_0 -> 16 in the cache */
   /* search1288_0 -> 3669 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ufind_msb_rev,
      -1, 0,
      { 3669 },
      -1,
   } },

   /* replace1288_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_find_lsb,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('~fmul', ('bcsel(is_used_once)', 'c', -1.0, 1.0), 'b') => ('bcsel', 'c', ('fneg', 'b'), 'b') */
   /* search1289_0_0 -> 521 in the cache */
   /* search1289_0_1 -> 275 in the cache */
   /* search1289_0_2 -> 270 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 521, 275, 270 },
      0,
   } },
   /* search1289_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 3673, 3 },
      -1,
   } },

   /* replace1289_0 -> 521 in the cache */
   /* replace1289_1_0 -> 3 in the cache */
   /* replace1289_1 -> 1087 in the cache */
   /* replace1289_2 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 521, 1087, 3 },
      -1,
   } },

   /* ('~fmul', ('bcsel(is_used_once)', 'c', 1.0, -1.0), 'b') => ('bcsel', 'c', 'b', ('fneg', 'b')) */
   /* search1290_0_0 -> 521 in the cache */
   /* search1290_0_1 -> 270 in the cache */
   /* search1290_0_2 -> 275 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 521, 270, 275 },
      0,
   } },
   /* search1290_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 3676, 3 },
      -1,
   } },

   /* replace1290_0 -> 521 in the cache */
   /* replace1290_1 -> 3 in the cache */
   /* replace1290_2_0 -> 3 in the cache */
   /* replace1290_2 -> 1087 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 521, 3, 1087 },
      -1,
   } },

   /* ('~fmulz', ('bcsel(is_used_once)', 'c', -1.0, 1.0), 'b') => ('bcsel', 'c', ('fneg', 'b'), 'b') */
   /* search1291_0_0 -> 521 in the cache */
   /* search1291_0_1 -> 278 in the cache */
   /* search1291_0_2 -> 243 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 521, 278, 243 },
      0,
   } },
   /* search1291_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 3679, 36 },
      -1,
   } },

   /* replace1291_0 -> 521 in the cache */
   /* replace1291_1_0 -> 36 in the cache */
   /* replace1291_1 -> 600 in the cache */
   /* replace1291_2 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 521, 600, 36 },
      -1,
   } },

   /* ('~fmulz', ('bcsel(is_used_once)', 'c', 1.0, -1.0), 'b') => ('bcsel', 'c', 'b', ('fneg', 'b')) */
   /* search1292_0_0 -> 521 in the cache */
   /* search1292_0_1 -> 243 in the cache */
   /* search1292_0_2 -> 278 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 521, 243, 278 },
      0,
   } },
   /* search1292_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 3682, 36 },
      -1,
   } },

   /* replace1292_0 -> 521 in the cache */
   /* replace1292_1 -> 36 in the cache */
   /* replace1292_2_0 -> 36 in the cache */
   /* replace1292_2 -> 600 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 521, 36, 600 },
      -1,
   } },

   /* ('fabs', ('bcsel(is_used_once)', 'b', ('fneg', 'a'), 'a')) => ('fabs', 'a') */
   { .variable = {
      { nir_search_value_variable, 1 },
      0, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search1293_0_1_0 -> 1114 in the cache */
   /* search1293_0_1 -> 1577 in the cache */
   /* search1293_0_2 -> 1114 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3685, 1577, 1114 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 3686 },
      -1,
   } },

   /* replace1293_0 -> 1114 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 1114 },
      -1,
   } },

   /* ('fabs', ('bcsel(is_used_once)', 'b', 'a', ('fneg', 'a'))) => ('fabs', 'a') */
   /* search1294_0_0 -> 3685 in the cache */
   /* search1294_0_1 -> 1114 in the cache */
   /* search1294_0_2_0 -> 1114 in the cache */
   /* search1294_0_2 -> 1577 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3685, 1114, 1577 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 3689 },
      -1,
   } },

   /* replace1294_0 -> 1114 in the cache */
   /* replace1294 -> 3688 in the cache */

   /* ('~bcsel', ('flt', 'a', 0.0), ('fneg', 'a'), 'a') => ('fabs', 'a') */
   /* search1295_0_0 -> 32 in the cache */
   /* search1295_0_1 -> 111 in the cache */
   /* search1295_0 -> 1172 in the cache */
   /* search1295_1_0 -> 32 in the cache */
   /* search1295_1 -> 98 in the cache */
   /* search1295_2 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1172, 98, 32 },
      -1,
   } },

   /* replace1295_0 -> 32 in the cache */
   /* replace1295 -> 103 in the cache */

   /* ('bcsel', 'a', ('bcsel', 'b', 'c', 'd'), 'd') => ('bcsel', ('iand', 'a', 'b'), 'c', 'd') */
   /* search1296_0 -> 760 in the cache */
   /* search1296_1_0 -> 1134 in the cache */
   /* search1296_1_1 -> 152 in the cache */
   /* search1296_1_2 -> 153 in the cache */
   /* search1296_1 -> 1322 in the cache */
   /* search1296_2 -> 153 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 760, 1322, 153 },
      -1,
   } },

   /* replace1296_0_0 -> 760 in the cache */
   /* replace1296_0_1 -> 1134 in the cache */
   /* replace1296_0 -> 1146 in the cache */
   /* replace1296_1 -> 152 in the cache */
   /* replace1296_2 -> 153 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 1146, 152, 153 },
      -1,
   } },

   /* ('bcsel', 'a', 'b', ('bcsel', 'c', 'b', 'd')) => ('bcsel', ('ior', 'a', 'c'), 'b', 'd') */
   /* search1297_0 -> 760 in the cache */
   /* search1297_1 -> 150 in the cache */
   /* search1297_2_0 -> 464 in the cache */
   /* search1297_2_1 -> 150 in the cache */
   /* search1297_2_2 -> 153 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 464, 150, 153 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 760, 150, 3694 },
      -1,
   } },

   /* replace1297_0_0 -> 760 in the cache */
   /* replace1297_0_1 -> 464 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 760, 464 },
      -1,
   } },
   /* replace1297_1 -> 150 in the cache */
   /* replace1297_2 -> 153 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 3696, 150, 153 },
      -1,
   } },

   /* ('fmod', 'a', 'b') => ('fsub', 'a', ('fmul', 'b', ('ffloor', ('fdiv', 'a', 'b')))) */
   /* search1298_0 -> 0 in the cache */
   /* search1298_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmod,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* replace1298_0 -> 0 in the cache */
   /* replace1298_1_0 -> 3 in the cache */
   /* replace1298_1_1_0_0 -> 0 in the cache */
   /* replace1298_1_1_0_1 -> 3 in the cache */
   /* replace1298_1_1_0 -> 2896 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ffloor,
      -1, 0,
      { 2896 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 3, 3699 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 1,
      { 0, 3700 },
      -1,
   } },

   /* ('frem', 'a', 'b') => ('fsub', 'a', ('fmul', 'b', ('ftrunc', ('fdiv', 'a', 'b')))) */
   /* search1299_0 -> 0 in the cache */
   /* search1299_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_frem,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* replace1299_0 -> 0 in the cache */
   /* replace1299_1_0 -> 3 in the cache */
   /* replace1299_1_1_0_0 -> 0 in the cache */
   /* replace1299_1_1_0_1 -> 3 in the cache */
   /* replace1299_1_1_0 -> 2896 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ftrunc,
      -1, 0,
      { 2896 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 3, 3703 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 1,
      { 0, 3704 },
      -1,
   } },

   /* ('uadd_carry', 'a', 'b') => ('b2i', ('ult', ('iadd', 'a', 'b'), 'a')) */
   /* search1300_0 -> 0 in the cache */
   /* search1300_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_uadd_carry,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace1300_0_0_0 -> 0 in the cache */
   /* replace1300_0_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 0, 3 },
      -1,
   } },
   /* replace1300_0_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 1,
      { 3707, 0 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_search_op_b2i,
      -1, 1,
      { 3708 },
      -1,
   } },

   /* ('usub_borrow', 'a', 'b') => ('b2i', ('ult', 'a', 'b')) */
   /* search1301_0 -> 0 in the cache */
   /* search1301_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_usub_borrow,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* replace1301_0_0 -> 0 in the cache */
   /* replace1301_0_1 -> 3 in the cache */
   /* replace1301_0 -> 1067 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_search_op_b2i,
      -1, 0,
      { 1067 },
      -1,
   } },

   /* ('bitfield_insert', 'base', 'insert', 'offset', 'bits') => ('bcsel', ('ult', 31, 'bits'), 'insert', ('bfi', ('bfm', 'bits', 'offset'), 'insert', 'base')) */
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* base */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* insert */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      2, /* offset */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      3, /* bits */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bitfield_insert,
      -1, 0,
      { 3712, 3713, 3714, 3715 },
      -1,
   } },

   /* replace1302_0_0 -> 19 in the cache */
   /* replace1302_0_1 -> 3715 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 19, 3715 },
      -1,
   } },
   /* replace1302_1 -> 3713 in the cache */
   /* replace1302_2_0_0 -> 3715 in the cache */
   /* replace1302_2_0_1 -> 3714 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bfm,
      -1, 0,
      { 3715, 3714 },
      -1,
   } },
   /* replace1302_2_1 -> 3713 in the cache */
   /* replace1302_2_2 -> 3712 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bfi,
      -1, 0,
      { 3718, 3713, 3712 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3717, 3713, 3719 },
      -1,
   } },

   /* ('ihadd', 'a', 'b') => ('iadd', ('iand', 'a', 'b'), ('ishr', ('ixor', 'a', 'b'), 1)) */
   /* search1303_0 -> 0 in the cache */
   /* search1303_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ihadd,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace1303_0_0 -> 0 in the cache */
   /* replace1303_0_1 -> 3 in the cache */
   /* replace1303_0 -> 201 in the cache */
   /* replace1303_1_0_0 -> 0 in the cache */
   /* replace1303_1_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ixor,
      2, 1,
      { 0, 3 },
      -1,
   } },
   /* replace1303_1_1 -> 396 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 1,
      { 3722, 396 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 3,
      { 201, 3723 },
      -1,
   } },

   /* ('uhadd', 'a', 'b') => ('iadd', ('iand', 'a', 'b'), ('ushr', ('ixor', 'a', 'b'), 1)) */
   /* search1304_0 -> 0 in the cache */
   /* search1304_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_uhadd,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace1304_0_0 -> 0 in the cache */
   /* replace1304_0_1 -> 3 in the cache */
   /* replace1304_0 -> 201 in the cache */
   /* replace1304_1_0_0 -> 0 in the cache */
   /* replace1304_1_0_1 -> 3 in the cache */
   /* replace1304_1_0 -> 3722 in the cache */
   /* replace1304_1_1 -> 396 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 3722, 396 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 3,
      { 201, 3726 },
      -1,
   } },

   /* ('irhadd', 'a', 'b') => ('isub', ('ior', 'a', 'b'), ('ishr', ('ixor', 'a', 'b'), 1)) */
   /* search1305_0 -> 0 in the cache */
   /* search1305_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_irhadd,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace1305_0_0 -> 0 in the cache */
   /* replace1305_0_1 -> 3 in the cache */
   /* replace1305_0 -> 2354 in the cache */
   /* replace1305_1_0_0 -> 0 in the cache */
   /* replace1305_1_0_1 -> 3 in the cache */
   /* replace1305_1_0 -> 2727 in the cache */
   /* replace1305_1_1 -> 396 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 1,
      { 2727, 396 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 2,
      { 2354, 3729 },
      -1,
   } },

   /* ('urhadd', 'a', 'b') => ('isub', ('ior', 'a', 'b'), ('ushr', ('ixor', 'a', 'b'), 1)) */
   /* search1306_0 -> 0 in the cache */
   /* search1306_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_urhadd,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace1306_0_0 -> 0 in the cache */
   /* replace1306_0_1 -> 3 in the cache */
   /* replace1306_0 -> 2354 in the cache */
   /* replace1306_1_0_0 -> 0 in the cache */
   /* replace1306_1_0_1 -> 3 in the cache */
   /* replace1306_1_0 -> 2727 in the cache */
   /* replace1306_1_1 -> 396 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 2727, 396 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 2,
      { 2354, 3732 },
      -1,
   } },

   /* ('ihadd@64', 'a', 'b') => ('iadd', ('iand', 'a', 'b'), ('ishr', ('ixor', 'a', 'b'), 1)) */
   /* search1307_0 -> 21 in the cache */
   /* search1307_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ihadd,
      0, 1,
      { 21, 41 },
      -1,
   } },

   /* replace1307_0_0 -> 21 in the cache */
   /* replace1307_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 21, 41 },
      -1,
   } },
   /* replace1307_1_0_0 -> 21 in the cache */
   /* replace1307_1_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ixor,
      2, 1,
      { 21, 41 },
      -1,
   } },
   /* replace1307_1_1 -> 396 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 1,
      { 3736, 396 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 3,
      { 3735, 3737 },
      -1,
   } },

   /* ('uhadd@64', 'a', 'b') => ('iadd', ('iand', 'a', 'b'), ('ushr', ('ixor', 'a', 'b'), 1)) */
   /* search1308_0 -> 21 in the cache */
   /* search1308_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_uhadd,
      0, 1,
      { 21, 41 },
      -1,
   } },

   /* replace1308_0_0 -> 21 in the cache */
   /* replace1308_0_1 -> 41 in the cache */
   /* replace1308_0 -> 3735 in the cache */
   /* replace1308_1_0_0 -> 21 in the cache */
   /* replace1308_1_0_1 -> 41 in the cache */
   /* replace1308_1_0 -> 3736 in the cache */
   /* replace1308_1_1 -> 396 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 3736, 396 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 3,
      { 3735, 3740 },
      -1,
   } },

   /* ('irhadd@64', 'a', 'b') => ('isub', ('ior', 'a', 'b'), ('ishr', ('ixor', 'a', 'b'), 1)) */
   /* search1309_0 -> 21 in the cache */
   /* search1309_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_irhadd,
      0, 1,
      { 21, 41 },
      -1,
   } },

   /* replace1309_0_0 -> 21 in the cache */
   /* replace1309_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 21, 41 },
      -1,
   } },
   /* replace1309_1_0_0 -> 21 in the cache */
   /* replace1309_1_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ixor,
      1, 1,
      { 21, 41 },
      -1,
   } },
   /* replace1309_1_1 -> 396 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 1,
      { 3744, 396 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 2,
      { 3743, 3745 },
      -1,
   } },

   /* ('urhadd@64', 'a', 'b') => ('isub', ('ior', 'a', 'b'), ('ushr', ('ixor', 'a', 'b'), 1)) */
   /* search1310_0 -> 21 in the cache */
   /* search1310_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_urhadd,
      0, 1,
      { 21, 41 },
      -1,
   } },

   /* replace1310_0_0 -> 21 in the cache */
   /* replace1310_0_1 -> 41 in the cache */
   /* replace1310_0 -> 3743 in the cache */
   /* replace1310_1_0_0 -> 21 in the cache */
   /* replace1310_1_0_1 -> 41 in the cache */
   /* replace1310_1_0 -> 3744 in the cache */
   /* replace1310_1_1 -> 396 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 3744, 396 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 2,
      { 3743, 3748 },
      -1,
   } },

   /* ('imul_32x16', 'a', 'b') => ('imul', 'a', ('extract_i16', 'b', 0)) */
   /* search1311_0 -> 16 in the cache */
   /* search1311_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul_32x16,
      -1, 0,
      { 16, 36 },
      -1,
   } },

   /* replace1311_0 -> 16 in the cache */
   /* replace1311_1_0 -> 36 in the cache */
   /* replace1311_1_1 -> 122 in the cache */
   /* replace1311_1 -> 437 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 16, 437 },
      -1,
   } },

   /* ('umul_32x16', 'a', 'b') => ('imul', 'a', ('extract_u16', 'b', 0)) */
   /* search1312_0 -> 16 in the cache */
   /* search1312_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_umul_32x16,
      -1, 0,
      { 16, 36 },
      -1,
   } },

   /* replace1312_0 -> 16 in the cache */
   /* replace1312_1_0 -> 36 in the cache */
   /* replace1312_1_1 -> 122 in the cache */
   /* replace1312_1 -> 445 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 16, 445 },
      -1,
   } },

   /* ('uadd_sat@64', 'a', 'b') => ('bcsel', ('ult', ('iadd', 'a', 'b'), 'a'), -1, ('iadd', 'a', 'b')) */
   /* search1313_0 -> 21 in the cache */
   /* search1313_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_uadd_sat,
      0, 1,
      { 21, 41 },
      -1,
   } },

   /* replace1313_0_0_0 -> 21 in the cache */
   /* replace1313_0_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 21, 41 },
      -1,
   } },
   /* replace1313_0_1 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 1,
      { 3755, 21 },
      -1,
   } },
   /* replace1313_1 -> 1499 in the cache */
   /* replace1313_2_0 -> 21 in the cache */
   /* replace1313_2_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 21, 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 3756, 1499, 3757 },
      -1,
   } },

   /* ('uadd_sat', 'a', 'b') => ('bcsel', ('ult', ('iadd', 'a', 'b'), 'a'), -1, ('iadd', 'a', 'b')) */
   /* search1314_0 -> 0 in the cache */
   /* search1314_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_uadd_sat,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace1314_0_0_0 -> 0 in the cache */
   /* replace1314_0_0_1 -> 3 in the cache */
   /* replace1314_0_0 -> 3707 in the cache */
   /* replace1314_0_1 -> 0 in the cache */
   /* replace1314_0 -> 3708 in the cache */
   { .constant = {
      { nir_search_value_constant, -2 },
      nir_type_int, { -0x1 /* -1 */ },
   } },
   /* replace1314_2_0 -> 0 in the cache */
   /* replace1314_2_1 -> 3 in the cache */
   /* replace1314_2 -> 208 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 3708, 3760, 208 },
      -1,
   } },

   /* ('usub_sat', 'a', 'b') => ('bcsel', ('ult', 'a', 'b'), 0, ('isub', 'a', 'b')) */
   /* search1315_0 -> 0 in the cache */
   /* search1315_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_usub_sat,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* replace1315_0_0 -> 0 in the cache */
   /* replace1315_0_1 -> 3 in the cache */
   /* replace1315_0 -> 1067 in the cache */
   /* replace1315_1 -> 86 in the cache */
   /* replace1315_2_0 -> 0 in the cache */
   /* replace1315_2_1 -> 3 in the cache */
   /* replace1315_2 -> 3477 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1067, 86, 3477 },
      -1,
   } },

   /* ('usub_sat@64', 'a', 'b') => ('bcsel', ('ult', 'a', 'b'), 0, ('isub', 'a', 'b')) */
   /* search1316_0 -> 21 in the cache */
   /* search1316_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_usub_sat,
      -1, 0,
      { 21, 41 },
      -1,
   } },

   /* replace1316_0_0 -> 21 in the cache */
   /* replace1316_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 21, 41 },
      -1,
   } },
   /* replace1316_1 -> 897 in the cache */
   /* replace1316_2_0 -> 21 in the cache */
   /* replace1316_2_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 21, 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3765, 897, 3766 },
      -1,
   } },

   /* ('iadd_sat@64', 'a', 'b') => ('bcsel', ('iand', ('iand', ('ilt', 'a', 0), ('ilt', 'b', 0)), ('ige', ('iadd', 'a', 'b'), 0)), 9223372036854775808, ('bcsel', ('ior', ('ior', ('ilt', 'a', 0), ('ilt', 'b', 0)), ('ige', ('iadd', 'a', 'b'), 0)), ('iadd', 'a', 'b'), 9223372036854775807)) */
   /* search1317_0 -> 21 in the cache */
   /* search1317_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_iadd_sat,
      0, 1,
      { 21, 41 },
      -1,
   } },

   /* replace1317_0_0_0_0 -> 21 in the cache */
   /* replace1317_0_0_0_1 -> 897 in the cache */
   /* replace1317_0_0_0 -> 1489 in the cache */
   /* replace1317_0_0_1_0 -> 41 in the cache */
   /* replace1317_0_0_1_1 -> 897 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 41, 897 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 1489, 3769 },
      -1,
   } },
   /* replace1317_0_1_0_0 -> 21 in the cache */
   /* replace1317_0_1_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_iadd,
      2, 1,
      { 21, 41 },
      -1,
   } },
   /* replace1317_0_1_1 -> 897 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 1,
      { 3771, 897 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 3770, 3772 },
      -1,
   } },
   /* replace1317_1 -> 22 in the cache */
   /* replace1317_2_0_0_0_0 -> 21 in the cache */
   /* replace1317_2_0_0_0_1 -> 897 in the cache */
   /* replace1317_2_0_0_0 -> 1489 in the cache */
   /* replace1317_2_0_0_1_0 -> 41 in the cache */
   /* replace1317_2_0_0_1_1 -> 897 in the cache */
   /* replace1317_2_0_0_1 -> 3769 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      4, 1,
      { 1489, 3769 },
      -1,
   } },
   /* replace1317_2_0_1_0_0 -> 21 in the cache */
   /* replace1317_2_0_1_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_iadd,
      5, 1,
      { 21, 41 },
      -1,
   } },
   /* replace1317_2_0_1_1 -> 897 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 1,
      { 3775, 897 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      3, 3,
      { 3774, 3776 },
      -1,
   } },
   /* replace1317_2_1_0 -> 21 in the cache */
   /* replace1317_2_1_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_iadd,
      6, 1,
      { 21, 41 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0x7fffffffffffffff /* 9223372036854775807 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 4,
      { 3777, 3778, 3779 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 7,
      { 3773, 22, 3780 },
      -1,
   } },

   /* ('isub_sat@64', 'a', 'b') => ('bcsel', ('iand', ('iand', ('ilt', 'a', 0), ('ige', 'b', 0)), ('ige', ('isub', 'a', 'b'), 0)), 9223372036854775808, ('bcsel', ('ior', ('ior', ('ilt', 'a', 0), ('ige', 'b', 0)), ('ige', ('isub', 'a', 'b'), 0)), ('isub', 'a', 'b'), 9223372036854775807)) */
   /* search1318_0 -> 21 in the cache */
   /* search1318_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_isub_sat,
      -1, 0,
      { 21, 41 },
      -1,
   } },

   /* replace1318_0_0_0_0 -> 21 in the cache */
   /* replace1318_0_0_0_1 -> 897 in the cache */
   /* replace1318_0_0_0 -> 1489 in the cache */
   /* replace1318_0_0_1_0 -> 41 in the cache */
   /* replace1318_0_0_1_1 -> 897 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 41, 897 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 1489, 3783 },
      -1,
   } },
   /* replace1318_0_1_0_0 -> 21 in the cache */
   /* replace1318_0_1_0_1 -> 41 in the cache */
   /* replace1318_0_1_0 -> 3766 in the cache */
   /* replace1318_0_1_1 -> 897 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 3766, 897 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 3784, 3785 },
      -1,
   } },
   /* replace1318_1 -> 22 in the cache */
   /* replace1318_2_0_0_0_0 -> 21 in the cache */
   /* replace1318_2_0_0_0_1 -> 897 in the cache */
   /* replace1318_2_0_0_0 -> 1489 in the cache */
   /* replace1318_2_0_0_1_0 -> 41 in the cache */
   /* replace1318_2_0_0_1_1 -> 897 in the cache */
   /* replace1318_2_0_0_1 -> 3783 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      3, 1,
      { 1489, 3783 },
      -1,
   } },
   /* replace1318_2_0_1_0_0 -> 21 in the cache */
   /* replace1318_2_0_1_0_1 -> 41 in the cache */
   /* replace1318_2_0_1_0 -> 3766 in the cache */
   /* replace1318_2_0_1_1 -> 897 in the cache */
   /* replace1318_2_0_1 -> 3785 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      2, 2,
      { 3787, 3785 },
      -1,
   } },
   /* replace1318_2_1_0 -> 21 in the cache */
   /* replace1318_2_1_1 -> 41 in the cache */
   /* replace1318_2_1 -> 3766 in the cache */
   /* replace1318_2_2 -> 3779 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 3788, 3766, 3779 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 4,
      { 3786, 22, 3789 },
      -1,
   } },

   /* ('ilt', ('imax(is_used_once)', 'a@64', 'b@64'), 0) => ('ilt', ('imax', ('unpack_64_2x32_split_y', 'a'), ('unpack_64_2x32_split_y', 'b')), 0) */
   /* search1319_0_0 -> 21 in the cache */
   /* search1319_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 21, 41 },
      0,
   } },
   /* search1319_1 -> 897 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 3791, 897 },
      -1,
   } },

   /* replace1319_0_0_0 -> 21 in the cache */
   /* replace1319_0_0 -> 2742 in the cache */
   /* replace1319_0_1_0 -> 41 in the cache */
   /* replace1319_0_1 -> 2743 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 2742, 2743 },
      -1,
   } },
   /* replace1319_1 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 3793, 122 },
      -1,
   } },

   /* ('ilt', ('imin(is_used_once)', 'a@64', 'b@64'), 0) => ('ilt', ('imin', ('unpack_64_2x32_split_y', 'a'), ('unpack_64_2x32_split_y', 'b')), 0) */
   /* search1320_0_0 -> 21 in the cache */
   /* search1320_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_imin,
      0, 1,
      { 21, 41 },
      0,
   } },
   /* search1320_1 -> 897 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 3795, 897 },
      -1,
   } },

   /* replace1320_0_0_0 -> 21 in the cache */
   /* replace1320_0_0 -> 2742 in the cache */
   /* replace1320_0_1_0 -> 41 in the cache */
   /* replace1320_0_1 -> 2743 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imin,
      0, 1,
      { 2742, 2743 },
      -1,
   } },
   /* replace1320_1 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 3797, 122 },
      -1,
   } },

   /* ('ige', ('imax(is_used_once)', 'a@64', 'b@64'), 0) => ('ige', ('imax', ('unpack_64_2x32_split_y', 'a'), ('unpack_64_2x32_split_y', 'b')), 0) */
   /* search1321_0_0 -> 21 in the cache */
   /* search1321_0_1 -> 41 in the cache */
   /* search1321_0 -> 3791 in the cache */
   /* search1321_1 -> 897 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 1,
      { 3791, 897 },
      -1,
   } },

   /* replace1321_0_0_0 -> 21 in the cache */
   /* replace1321_0_0 -> 2742 in the cache */
   /* replace1321_0_1_0 -> 41 in the cache */
   /* replace1321_0_1 -> 2743 in the cache */
   /* replace1321_0 -> 3793 in the cache */
   /* replace1321_1 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 1,
      { 3793, 122 },
      -1,
   } },

   /* ('ige', ('imin(is_used_once)', 'a@64', 'b@64'), 0) => ('ige', ('imin', ('unpack_64_2x32_split_y', 'a'), ('unpack_64_2x32_split_y', 'b')), 0) */
   /* search1322_0_0 -> 21 in the cache */
   /* search1322_0_1 -> 41 in the cache */
   /* search1322_0 -> 3795 in the cache */
   /* search1322_1 -> 897 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 1,
      { 3795, 897 },
      -1,
   } },

   /* replace1322_0_0_0 -> 21 in the cache */
   /* replace1322_0_0 -> 2742 in the cache */
   /* replace1322_0_1_0 -> 41 in the cache */
   /* replace1322_0_1 -> 2743 in the cache */
   /* replace1322_0 -> 3797 in the cache */
   /* replace1322_1 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 1,
      { 3797, 122 },
      -1,
   } },

   /* ('ilt', 'a@64', 0) => ('ilt', ('unpack_64_2x32_split_y', 'a'), 0) */
   /* search1323_0 -> 21 in the cache */
   /* search1323_1 -> 897 in the cache */
   /* search1323 -> 1489 in the cache */

   /* replace1323_0_0 -> 21 in the cache */
   /* replace1323_0 -> 2742 in the cache */
   /* replace1323_1 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 2742, 122 },
      -1,
   } },

   /* ('ige', 'a@64', 0) => ('ige', ('unpack_64_2x32_split_y', 'a'), 0) */
   /* search1324_0 -> 21 in the cache */
   /* search1324_1 -> 897 in the cache */
   /* search1324 -> 1486 in the cache */

   /* replace1324_0_0 -> 21 in the cache */
   /* replace1324_0 -> 2742 in the cache */
   /* replace1324_1 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 2742, 122 },
      -1,
   } },

   /* ('ine', 'a@64', 0) => ('ine', ('ior', ('unpack_64_2x32_split_x', 'a'), ('unpack_64_2x32_split_y', 'a')), 0) */
   /* search1325_0 -> 21 in the cache */
   /* search1325_1 -> 897 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 21, 897 },
      -1,
   } },

   /* replace1325_0_0_0 -> 21 in the cache */
   /* replace1325_0_0 -> 2748 in the cache */
   /* replace1325_0_1_0 -> 21 in the cache */
   /* replace1325_0_1 -> 2742 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 2748, 2742 },
      -1,
   } },
   /* replace1325_1 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 3806, 122 },
      -1,
   } },

   /* ('ieq', 'a@64', 0) => ('ieq', ('ior', ('unpack_64_2x32_split_x', 'a'), ('unpack_64_2x32_split_y', 'a')), 0) */
   /* search1326_0 -> 21 in the cache */
   /* search1326_1 -> 897 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 21, 897 },
      -1,
   } },

   /* replace1326_0_0_0 -> 21 in the cache */
   /* replace1326_0_0 -> 2748 in the cache */
   /* replace1326_0_1_0 -> 21 in the cache */
   /* replace1326_0_1 -> 2742 in the cache */
   /* replace1326_0 -> 3806 in the cache */
   /* replace1326_1 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 3806, 122 },
      -1,
   } },

   /* ('ult', 0, 'a@64') => ('ine', ('ior', ('unpack_64_2x32_split_x', 'a'), ('unpack_64_2x32_split_y', 'a')), 0) */
   /* search1327_0 -> 897 in the cache */
   /* search1327_1 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 897, 21 },
      -1,
   } },

   /* replace1327_0_0_0 -> 21 in the cache */
   /* replace1327_0_0 -> 2748 in the cache */
   /* replace1327_0_1_0 -> 21 in the cache */
   /* replace1327_0_1 -> 2742 in the cache */
   /* replace1327_0 -> 3806 in the cache */
   /* replace1327_1 -> 122 in the cache */
   /* replace1327 -> 3807 in the cache */

   /* ('bitfield_insert', 'base', 'insert', 'offset', 'bits') => ('bcsel', ('ult', 31, 'bits'), 'insert', ('ior', ('iand', 'base', ('inot', ('ishl', ('isub', ('ishl', 1, 'bits'), 1), 'offset'))), ('iand', ('ishl', 'insert', 'offset'), ('ishl', ('isub', ('ishl', 1, 'bits'), 1), 'offset')))) */
   /* search1328_0 -> 3712 in the cache */
   /* search1328_1 -> 3713 in the cache */
   /* search1328_2 -> 3714 in the cache */
   /* search1328_3 -> 3715 in the cache */
   /* search1328 -> 3716 in the cache */

   /* replace1328_0_0 -> 19 in the cache */
   /* replace1328_0_1 -> 3715 in the cache */
   /* replace1328_0 -> 3717 in the cache */
   /* replace1328_1 -> 3713 in the cache */
   /* replace1328_2_0_0 -> 3712 in the cache */
   /* replace1328_2_0_1_0_0_0_0 -> 396 in the cache */
   /* replace1328_2_0_1_0_0_0_1 -> 3715 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 396, 3715 },
      -1,
   } },
   /* replace1328_2_0_1_0_0_1 -> 396 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 3811, 396 },
      -1,
   } },
   /* replace1328_2_0_1_0_1 -> 3714 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 3812, 3714 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 3813 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 3712, 3814 },
      -1,
   } },
   /* replace1328_2_1_0_0 -> 3713 in the cache */
   /* replace1328_2_1_0_1 -> 3714 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 3713, 3714 },
      -1,
   } },
   /* replace1328_2_1_1_0_0_0 -> 396 in the cache */
   /* replace1328_2_1_1_0_0_1 -> 3715 in the cache */
   /* replace1328_2_1_1_0_0 -> 3811 in the cache */
   /* replace1328_2_1_1_0_1 -> 396 in the cache */
   /* replace1328_2_1_1_0 -> 3812 in the cache */
   /* replace1328_2_1_1_1 -> 3714 in the cache */
   /* replace1328_2_1_1 -> 3813 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      2, 1,
      { 3816, 3813 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 3815, 3817 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 3,
      { 3717, 3713, 3818 },
      -1,
   } },

   /* ('bitfield_insert', 'base', 'insert', 'offset', 'bits') => ('bcsel', ('ult', 31, 'bits'), 'insert', ('bitfield_select', ('bfm', 'bits', 'offset'), ('ishl', 'insert', 'offset'), 'base')) */
   /* search1329_0 -> 3712 in the cache */
   /* search1329_1 -> 3713 in the cache */
   /* search1329_2 -> 3714 in the cache */
   /* search1329_3 -> 3715 in the cache */
   /* search1329 -> 3716 in the cache */

   /* replace1329_0_0 -> 19 in the cache */
   /* replace1329_0_1 -> 3715 in the cache */
   /* replace1329_0 -> 3717 in the cache */
   /* replace1329_1 -> 3713 in the cache */
   /* replace1329_2_0_0 -> 3715 in the cache */
   /* replace1329_2_0_1 -> 3714 in the cache */
   /* replace1329_2_0 -> 3718 in the cache */
   /* replace1329_2_1_0 -> 3713 in the cache */
   /* replace1329_2_1_1 -> 3714 in the cache */
   /* replace1329_2_1 -> 3816 in the cache */
   /* replace1329_2_2 -> 3712 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bitfield_select,
      -1, 0,
      { 3718, 3816, 3712 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3717, 3713, 3820 },
      -1,
   } },

   /* ('ibitfield_extract', 'value', 'offset', 'bits') => ('bcsel', ('ult', 31, 'bits'), 'value', ('ibfe', 'value', 'offset', 'bits')) */
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* value */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* offset */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      2, /* bits */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ibitfield_extract,
      -1, 0,
      { 3822, 3823, 3824 },
      -1,
   } },

   /* replace1330_0_0 -> 19 in the cache */
   /* replace1330_0_1 -> 3824 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 19, 3824 },
      -1,
   } },
   /* replace1330_1 -> 3822 in the cache */
   /* replace1330_2_0 -> 3822 in the cache */
   /* replace1330_2_1 -> 3823 in the cache */
   /* replace1330_2_2 -> 3824 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ibfe,
      -1, 0,
      { 3822, 3823, 3824 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3826, 3822, 3827 },
      -1,
   } },

   /* ('ubitfield_extract', 'value', 'offset', 'bits') => ('bcsel', ('ult', 31, 'bits'), 'value', ('ubfe', 'value', 'offset', 'bits')) */
   /* search1331_0 -> 3822 in the cache */
   /* search1331_1 -> 3823 in the cache */
   /* search1331_2 -> 3824 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ubitfield_extract,
      -1, 0,
      { 3822, 3823, 3824 },
      -1,
   } },

   /* replace1331_0_0 -> 19 in the cache */
   /* replace1331_0_1 -> 3824 in the cache */
   /* replace1331_0 -> 3826 in the cache */
   /* replace1331_1 -> 3822 in the cache */
   /* replace1331_2_0 -> 3822 in the cache */
   /* replace1331_2_1 -> 3823 in the cache */
   /* replace1331_2_2 -> 3824 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ubfe,
      -1, 0,
      { 3822, 3823, 3824 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3826, 3822, 3830 },
      -1,
   } },

   /* ('bitfield_select', 'a', 'b', 0) => ('iand', 'a', 'b') */
   /* search1332_0 -> 0 in the cache */
   /* search1332_1 -> 3 in the cache */
   /* search1332_2 -> 86 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_bitfield_select,
      -1, 0,
      { 0, 3, 86 },
      -1,
   } },

   /* replace1332_0 -> 0 in the cache */
   /* replace1332_1 -> 3 in the cache */
   /* replace1332 -> 2735 in the cache */

   /* ('bitfield_select', 'a', ('iand', 'a', 'b'), 'c') => ('bitfield_select', 'a', 'b', 'c') */
   /* search1333_0 -> 126 in the cache */
   /* search1333_1_0 -> 126 in the cache */
   /* search1333_1_1 -> 127 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 126, 127 },
      -1,
   } },
   /* search1333_2 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bitfield_select,
      -1, 1,
      { 126, 3833, 129 },
      -1,
   } },

   /* replace1333_0 -> 126 in the cache */
   /* replace1333_1 -> 127 in the cache */
   /* replace1333_2 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bitfield_select,
      -1, 0,
      { 126, 127, 129 },
      -1,
   } },

   /* ('ubfe', 'value', 'offset', ('iand', 31, 'bits')) => ('ubfe', 'value', 'offset', 'bits') */
   /* search1334_0 -> 3822 in the cache */
   /* search1334_1 -> 3823 in the cache */
   /* search1334_2_0 -> 19 in the cache */
   /* search1334_2_1 -> 3824 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 19, 3824 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ubfe,
      -1, 1,
      { 3822, 3823, 3836 },
      -1,
   } },

   /* replace1334_0 -> 3822 in the cache */
   /* replace1334_1 -> 3823 in the cache */
   /* replace1334_2 -> 3824 in the cache */
   /* replace1334 -> 3830 in the cache */

   /* ('ubfe', 'value', ('iand', 31, 'offset'), 'bits') => ('ubfe', 'value', 'offset', 'bits') */
   /* search1335_0 -> 3822 in the cache */
   /* search1335_1_0 -> 19 in the cache */
   /* search1335_1_1 -> 3823 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 19, 3823 },
      -1,
   } },
   /* search1335_2 -> 3824 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ubfe,
      -1, 1,
      { 3822, 3838, 3824 },
      -1,
   } },

   /* replace1335_0 -> 3822 in the cache */
   /* replace1335_1 -> 3823 in the cache */
   /* replace1335_2 -> 3824 in the cache */
   /* replace1335 -> 3830 in the cache */

   /* ('ibfe', 'value', 'offset', ('iand', 31, 'bits')) => ('ibfe', 'value', 'offset', 'bits') */
   /* search1336_0 -> 3822 in the cache */
   /* search1336_1 -> 3823 in the cache */
   /* search1336_2_0 -> 19 in the cache */
   /* search1336_2_1 -> 3824 in the cache */
   /* search1336_2 -> 3836 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ibfe,
      -1, 1,
      { 3822, 3823, 3836 },
      -1,
   } },

   /* replace1336_0 -> 3822 in the cache */
   /* replace1336_1 -> 3823 in the cache */
   /* replace1336_2 -> 3824 in the cache */
   /* replace1336 -> 3827 in the cache */

   /* ('ibfe', 'value', ('iand', 31, 'offset'), 'bits') => ('ibfe', 'value', 'offset', 'bits') */
   /* search1337_0 -> 3822 in the cache */
   /* search1337_1_0 -> 19 in the cache */
   /* search1337_1_1 -> 3823 in the cache */
   /* search1337_1 -> 3838 in the cache */
   /* search1337_2 -> 3824 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ibfe,
      -1, 1,
      { 3822, 3838, 3824 },
      -1,
   } },

   /* replace1337_0 -> 3822 in the cache */
   /* replace1337_1 -> 3823 in the cache */
   /* replace1337_2 -> 3824 in the cache */
   /* replace1337 -> 3827 in the cache */

   /* ('bfm', 'bits', ('iand', 31, 'offset')) => ('bfm', 'bits', 'offset') */
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* bits */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search1338_1_0 -> 19 in the cache */
   /* search1338_1_1 -> 3823 in the cache */
   /* search1338_1 -> 3838 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bfm,
      -1, 1,
      { 3842, 3838 },
      -1,
   } },

   /* replace1338_0 -> 3842 in the cache */
   /* replace1338_1 -> 3823 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bfm,
      -1, 0,
      { 3842, 3823 },
      -1,
   } },

   /* ('bfm', ('iand', 31, 'bits'), 'offset') => ('bfm', 'bits', 'offset') */
   /* search1339_0_0 -> 19 in the cache */
   /* search1339_0_1 -> 3842 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 19, 3842 },
      -1,
   } },
   /* search1339_1 -> 3823 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bfm,
      -1, 1,
      { 3845, 3823 },
      -1,
   } },

   /* replace1339_0 -> 3842 in the cache */
   /* replace1339_1 -> 3823 in the cache */
   /* replace1339 -> 3844 in the cache */

   /* ('ult', 'a', ('umin', ('iand', 'a', 'b'), 'c')) => False */
   /* search1340_0 -> 126 in the cache */
   /* search1340_1_0_0 -> 126 in the cache */
   /* search1340_1_0_1 -> 127 in the cache */
   /* search1340_1_0 -> 194 in the cache */
   /* search1340_1_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_umin,
      0, 2,
      { 194, 129 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 2,
      { 126, 3847 },
      -1,
   } },

   /* replace1340 -> 1077 in the cache */

   /* ('ult', 31, ('umin', '#bits(is_ult_32)', 'a')) => False */
   { .constant = {
      { nir_search_value_constant, -2 },
      nir_type_int, { 0x1f /* 31 */ },
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* bits */
      true,
      nir_type_invalid,
      34,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search1341_1_1 -> 1114 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_umin,
      0, 1,
      { 3850, 1114 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 1,
      { 3849, 3851 },
      -1,
   } },

   /* replace1341 -> 1077 in the cache */

   /* ('ubfe', 'value', 'offset', ('umin', 'width', ('iadd', 32, ('ineg', ('iand', 31, 'offset'))))) => ('ubfe', 'value', 'offset', 'width') */
   /* search1342_0 -> 3822 in the cache */
   /* search1342_1 -> 3823 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      2, /* width */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search1342_2_1_0 -> 874 in the cache */
   /* search1342_2_1_1_0_0 -> 19 in the cache */
   /* search1342_2_1_1_0_1 -> 3823 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      2, 1,
      { 19, 3823 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 1,
      { 3854 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 2,
      { 874, 3855 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_umin,
      0, 3,
      { 3853, 3856 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ubfe,
      -1, 3,
      { 3822, 3823, 3857 },
      -1,
   } },

   /* replace1342_0 -> 3822 in the cache */
   /* replace1342_1 -> 3823 in the cache */
   /* replace1342_2 -> 3853 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ubfe,
      -1, 0,
      { 3822, 3823, 3853 },
      -1,
   } },

   /* ('ibfe', 'value', 'offset', ('umin', 'width', ('iadd', 32, ('ineg', ('iand', 31, 'offset'))))) => ('ibfe', 'value', 'offset', 'width') */
   /* search1343_0 -> 3822 in the cache */
   /* search1343_1 -> 3823 in the cache */
   /* search1343_2_0 -> 3853 in the cache */
   /* search1343_2_1_0 -> 874 in the cache */
   /* search1343_2_1_1_0_0 -> 19 in the cache */
   /* search1343_2_1_1_0_1 -> 3823 in the cache */
   /* search1343_2_1_1_0 -> 3854 in the cache */
   /* search1343_2_1_1 -> 3855 in the cache */
   /* search1343_2_1 -> 3856 in the cache */
   /* search1343_2 -> 3857 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ibfe,
      -1, 3,
      { 3822, 3823, 3857 },
      -1,
   } },

   /* replace1343_0 -> 3822 in the cache */
   /* replace1343_1 -> 3823 in the cache */
   /* replace1343_2 -> 3853 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ibfe,
      -1, 0,
      { 3822, 3823, 3853 },
      -1,
   } },

   /* ('bfm', ('umin', 'width', ('iadd', 32, ('ineg', ('iand', 31, 'offset')))), 'offset') => ('bfm', 'width', 'offset') */
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* width */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search1344_0_1_0 -> 874 in the cache */
   /* search1344_0_1_1_0_0 -> 19 in the cache */
   /* search1344_0_1_1_0_1 -> 3823 in the cache */
   /* search1344_0_1_1_0 -> 3854 in the cache */
   /* search1344_0_1_1 -> 3855 in the cache */
   /* search1344_0_1 -> 3856 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_umin,
      0, 3,
      { 3862, 3856 },
      -1,
   } },
   /* search1344_1 -> 3823 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bfm,
      -1, 3,
      { 3863, 3823 },
      -1,
   } },

   /* replace1344_0 -> 3862 in the cache */
   /* replace1344_1 -> 3823 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bfm,
      -1, 0,
      { 3862, 3823 },
      -1,
   } },

   /* ('iadd@32', ('ishl', 1, 'a'), -1) => ('bfm', 'a', 0) */
   /* search1345_0_0 -> 396 in the cache */
   /* search1345_0_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 396, 16 },
      -1,
   } },
   /* search1345_1 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 3866, 124 },
      -1,
   } },

   /* replace1345_0 -> 16 in the cache */
   /* replace1345_1 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bfm,
      -1, 0,
      { 16, 122 },
      -1,
   } },

   /* ('ishl', ('bfm', 'a', 0), 'b') => ('bfm', 'a', 'b') */
   /* search1346_0_0 -> 16 in the cache */
   /* search1346_0_1 -> 122 in the cache */
   /* search1346_0 -> 3868 in the cache */
   /* search1346_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 3868, 36 },
      -1,
   } },

   /* replace1346_0 -> 16 in the cache */
   /* replace1346_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bfm,
      -1, 0,
      { 16, 36 },
      -1,
   } },

   /* ('ubfe', 'a', 'b', 0) => 0 */
   /* search1347_0 -> 16 in the cache */
   /* search1347_1 -> 36 in the cache */
   /* search1347_2 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ubfe,
      -1, 0,
      { 16, 36, 122 },
      -1,
   } },

   /* replace1347 -> 122 in the cache */

   /* ('ibfe', 'a', 'b', 0) => 0 */
   /* search1348_0 -> 16 in the cache */
   /* search1348_1 -> 36 in the cache */
   /* search1348_2 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ibfe,
      -1, 0,
      { 16, 36, 122 },
      -1,
   } },

   /* replace1348 -> 122 in the cache */

   /* ('ubfe', 'a', 0, '#b') => ('iand', 'a', ('ushr', 4294967295, ('ineg', 'b'))) */
   /* search1349_0 -> 16 in the cache */
   /* search1349_1 -> 122 in the cache */
   /* search1349_2 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ubfe,
      -1, 0,
      { 16, 122, 33 },
      -1,
   } },

   /* replace1349_0 -> 16 in the cache */
   /* replace1349_1_0 -> 927 in the cache */
   /* replace1349_1_1_0 -> 36 in the cache */
   /* replace1349_1_1 -> 2788 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 927, 2788 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 16, 3874 },
      -1,
   } },

   /* ('b2i32', ('ine', ('ubfe', 'a', 'b', 1), 0)) => ('ubfe', 'a', 'b', 1) */
   /* search1350_0_0_0 -> 16 in the cache */
   /* search1350_0_0_1 -> 36 in the cache */
   /* search1350_0_0_2 -> 396 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ubfe,
      -1, 0,
      { 16, 36, 396 },
      -1,
   } },
   /* search1350_0_1 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 3876, 122 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_b2i32,
      -1, 1,
      { 3877 },
      -1,
   } },

   /* replace1350_0 -> 16 in the cache */
   /* replace1350_1 -> 36 in the cache */
   /* replace1350_2 -> 396 in the cache */
   /* replace1350 -> 3876 in the cache */

   /* ('b2i32', ('ine', ('ibfe', 'a', 'b', 1), 0)) => ('ubfe', 'a', 'b', 1) */
   /* search1351_0_0_0 -> 16 in the cache */
   /* search1351_0_0_1 -> 36 in the cache */
   /* search1351_0_0_2 -> 396 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ibfe,
      -1, 0,
      { 16, 36, 396 },
      -1,
   } },
   /* search1351_0_1 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 3879, 122 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_b2i32,
      -1, 1,
      { 3880 },
      -1,
   } },

   /* replace1351_0 -> 16 in the cache */
   /* replace1351_1 -> 36 in the cache */
   /* replace1351_2 -> 396 in the cache */
   /* replace1351 -> 3876 in the cache */

   /* ('ine', ('ibfe(is_used_once)', 'a', '#b', '#c'), 0) => ('ine', ('iand', 'a', ('ishl', ('ushr', 4294967295, ('ineg', 'c')), 'b')), 0) */
   /* search1352_0_0 -> 16 in the cache */
   /* search1352_0_1 -> 33 in the cache */
   /* search1352_0_2 -> 309 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ibfe,
      -1, 0,
      { 16, 33, 309 },
      0,
   } },
   /* search1352_1 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 3882, 122 },
      -1,
   } },

   /* replace1352_0_0 -> 16 in the cache */
   /* replace1352_0_1_0_0 -> 927 in the cache */
   /* replace1352_0_1_0_1_0 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 135 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 927, 3884 },
      -1,
   } },
   /* replace1352_0_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 3885, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 16, 3886 },
      -1,
   } },
   /* replace1352_1 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 3887, 122 },
      -1,
   } },

   /* ('ieq', ('ibfe(is_used_once)', 'a', '#b', '#c'), 0) => ('ieq', ('iand', 'a', ('ishl', ('ushr', 4294967295, ('ineg', 'c')), 'b')), 0) */
   /* search1353_0_0 -> 16 in the cache */
   /* search1353_0_1 -> 33 in the cache */
   /* search1353_0_2 -> 309 in the cache */
   /* search1353_0 -> 3882 in the cache */
   /* search1353_1 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 3882, 122 },
      -1,
   } },

   /* replace1353_0_0 -> 16 in the cache */
   /* replace1353_0_1_0_0 -> 927 in the cache */
   /* replace1353_0_1_0_1_0 -> 135 in the cache */
   /* replace1353_0_1_0_1 -> 3884 in the cache */
   /* replace1353_0_1_0 -> 3885 in the cache */
   /* replace1353_0_1_1 -> 36 in the cache */
   /* replace1353_0_1 -> 3886 in the cache */
   /* replace1353_0 -> 3887 in the cache */
   /* replace1353_1 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 3887, 122 },
      -1,
   } },

   /* ('ine', ('ubfe(is_used_once)', 'a', '#b', '#c'), 0) => ('ine', ('iand', 'a', ('ishl', ('ushr', 4294967295, ('ineg', 'c')), 'b')), 0) */
   /* search1354_0_0 -> 16 in the cache */
   /* search1354_0_1 -> 33 in the cache */
   /* search1354_0_2 -> 309 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ubfe,
      -1, 0,
      { 16, 33, 309 },
      0,
   } },
   /* search1354_1 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 3891, 122 },
      -1,
   } },

   /* replace1354_0_0 -> 16 in the cache */
   /* replace1354_0_1_0_0 -> 927 in the cache */
   /* replace1354_0_1_0_1_0 -> 135 in the cache */
   /* replace1354_0_1_0_1 -> 3884 in the cache */
   /* replace1354_0_1_0 -> 3885 in the cache */
   /* replace1354_0_1_1 -> 36 in the cache */
   /* replace1354_0_1 -> 3886 in the cache */
   /* replace1354_0 -> 3887 in the cache */
   /* replace1354_1 -> 122 in the cache */
   /* replace1354 -> 3888 in the cache */

   /* ('ieq', ('ubfe(is_used_once)', 'a', '#b', '#c'), 0) => ('ieq', ('iand', 'a', ('ishl', ('ushr', 4294967295, ('ineg', 'c')), 'b')), 0) */
   /* search1355_0_0 -> 16 in the cache */
   /* search1355_0_1 -> 33 in the cache */
   /* search1355_0_2 -> 309 in the cache */
   /* search1355_0 -> 3891 in the cache */
   /* search1355_1 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 3891, 122 },
      -1,
   } },

   /* replace1355_0_0 -> 16 in the cache */
   /* replace1355_0_1_0_0 -> 927 in the cache */
   /* replace1355_0_1_0_1_0 -> 135 in the cache */
   /* replace1355_0_1_0_1 -> 3884 in the cache */
   /* replace1355_0_1_0 -> 3885 in the cache */
   /* replace1355_0_1_1 -> 36 in the cache */
   /* replace1355_0_1 -> 3886 in the cache */
   /* replace1355_0 -> 3887 in the cache */
   /* replace1355_1 -> 122 in the cache */
   /* replace1355 -> 3890 in the cache */

   /* ('ibitfield_extract', 'value', 'offset', 'bits') => ('bcsel', ('ieq', 0, 'bits'), 0, ('ishr', ('ishl', 'value', ('isub', ('isub', 32, 'bits'), 'offset')), ('isub', 32, 'bits'))) */
   /* search1356_0 -> 3822 in the cache */
   /* search1356_1 -> 3823 in the cache */
   /* search1356_2 -> 3824 in the cache */
   /* search1356 -> 3825 in the cache */

   /* replace1356_0_0 -> 122 in the cache */
   /* replace1356_0_1 -> 3824 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 122, 3824 },
      -1,
   } },
   /* replace1356_1 -> 122 in the cache */
   /* replace1356_2_0_0 -> 3822 in the cache */
   /* replace1356_2_0_1_0_0 -> 874 in the cache */
   /* replace1356_2_0_1_0_1 -> 3824 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 874, 3824 },
      -1,
   } },
   /* replace1356_2_0_1_1 -> 3823 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 3895, 3823 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 3822, 3896 },
      -1,
   } },
   /* replace1356_2_1_0 -> 874 in the cache */
   /* replace1356_2_1_1 -> 3824 in the cache */
   /* replace1356_2_1 -> 3895 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 3897, 3895 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 3894, 122, 3898 },
      -1,
   } },

   /* ('ubitfield_extract', 'value', 'offset', 'bits') => ('iand', ('ushr', 'value', 'offset'), ('bcsel', ('ieq', 'bits', 32), 4294967295, ('isub', ('ishl', 1, 'bits'), 1))) */
   /* search1357_0 -> 3822 in the cache */
   /* search1357_1 -> 3823 in the cache */
   /* search1357_2 -> 3824 in the cache */
   /* search1357 -> 3829 in the cache */

   /* replace1357_0_0 -> 3822 in the cache */
   /* replace1357_0_1 -> 3823 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 3822, 3823 },
      -1,
   } },
   /* replace1357_1_0_0 -> 3824 in the cache */
   /* replace1357_1_0_1 -> 874 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 3824, 874 },
      -1,
   } },
   /* replace1357_1_1 -> 927 in the cache */
   /* replace1357_1_2_0_0 -> 396 in the cache */
   /* replace1357_1_2_0_1 -> 3824 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 396, 3824 },
      -1,
   } },
   /* replace1357_1_2_1 -> 396 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 3902, 396 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 3901, 927, 3903 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 3900, 3904 },
      -1,
   } },

   /* ('ifind_msb', 'value') => ('ufind_msb', ('bcsel', ('ilt', 'value', 0), ('inot', 'value'), 'value')) */
   /* search1358_0 -> 3822 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ifind_msb,
      -1, 0,
      { 3822 },
      -1,
   } },

   /* replace1358_0_0_0 -> 3822 in the cache */
   /* replace1358_0_0_1 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 3822, 122 },
      -1,
   } },
   /* replace1358_0_1_0 -> 3822 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 3822 },
      -1,
   } },
   /* replace1358_0_2 -> 3822 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3907, 3908, 3822 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ufind_msb,
      -1, 0,
      { 3909 },
      -1,
   } },

   /* ('ifind_msb', 'value') => ('bcsel', ('ige', ('ifind_msb_rev', 'value'), 0), ('isub', 31, ('ifind_msb_rev', 'value')), ('ifind_msb_rev', 'value')) */
   /* search1359_0 -> 3822 in the cache */
   /* search1359 -> 3906 in the cache */

   /* replace1359_0_0_0 -> 3822 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ifind_msb_rev,
      -1, 0,
      { 3822 },
      -1,
   } },
   /* replace1359_0_1 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 3911, 122 },
      -1,
   } },
   /* replace1359_1_0 -> 19 in the cache */
   /* replace1359_1_1_0 -> 3822 in the cache */
   /* replace1359_1_1 -> 3911 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 19, 3911 },
      -1,
   } },
   /* replace1359_2_0 -> 3822 in the cache */
   /* replace1359_2 -> 3911 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3912, 3913, 3911 },
      -1,
   } },

   /* ('ufind_msb', 'value') => ('bcsel', ('ige', ('ufind_msb_rev', 'value'), 0), ('isub', 31, ('ufind_msb_rev', 'value')), ('ufind_msb_rev', 'value')) */
   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* value */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ufind_msb,
      -1, 0,
      { 3915 },
      -1,
   } },

   /* replace1360_0_0_0 -> 3915 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ufind_msb_rev,
      -1, 0,
      { 3915 },
      -1,
   } },
   /* replace1360_0_1 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 3917, 122 },
      -1,
   } },
   /* replace1360_1_0 -> 19 in the cache */
   /* replace1360_1_1_0 -> 3915 in the cache */
   /* replace1360_1_1 -> 3917 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 19, 3917 },
      -1,
   } },
   /* replace1360_2_0 -> 3915 in the cache */
   /* replace1360_2 -> 3917 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3918, 3919, 3917 },
      -1,
   } },

   /* ('uclz', 'a') => ('umin', 32, ('ufind_msb_rev', 'a')) */
   /* search1361_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_uclz,
      -1, 0,
      { 16 },
      -1,
   } },

   /* replace1361_0 -> 874 in the cache */
   /* replace1361_1_0 -> 16 in the cache */
   /* replace1361_1 -> 3635 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_umin,
      0, 1,
      { 874, 3635 },
      -1,
   } },

   /* ('find_lsb', 'value') => ('ufind_msb', ('iand', 'value', ('ineg', 'value'))) */
   /* search1362_0 -> 3915 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_find_lsb,
      -1, 0,
      { 3915 },
      -1,
   } },

   /* replace1362_0_0 -> 3915 in the cache */
   /* replace1362_0_1_0 -> 3915 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 3915 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 3915, 3924 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ufind_msb,
      -1, 1,
      { 3925 },
      -1,
   } },

   /* ('extract_i8', 'a', 'b@32') => ('ishr', ('ishl', 'a', ('imul', ('isub', 3, 'b'), 8)), 24) */
   /* search1363_0 -> 16 in the cache */
   /* search1363_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 16, 36 },
      -1,
   } },

   /* replace1363_0_0 -> 16 in the cache */
   /* replace1363_0_1_0_0 -> 405 in the cache */
   /* replace1363_0_1_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 405, 36 },
      -1,
   } },
   /* replace1363_0_1_1 -> 831 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 3928, 831 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 16, 3929 },
      -1,
   } },
   /* replace1363_1 -> 1012 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 1,
      { 3930, 1012 },
      -1,
   } },

   /* ('extract_u8', 'a', 'b@32') => ('iand', ('ushr', 'a', ('imul', 'b', 8)), 255) */
   /* search1364_0 -> 16 in the cache */
   /* search1364_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 16, 36 },
      -1,
   } },

   /* replace1364_0_0 -> 16 in the cache */
   /* replace1364_0_1_0 -> 36 in the cache */
   /* replace1364_0_1_1 -> 831 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      1, 1,
      { 36, 831 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 16, 3933 },
      -1,
   } },
   /* replace1364_1 -> 1010 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 3934, 1010 },
      -1,
   } },

   /* ('extract_i16', 'a', 'b@32') => ('ishr', ('ishl', 'a', ('imul', ('isub', 1, 'b'), 16)), 16) */
   /* search1365_0 -> 16 in the cache */
   /* search1365_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i16,
      -1, 0,
      { 16, 36 },
      -1,
   } },

   /* replace1365_0_0 -> 16 in the cache */
   /* replace1365_0_1_0_0 -> 396 in the cache */
   /* replace1365_0_1_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 396, 36 },
      -1,
   } },
   /* replace1365_0_1_1 -> 853 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 3937, 853 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 16, 3938 },
      -1,
   } },
   /* replace1365_1 -> 853 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 1,
      { 3939, 853 },
      -1,
   } },

   /* ('extract_u16', 'a', 'b@32') => ('iand', ('ushr', 'a', ('imul', 'b', 16)), 65535) */
   /* search1366_0 -> 16 in the cache */
   /* search1366_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 0,
      { 16, 36 },
      -1,
   } },

   /* replace1366_0_0 -> 16 in the cache */
   /* replace1366_0_1_0 -> 36 in the cache */
   /* replace1366_0_1_1 -> 853 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      1, 1,
      { 36, 853 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 16, 3942 },
      -1,
   } },
   /* replace1366_1 -> 1002 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 3943, 1002 },
      -1,
   } },

   /* ('pack_unorm_2x16', 'v') => ('pack_uvec2_to_uint', ('f2u32', ('fround_even', ('fmul', ('fsat', 'v'), 65535.0)))) */
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* v */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_pack_unorm_2x16,
      -1, 0,
      { 3945 },
      -1,
   } },

   /* replace1367_0_0_0_0_0 -> 3945 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 3945 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_float, { 0x40efffe000000000 /* 65535.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 3947, 3948 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fround_even,
      -1, 1,
      { 3949 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2u32,
      -1, 1,
      { 3950 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_pack_uvec2_to_uint,
      -1, 1,
      { 3951 },
      -1,
   } },

   /* ('pack_unorm_4x8', 'v') => ('pack_uvec4_to_uint', ('f2u32', ('fround_even', ('fmul', ('fsat', 'v'), 255.0)))) */
   /* search1368_0 -> 3945 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_pack_unorm_4x8,
      -1, 0,
      { 3945 },
      -1,
   } },

   /* replace1368_0_0_0_0_0 -> 3945 in the cache */
   /* replace1368_0_0_0_0 -> 3947 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_float, { 0x406fe00000000000 /* 255.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 3947, 3954 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fround_even,
      -1, 1,
      { 3955 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2u32,
      -1, 1,
      { 3956 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_pack_uvec4_to_uint,
      -1, 1,
      { 3957 },
      -1,
   } },

   /* ('pack_snorm_2x16', 'v') => ('pack_uvec2_to_uint', ('f2i32', ('fround_even', ('fmul', ('fmin', 1.0, ('fmax', -1.0, 'v')), 32767.0)))) */
   /* search1369_0 -> 3945 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_pack_snorm_2x16,
      -1, 0,
      { 3945 },
      -1,
   } },

   /* replace1369_0_0_0_0_0 -> 243 in the cache */
   /* replace1369_0_0_0_0_1_0 -> 278 in the cache */
   /* replace1369_0_0_0_0_1_1 -> 3945 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmax,
      2, 1,
      { 278, 3945 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmin,
      1, 2,
      { 243, 3960 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_float, { 0x40dfffc000000000 /* 32767.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 3,
      { 3961, 3962 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fround_even,
      -1, 3,
      { 3963 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2i32,
      -1, 3,
      { 3964 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_pack_uvec2_to_uint,
      -1, 3,
      { 3965 },
      -1,
   } },

   /* ('pack_snorm_4x8', 'v') => ('pack_uvec4_to_uint', ('f2i32', ('fround_even', ('fmul', ('fmin', 1.0, ('fmax', -1.0, 'v')), 127.0)))) */
   /* search1370_0 -> 3945 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_pack_snorm_4x8,
      -1, 0,
      { 3945 },
      -1,
   } },

   /* replace1370_0_0_0_0_0 -> 243 in the cache */
   /* replace1370_0_0_0_0_1_0 -> 278 in the cache */
   /* replace1370_0_0_0_0_1_1 -> 3945 in the cache */
   /* replace1370_0_0_0_0_1 -> 3960 in the cache */
   /* replace1370_0_0_0_0 -> 3961 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_float, { 0x405fc00000000000 /* 127.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 3,
      { 3961, 3968 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fround_even,
      -1, 3,
      { 3969 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2i32,
      -1, 3,
      { 3970 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_pack_uvec4_to_uint,
      -1, 3,
      { 3971 },
      -1,
   } },

   /* ('unpack_unorm_2x16', 'v') => ('fdiv', ('u2f32', ('vec2', ('extract_u16', 'v', 0), ('extract_u16', 'v', 1))), 65535.0) */
   /* search1371_0 -> 3945 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_unorm_2x16,
      -1, 0,
      { 3945 },
      -1,
   } },

   /* replace1371_0_0_0_0 -> 3945 in the cache */
   /* replace1371_0_0_0_1 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 0,
      { 3945, 122 },
      -1,
   } },
   /* replace1371_0_0_1_0 -> 3945 in the cache */
   /* replace1371_0_0_1_1 -> 396 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 0,
      { 3945, 396 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_vec2,
      -1, 0,
      { 3974, 3975 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2f32,
      -1, 0,
      { 3976 },
      -1,
   } },
   /* replace1371_1 -> 3948 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fdiv,
      -1, 0,
      { 3977, 3948 },
      -1,
   } },

   /* ('unpack_unorm_4x8', 'v') => ('fdiv', ('u2f32', ('vec4', ('extract_u8', 'v', 0), ('extract_u8', 'v', 1), ('extract_u8', 'v', 2), ('extract_u8', 'v', 3))), 255.0) */
   /* search1372_0 -> 3945 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_unorm_4x8,
      -1, 0,
      { 3945 },
      -1,
   } },

   /* replace1372_0_0_0_0 -> 3945 in the cache */
   /* replace1372_0_0_0_1 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3945, 122 },
      -1,
   } },
   /* replace1372_0_0_1_0 -> 3945 in the cache */
   /* replace1372_0_0_1_1 -> 396 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3945, 396 },
      -1,
   } },
   /* replace1372_0_0_2_0 -> 3945 in the cache */
   /* replace1372_0_0_2_1 -> 401 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3945, 401 },
      -1,
   } },
   /* replace1372_0_0_3_0 -> 3945 in the cache */
   /* replace1372_0_0_3_1 -> 405 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 3945, 405 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_vec4,
      -1, 0,
      { 3980, 3981, 3982, 3983 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2f32,
      -1, 0,
      { 3984 },
      -1,
   } },
   /* replace1372_1 -> 3954 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fdiv,
      -1, 0,
      { 3985, 3954 },
      -1,
   } },

   /* ('unpack_snorm_2x16', 'v') => ('fmin', 1.0, ('fmax', -1.0, ('fdiv', ('i2f', ('vec2', ('extract_i16', 'v', 0), ('extract_i16', 'v', 1))), 32767.0))) */
   /* search1373_0 -> 3945 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_snorm_2x16,
      -1, 0,
      { 3945 },
      -1,
   } },

   /* replace1373_0 -> 243 in the cache */
   /* replace1373_1_0 -> 278 in the cache */
   /* replace1373_1_1_0_0_0_0 -> 3945 in the cache */
   /* replace1373_1_1_0_0_0_1 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i16,
      -1, 0,
      { 3945, 122 },
      -1,
   } },
   /* replace1373_1_1_0_0_1_0 -> 3945 in the cache */
   /* replace1373_1_1_0_0_1_1 -> 396 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i16,
      -1, 0,
      { 3945, 396 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_vec2,
      -1, 0,
      { 3988, 3989 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_search_op_i2f,
      -1, 0,
      { 3990 },
      -1,
   } },
   /* replace1373_1_1_1 -> 3962 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fdiv,
      -1, 0,
      { 3991, 3962 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmax,
      1, 1,
      { 278, 3992 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 2,
      { 243, 3993 },
      -1,
   } },

   /* ('unpack_snorm_4x8', 'v') => ('fmin', 1.0, ('fmax', -1.0, ('fdiv', ('i2f', ('vec4', ('extract_i8', 'v', 0), ('extract_i8', 'v', 1), ('extract_i8', 'v', 2), ('extract_i8', 'v', 3))), 127.0))) */
   /* search1374_0 -> 3945 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_unpack_snorm_4x8,
      -1, 0,
      { 3945 },
      -1,
   } },

   /* replace1374_0 -> 243 in the cache */
   /* replace1374_1_0 -> 278 in the cache */
   /* replace1374_1_1_0_0_0_0 -> 3945 in the cache */
   /* replace1374_1_1_0_0_0_1 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 3945, 122 },
      -1,
   } },
   /* replace1374_1_1_0_0_1_0 -> 3945 in the cache */
   /* replace1374_1_1_0_0_1_1 -> 396 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 3945, 396 },
      -1,
   } },
   /* replace1374_1_1_0_0_2_0 -> 3945 in the cache */
   /* replace1374_1_1_0_0_2_1 -> 401 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 3945, 401 },
      -1,
   } },
   /* replace1374_1_1_0_0_3_0 -> 3945 in the cache */
   /* replace1374_1_1_0_0_3_1 -> 405 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 3945, 405 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_vec4,
      -1, 0,
      { 3996, 3997, 3998, 3999 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_search_op_i2f,
      -1, 0,
      { 4000 },
      -1,
   } },
   /* replace1374_1_1_1 -> 3968 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fdiv,
      -1, 0,
      { 4001, 3968 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmax,
      1, 1,
      { 278, 4002 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 2,
      { 243, 4003 },
      -1,
   } },

   /* ('pack_half_2x16_split', 'a@32', 'b@32') => ('ior', ('ishl', ('u2u32', ('f2f16', 'b')), 16), ('u2u32', ('f2f16', 'a'))) */
   /* search1375_0 -> 16 in the cache */
   /* search1375_1 -> 36 in the cache */
   /* search1375 -> 3364 in the cache */

   /* replace1375_0_0_0_0 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 4005 },
      -1,
   } },
   /* replace1375_0_1 -> 853 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 4006, 853 },
      -1,
   } },
   /* replace1375_1_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 4008 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 4007, 4009 },
      -1,
   } },

   /* ('unpack_half_2x16_split_x', 'a@32') => ('f2f32', ('u2u16', 'a')) */
   /* search1376_0 -> 16 in the cache */
   /* search1376 -> 3329 in the cache */

   /* replace1376_0_0 -> 16 in the cache */
   /* replace1376_0 -> 3326 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 3326 },
      -1,
   } },

   /* ('unpack_half_2x16_split_y', 'a@32') => ('f2f32', ('u2u16', ('ushr', 'a', 16))) */
   /* search1377_0 -> 16 in the cache */
   /* search1377 -> 3336 in the cache */

   /* replace1377_0_0_0 -> 16 in the cache */
   /* replace1377_0_0_1 -> 853 in the cache */
   /* replace1377_0_0 -> 1008 in the cache */
   /* replace1377_0 -> 3327 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 3327 },
      -1,
   } },

   /* ('pack_32_2x16_split', 'a@16', 'b@16') => ('ior', ('ishl', ('u2u32', 'b'), 16), ('u2u32', 'a')) */
   /* search1378_0 -> 11 in the cache */
   /* search1378_1 -> 258 in the cache */
   /* search1378 -> 3319 in the cache */

   /* replace1378_0_0_0 -> 258 in the cache */
   /* replace1378_0_0 -> 3320 in the cache */
   /* replace1378_0_1 -> 853 in the cache */
   /* replace1378_0 -> 3321 in the cache */
   /* replace1378_1_0 -> 11 in the cache */
   /* replace1378_1 -> 1817 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 3321, 1817 },
      -1,
   } },

   /* ('unpack_32_2x16_split_x', 'a@32') => ('u2u16', 'a') */
   /* search1379_0 -> 16 in the cache */
   /* search1379 -> 3242 in the cache */

   /* replace1379_0 -> 16 in the cache */
   /* replace1379 -> 3326 in the cache */

   /* ('unpack_32_2x16_split_y', 'a@32') => ('u2u16', ('ushr', 'a', 16)) */
   /* search1380_0 -> 16 in the cache */
   /* search1380 -> 3244 in the cache */

   /* replace1380_0_0 -> 16 in the cache */
   /* replace1380_0_1 -> 853 in the cache */
   /* replace1380_0 -> 1008 in the cache */
   /* replace1380 -> 3327 in the cache */

   /* ('isign', 'a') => ('imin', ('imax', 'a', -1), 1) */
   /* search1381_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_isign,
      -1, 0,
      { 32 },
      -1,
   } },

   /* replace1381_0_0 -> 32 in the cache */
   /* replace1381_0_1 -> 63 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imax,
      1, 1,
      { 32, 63 },
      -1,
   } },
   /* replace1381_1 -> 35 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imin,
      0, 2,
      { 4015, 35 },
      -1,
   } },

   /* ('imin', ('imax', 'a', -1), 1) => ('isign', 'a') */
   /* search1382_0_0 -> 32 in the cache */
   /* search1382_0_1 -> 63 in the cache */
   /* search1382_0 -> 4015 in the cache */
   /* search1382_1 -> 35 in the cache */
   /* search1382 -> 4016 in the cache */

   /* replace1382_0 -> 32 in the cache */
   /* replace1382 -> 4014 in the cache */

   /* ('imax', ('imin', 'a', 1), -1) => ('isign', 'a') */
   /* search1383_0_0 -> 32 in the cache */
   /* search1383_0_1 -> 35 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imin,
      1, 1,
      { 32, 35 },
      -1,
   } },
   /* search1383_1 -> 63 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imax,
      0, 2,
      { 4017, 63 },
      -1,
   } },

   /* replace1383_0 -> 32 in the cache */
   /* replace1383 -> 4014 in the cache */

   /* ('fsign', 'a') => ('fsub', ('b2f', ('!flt', 0.0, 'a')), ('b2f', ('!flt', 'a', 0.0))) */
   /* search1384_0 -> 32 in the cache */
   /* search1384 -> 250 in the cache */

   /* replace1384_0_0_0 -> 111 in the cache */
   /* replace1384_0_0_1 -> 32 in the cache */
   /* replace1384_0_0 -> 1526 in the cache */
   /* replace1384_0 -> 1527 in the cache */
   /* replace1384_1_0_0 -> 32 in the cache */
   /* replace1384_1_0_1 -> 111 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      nir_op_flt,
      -1, 0,
      { 32, 111 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 4019 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 0,
      { 1527, 4020 },
      -1,
   } },

   /* ('amul', 'a', 'b') => ('imul', 'a', 'b') */
   /* search1385_0 -> 0 in the cache */
   /* search1385_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_amul,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* replace1385_0 -> 0 in the cache */
   /* replace1385_1 -> 3 in the cache */
   /* replace1385 -> 951 in the cache */

   /* ('umul24', 'a', 'b') => ('imul', ('iand', 'a', 16777215), ('iand', 'b', 16777215)) */
   /* search1386_0 -> 16 in the cache */
   /* search1386_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_umul24,
      0, 1,
      { 16, 36 },
      -1,
   } },

   /* replace1386_0_0 -> 16 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xffffff /* 16777215 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 16, 4024 },
      -1,
   } },
   /* replace1386_1_0 -> 36 in the cache */
   /* replace1386_1_1 -> 4024 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      2, 1,
      { 36, 4024 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      0, 3,
      { 4025, 4026 },
      -1,
   } },

   /* ('umad24', 'a', 'b', 'c') => ('iadd', ('imul', ('iand', 'a', 16777215), ('iand', 'b', 16777215)), 'c') */
   /* search1387_0 -> 16 in the cache */
   /* search1387_1 -> 36 in the cache */
   /* search1387_2 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_umad24,
      0, 1,
      { 16, 36, 135 },
      -1,
   } },

   /* replace1387_0_0_0 -> 16 in the cache */
   /* replace1387_0_0_1 -> 4024 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      2, 1,
      { 16, 4024 },
      -1,
   } },
   /* replace1387_0_1_0 -> 36 in the cache */
   /* replace1387_0_1_1 -> 4024 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      3, 1,
      { 36, 4024 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      1, 3,
      { 4029, 4030 },
      -1,
   } },
   /* replace1387_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 4,
      { 4031, 135 },
      -1,
   } },

   /* ('imul24_relaxed', 'a', 'b') => ('imul24', 'a', 'b') */
   /* search1388_0 -> 16 in the cache */
   /* search1388_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul24_relaxed,
      0, 1,
      { 16, 36 },
      -1,
   } },

   /* replace1388_0 -> 16 in the cache */
   /* replace1388_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul24,
      0, 1,
      { 16, 36 },
      -1,
   } },

   /* ('imul24_relaxed', 'a', 'b') => ('imul', 'a', 'b') */
   /* search1389_0 -> 16 in the cache */
   /* search1389_1 -> 36 in the cache */
   /* search1389 -> 4033 in the cache */

   /* replace1389_0 -> 16 in the cache */
   /* replace1389_1 -> 36 in the cache */
   /* replace1389 -> 49 in the cache */

   /* ('umad24_relaxed', 'a', 'b', 'c') => ('umad24', 'a', 'b', 'c') */
   /* search1390_0 -> 16 in the cache */
   /* search1390_1 -> 36 in the cache */
   /* search1390_2 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_umad24_relaxed,
      0, 1,
      { 16, 36, 135 },
      -1,
   } },

   /* replace1390_0 -> 16 in the cache */
   /* replace1390_1 -> 36 in the cache */
   /* replace1390_2 -> 135 in the cache */
   /* replace1390 -> 4028 in the cache */

   /* ('umad24_relaxed', 'a', 'b', 'c') => ('iadd', ('umul24_relaxed', 'a', 'b'), 'c') */
   /* search1391_0 -> 16 in the cache */
   /* search1391_1 -> 36 in the cache */
   /* search1391_2 -> 135 in the cache */
   /* search1391 -> 4035 in the cache */

   /* replace1391_0_0 -> 16 in the cache */
   /* replace1391_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_umul24_relaxed,
      1, 1,
      { 16, 36 },
      -1,
   } },
   /* replace1391_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 4036, 135 },
      -1,
   } },

   /* ('umul24_relaxed', 'a', 'b') => ('umul24', 'a', 'b') */
   /* search1392_0 -> 16 in the cache */
   /* search1392_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_umul24_relaxed,
      0, 1,
      { 16, 36 },
      -1,
   } },

   /* replace1392_0 -> 16 in the cache */
   /* replace1392_1 -> 36 in the cache */
   /* replace1392 -> 4023 in the cache */

   /* ('umul24_relaxed', 'a', 'b') => ('imul', 'a', 'b') */
   /* search1393_0 -> 16 in the cache */
   /* search1393_1 -> 36 in the cache */
   /* search1393 -> 4038 in the cache */

   /* replace1393_0 -> 16 in the cache */
   /* replace1393_1 -> 36 in the cache */
   /* replace1393 -> 49 in the cache */

   /* ('imad24_ir3', 'a', 'b', 0) => ('imul24', 'a', 'b') */
   /* search1394_0 -> 16 in the cache */
   /* search1394_1 -> 36 in the cache */
   /* search1394_2 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imad24_ir3,
      0, 1,
      { 16, 36, 122 },
      -1,
   } },

   /* replace1394_0 -> 16 in the cache */
   /* replace1394_1 -> 36 in the cache */
   /* replace1394 -> 4034 in the cache */

   /* ('imad24_ir3', 'a', 0, 'c') => c */
   /* search1395_0 -> 16 in the cache */
   /* search1395_1 -> 122 in the cache */
   /* search1395_2 -> 555 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imad24_ir3,
      0, 1,
      { 16, 122, 555 },
      -1,
   } },

   /* replace1395 -> 555 in the cache */

   /* ('imad24_ir3', 'a', 1, 'c') => ('iadd', 'a', 'c') */
   /* search1396_0 -> 16 in the cache */
   /* search1396_1 -> 396 in the cache */
   /* search1396_2 -> 555 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imad24_ir3,
      0, 1,
      { 16, 396, 555 },
      -1,
   } },

   /* replace1396_0 -> 16 in the cache */
   /* replace1396_1 -> 555 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 16, 555 },
      -1,
   } },

   /* ('imad24_ir3', '#a', '#b', 'c') => ('iadd', ('imul', 'a', 'b'), 'c') */
   /* search1397_0 -> 286 in the cache */
   /* search1397_1 -> 33 in the cache */
   /* search1397_2 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imad24_ir3,
      0, 1,
      { 286, 33, 135 },
      -1,
   } },

   /* replace1397_0_0 -> 16 in the cache */
   /* replace1397_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      1, 1,
      { 16, 36 },
      -1,
   } },
   /* replace1397_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 4044, 135 },
      -1,
   } },

   /* ('imul24', 'a', '#b@32(is_pos_power_of_two)') => ('ishl', 'a', ('find_lsb', 'b')) */
   /* search1398_0 -> 16 in the cache */
   /* search1398_1 -> 2270 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul24,
      0, 1,
      { 16, 2270 },
      -1,
   } },

   /* replace1398_0 -> 16 in the cache */
   /* replace1398_1_0 -> 36 in the cache */
   /* replace1398_1 -> 2276 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 16, 2276 },
      -1,
   } },

   /* ('imul24', 'a', '#b@32(is_neg_power_of_two)') => ('ineg', ('ishl', 'a', ('find_lsb', ('iabs', 'b')))) */
   /* search1399_0 -> 16 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      true,
      nir_type_invalid,
      1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul24,
      0, 1,
      { 16, 4048 },
      -1,
   } },

   /* replace1399_0_0 -> 16 in the cache */
   /* replace1399_0_1_0_0 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iabs,
      -1, 0,
      { 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_find_lsb,
      -1, 0,
      { 4050 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 16, 4051 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 4052 },
      -1,
   } },

   /* ('imul24', 'a', 0) => 0 */
   /* search1400_0 -> 16 in the cache */
   /* search1400_1 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul24,
      0, 1,
      { 16, 122 },
      -1,
   } },

   /* replace1400 -> 122 in the cache */

   /* ('bcsel', ('ult', ('iadd', 'a', 'b'), 'a'), -1, ('iadd@8', 'a', 'b')) => ('uadd_sat', 'a', 'b') */
   /* search1401_0_0_0 -> 6 in the cache */
   /* search1401_0_0_1 -> 2128 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 6, 2128 },
      -1,
   } },
   /* search1401_0_1 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 1,
      { 4055, 6 },
      -1,
   } },
   /* search1401_1 -> 1435 in the cache */
   /* search1401_2_0 -> 6 in the cache */
   /* search1401_2_1 -> 2128 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 6, 2128 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 4056, 1435, 4057 },
      -1,
   } },

   /* replace1401_0 -> 6 in the cache */
   /* replace1401_1 -> 2128 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_uadd_sat,
      0, 1,
      { 6, 2128 },
      -1,
   } },

   /* ('bcsel', ('uge', ('iadd', 'a', 'b'), 'a'), ('iadd@8', 'a', 'b'), -1) => ('uadd_sat', 'a', 'b') */
   /* search1402_0_0_0 -> 6 in the cache */
   /* search1402_0_0_1 -> 2128 in the cache */
   /* search1402_0_0 -> 4055 in the cache */
   /* search1402_0_1 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 1,
      { 4055, 6 },
      -1,
   } },
   /* search1402_1_0 -> 6 in the cache */
   /* search1402_1_1 -> 2128 in the cache */
   /* search1402_1 -> 4057 in the cache */
   /* search1402_2 -> 1435 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 4060, 4057, 1435 },
      -1,
   } },

   /* replace1402_0 -> 6 in the cache */
   /* replace1402_1 -> 2128 in the cache */
   /* replace1402 -> 4059 in the cache */

   /* ('bcsel', ('ieq', ('uadd_carry', 'a', 'b'), 0), ('iadd@8', 'a', 'b'), -1) => ('uadd_sat', 'a', 'b') */
   /* search1403_0_0_0 -> 6 in the cache */
   /* search1403_0_0_1 -> 2128 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_uadd_carry,
      1, 1,
      { 6, 2128 },
      -1,
   } },
   /* search1403_0_1 -> 835 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 4062, 835 },
      -1,
   } },
   /* search1403_1_0 -> 6 in the cache */
   /* search1403_1_1 -> 2128 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_iadd,
      2, 1,
      { 6, 2128 },
      -1,
   } },
   /* search1403_2 -> 1435 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 3,
      { 4063, 4064, 1435 },
      -1,
   } },

   /* replace1403_0 -> 6 in the cache */
   /* replace1403_1 -> 2128 in the cache */
   /* replace1403 -> 4059 in the cache */

   /* ('bcsel', ('ine', ('uadd_carry', 'a', 'b'), 0), -1, ('iadd@8', 'a', 'b')) => ('uadd_sat', 'a', 'b') */
   /* search1404_0_0_0 -> 6 in the cache */
   /* search1404_0_0_1 -> 2128 in the cache */
   /* search1404_0_0 -> 4062 in the cache */
   /* search1404_0_1 -> 835 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 4062, 835 },
      -1,
   } },
   /* search1404_1 -> 1435 in the cache */
   /* search1404_2_0 -> 6 in the cache */
   /* search1404_2_1 -> 2128 in the cache */
   /* search1404_2 -> 4064 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 3,
      { 4066, 1435, 4064 },
      -1,
   } },

   /* replace1404_0 -> 6 in the cache */
   /* replace1404_1 -> 2128 in the cache */
   /* replace1404 -> 4059 in the cache */

   /* ('bcsel', ('ult', ('iadd', 'a', 'b'), 'a'), -1, ('iadd@16', 'a', 'b')) => ('uadd_sat', 'a', 'b') */
   /* search1405_0_0_0 -> 11 in the cache */
   /* search1405_0_0_1 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 11, 258 },
      -1,
   } },
   /* search1405_0_1 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 1,
      { 4068, 11 },
      -1,
   } },
   /* search1405_1 -> 1457 in the cache */
   /* search1405_2_0 -> 11 in the cache */
   /* search1405_2_1 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 11, 258 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 4069, 1457, 4070 },
      -1,
   } },

   /* replace1405_0 -> 11 in the cache */
   /* replace1405_1 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_uadd_sat,
      0, 1,
      { 11, 258 },
      -1,
   } },

   /* ('bcsel', ('uge', ('iadd', 'a', 'b'), 'a'), ('iadd@16', 'a', 'b'), -1) => ('uadd_sat', 'a', 'b') */
   /* search1406_0_0_0 -> 11 in the cache */
   /* search1406_0_0_1 -> 258 in the cache */
   /* search1406_0_0 -> 4068 in the cache */
   /* search1406_0_1 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 1,
      { 4068, 11 },
      -1,
   } },
   /* search1406_1_0 -> 11 in the cache */
   /* search1406_1_1 -> 258 in the cache */
   /* search1406_1 -> 4070 in the cache */
   /* search1406_2 -> 1457 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 4073, 4070, 1457 },
      -1,
   } },

   /* replace1406_0 -> 11 in the cache */
   /* replace1406_1 -> 258 in the cache */
   /* replace1406 -> 4072 in the cache */

   /* ('bcsel', ('ieq', ('uadd_carry', 'a', 'b'), 0), ('iadd@16', 'a', 'b'), -1) => ('uadd_sat', 'a', 'b') */
   /* search1407_0_0_0 -> 11 in the cache */
   /* search1407_0_0_1 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_uadd_carry,
      1, 1,
      { 11, 258 },
      -1,
   } },
   /* search1407_0_1 -> 856 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 4075, 856 },
      -1,
   } },
   /* search1407_1_0 -> 11 in the cache */
   /* search1407_1_1 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iadd,
      2, 1,
      { 11, 258 },
      -1,
   } },
   /* search1407_2 -> 1457 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 3,
      { 4076, 4077, 1457 },
      -1,
   } },

   /* replace1407_0 -> 11 in the cache */
   /* replace1407_1 -> 258 in the cache */
   /* replace1407 -> 4072 in the cache */

   /* ('bcsel', ('ine', ('uadd_carry', 'a', 'b'), 0), -1, ('iadd@16', 'a', 'b')) => ('uadd_sat', 'a', 'b') */
   /* search1408_0_0_0 -> 11 in the cache */
   /* search1408_0_0_1 -> 258 in the cache */
   /* search1408_0_0 -> 4075 in the cache */
   /* search1408_0_1 -> 856 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 4075, 856 },
      -1,
   } },
   /* search1408_1 -> 1457 in the cache */
   /* search1408_2_0 -> 11 in the cache */
   /* search1408_2_1 -> 258 in the cache */
   /* search1408_2 -> 4077 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 3,
      { 4079, 1457, 4077 },
      -1,
   } },

   /* replace1408_0 -> 11 in the cache */
   /* replace1408_1 -> 258 in the cache */
   /* replace1408 -> 4072 in the cache */

   /* ('bcsel', ('ult', ('iadd', 'a', 'b'), 'a'), -1, ('iadd@32', 'a', 'b')) => ('uadd_sat', 'a', 'b') */
   /* search1409_0_0_0 -> 16 in the cache */
   /* search1409_0_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 16, 36 },
      -1,
   } },
   /* search1409_0_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 1,
      { 4081, 16 },
      -1,
   } },
   /* search1409_1 -> 124 in the cache */
   /* search1409_2_0 -> 16 in the cache */
   /* search1409_2_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 16, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 4082, 124, 4083 },
      -1,
   } },

   /* replace1409_0 -> 16 in the cache */
   /* replace1409_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_uadd_sat,
      0, 1,
      { 16, 36 },
      -1,
   } },

   /* ('bcsel', ('uge', ('iadd', 'a', 'b'), 'a'), ('iadd@32', 'a', 'b'), -1) => ('uadd_sat', 'a', 'b') */
   /* search1410_0_0_0 -> 16 in the cache */
   /* search1410_0_0_1 -> 36 in the cache */
   /* search1410_0_0 -> 4081 in the cache */
   /* search1410_0_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 1,
      { 4081, 16 },
      -1,
   } },
   /* search1410_1_0 -> 16 in the cache */
   /* search1410_1_1 -> 36 in the cache */
   /* search1410_1 -> 4083 in the cache */
   /* search1410_2 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 4086, 4083, 124 },
      -1,
   } },

   /* replace1410_0 -> 16 in the cache */
   /* replace1410_1 -> 36 in the cache */
   /* replace1410 -> 4085 in the cache */

   /* ('bcsel', ('ieq', ('uadd_carry', 'a', 'b'), 0), ('iadd@32', 'a', 'b'), -1) => ('uadd_sat', 'a', 'b') */
   /* search1411_0_0_0 -> 16 in the cache */
   /* search1411_0_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_uadd_carry,
      1, 1,
      { 16, 36 },
      -1,
   } },
   /* search1411_0_1 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 4088, 122 },
      -1,
   } },
   /* search1411_1_0 -> 16 in the cache */
   /* search1411_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      2, 1,
      { 16, 36 },
      -1,
   } },
   /* search1411_2 -> 124 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 3,
      { 4089, 4090, 124 },
      -1,
   } },

   /* replace1411_0 -> 16 in the cache */
   /* replace1411_1 -> 36 in the cache */
   /* replace1411 -> 4085 in the cache */

   /* ('bcsel', ('ine', ('uadd_carry', 'a', 'b'), 0), -1, ('iadd@32', 'a', 'b')) => ('uadd_sat', 'a', 'b') */
   /* search1412_0_0_0 -> 16 in the cache */
   /* search1412_0_0_1 -> 36 in the cache */
   /* search1412_0_0 -> 4088 in the cache */
   /* search1412_0_1 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 4088, 122 },
      -1,
   } },
   /* search1412_1 -> 124 in the cache */
   /* search1412_2_0 -> 16 in the cache */
   /* search1412_2_1 -> 36 in the cache */
   /* search1412_2 -> 4090 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 3,
      { 4092, 124, 4090 },
      -1,
   } },

   /* replace1412_0 -> 16 in the cache */
   /* replace1412_1 -> 36 in the cache */
   /* replace1412 -> 4085 in the cache */

   /* ('bcsel', ('ult', ('iadd', 'a', 'b'), 'a'), -1, ('iadd@64', 'a', 'b')) => ('uadd_sat', 'a', 'b') */
   /* search1413_0_0_0 -> 21 in the cache */
   /* search1413_0_0_1 -> 41 in the cache */
   /* search1413_0_0 -> 3755 in the cache */
   /* search1413_0_1 -> 21 in the cache */
   /* search1413_0 -> 3756 in the cache */
   /* search1413_1 -> 1499 in the cache */
   /* search1413_2_0 -> 21 in the cache */
   /* search1413_2_1 -> 41 in the cache */
   /* search1413_2 -> 3757 in the cache */
   /* search1413 -> 3758 in the cache */

   /* replace1413_0 -> 21 in the cache */
   /* replace1413_1 -> 41 in the cache */
   /* replace1413 -> 3754 in the cache */

   /* ('bcsel', ('uge', ('iadd', 'a', 'b'), 'a'), ('iadd@64', 'a', 'b'), -1) => ('uadd_sat', 'a', 'b') */
   /* search1414_0_0_0 -> 21 in the cache */
   /* search1414_0_0_1 -> 41 in the cache */
   /* search1414_0_0 -> 3755 in the cache */
   /* search1414_0_1 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 1,
      { 3755, 21 },
      -1,
   } },
   /* search1414_1_0 -> 21 in the cache */
   /* search1414_1_1 -> 41 in the cache */
   /* search1414_1 -> 3757 in the cache */
   /* search1414_2 -> 1499 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 4094, 3757, 1499 },
      -1,
   } },

   /* replace1414_0 -> 21 in the cache */
   /* replace1414_1 -> 41 in the cache */
   /* replace1414 -> 3754 in the cache */

   /* ('bcsel', ('ieq', ('uadd_carry', 'a', 'b'), 0), ('iadd@64', 'a', 'b'), -1) => ('uadd_sat', 'a', 'b') */
   /* search1415_0_0_0 -> 21 in the cache */
   /* search1415_0_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_uadd_carry,
      1, 1,
      { 21, 41 },
      -1,
   } },
   /* search1415_0_1 -> 897 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 4096, 897 },
      -1,
   } },
   /* search1415_1_0 -> 21 in the cache */
   /* search1415_1_1 -> 41 in the cache */
   /* search1415_1 -> 3771 in the cache */
   /* search1415_2 -> 1499 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 3,
      { 4097, 3771, 1499 },
      -1,
   } },

   /* replace1415_0 -> 21 in the cache */
   /* replace1415_1 -> 41 in the cache */
   /* replace1415 -> 3754 in the cache */

   /* ('bcsel', ('ine', ('uadd_carry', 'a', 'b'), 0), -1, ('iadd@64', 'a', 'b')) => ('uadd_sat', 'a', 'b') */
   /* search1416_0_0_0 -> 21 in the cache */
   /* search1416_0_0_1 -> 41 in the cache */
   /* search1416_0_0 -> 4096 in the cache */
   /* search1416_0_1 -> 897 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 4096, 897 },
      -1,
   } },
   /* search1416_1 -> 1499 in the cache */
   /* search1416_2_0 -> 21 in the cache */
   /* search1416_2_1 -> 41 in the cache */
   /* search1416_2 -> 3771 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 3,
      { 4099, 1499, 3771 },
      -1,
   } },

   /* replace1416_0 -> 21 in the cache */
   /* replace1416_1 -> 41 in the cache */
   /* replace1416 -> 3754 in the cache */

   /* ('bcsel', ('ult', 'a', 'b'), 0, ('iadd@8', 'a', ('ineg', 'b'))) => ('usub_sat', 'a', 'b') */
   /* search1417_0_0 -> 6 in the cache */
   /* search1417_0_1 -> 2128 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 6, 2128 },
      -1,
   } },
   /* search1417_1 -> 835 in the cache */
   /* search1417_2_0 -> 6 in the cache */
   /* search1417_2_1_0 -> 2128 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 2128 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 6, 4102 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 4101, 835, 4103 },
      -1,
   } },

   /* replace1417_0 -> 6 in the cache */
   /* replace1417_1 -> 2128 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_usub_sat,
      -1, 0,
      { 6, 2128 },
      -1,
   } },

   /* ('bcsel', ('uge', 'a', 'b'), ('iadd@8', 'a', ('ineg', 'b')), 0) => ('usub_sat', 'a', 'b') */
   /* search1418_0_0 -> 6 in the cache */
   /* search1418_0_1 -> 2128 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 6, 2128 },
      -1,
   } },
   /* search1418_1_0 -> 6 in the cache */
   /* search1418_1_1_0 -> 2128 in the cache */
   /* search1418_1_1 -> 4102 in the cache */
   /* search1418_1 -> 4103 in the cache */
   /* search1418_2 -> 835 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 4106, 4103, 835 },
      -1,
   } },

   /* replace1418_0 -> 6 in the cache */
   /* replace1418_1 -> 2128 in the cache */
   /* replace1418 -> 4105 in the cache */

   /* ('bcsel', ('ieq', ('usub_borrow', 'a', 'b'), 0), ('iadd@8', 'a', ('ineg', 'b')), 0) => ('usub_sat', 'a', 'b') */
   /* search1419_0_0_0 -> 6 in the cache */
   /* search1419_0_0_1 -> 2128 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_usub_borrow,
      -1, 0,
      { 6, 2128 },
      -1,
   } },
   /* search1419_0_1 -> 835 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 4108, 835 },
      -1,
   } },
   /* search1419_1_0 -> 6 in the cache */
   /* search1419_1_1_0 -> 2128 in the cache */
   /* search1419_1_1 -> 4102 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 6, 4102 },
      -1,
   } },
   /* search1419_2 -> 835 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 4109, 4110, 835 },
      -1,
   } },

   /* replace1419_0 -> 6 in the cache */
   /* replace1419_1 -> 2128 in the cache */
   /* replace1419 -> 4105 in the cache */

   /* ('bcsel', ('ine', ('usub_borrow', 'a', 'b'), 0), 0, ('iadd@8', 'a', ('ineg', 'b'))) => ('usub_sat', 'a', 'b') */
   /* search1420_0_0_0 -> 6 in the cache */
   /* search1420_0_0_1 -> 2128 in the cache */
   /* search1420_0_0 -> 4108 in the cache */
   /* search1420_0_1 -> 835 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 4108, 835 },
      -1,
   } },
   /* search1420_1 -> 835 in the cache */
   /* search1420_2_0 -> 6 in the cache */
   /* search1420_2_1_0 -> 2128 in the cache */
   /* search1420_2_1 -> 4102 in the cache */
   /* search1420_2 -> 4110 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 4112, 835, 4110 },
      -1,
   } },

   /* replace1420_0 -> 6 in the cache */
   /* replace1420_1 -> 2128 in the cache */
   /* replace1420 -> 4105 in the cache */

   /* ('bcsel', ('ult', 'a', 'b'), 0, ('iadd@16', 'a', ('ineg', 'b'))) => ('usub_sat', 'a', 'b') */
   /* search1421_0_0 -> 11 in the cache */
   /* search1421_0_1 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 11, 258 },
      -1,
   } },
   /* search1421_1 -> 856 in the cache */
   /* search1421_2_0 -> 11 in the cache */
   /* search1421_2_1_0 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 258 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 11, 4115 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 4114, 856, 4116 },
      -1,
   } },

   /* replace1421_0 -> 11 in the cache */
   /* replace1421_1 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_usub_sat,
      -1, 0,
      { 11, 258 },
      -1,
   } },

   /* ('bcsel', ('uge', 'a', 'b'), ('iadd@16', 'a', ('ineg', 'b')), 0) => ('usub_sat', 'a', 'b') */
   /* search1422_0_0 -> 11 in the cache */
   /* search1422_0_1 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 11, 258 },
      -1,
   } },
   /* search1422_1_0 -> 11 in the cache */
   /* search1422_1_1_0 -> 258 in the cache */
   /* search1422_1_1 -> 4115 in the cache */
   /* search1422_1 -> 4116 in the cache */
   /* search1422_2 -> 856 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 4119, 4116, 856 },
      -1,
   } },

   /* replace1422_0 -> 11 in the cache */
   /* replace1422_1 -> 258 in the cache */
   /* replace1422 -> 4118 in the cache */

   /* ('bcsel', ('ieq', ('usub_borrow', 'a', 'b'), 0), ('iadd@16', 'a', ('ineg', 'b')), 0) => ('usub_sat', 'a', 'b') */
   /* search1423_0_0_0 -> 11 in the cache */
   /* search1423_0_0_1 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_usub_borrow,
      -1, 0,
      { 11, 258 },
      -1,
   } },
   /* search1423_0_1 -> 856 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 4121, 856 },
      -1,
   } },
   /* search1423_1_0 -> 11 in the cache */
   /* search1423_1_1_0 -> 258 in the cache */
   /* search1423_1_1 -> 4115 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 11, 4115 },
      -1,
   } },
   /* search1423_2 -> 856 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 4122, 4123, 856 },
      -1,
   } },

   /* replace1423_0 -> 11 in the cache */
   /* replace1423_1 -> 258 in the cache */
   /* replace1423 -> 4118 in the cache */

   /* ('bcsel', ('ine', ('usub_borrow', 'a', 'b'), 0), 0, ('iadd@16', 'a', ('ineg', 'b'))) => ('usub_sat', 'a', 'b') */
   /* search1424_0_0_0 -> 11 in the cache */
   /* search1424_0_0_1 -> 258 in the cache */
   /* search1424_0_0 -> 4121 in the cache */
   /* search1424_0_1 -> 856 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 4121, 856 },
      -1,
   } },
   /* search1424_1 -> 856 in the cache */
   /* search1424_2_0 -> 11 in the cache */
   /* search1424_2_1_0 -> 258 in the cache */
   /* search1424_2_1 -> 4115 in the cache */
   /* search1424_2 -> 4123 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 4125, 856, 4123 },
      -1,
   } },

   /* replace1424_0 -> 11 in the cache */
   /* replace1424_1 -> 258 in the cache */
   /* replace1424 -> 4118 in the cache */

   /* ('bcsel', ('ult', 'a', 'b'), 0, ('iadd@32', 'a', ('ineg', 'b'))) => ('usub_sat', 'a', 'b') */
   /* search1425_0_0 -> 16 in the cache */
   /* search1425_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 16, 36 },
      -1,
   } },
   /* search1425_1 -> 122 in the cache */
   /* search1425_2_0 -> 16 in the cache */
   /* search1425_2_1_0 -> 36 in the cache */
   /* search1425_2_1 -> 2788 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 16, 2788 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 4127, 122, 4128 },
      -1,
   } },

   /* replace1425_0 -> 16 in the cache */
   /* replace1425_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_usub_sat,
      -1, 0,
      { 16, 36 },
      -1,
   } },

   /* ('bcsel', ('uge', 'a', 'b'), ('iadd@32', 'a', ('ineg', 'b')), 0) => ('usub_sat', 'a', 'b') */
   /* search1426_0_0 -> 16 in the cache */
   /* search1426_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 16, 36 },
      -1,
   } },
   /* search1426_1_0 -> 16 in the cache */
   /* search1426_1_1_0 -> 36 in the cache */
   /* search1426_1_1 -> 2788 in the cache */
   /* search1426_1 -> 4128 in the cache */
   /* search1426_2 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 4131, 4128, 122 },
      -1,
   } },

   /* replace1426_0 -> 16 in the cache */
   /* replace1426_1 -> 36 in the cache */
   /* replace1426 -> 4130 in the cache */

   /* ('bcsel', ('ieq', ('usub_borrow', 'a', 'b'), 0), ('iadd@32', 'a', ('ineg', 'b')), 0) => ('usub_sat', 'a', 'b') */
   /* search1427_0_0_0 -> 16 in the cache */
   /* search1427_0_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_usub_borrow,
      -1, 0,
      { 16, 36 },
      -1,
   } },
   /* search1427_0_1 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 4133, 122 },
      -1,
   } },
   /* search1427_1_0 -> 16 in the cache */
   /* search1427_1_1_0 -> 36 in the cache */
   /* search1427_1_1 -> 2788 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 16, 2788 },
      -1,
   } },
   /* search1427_2 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 4134, 4135, 122 },
      -1,
   } },

   /* replace1427_0 -> 16 in the cache */
   /* replace1427_1 -> 36 in the cache */
   /* replace1427 -> 4130 in the cache */

   /* ('bcsel', ('ine', ('usub_borrow', 'a', 'b'), 0), 0, ('iadd@32', 'a', ('ineg', 'b'))) => ('usub_sat', 'a', 'b') */
   /* search1428_0_0_0 -> 16 in the cache */
   /* search1428_0_0_1 -> 36 in the cache */
   /* search1428_0_0 -> 4133 in the cache */
   /* search1428_0_1 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 4133, 122 },
      -1,
   } },
   /* search1428_1 -> 122 in the cache */
   /* search1428_2_0 -> 16 in the cache */
   /* search1428_2_1_0 -> 36 in the cache */
   /* search1428_2_1 -> 2788 in the cache */
   /* search1428_2 -> 4135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 4137, 122, 4135 },
      -1,
   } },

   /* replace1428_0 -> 16 in the cache */
   /* replace1428_1 -> 36 in the cache */
   /* replace1428 -> 4130 in the cache */

   /* ('bcsel', ('ult', 'a', 'b'), 0, ('iadd@64', 'a', ('ineg', 'b'))) => ('usub_sat', 'a', 'b') */
   /* search1429_0_0 -> 21 in the cache */
   /* search1429_0_1 -> 41 in the cache */
   /* search1429_0 -> 3765 in the cache */
   /* search1429_1 -> 897 in the cache */
   /* search1429_2_0 -> 21 in the cache */
   /* search1429_2_1_0 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 21, 4139 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 3765, 897, 4140 },
      -1,
   } },

   /* replace1429_0 -> 21 in the cache */
   /* replace1429_1 -> 41 in the cache */
   /* replace1429 -> 3764 in the cache */

   /* ('bcsel', ('uge', 'a', 'b'), ('iadd@64', 'a', ('ineg', 'b')), 0) => ('usub_sat', 'a', 'b') */
   /* search1430_0_0 -> 21 in the cache */
   /* search1430_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 21, 41 },
      -1,
   } },
   /* search1430_1_0 -> 21 in the cache */
   /* search1430_1_1_0 -> 41 in the cache */
   /* search1430_1_1 -> 4139 in the cache */
   /* search1430_1 -> 4140 in the cache */
   /* search1430_2 -> 897 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 4142, 4140, 897 },
      -1,
   } },

   /* replace1430_0 -> 21 in the cache */
   /* replace1430_1 -> 41 in the cache */
   /* replace1430 -> 3764 in the cache */

   /* ('bcsel', ('ieq', ('usub_borrow', 'a', 'b'), 0), ('iadd@64', 'a', ('ineg', 'b')), 0) => ('usub_sat', 'a', 'b') */
   /* search1431_0_0_0 -> 21 in the cache */
   /* search1431_0_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_usub_borrow,
      -1, 0,
      { 21, 41 },
      -1,
   } },
   /* search1431_0_1 -> 897 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 4144, 897 },
      -1,
   } },
   /* search1431_1_0 -> 21 in the cache */
   /* search1431_1_1_0 -> 41 in the cache */
   /* search1431_1_1 -> 4139 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 21, 4139 },
      -1,
   } },
   /* search1431_2 -> 897 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 4145, 4146, 897 },
      -1,
   } },

   /* replace1431_0 -> 21 in the cache */
   /* replace1431_1 -> 41 in the cache */
   /* replace1431 -> 3764 in the cache */

   /* ('bcsel', ('ine', ('usub_borrow', 'a', 'b'), 0), 0, ('iadd@64', 'a', ('ineg', 'b'))) => ('usub_sat', 'a', 'b') */
   /* search1432_0_0_0 -> 21 in the cache */
   /* search1432_0_0_1 -> 41 in the cache */
   /* search1432_0_0 -> 4144 in the cache */
   /* search1432_0_1 -> 897 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 4144, 897 },
      -1,
   } },
   /* search1432_1 -> 897 in the cache */
   /* search1432_2_0 -> 21 in the cache */
   /* search1432_2_1_0 -> 41 in the cache */
   /* search1432_2_1 -> 4139 in the cache */
   /* search1432_2 -> 4146 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 4148, 897, 4146 },
      -1,
   } },

   /* replace1432_0 -> 21 in the cache */
   /* replace1432_1 -> 41 in the cache */
   /* replace1432 -> 3764 in the cache */

   /* ('iadd_sat@8', 'a', 'b') => ('bcsel', ('ige', 'b', 1), ('bcsel', ('ilt', ('iadd', 'a', 'b'), 'a'), 127, ('iadd', 'a', 'b')), ('bcsel', ('ilt', 'a', ('iadd', 'a', 'b')), 128, ('iadd', 'a', 'b'))) */
   /* search1433_0 -> 6 in the cache */
   /* search1433_1 -> 2128 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_iadd_sat,
      0, 1,
      { 6, 2128 },
      -1,
   } },

   /* replace1433_0_0 -> 2128 in the cache */
   /* replace1433_0_1 -> 1430 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 2128, 1430 },
      -1,
   } },
   /* replace1433_1_0_0_0 -> 6 in the cache */
   /* replace1433_1_0_0_1 -> 2128 in the cache */
   /* replace1433_1_0_0 -> 4055 in the cache */
   /* replace1433_1_0_1 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 4055, 6 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 8 },
      nir_type_int, { 0x7f /* 127 */ },
   } },
   /* replace1433_1_2_0 -> 6 in the cache */
   /* replace1433_1_2_1 -> 2128 in the cache */
   /* replace1433_1_2 -> 4057 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 4152, 4153, 4057 },
      -1,
   } },
   /* replace1433_2_0_0 -> 6 in the cache */
   /* replace1433_2_0_1_0 -> 6 in the cache */
   /* replace1433_2_0_1_1 -> 2128 in the cache */
   /* replace1433_2_0_1 -> 4064 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 6, 4064 },
      -1,
   } },
   /* replace1433_2_1 -> 7 in the cache */
   /* replace1433_2_2_0 -> 6 in the cache */
   /* replace1433_2_2_1 -> 2128 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_iadd,
      3, 1,
      { 6, 2128 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 4155, 7, 4156 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 4,
      { 4151, 4154, 4157 },
      -1,
   } },

   /* ('isub_sat@8', 'a', 'b') => ('bcsel', ('ilt', 'b', 0), ('bcsel', ('ilt', ('isub', 'a', 'b'), 'a'), 127, ('isub', 'a', 'b')), ('bcsel', ('ilt', 'a', ('isub', 'a', 'b')), 128, ('isub', 'a', 'b'))) */
   /* search1434_0 -> 6 in the cache */
   /* search1434_1 -> 2128 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_isub_sat,
      -1, 0,
      { 6, 2128 },
      -1,
   } },

   /* replace1434_0_0 -> 2128 in the cache */
   /* replace1434_0_1 -> 835 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 2128, 835 },
      -1,
   } },
   /* replace1434_1_0_0_0 -> 6 in the cache */
   /* replace1434_1_0_0_1 -> 2128 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 6, 2128 },
      -1,
   } },
   /* replace1434_1_0_1 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4161, 6 },
      -1,
   } },
   /* replace1434_1_1 -> 4153 in the cache */
   /* replace1434_1_2_0 -> 6 in the cache */
   /* replace1434_1_2_1 -> 2128 in the cache */
   /* replace1434_1_2 -> 4161 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 4162, 4153, 4161 },
      -1,
   } },
   /* replace1434_2_0_0 -> 6 in the cache */
   /* replace1434_2_0_1_0 -> 6 in the cache */
   /* replace1434_2_0_1_1 -> 2128 in the cache */
   /* replace1434_2_0_1 -> 4161 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 6, 4161 },
      -1,
   } },
   /* replace1434_2_1 -> 7 in the cache */
   /* replace1434_2_2_0 -> 6 in the cache */
   /* replace1434_2_2_1 -> 2128 in the cache */
   /* replace1434_2_2 -> 4161 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 4164, 7, 4161 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 4160, 4163, 4165 },
      -1,
   } },

   /* ('iadd_sat@16', 'a', 'b') => ('bcsel', ('ige', 'b', 1), ('bcsel', ('ilt', ('iadd', 'a', 'b'), 'a'), 32767, ('iadd', 'a', 'b')), ('bcsel', ('ilt', 'a', ('iadd', 'a', 'b')), 32768, ('iadd', 'a', 'b'))) */
   /* search1435_0 -> 11 in the cache */
   /* search1435_1 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iadd_sat,
      0, 1,
      { 11, 258 },
      -1,
   } },

   /* replace1435_0_0 -> 258 in the cache */
   /* replace1435_0_1 -> 1452 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 258, 1452 },
      -1,
   } },
   /* replace1435_1_0_0_0 -> 11 in the cache */
   /* replace1435_1_0_0_1 -> 258 in the cache */
   /* replace1435_1_0_0 -> 4068 in the cache */
   /* replace1435_1_0_1 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 4068, 11 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 16 },
      nir_type_int, { 0x7fff /* 32767 */ },
   } },
   /* replace1435_1_2_0 -> 11 in the cache */
   /* replace1435_1_2_1 -> 258 in the cache */
   /* replace1435_1_2 -> 4070 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 4169, 4170, 4070 },
      -1,
   } },
   /* replace1435_2_0_0 -> 11 in the cache */
   /* replace1435_2_0_1_0 -> 11 in the cache */
   /* replace1435_2_0_1_1 -> 258 in the cache */
   /* replace1435_2_0_1 -> 4077 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 11, 4077 },
      -1,
   } },
   /* replace1435_2_1 -> 12 in the cache */
   /* replace1435_2_2_0 -> 11 in the cache */
   /* replace1435_2_2_1 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iadd,
      3, 1,
      { 11, 258 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 4172, 12, 4173 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 4,
      { 4168, 4171, 4174 },
      -1,
   } },

   /* ('isub_sat@16', 'a', 'b') => ('bcsel', ('ilt', 'b', 0), ('bcsel', ('ilt', ('isub', 'a', 'b'), 'a'), 32767, ('isub', 'a', 'b')), ('bcsel', ('ilt', 'a', ('isub', 'a', 'b')), 32768, ('isub', 'a', 'b'))) */
   /* search1436_0 -> 11 in the cache */
   /* search1436_1 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_isub_sat,
      -1, 0,
      { 11, 258 },
      -1,
   } },

   /* replace1436_0_0 -> 258 in the cache */
   /* replace1436_0_1 -> 856 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 258, 856 },
      -1,
   } },
   /* replace1436_1_0_0_0 -> 11 in the cache */
   /* replace1436_1_0_0_1 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 11, 258 },
      -1,
   } },
   /* replace1436_1_0_1 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4178, 11 },
      -1,
   } },
   /* replace1436_1_1 -> 4170 in the cache */
   /* replace1436_1_2_0 -> 11 in the cache */
   /* replace1436_1_2_1 -> 258 in the cache */
   /* replace1436_1_2 -> 4178 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 4179, 4170, 4178 },
      -1,
   } },
   /* replace1436_2_0_0 -> 11 in the cache */
   /* replace1436_2_0_1_0 -> 11 in the cache */
   /* replace1436_2_0_1_1 -> 258 in the cache */
   /* replace1436_2_0_1 -> 4178 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 11, 4178 },
      -1,
   } },
   /* replace1436_2_1 -> 12 in the cache */
   /* replace1436_2_2_0 -> 11 in the cache */
   /* replace1436_2_2_1 -> 258 in the cache */
   /* replace1436_2_2 -> 4178 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 4181, 12, 4178 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 4177, 4180, 4182 },
      -1,
   } },

   /* ('iadd_sat@32', 'a', 'b') => ('bcsel', ('ige', 'b', 1), ('bcsel', ('ilt', ('iadd', 'a', 'b'), 'a'), 2147483647, ('iadd', 'a', 'b')), ('bcsel', ('ilt', 'a', ('iadd', 'a', 'b')), 2147483648, ('iadd', 'a', 'b'))) */
   /* search1437_0 -> 16 in the cache */
   /* search1437_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd_sat,
      0, 1,
      { 16, 36 },
      -1,
   } },

   /* replace1437_0_0 -> 36 in the cache */
   /* replace1437_0_1 -> 396 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 36, 396 },
      -1,
   } },
   /* replace1437_1_0_0_0 -> 16 in the cache */
   /* replace1437_1_0_0_1 -> 36 in the cache */
   /* replace1437_1_0_0 -> 4081 in the cache */
   /* replace1437_1_0_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 4081, 16 },
      -1,
   } },
   /* replace1437_1_1 -> 988 in the cache */
   /* replace1437_1_2_0 -> 16 in the cache */
   /* replace1437_1_2_1 -> 36 in the cache */
   /* replace1437_1_2 -> 4083 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 4186, 988, 4083 },
      -1,
   } },
   /* replace1437_2_0_0 -> 16 in the cache */
   /* replace1437_2_0_1_0 -> 16 in the cache */
   /* replace1437_2_0_1_1 -> 36 in the cache */
   /* replace1437_2_0_1 -> 4090 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 16, 4090 },
      -1,
   } },
   /* replace1437_2_1 -> 17 in the cache */
   /* replace1437_2_2_0 -> 16 in the cache */
   /* replace1437_2_2_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      3, 1,
      { 16, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 4188, 17, 4189 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 4,
      { 4185, 4187, 4190 },
      -1,
   } },

   /* ('isub_sat@32', 'a', 'b') => ('bcsel', ('ilt', 'b', 0), ('bcsel', ('ilt', ('isub', 'a', 'b'), 'a'), 2147483647, ('isub', 'a', 'b')), ('bcsel', ('ilt', 'a', ('isub', 'a', 'b')), 2147483648, ('isub', 'a', 'b'))) */
   /* search1438_0 -> 16 in the cache */
   /* search1438_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_isub_sat,
      -1, 0,
      { 16, 36 },
      -1,
   } },

   /* replace1438_0_0 -> 36 in the cache */
   /* replace1438_0_1 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 36, 122 },
      -1,
   } },
   /* replace1438_1_0_0_0 -> 16 in the cache */
   /* replace1438_1_0_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 16, 36 },
      -1,
   } },
   /* replace1438_1_0_1 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4194, 16 },
      -1,
   } },
   /* replace1438_1_1 -> 988 in the cache */
   /* replace1438_1_2_0 -> 16 in the cache */
   /* replace1438_1_2_1 -> 36 in the cache */
   /* replace1438_1_2 -> 4194 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 4195, 988, 4194 },
      -1,
   } },
   /* replace1438_2_0_0 -> 16 in the cache */
   /* replace1438_2_0_1_0 -> 16 in the cache */
   /* replace1438_2_0_1_1 -> 36 in the cache */
   /* replace1438_2_0_1 -> 4194 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 16, 4194 },
      -1,
   } },
   /* replace1438_2_1 -> 17 in the cache */
   /* replace1438_2_2_0 -> 16 in the cache */
   /* replace1438_2_2_1 -> 36 in the cache */
   /* replace1438_2_2 -> 4194 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 4197, 17, 4194 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 4193, 4196, 4198 },
      -1,
   } },

   /* ('iadd_sat@64', 'a', 'b') => ('bcsel', ('ige', 'b', 1), ('bcsel', ('ilt', ('iadd', 'a', 'b'), 'a'), 9223372036854775807, ('iadd', 'a', 'b')), ('bcsel', ('ilt', 'a', ('iadd', 'a', 'b')), 9223372036854775808, ('iadd', 'a', 'b'))) */
   /* search1439_0 -> 21 in the cache */
   /* search1439_1 -> 41 in the cache */
   /* search1439 -> 3768 in the cache */

   /* replace1439_0_0 -> 41 in the cache */
   /* replace1439_0_1 -> 1494 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 41, 1494 },
      -1,
   } },
   /* replace1439_1_0_0_0 -> 21 in the cache */
   /* replace1439_1_0_0_1 -> 41 in the cache */
   /* replace1439_1_0_0 -> 3755 in the cache */
   /* replace1439_1_0_1 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 3755, 21 },
      -1,
   } },
   /* replace1439_1_1 -> 3779 in the cache */
   /* replace1439_1_2_0 -> 21 in the cache */
   /* replace1439_1_2_1 -> 41 in the cache */
   /* replace1439_1_2 -> 3757 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 4201, 3779, 3757 },
      -1,
   } },
   /* replace1439_2_0_0 -> 21 in the cache */
   /* replace1439_2_0_1_0 -> 21 in the cache */
   /* replace1439_2_0_1_1 -> 41 in the cache */
   /* replace1439_2_0_1 -> 3771 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 1,
      { 21, 3771 },
      -1,
   } },
   /* replace1439_2_1 -> 22 in the cache */
   /* replace1439_2_2_0 -> 21 in the cache */
   /* replace1439_2_2_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_iadd,
      3, 1,
      { 21, 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 4203, 22, 4204 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 4,
      { 4200, 4202, 4205 },
      -1,
   } },

   /* ('isub_sat@64', 'a', 'b') => ('bcsel', ('ilt', 'b', 0), ('bcsel', ('ilt', ('isub', 'a', 'b'), 'a'), 9223372036854775807, ('isub', 'a', 'b')), ('bcsel', ('ilt', 'a', ('isub', 'a', 'b')), 9223372036854775808, ('isub', 'a', 'b'))) */
   /* search1440_0 -> 21 in the cache */
   /* search1440_1 -> 41 in the cache */
   /* search1440 -> 3782 in the cache */

   /* replace1440_0_0 -> 41 in the cache */
   /* replace1440_0_1 -> 897 in the cache */
   /* replace1440_0 -> 3769 in the cache */
   /* replace1440_1_0_0_0 -> 21 in the cache */
   /* replace1440_1_0_0_1 -> 41 in the cache */
   /* replace1440_1_0_0 -> 3766 in the cache */
   /* replace1440_1_0_1 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 3766, 21 },
      -1,
   } },
   /* replace1440_1_1 -> 3779 in the cache */
   /* replace1440_1_2_0 -> 21 in the cache */
   /* replace1440_1_2_1 -> 41 in the cache */
   /* replace1440_1_2 -> 3766 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 4207, 3779, 3766 },
      -1,
   } },
   /* replace1440_2_0_0 -> 21 in the cache */
   /* replace1440_2_0_1_0 -> 21 in the cache */
   /* replace1440_2_0_1_1 -> 41 in the cache */
   /* replace1440_2_0_1 -> 3766 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 21, 3766 },
      -1,
   } },
   /* replace1440_2_1 -> 22 in the cache */
   /* replace1440_2_2_0 -> 21 in the cache */
   /* replace1440_2_2_1 -> 41 in the cache */
   /* replace1440_2_2 -> 3766 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 4209, 22, 3766 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 3769, 4208, 4210 },
      -1,
   } },

   /* ('inot', ('ior(is_used_once)', ('feq', 'a', 'b'), ('feq', 'c', 'd'))) => ('iand', ('fneu', 'a', 'b'), ('fneu', 'c', 'd')) */
   /* search1441_0_0_0 -> 0 in the cache */
   /* search1441_0_0_1 -> 3 in the cache */
   /* search1441_0_0 -> 1074 in the cache */
   /* search1441_0_1_0 -> 152 in the cache */
   /* search1441_0_1_1 -> 153 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      2, 1,
      { 152, 153 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 1074, 4212 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 3,
      { 4213 },
      -1,
   } },

   /* replace1441_0_0 -> 0 in the cache */
   /* replace1441_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      1, 1,
      { 0, 3 },
      -1,
   } },
   /* replace1441_1_0 -> 152 in the cache */
   /* replace1441_1_1 -> 153 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      2, 1,
      { 152, 153 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 4215, 4216 },
      -1,
   } },

   /* ('inot', ('iand(is_used_once)', ('feq', 'a', 'b'), ('feq', 'c', 'd'))) => ('ior', ('fneu', 'a', 'b'), ('fneu', 'c', 'd')) */
   /* search1442_0_0_0 -> 0 in the cache */
   /* search1442_0_0_1 -> 3 in the cache */
   /* search1442_0_0 -> 1074 in the cache */
   /* search1442_0_1_0 -> 152 in the cache */
   /* search1442_0_1_1 -> 153 in the cache */
   /* search1442_0_1 -> 4212 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 1074, 4212 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 3,
      { 4218 },
      -1,
   } },

   /* replace1442_0_0 -> 0 in the cache */
   /* replace1442_0_1 -> 3 in the cache */
   /* replace1442_0 -> 4215 in the cache */
   /* replace1442_1_0 -> 152 in the cache */
   /* replace1442_1_1 -> 153 in the cache */
   /* replace1442_1 -> 4216 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 4215, 4216 },
      -1,
   } },

   /* ('inot', ('ior(is_used_once)', ('feq', 'a', 'b'), ('fneu', 'c', 'd'))) => ('iand', ('fneu', 'a', 'b'), ('feq', 'c', 'd')) */
   /* search1443_0_0_0 -> 0 in the cache */
   /* search1443_0_0_1 -> 3 in the cache */
   /* search1443_0_0 -> 1074 in the cache */
   /* search1443_0_1_0 -> 152 in the cache */
   /* search1443_0_1_1 -> 153 in the cache */
   /* search1443_0_1 -> 4216 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 1074, 4216 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 3,
      { 4221 },
      -1,
   } },

   /* replace1443_0_0 -> 0 in the cache */
   /* replace1443_0_1 -> 3 in the cache */
   /* replace1443_0 -> 4215 in the cache */
   /* replace1443_1_0 -> 152 in the cache */
   /* replace1443_1_1 -> 153 in the cache */
   /* replace1443_1 -> 4212 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 4215, 4212 },
      -1,
   } },

   /* ('inot', ('iand(is_used_once)', ('feq', 'a', 'b'), ('fneu', 'c', 'd'))) => ('ior', ('fneu', 'a', 'b'), ('feq', 'c', 'd')) */
   /* search1444_0_0_0 -> 0 in the cache */
   /* search1444_0_0_1 -> 3 in the cache */
   /* search1444_0_0 -> 1074 in the cache */
   /* search1444_0_1_0 -> 152 in the cache */
   /* search1444_0_1_1 -> 153 in the cache */
   /* search1444_0_1 -> 4216 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 1074, 4216 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 3,
      { 4224 },
      -1,
   } },

   /* replace1444_0_0 -> 0 in the cache */
   /* replace1444_0_1 -> 3 in the cache */
   /* replace1444_0 -> 4215 in the cache */
   /* replace1444_1_0 -> 152 in the cache */
   /* replace1444_1_1 -> 153 in the cache */
   /* replace1444_1 -> 4212 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 4215, 4212 },
      -1,
   } },

   /* ('inot', ('ior(is_used_once)', ('fneu', 'a', 'b'), ('fneu', 'c', 'd'))) => ('iand', ('feq', 'a', 'b'), ('feq', 'c', 'd')) */
   /* search1445_0_0_0 -> 0 in the cache */
   /* search1445_0_0_1 -> 3 in the cache */
   /* search1445_0_0 -> 4215 in the cache */
   /* search1445_0_1_0 -> 152 in the cache */
   /* search1445_0_1_1 -> 153 in the cache */
   /* search1445_0_1 -> 4216 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 4215, 4216 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 3,
      { 4227 },
      -1,
   } },

   /* replace1445_0_0 -> 0 in the cache */
   /* replace1445_0_1 -> 3 in the cache */
   /* replace1445_0 -> 1074 in the cache */
   /* replace1445_1_0 -> 152 in the cache */
   /* replace1445_1_1 -> 153 in the cache */
   /* replace1445_1 -> 4212 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 1074, 4212 },
      -1,
   } },

   /* ('inot', ('iand(is_used_once)', ('fneu', 'a', 'b'), ('fneu', 'c', 'd'))) => ('ior', ('feq', 'a', 'b'), ('feq', 'c', 'd')) */
   /* search1446_0_0_0 -> 0 in the cache */
   /* search1446_0_0_1 -> 3 in the cache */
   /* search1446_0_0 -> 4215 in the cache */
   /* search1446_0_1_0 -> 152 in the cache */
   /* search1446_0_1_1 -> 153 in the cache */
   /* search1446_0_1 -> 4216 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 4215, 4216 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 3,
      { 4230 },
      -1,
   } },

   /* replace1446_0_0 -> 0 in the cache */
   /* replace1446_0_1 -> 3 in the cache */
   /* replace1446_0 -> 1074 in the cache */
   /* replace1446_1_0 -> 152 in the cache */
   /* replace1446_1_1 -> 153 in the cache */
   /* replace1446_1 -> 4212 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 1074, 4212 },
      -1,
   } },

   /* ('f2b1', ('b2f', 'a@1')) => a */
   /* search1447_0_0 -> 760 in the cache */
   /* search1447_0 -> 1129 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_f2b1,
      -1, 0,
      { 1129 },
      -1,
   } },

   /* replace1447 -> 760 in the cache */

   /* ('f2b8', ('b2f', 'a@8')) => a */
   /* search1448_0_0 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 6 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_f2b8,
      -1, 0,
      { 4234 },
      -1,
   } },

   /* replace1448 -> 6 in the cache */

   /* ('f2b16', ('b2f', 'a@16')) => a */
   /* search1449_0_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 11 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2b16,
      -1, 0,
      { 4236 },
      -1,
   } },

   /* replace1449 -> 11 in the cache */

   /* ('f2b32', ('b2f', 'a@32')) => a */
   /* search1450_0_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_b2f,
      -1, 0,
      { 16 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2b32,
      -1, 0,
      { 4238 },
      -1,
   } },

   /* replace1450 -> 16 in the cache */

   /* ('f2f', ('b2f', 'a')) => ('b2f', 'a') */
   /* search1451_0_0 -> 32 in the cache */
   /* search1451_0 -> 1528 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_f2f,
      -1, 0,
      { 1528 },
      -1,
   } },

   /* replace1451_0 -> 32 in the cache */
   /* replace1451 -> 1528 in the cache */

   /* ('f2u', ('b2f', 'a')) => ('b2i', 'a') */
   /* search1452_0_0 -> 32 in the cache */
   /* search1452_0 -> 1528 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_f2u,
      -1, 0,
      { 1528 },
      -1,
   } },

   /* replace1452_0 -> 32 in the cache */
   /* replace1452 -> 3111 in the cache */

   /* ('f2i', ('b2f', 'a')) => ('b2i', 'a') */
   /* search1453_0_0 -> 32 in the cache */
   /* search1453_0 -> 1528 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_f2i,
      -1, 0,
      { 1528 },
      -1,
   } },

   /* replace1453_0 -> 32 in the cache */
   /* replace1453 -> 3111 in the cache */

   /* ('u2f', ('b2i', 'a')) => ('b2f', 'a') */
   /* search1454_0_0 -> 32 in the cache */
   /* search1454_0 -> 3111 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_u2f,
      -1, 0,
      { 3111 },
      -1,
   } },

   /* replace1454_0 -> 32 in the cache */
   /* replace1454 -> 1528 in the cache */

   /* ('u2u', ('b2i', 'a')) => ('b2i', 'a') */
   /* search1455_0_0 -> 32 in the cache */
   /* search1455_0 -> 3111 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_u2u,
      -1, 0,
      { 3111 },
      -1,
   } },

   /* replace1455_0 -> 32 in the cache */
   /* replace1455 -> 3111 in the cache */

   /* ('i2f', ('b2i', 'a')) => ('b2f', 'a') */
   /* search1456_0_0 -> 32 in the cache */
   /* search1456_0 -> 3111 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_i2f,
      -1, 0,
      { 3111 },
      -1,
   } },

   /* replace1456_0 -> 32 in the cache */
   /* replace1456 -> 1528 in the cache */

   /* ('i2i', ('b2i', 'a')) => ('b2i', 'a') */
   /* search1457_0_0 -> 32 in the cache */
   /* search1457_0 -> 3111 in the cache */
   { .expression = {
      { nir_search_value_expression, 0 },
      false,
      false,
      false,
      nir_search_op_i2i,
      -1, 0,
      { 3111 },
      -1,
   } },

   /* replace1457_0 -> 32 in the cache */
   /* replace1457 -> 3111 in the cache */

   /* ('i2i1', 'a@1') => a */
   /* search1458_0 -> 760 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_i2i1,
      -1, 0,
      { 760 },
      -1,
   } },

   /* replace1458 -> 760 in the cache */

   /* ('i2i8', 'a@8') => a */
   /* search1459_0 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 6 },
      -1,
   } },

   /* replace1459 -> 6 in the cache */

   /* ('i2i16', 'a@16') => a */
   /* search1460_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 11 },
      -1,
   } },

   /* replace1460 -> 11 in the cache */

   /* ('i2i32', 'a@32') => a */
   /* search1461_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 16 },
      -1,
   } },

   /* replace1461 -> 16 in the cache */

   /* ('i2i64', 'a@64') => a */
   /* search1462_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 21 },
      -1,
   } },

   /* replace1462 -> 21 in the cache */

   /* ('u2u1', 'a@1') => a */
   /* search1463_0 -> 760 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_u2u1,
      -1, 0,
      { 760 },
      -1,
   } },

   /* replace1463 -> 760 in the cache */

   /* ('u2u8', 'a@8') => a */
   /* search1464_0 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 6 },
      -1,
   } },

   /* replace1464 -> 6 in the cache */

   /* ('u2u16', 'a@16') => a */
   /* search1465_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 11 },
      -1,
   } },

   /* replace1465 -> 11 in the cache */

   /* ('u2u32', 'a@32') => a */
   /* search1466_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 16 },
      -1,
   } },

   /* replace1466 -> 16 in the cache */

   /* ('u2u64', 'a@64') => a */
   /* search1467_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 21 },
      -1,
   } },

   /* replace1467 -> 21 in the cache */

   /* ('f2f16', 'a@16') => a */
   /* search1468_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 11 },
      -1,
   } },

   /* replace1468 -> 11 in the cache */

   /* ('f2f32', 'a@32') => a */
   /* search1469_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 16 },
      -1,
   } },

   /* replace1469 -> 16 in the cache */

   /* ('f2f64', 'a@64') => a */
   /* search1470_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_f2f64,
      -1, 0,
      { 21 },
      -1,
   } },

   /* replace1470 -> 21 in the cache */

   /* ('b2b1', 'a@1') => a */
   /* search1471_0 -> 760 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_b2b1,
      -1, 0,
      { 760 },
      -1,
   } },

   /* replace1471 -> 760 in the cache */

   /* ('b2b8', 'a@8') => a */
   /* search1472_0 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_b2b8,
      -1, 0,
      { 6 },
      -1,
   } },

   /* replace1472 -> 6 in the cache */

   /* ('b2b16', 'a@16') => a */
   /* search1473_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_b2b16,
      -1, 0,
      { 11 },
      -1,
   } },

   /* replace1473 -> 11 in the cache */

   /* ('b2b32', 'a@32') => a */
   /* search1474_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_b2b32,
      -1, 0,
      { 16 },
      -1,
   } },

   /* replace1474 -> 16 in the cache */

   /* ('i2i1', ('i2i8', 'a')) => ('i2i1', 'a') */
   /* search1475_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_i2i1,
      -1, 0,
      { 4264 },
      -1,
   } },

   /* replace1475_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_i2i1,
      -1, 0,
      { 32 },
      -1,
   } },

   /* ('i2i1', ('u2u8', 'a')) => ('u2u1', 'a') */
   /* search1476_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_i2i1,
      -1, 0,
      { 4267 },
      -1,
   } },

   /* replace1476_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_u2u1,
      -1, 0,
      { 32 },
      -1,
   } },

   /* ('u2u1', ('i2i8', 'a')) => ('i2i1', 'a') */
   /* search1477_0_0 -> 32 in the cache */
   /* search1477_0 -> 4264 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_u2u1,
      -1, 0,
      { 4264 },
      -1,
   } },

   /* replace1477_0 -> 32 in the cache */
   /* replace1477 -> 4266 in the cache */

   /* ('u2u1', ('u2u8', 'a')) => ('u2u1', 'a') */
   /* search1478_0_0 -> 32 in the cache */
   /* search1478_0 -> 4267 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_u2u1,
      -1, 0,
      { 4267 },
      -1,
   } },

   /* replace1478_0 -> 32 in the cache */
   /* replace1478 -> 4269 in the cache */

   /* ('i2i1', ('i2i16', 'a')) => ('i2i1', 'a') */
   /* search1479_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_i2i1,
      -1, 0,
      { 4272 },
      -1,
   } },

   /* replace1479_0 -> 32 in the cache */
   /* replace1479 -> 4266 in the cache */

   /* ('i2i1', ('u2u16', 'a')) => ('u2u1', 'a') */
   /* search1480_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_i2i1,
      -1, 0,
      { 4274 },
      -1,
   } },

   /* replace1480_0 -> 32 in the cache */
   /* replace1480 -> 4269 in the cache */

   /* ('u2u1', ('i2i16', 'a')) => ('i2i1', 'a') */
   /* search1481_0_0 -> 32 in the cache */
   /* search1481_0 -> 4272 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_u2u1,
      -1, 0,
      { 4272 },
      -1,
   } },

   /* replace1481_0 -> 32 in the cache */
   /* replace1481 -> 4266 in the cache */

   /* ('u2u1', ('u2u16', 'a')) => ('u2u1', 'a') */
   /* search1482_0_0 -> 32 in the cache */
   /* search1482_0 -> 4274 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_u2u1,
      -1, 0,
      { 4274 },
      -1,
   } },

   /* replace1482_0 -> 32 in the cache */
   /* replace1482 -> 4269 in the cache */

   /* ('i2i1', ('i2i32', 'a')) => ('i2i1', 'a') */
   /* search1483_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_i2i1,
      -1, 0,
      { 4278 },
      -1,
   } },

   /* replace1483_0 -> 32 in the cache */
   /* replace1483 -> 4266 in the cache */

   /* ('i2i1', ('u2u32', 'a')) => ('u2u1', 'a') */
   /* search1484_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_i2i1,
      -1, 0,
      { 4280 },
      -1,
   } },

   /* replace1484_0 -> 32 in the cache */
   /* replace1484 -> 4269 in the cache */

   /* ('u2u1', ('i2i32', 'a')) => ('i2i1', 'a') */
   /* search1485_0_0 -> 32 in the cache */
   /* search1485_0 -> 4278 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_u2u1,
      -1, 0,
      { 4278 },
      -1,
   } },

   /* replace1485_0 -> 32 in the cache */
   /* replace1485 -> 4266 in the cache */

   /* ('u2u1', ('u2u32', 'a')) => ('u2u1', 'a') */
   /* search1486_0_0 -> 32 in the cache */
   /* search1486_0 -> 4280 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_u2u1,
      -1, 0,
      { 4280 },
      -1,
   } },

   /* replace1486_0 -> 32 in the cache */
   /* replace1486 -> 4269 in the cache */

   /* ('i2i1', ('i2i64', 'a')) => ('i2i1', 'a') */
   /* search1487_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_i2i1,
      -1, 0,
      { 4284 },
      -1,
   } },

   /* replace1487_0 -> 32 in the cache */
   /* replace1487 -> 4266 in the cache */

   /* ('i2i1', ('u2u64', 'a')) => ('u2u1', 'a') */
   /* search1488_0_0 -> 32 in the cache */
   /* search1488_0 -> 3225 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_i2i1,
      -1, 0,
      { 3225 },
      -1,
   } },

   /* replace1488_0 -> 32 in the cache */
   /* replace1488 -> 4269 in the cache */

   /* ('u2u1', ('i2i64', 'a')) => ('i2i1', 'a') */
   /* search1489_0_0 -> 32 in the cache */
   /* search1489_0 -> 4284 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_u2u1,
      -1, 0,
      { 4284 },
      -1,
   } },

   /* replace1489_0 -> 32 in the cache */
   /* replace1489 -> 4266 in the cache */

   /* ('u2u1', ('u2u64', 'a')) => ('u2u1', 'a') */
   /* search1490_0_0 -> 32 in the cache */
   /* search1490_0 -> 3225 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_u2u1,
      -1, 0,
      { 3225 },
      -1,
   } },

   /* replace1490_0 -> 32 in the cache */
   /* replace1490 -> 4269 in the cache */

   /* ('i2i8', ('i2i1', 'a@1')) => ('i2i8', 'a') */
   /* search1491_0_0 -> 760 in the cache */
   /* search1491_0 -> 4247 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 4247 },
      -1,
   } },

   /* replace1491_0 -> 760 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 760 },
      -1,
   } },

   /* ('u2u8', ('u2u1', 'a@1')) => ('u2u8', 'a') */
   /* search1492_0_0 -> 760 in the cache */
   /* search1492_0 -> 4252 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 4252 },
      -1,
   } },

   /* replace1492_0 -> 760 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 760 },
      -1,
   } },

   /* ('i2i8', ('i2i16', 'a')) => ('i2i8', 'a') */
   /* search1493_0_0 -> 32 in the cache */
   /* search1493_0 -> 4272 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 4272 },
      -1,
   } },

   /* replace1493_0 -> 32 in the cache */
   /* replace1493 -> 4264 in the cache */

   /* ('i2i8', ('u2u16', 'a')) => ('u2u8', 'a') */
   /* search1494_0_0 -> 32 in the cache */
   /* search1494_0 -> 4274 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 4274 },
      -1,
   } },

   /* replace1494_0 -> 32 in the cache */
   /* replace1494 -> 4267 in the cache */

   /* ('u2u8', ('i2i16', 'a')) => ('i2i8', 'a') */
   /* search1495_0_0 -> 32 in the cache */
   /* search1495_0 -> 4272 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 4272 },
      -1,
   } },

   /* replace1495_0 -> 32 in the cache */
   /* replace1495 -> 4264 in the cache */

   /* ('u2u8', ('u2u16', 'a')) => ('u2u8', 'a') */
   /* search1496_0_0 -> 32 in the cache */
   /* search1496_0 -> 4274 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 4274 },
      -1,
   } },

   /* replace1496_0 -> 32 in the cache */
   /* replace1496 -> 4267 in the cache */

   /* ('i2i8', ('i2i32', 'a')) => ('i2i8', 'a') */
   /* search1497_0_0 -> 32 in the cache */
   /* search1497_0 -> 4278 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 4278 },
      -1,
   } },

   /* replace1497_0 -> 32 in the cache */
   /* replace1497 -> 4264 in the cache */

   /* ('i2i8', ('u2u32', 'a')) => ('u2u8', 'a') */
   /* search1498_0_0 -> 32 in the cache */
   /* search1498_0 -> 4280 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 4280 },
      -1,
   } },

   /* replace1498_0 -> 32 in the cache */
   /* replace1498 -> 4267 in the cache */

   /* ('u2u8', ('i2i32', 'a')) => ('i2i8', 'a') */
   /* search1499_0_0 -> 32 in the cache */
   /* search1499_0 -> 4278 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 4278 },
      -1,
   } },

   /* replace1499_0 -> 32 in the cache */
   /* replace1499 -> 4264 in the cache */

   /* ('u2u8', ('u2u32', 'a')) => ('u2u8', 'a') */
   /* search1500_0_0 -> 32 in the cache */
   /* search1500_0 -> 4280 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 4280 },
      -1,
   } },

   /* replace1500_0 -> 32 in the cache */
   /* replace1500 -> 4267 in the cache */

   /* ('i2i8', ('i2i64', 'a')) => ('i2i8', 'a') */
   /* search1501_0_0 -> 32 in the cache */
   /* search1501_0 -> 4284 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 4284 },
      -1,
   } },

   /* replace1501_0 -> 32 in the cache */
   /* replace1501 -> 4264 in the cache */

   /* ('i2i8', ('u2u64', 'a')) => ('u2u8', 'a') */
   /* search1502_0_0 -> 32 in the cache */
   /* search1502_0 -> 3225 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 3225 },
      -1,
   } },

   /* replace1502_0 -> 32 in the cache */
   /* replace1502 -> 4267 in the cache */

   /* ('u2u8', ('i2i64', 'a')) => ('i2i8', 'a') */
   /* search1503_0_0 -> 32 in the cache */
   /* search1503_0 -> 4284 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 4284 },
      -1,
   } },

   /* replace1503_0 -> 32 in the cache */
   /* replace1503 -> 4264 in the cache */

   /* ('u2u8', ('u2u64', 'a')) => ('u2u8', 'a') */
   /* search1504_0_0 -> 32 in the cache */
   /* search1504_0 -> 3225 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 3225 },
      -1,
   } },

   /* replace1504_0 -> 32 in the cache */
   /* replace1504 -> 4267 in the cache */

   /* ('i2i16', ('i2i1', 'a@1')) => ('i2i16', 'a') */
   /* search1505_0_0 -> 760 in the cache */
   /* search1505_0 -> 4247 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 4247 },
      -1,
   } },

   /* replace1505_0 -> 760 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 760 },
      -1,
   } },

   /* ('u2u16', ('u2u1', 'a@1')) => ('u2u16', 'a') */
   /* search1506_0_0 -> 760 in the cache */
   /* search1506_0 -> 4252 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 4252 },
      -1,
   } },

   /* replace1506_0 -> 760 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 760 },
      -1,
   } },

   /* ('i2i16', ('i2i8', 'a@1')) => ('i2i16', 'a') */
   /* search1507_0_0 -> 760 in the cache */
   /* search1507_0 -> 4290 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 4290 },
      -1,
   } },

   /* replace1507_0 -> 760 in the cache */
   /* replace1507 -> 4306 in the cache */

   /* ('u2u16', ('u2u8', 'a@1')) => ('u2u16', 'a') */
   /* search1508_0_0 -> 760 in the cache */
   /* search1508_0 -> 4292 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 4292 },
      -1,
   } },

   /* replace1508_0 -> 760 in the cache */
   /* replace1508 -> 4308 in the cache */

   /* ('i2i16', ('i2i8', 'a@8')) => ('i2i16', 'a') */
   /* search1509_0_0 -> 6 in the cache */
   /* search1509_0 -> 4248 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 4248 },
      -1,
   } },

   /* replace1509_0 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 6 },
      -1,
   } },

   /* ('u2u16', ('u2u8', 'a@8')) => ('u2u16', 'a') */
   /* search1510_0_0 -> 6 in the cache */
   /* search1510_0 -> 4253 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 4253 },
      -1,
   } },

   /* replace1510_0 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 6 },
      -1,
   } },

   /* ('i2i16', ('i2i32', 'a')) => ('i2i16', 'a') */
   /* search1511_0_0 -> 32 in the cache */
   /* search1511_0 -> 4278 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 4278 },
      -1,
   } },

   /* replace1511_0 -> 32 in the cache */
   /* replace1511 -> 4272 in the cache */

   /* ('i2i16', ('u2u32', 'a')) => ('u2u16', 'a') */
   /* search1512_0_0 -> 32 in the cache */
   /* search1512_0 -> 4280 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 4280 },
      -1,
   } },

   /* replace1512_0 -> 32 in the cache */
   /* replace1512 -> 4274 in the cache */

   /* ('u2u16', ('i2i32', 'a')) => ('i2i16', 'a') */
   /* search1513_0_0 -> 32 in the cache */
   /* search1513_0 -> 4278 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 4278 },
      -1,
   } },

   /* replace1513_0 -> 32 in the cache */
   /* replace1513 -> 4272 in the cache */

   /* ('u2u16', ('u2u32', 'a')) => ('u2u16', 'a') */
   /* search1514_0_0 -> 32 in the cache */
   /* search1514_0 -> 4280 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 4280 },
      -1,
   } },

   /* replace1514_0 -> 32 in the cache */
   /* replace1514 -> 4274 in the cache */

   /* ('i2i16', ('i2i64', 'a')) => ('i2i16', 'a') */
   /* search1515_0_0 -> 32 in the cache */
   /* search1515_0 -> 4284 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 4284 },
      -1,
   } },

   /* replace1515_0 -> 32 in the cache */
   /* replace1515 -> 4272 in the cache */

   /* ('i2i16', ('u2u64', 'a')) => ('u2u16', 'a') */
   /* search1516_0_0 -> 32 in the cache */
   /* search1516_0 -> 3225 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 3225 },
      -1,
   } },

   /* replace1516_0 -> 32 in the cache */
   /* replace1516 -> 4274 in the cache */

   /* ('u2u16', ('i2i64', 'a')) => ('i2i16', 'a') */
   /* search1517_0_0 -> 32 in the cache */
   /* search1517_0 -> 4284 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 4284 },
      -1,
   } },

   /* replace1517_0 -> 32 in the cache */
   /* replace1517 -> 4272 in the cache */

   /* ('u2u16', ('u2u64', 'a')) => ('u2u16', 'a') */
   /* search1518_0_0 -> 32 in the cache */
   /* search1518_0 -> 3225 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 3225 },
      -1,
   } },

   /* replace1518_0 -> 32 in the cache */
   /* replace1518 -> 4274 in the cache */

   /* ('i2i32', ('i2i1', 'a@1')) => ('i2i32', 'a') */
   /* search1519_0_0 -> 760 in the cache */
   /* search1519_0 -> 4247 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 4247 },
      -1,
   } },

   /* replace1519_0 -> 760 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 760 },
      -1,
   } },

   /* ('u2u32', ('u2u1', 'a@1')) => ('u2u32', 'a') */
   /* search1520_0_0 -> 760 in the cache */
   /* search1520_0 -> 4252 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 4252 },
      -1,
   } },

   /* replace1520_0 -> 760 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 760 },
      -1,
   } },

   /* ('i2i32', ('i2i8', 'a@1')) => ('i2i32', 'a') */
   /* search1521_0_0 -> 760 in the cache */
   /* search1521_0 -> 4290 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 4290 },
      -1,
   } },

   /* replace1521_0 -> 760 in the cache */
   /* replace1521 -> 4324 in the cache */

   /* ('u2u32', ('u2u8', 'a@1')) => ('u2u32', 'a') */
   /* search1522_0_0 -> 760 in the cache */
   /* search1522_0 -> 4292 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 4292 },
      -1,
   } },

   /* replace1522_0 -> 760 in the cache */
   /* replace1522 -> 4326 in the cache */

   /* ('i2i32', ('i2i8', 'a@8')) => ('i2i32', 'a') */
   /* search1523_0_0 -> 6 in the cache */
   /* search1523_0 -> 4248 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 4248 },
      -1,
   } },

   /* replace1523_0 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 6 },
      -1,
   } },

   /* ('u2u32', ('u2u8', 'a@8')) => ('u2u32', 'a') */
   /* search1524_0_0 -> 6 in the cache */
   /* search1524_0 -> 4253 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 4253 },
      -1,
   } },

   /* replace1524_0 -> 6 in the cache */
   /* replace1524 -> 3298 in the cache */

   /* ('i2i32', ('i2i16', 'a@1')) => ('i2i32', 'a') */
   /* search1525_0_0 -> 760 in the cache */
   /* search1525_0 -> 4306 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 4306 },
      -1,
   } },

   /* replace1525_0 -> 760 in the cache */
   /* replace1525 -> 4324 in the cache */

   /* ('u2u32', ('u2u16', 'a@1')) => ('u2u32', 'a') */
   /* search1526_0_0 -> 760 in the cache */
   /* search1526_0 -> 4308 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 4308 },
      -1,
   } },

   /* replace1526_0 -> 760 in the cache */
   /* replace1526 -> 4326 in the cache */

   /* ('i2i32', ('i2i16', 'a@8')) => ('i2i32', 'a') */
   /* search1527_0_0 -> 6 in the cache */
   /* search1527_0 -> 4312 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 4312 },
      -1,
   } },

   /* replace1527_0 -> 6 in the cache */
   /* replace1527 -> 4330 in the cache */

   /* ('u2u32', ('u2u16', 'a@8')) => ('u2u32', 'a') */
   /* search1528_0_0 -> 6 in the cache */
   /* search1528_0 -> 4314 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 4314 },
      -1,
   } },

   /* replace1528_0 -> 6 in the cache */
   /* replace1528 -> 3298 in the cache */

   /* ('i2i32', ('i2i16', 'a@16')) => ('i2i32', 'a') */
   /* search1529_0_0 -> 11 in the cache */
   /* search1529_0 -> 4249 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 4249 },
      -1,
   } },

   /* replace1529_0 -> 11 in the cache */
   /* replace1529 -> 1815 in the cache */

   /* ('u2u32', ('u2u16', 'a@16')) => ('u2u32', 'a') */
   /* search1530_0_0 -> 11 in the cache */
   /* search1530_0 -> 4254 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 4254 },
      -1,
   } },

   /* replace1530_0 -> 11 in the cache */
   /* replace1530 -> 1817 in the cache */

   /* ('i2i32', ('i2i64', 'a')) => ('i2i32', 'a') */
   /* search1531_0_0 -> 32 in the cache */
   /* search1531_0 -> 4284 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 4284 },
      -1,
   } },

   /* replace1531_0 -> 32 in the cache */
   /* replace1531 -> 4278 in the cache */

   /* ('i2i32', ('u2u64', 'a')) => ('u2u32', 'a') */
   /* search1532_0_0 -> 32 in the cache */
   /* search1532_0 -> 3225 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 3225 },
      -1,
   } },

   /* replace1532_0 -> 32 in the cache */
   /* replace1532 -> 4280 in the cache */

   /* ('u2u32', ('i2i64', 'a')) => ('i2i32', 'a') */
   /* search1533_0_0 -> 32 in the cache */
   /* search1533_0 -> 4284 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 4284 },
      -1,
   } },

   /* replace1533_0 -> 32 in the cache */
   /* replace1533 -> 4278 in the cache */

   /* ('u2u32', ('u2u64', 'a')) => ('u2u32', 'a') */
   /* search1534_0_0 -> 32 in the cache */
   /* search1534_0 -> 3225 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 3225 },
      -1,
   } },

   /* replace1534_0 -> 32 in the cache */
   /* replace1534 -> 4280 in the cache */

   /* ('i2i64', ('i2i1', 'a@1')) => ('i2i64', 'a') */
   /* search1535_0_0 -> 760 in the cache */
   /* search1535_0 -> 4247 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 4247 },
      -1,
   } },

   /* replace1535_0 -> 760 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 760 },
      -1,
   } },

   /* ('u2u64', ('u2u1', 'a@1')) => ('u2u64', 'a') */
   /* search1536_0_0 -> 760 in the cache */
   /* search1536_0 -> 4252 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 4252 },
      -1,
   } },

   /* replace1536_0 -> 760 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 760 },
      -1,
   } },

   /* ('i2i64', ('i2i8', 'a@1')) => ('i2i64', 'a') */
   /* search1537_0_0 -> 760 in the cache */
   /* search1537_0 -> 4290 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 4290 },
      -1,
   } },

   /* replace1537_0 -> 760 in the cache */
   /* replace1537 -> 4343 in the cache */

   /* ('u2u64', ('u2u8', 'a@1')) => ('u2u64', 'a') */
   /* search1538_0_0 -> 760 in the cache */
   /* search1538_0 -> 4292 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 4292 },
      -1,
   } },

   /* replace1538_0 -> 760 in the cache */
   /* replace1538 -> 4345 in the cache */

   /* ('i2i64', ('i2i8', 'a@8')) => ('i2i64', 'a') */
   /* search1539_0_0 -> 6 in the cache */
   /* search1539_0 -> 4248 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 4248 },
      -1,
   } },

   /* replace1539_0 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 6 },
      -1,
   } },

   /* ('u2u64', ('u2u8', 'a@8')) => ('u2u64', 'a') */
   /* search1540_0_0 -> 6 in the cache */
   /* search1540_0 -> 4253 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 4253 },
      -1,
   } },

   /* replace1540_0 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 6 },
      -1,
   } },

   /* ('i2i64', ('i2i16', 'a@1')) => ('i2i64', 'a') */
   /* search1541_0_0 -> 760 in the cache */
   /* search1541_0 -> 4306 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 4306 },
      -1,
   } },

   /* replace1541_0 -> 760 in the cache */
   /* replace1541 -> 4343 in the cache */

   /* ('u2u64', ('u2u16', 'a@1')) => ('u2u64', 'a') */
   /* search1542_0_0 -> 760 in the cache */
   /* search1542_0 -> 4308 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 4308 },
      -1,
   } },

   /* replace1542_0 -> 760 in the cache */
   /* replace1542 -> 4345 in the cache */

   /* ('i2i64', ('i2i16', 'a@8')) => ('i2i64', 'a') */
   /* search1543_0_0 -> 6 in the cache */
   /* search1543_0 -> 4312 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 4312 },
      -1,
   } },

   /* replace1543_0 -> 6 in the cache */
   /* replace1543 -> 4349 in the cache */

   /* ('u2u64', ('u2u16', 'a@8')) => ('u2u64', 'a') */
   /* search1544_0_0 -> 6 in the cache */
   /* search1544_0 -> 4314 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 4314 },
      -1,
   } },

   /* replace1544_0 -> 6 in the cache */
   /* replace1544 -> 4351 in the cache */

   /* ('i2i64', ('i2i16', 'a@16')) => ('i2i64', 'a') */
   /* search1545_0_0 -> 11 in the cache */
   /* search1545_0 -> 4249 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 4249 },
      -1,
   } },

   /* replace1545_0 -> 11 in the cache */
   /* replace1545 -> 1833 in the cache */

   /* ('u2u64', ('u2u16', 'a@16')) => ('u2u64', 'a') */
   /* search1546_0_0 -> 11 in the cache */
   /* search1546_0 -> 4254 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 4254 },
      -1,
   } },

   /* replace1546_0 -> 11 in the cache */
   /* replace1546 -> 1835 in the cache */

   /* ('i2i64', ('i2i32', 'a@1')) => ('i2i64', 'a') */
   /* search1547_0_0 -> 760 in the cache */
   /* search1547_0 -> 4324 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 4324 },
      -1,
   } },

   /* replace1547_0 -> 760 in the cache */
   /* replace1547 -> 4343 in the cache */

   /* ('u2u64', ('u2u32', 'a@1')) => ('u2u64', 'a') */
   /* search1548_0_0 -> 760 in the cache */
   /* search1548_0 -> 4326 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 4326 },
      -1,
   } },

   /* replace1548_0 -> 760 in the cache */
   /* replace1548 -> 4345 in the cache */

   /* ('i2i64', ('i2i32', 'a@8')) => ('i2i64', 'a') */
   /* search1549_0_0 -> 6 in the cache */
   /* search1549_0 -> 4330 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 4330 },
      -1,
   } },

   /* replace1549_0 -> 6 in the cache */
   /* replace1549 -> 4349 in the cache */

   /* ('u2u64', ('u2u32', 'a@8')) => ('u2u64', 'a') */
   /* search1550_0_0 -> 6 in the cache */
   /* search1550_0 -> 3298 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 3298 },
      -1,
   } },

   /* replace1550_0 -> 6 in the cache */
   /* replace1550 -> 4351 in the cache */

   /* ('i2i64', ('i2i32', 'a@16')) => ('i2i64', 'a') */
   /* search1551_0_0 -> 11 in the cache */
   /* search1551_0 -> 1815 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 1815 },
      -1,
   } },

   /* replace1551_0 -> 11 in the cache */
   /* replace1551 -> 1833 in the cache */

   /* ('u2u64', ('u2u32', 'a@16')) => ('u2u64', 'a') */
   /* search1552_0_0 -> 11 in the cache */
   /* search1552_0 -> 1817 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 1817 },
      -1,
   } },

   /* replace1552_0 -> 11 in the cache */
   /* replace1552 -> 1835 in the cache */

   /* ('i2i64', ('i2i32', 'a@32')) => ('i2i64', 'a') */
   /* search1553_0_0 -> 16 in the cache */
   /* search1553_0 -> 4250 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 4250 },
      -1,
   } },

   /* replace1553_0 -> 16 in the cache */
   /* replace1553 -> 1920 in the cache */

   /* ('u2u64', ('u2u32', 'a@32')) => ('u2u64', 'a') */
   /* search1554_0_0 -> 16 in the cache */
   /* search1554_0 -> 4255 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 4255 },
      -1,
   } },

   /* replace1554_0 -> 16 in the cache */
   /* replace1554 -> 1922 in the cache */

   /* ('i2i8', ('pack_64_2x32_split', 'a', 'b')) => ('i2i8', 'a') */
   /* search1555_0_0 -> 16 in the cache */
   /* search1555_0_1 -> 36 in the cache */
   /* search1555_0 -> 3218 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 3218 },
      -1,
   } },

   /* replace1555_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('i2i8', ('pack_64_2x32_split', 'a', 'b')) => ('i2i8', 'a') */
   /* search1556_0_0 -> 16 in the cache */
   /* search1556_0_1 -> 36 in the cache */
   /* search1556_0 -> 3218 in the cache */
   /* search1556 -> 4366 in the cache */

   /* replace1556_0 -> 16 in the cache */
   /* replace1556 -> 4367 in the cache */

   /* ('i2i16', ('pack_64_2x32_split', 'a', 'b')) => ('i2i16', 'a') */
   /* search1557_0_0 -> 16 in the cache */
   /* search1557_0_1 -> 36 in the cache */
   /* search1557_0 -> 3218 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 3218 },
      -1,
   } },

   /* replace1557_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 16 },
      -1,
   } },

   /* ('i2i16', ('pack_64_2x32_split', 'a', 'b')) => ('i2i16', 'a') */
   /* search1558_0_0 -> 16 in the cache */
   /* search1558_0_1 -> 36 in the cache */
   /* search1558_0 -> 3218 in the cache */
   /* search1558 -> 4368 in the cache */

   /* replace1558_0 -> 16 in the cache */
   /* replace1558 -> 4369 in the cache */

   /* ('i2i32', ('pack_64_2x32_split', 'a', 'b')) => ('i2i32', 'a') */
   /* search1559_0_0 -> 16 in the cache */
   /* search1559_0_1 -> 36 in the cache */
   /* search1559_0 -> 3218 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 3218 },
      -1,
   } },

   /* replace1559_0 -> 16 in the cache */
   /* replace1559 -> 4250 in the cache */

   /* ('i2i32', ('pack_64_2x32_split', 'a', 'b')) => ('i2i32', 'a') */
   /* search1560_0_0 -> 16 in the cache */
   /* search1560_0_1 -> 36 in the cache */
   /* search1560_0 -> 3218 in the cache */
   /* search1560 -> 4370 in the cache */

   /* replace1560_0 -> 16 in the cache */
   /* replace1560 -> 4250 in the cache */

   /* ('u2u8', ('pack_64_2x32_split', 'a', 'b')) => ('u2u8', 'a') */
   /* search1561_0_0 -> 16 in the cache */
   /* search1561_0_1 -> 36 in the cache */
   /* search1561_0 -> 3218 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 3218 },
      -1,
   } },

   /* replace1561_0 -> 16 in the cache */
   /* replace1561 -> 2041 in the cache */

   /* ('u2u8', ('pack_64_2x32_split', 'a', 'b')) => ('u2u8', 'a') */
   /* search1562_0_0 -> 16 in the cache */
   /* search1562_0_1 -> 36 in the cache */
   /* search1562_0 -> 3218 in the cache */
   /* search1562 -> 4371 in the cache */

   /* replace1562_0 -> 16 in the cache */
   /* replace1562 -> 2041 in the cache */

   /* ('u2u16', ('pack_64_2x32_split', 'a', 'b')) => ('u2u16', 'a') */
   /* search1563_0_0 -> 16 in the cache */
   /* search1563_0_1 -> 36 in the cache */
   /* search1563_0 -> 3218 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 3218 },
      -1,
   } },

   /* replace1563_0 -> 16 in the cache */
   /* replace1563 -> 3326 in the cache */

   /* ('u2u16', ('pack_64_2x32_split', 'a', 'b')) => ('u2u16', 'a') */
   /* search1564_0_0 -> 16 in the cache */
   /* search1564_0_1 -> 36 in the cache */
   /* search1564_0 -> 3218 in the cache */
   /* search1564 -> 4372 in the cache */

   /* replace1564_0 -> 16 in the cache */
   /* replace1564 -> 3326 in the cache */

   /* ('u2u32', ('pack_64_2x32_split', 'a', 'b')) => ('u2u32', 'a') */
   /* search1565_0_0 -> 16 in the cache */
   /* search1565_0_1 -> 36 in the cache */
   /* search1565_0 -> 3218 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 3218 },
      -1,
   } },

   /* replace1565_0 -> 16 in the cache */
   /* replace1565 -> 4255 in the cache */

   /* ('u2u32', ('pack_64_2x32_split', 'a', 'b')) => ('u2u32', 'a') */
   /* search1566_0_0 -> 16 in the cache */
   /* search1566_0_1 -> 36 in the cache */
   /* search1566_0 -> 3218 in the cache */
   /* search1566 -> 4373 in the cache */

   /* replace1566_0 -> 16 in the cache */
   /* replace1566 -> 4255 in the cache */

   /* ('ieq', ('i2i16', 'a@8'), ('i2i16', 'b@8')) => ('ieq', 'a', ('i2i8', 'b')) */
   /* search1567_0_0 -> 6 in the cache */
   /* search1567_0 -> 4312 in the cache */
   /* search1567_1_0 -> 2128 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 2128 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 4312, 4374 },
      -1,
   } },

   /* replace1567_0 -> 6 in the cache */
   /* replace1567_1_0 -> 2128 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 2128 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 6, 4376 },
      -1,
   } },

   /* ('ine', ('i2i16', 'a@8'), ('i2i16', 'b@8')) => ('ine', 'a', ('i2i8', 'b')) */
   /* search1568_0_0 -> 6 in the cache */
   /* search1568_0 -> 4312 in the cache */
   /* search1568_1_0 -> 2128 in the cache */
   /* search1568_1 -> 4374 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 4312, 4374 },
      -1,
   } },

   /* replace1568_0 -> 6 in the cache */
   /* replace1568_1_0 -> 2128 in the cache */
   /* replace1568_1 -> 4376 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 6, 4376 },
      -1,
   } },

   /* ('ige', ('i2i16', 'a@8'), ('i2i16', 'b@8')) => ('ige', 'a', ('i2i8', 'b')) */
   /* search1569_0_0 -> 6 in the cache */
   /* search1569_0 -> 4312 in the cache */
   /* search1569_1_0 -> 2128 in the cache */
   /* search1569_1 -> 4374 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4312, 4374 },
      -1,
   } },

   /* replace1569_0 -> 6 in the cache */
   /* replace1569_1_0 -> 2128 in the cache */
   /* replace1569_1 -> 4376 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 6, 4376 },
      -1,
   } },

   /* ('ilt', ('i2i16', 'a@8'), ('i2i16', 'b@8')) => ('ilt', 'a', ('i2i8', 'b')) */
   /* search1570_0_0 -> 6 in the cache */
   /* search1570_0 -> 4312 in the cache */
   /* search1570_1_0 -> 2128 in the cache */
   /* search1570_1 -> 4374 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4312, 4374 },
      -1,
   } },

   /* replace1570_0 -> 6 in the cache */
   /* replace1570_1_0 -> 2128 in the cache */
   /* replace1570_1 -> 4376 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 6, 4376 },
      -1,
   } },

   /* ('ige', ('i2i16', 'b@8'), ('i2i16', 'a@8')) => ('ige', ('i2i8', 'b'), 'a') */
   { .variable = {
      { nir_search_value_variable, 8 },
      0, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 4384 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, 8 },
      1, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 4386 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4385, 4387 },
      -1,
   } },

   /* replace1571_0_0 -> 4384 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 4384 },
      -1,
   } },
   /* replace1571_1 -> 4386 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4389, 4386 },
      -1,
   } },

   /* ('ilt', ('i2i16', 'b@8'), ('i2i16', 'a@8')) => ('ilt', ('i2i8', 'b'), 'a') */
   /* search1572_0_0 -> 4384 in the cache */
   /* search1572_0 -> 4385 in the cache */
   /* search1572_1_0 -> 4386 in the cache */
   /* search1572_1 -> 4387 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4385, 4387 },
      -1,
   } },

   /* replace1572_0_0 -> 4384 in the cache */
   /* replace1572_0 -> 4389 in the cache */
   /* replace1572_1 -> 4386 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4389, 4386 },
      -1,
   } },

   /* ('ieq', ('i2i16', 'a@8'), '#b') => ('iand', ('ieq', 'a', ('i2i8', 'b')), ('ieq', ('i2i16', ('i2i8', 'b')), 'b')) */
   /* search1573_0_0 -> 6 in the cache */
   /* search1573_0 -> 4312 in the cache */
   /* search1573_1 -> 2027 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 4312, 2027 },
      -1,
   } },

   /* replace1573_0_0 -> 6 in the cache */
   /* replace1573_0_1_0 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 258 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 6, 4394 },
      -1,
   } },
   /* replace1573_1_0_0_0 -> 258 in the cache */
   /* replace1573_1_0_0 -> 4394 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 4394 },
      -1,
   } },
   /* replace1573_1_1 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 4396, 258 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 4395, 4397 },
      -1,
   } },

   /* ('ine', ('i2i16', 'a@8'), '#b') => ('ior', ('ine', 'a', ('i2i8', 'b')), ('ine', ('i2i16', ('i2i8', 'b')), 'b')) */
   /* search1574_0_0 -> 6 in the cache */
   /* search1574_0 -> 4312 in the cache */
   /* search1574_1 -> 2027 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 4312, 2027 },
      -1,
   } },

   /* replace1574_0_0 -> 6 in the cache */
   /* replace1574_0_1_0 -> 258 in the cache */
   /* replace1574_0_1 -> 4394 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 6, 4394 },
      -1,
   } },
   /* replace1574_1_0_0_0 -> 258 in the cache */
   /* replace1574_1_0_0 -> 4394 in the cache */
   /* replace1574_1_0 -> 4396 in the cache */
   /* replace1574_1_1 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 4396, 258 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 4400, 4401 },
      -1,
   } },

   /* ('ilt', ('i2i16', 'a@8'), '#b') => ('iand', ('ilt', -128, 'b'), ('ior', ('ilt', 127, 'b'), ('ilt', 'a', ('i2i8', 'b')))) */
   /* search1575_0_0 -> 6 in the cache */
   /* search1575_0 -> 4312 in the cache */
   /* search1575_1 -> 2027 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4312, 2027 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, 16 },
      nir_type_int, { -0x80 /* -128 */ },
   } },
   /* replace1575_0_1 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4404, 258 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 16 },
      nir_type_int, { 0x7f /* 127 */ },
   } },
   /* replace1575_1_0_1 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4406, 258 },
      -1,
   } },
   /* replace1575_1_1_0 -> 6 in the cache */
   /* replace1575_1_1_1_0 -> 258 in the cache */
   /* replace1575_1_1_1 -> 4394 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 6, 4394 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4407, 4408 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4405, 4409 },
      -1,
   } },

   /* ('ilt', '#a', ('i2i16', 'b@8')) => ('iand', ('ilt', 'a', 127), ('ior', ('ilt', 'a', -128), ('ilt', ('i2i8', 'a'), 'b'))) */
   { .variable = {
      { nir_search_value_variable, 16 },
      0, /* a */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search1576_1_0 -> 2128 in the cache */
   /* search1576_1 -> 4374 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4411, 4374 },
      -1,
   } },

   /* replace1576_0_0 -> 11 in the cache */
   /* replace1576_0_1 -> 4406 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 11, 4406 },
      -1,
   } },
   /* replace1576_1_0_0 -> 11 in the cache */
   /* replace1576_1_0_1 -> 4404 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 11, 4404 },
      -1,
   } },
   /* replace1576_1_1_0_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 11 },
      -1,
   } },
   /* replace1576_1_1_1 -> 2128 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4415, 2128 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4414, 4416 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4413, 4417 },
      -1,
   } },

   /* ('ige', ('i2i16', 'a@8'), '#b') => ('iand', ('ige', 127, 'b'), ('ior', ('ige', -128, 'b'), ('ige', 'a', ('i2i8', 'b')))) */
   /* search1577_0_0 -> 6 in the cache */
   /* search1577_0 -> 4312 in the cache */
   /* search1577_1 -> 2027 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4312, 2027 },
      -1,
   } },

   /* replace1577_0_0 -> 4406 in the cache */
   /* replace1577_0_1 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4406, 258 },
      -1,
   } },
   /* replace1577_1_0_0 -> 4404 in the cache */
   /* replace1577_1_0_1 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4404, 258 },
      -1,
   } },
   /* replace1577_1_1_0 -> 6 in the cache */
   /* replace1577_1_1_1_0 -> 258 in the cache */
   /* replace1577_1_1_1 -> 4394 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 6, 4394 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4421, 4422 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4420, 4423 },
      -1,
   } },

   /* ('ige', '#a', ('i2i16', 'b@8')) => ('iand', ('ige', 'a', -128), ('ior', ('ige', 'a', 127), ('ige', ('i2i8', 'a'), 'b'))) */
   /* search1578_0 -> 4411 in the cache */
   /* search1578_1_0 -> 2128 in the cache */
   /* search1578_1 -> 4374 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4411, 4374 },
      -1,
   } },

   /* replace1578_0_0 -> 11 in the cache */
   /* replace1578_0_1 -> 4404 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 11, 4404 },
      -1,
   } },
   /* replace1578_1_0_0 -> 11 in the cache */
   /* replace1578_1_0_1 -> 4406 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 11, 4406 },
      -1,
   } },
   /* replace1578_1_1_0_0 -> 11 in the cache */
   /* replace1578_1_1_0 -> 4415 in the cache */
   /* replace1578_1_1_1 -> 2128 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4415, 2128 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4427, 4428 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4426, 4429 },
      -1,
   } },

   /* ('ieq', ('i2i32', 'a@8'), ('i2i32', 'b@8')) => ('ieq', 'a', ('i2i8', 'b')) */
   /* search1579_0_0 -> 6 in the cache */
   /* search1579_0 -> 4330 in the cache */
   /* search1579_1_0 -> 2128 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 2128 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 4330, 4431 },
      -1,
   } },

   /* replace1579_0 -> 6 in the cache */
   /* replace1579_1_0 -> 2128 in the cache */
   /* replace1579_1 -> 4376 in the cache */
   /* replace1579 -> 4377 in the cache */

   /* ('ine', ('i2i32', 'a@8'), ('i2i32', 'b@8')) => ('ine', 'a', ('i2i8', 'b')) */
   /* search1580_0_0 -> 6 in the cache */
   /* search1580_0 -> 4330 in the cache */
   /* search1580_1_0 -> 2128 in the cache */
   /* search1580_1 -> 4431 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 4330, 4431 },
      -1,
   } },

   /* replace1580_0 -> 6 in the cache */
   /* replace1580_1_0 -> 2128 in the cache */
   /* replace1580_1 -> 4376 in the cache */
   /* replace1580 -> 4379 in the cache */

   /* ('ige', ('i2i32', 'a@8'), ('i2i32', 'b@8')) => ('ige', 'a', ('i2i8', 'b')) */
   /* search1581_0_0 -> 6 in the cache */
   /* search1581_0 -> 4330 in the cache */
   /* search1581_1_0 -> 2128 in the cache */
   /* search1581_1 -> 4431 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4330, 4431 },
      -1,
   } },

   /* replace1581_0 -> 6 in the cache */
   /* replace1581_1_0 -> 2128 in the cache */
   /* replace1581_1 -> 4376 in the cache */
   /* replace1581 -> 4381 in the cache */

   /* ('ilt', ('i2i32', 'a@8'), ('i2i32', 'b@8')) => ('ilt', 'a', ('i2i8', 'b')) */
   /* search1582_0_0 -> 6 in the cache */
   /* search1582_0 -> 4330 in the cache */
   /* search1582_1_0 -> 2128 in the cache */
   /* search1582_1 -> 4431 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4330, 4431 },
      -1,
   } },

   /* replace1582_0 -> 6 in the cache */
   /* replace1582_1_0 -> 2128 in the cache */
   /* replace1582_1 -> 4376 in the cache */
   /* replace1582 -> 4383 in the cache */

   /* ('ige', ('i2i32', 'b@8'), ('i2i32', 'a@8')) => ('ige', ('i2i8', 'b'), 'a') */
   /* search1583_0_0 -> 4384 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 4384 },
      -1,
   } },
   /* search1583_1_0 -> 4386 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 4386 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4436, 4437 },
      -1,
   } },

   /* replace1583_0_0 -> 4384 in the cache */
   /* replace1583_0 -> 4389 in the cache */
   /* replace1583_1 -> 4386 in the cache */
   /* replace1583 -> 4390 in the cache */

   /* ('ilt', ('i2i32', 'b@8'), ('i2i32', 'a@8')) => ('ilt', ('i2i8', 'b'), 'a') */
   /* search1584_0_0 -> 4384 in the cache */
   /* search1584_0 -> 4436 in the cache */
   /* search1584_1_0 -> 4386 in the cache */
   /* search1584_1 -> 4437 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4436, 4437 },
      -1,
   } },

   /* replace1584_0_0 -> 4384 in the cache */
   /* replace1584_0 -> 4389 in the cache */
   /* replace1584_1 -> 4386 in the cache */
   /* replace1584 -> 4392 in the cache */

   /* ('ieq', ('i2i32', 'a@8'), '#b') => ('iand', ('ieq', 'a', ('i2i8', 'b')), ('ieq', ('i2i32', ('i2i8', 'b')), 'b')) */
   /* search1585_0_0 -> 6 in the cache */
   /* search1585_0 -> 4330 in the cache */
   /* search1585_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 4330, 33 },
      -1,
   } },

   /* replace1585_0_0 -> 6 in the cache */
   /* replace1585_0_1_0 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 6, 4441 },
      -1,
   } },
   /* replace1585_1_0_0_0 -> 36 in the cache */
   /* replace1585_1_0_0 -> 4441 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 4441 },
      -1,
   } },
   /* replace1585_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 4443, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 4442, 4444 },
      -1,
   } },

   /* ('ine', ('i2i32', 'a@8'), '#b') => ('ior', ('ine', 'a', ('i2i8', 'b')), ('ine', ('i2i32', ('i2i8', 'b')), 'b')) */
   /* search1586_0_0 -> 6 in the cache */
   /* search1586_0 -> 4330 in the cache */
   /* search1586_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 4330, 33 },
      -1,
   } },

   /* replace1586_0_0 -> 6 in the cache */
   /* replace1586_0_1_0 -> 36 in the cache */
   /* replace1586_0_1 -> 4441 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 6, 4441 },
      -1,
   } },
   /* replace1586_1_0_0_0 -> 36 in the cache */
   /* replace1586_1_0_0 -> 4441 in the cache */
   /* replace1586_1_0 -> 4443 in the cache */
   /* replace1586_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 4443, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 4447, 4448 },
      -1,
   } },

   /* ('ilt', ('i2i32', 'a@8'), '#b') => ('iand', ('ilt', -128, 'b'), ('ior', ('ilt', 127, 'b'), ('ilt', 'a', ('i2i8', 'b')))) */
   /* search1587_0_0 -> 6 in the cache */
   /* search1587_0 -> 4330 in the cache */
   /* search1587_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4330, 33 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { -0x80 /* -128 */ },
   } },
   /* replace1587_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4451, 36 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x7f /* 127 */ },
   } },
   /* replace1587_1_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4453, 36 },
      -1,
   } },
   /* replace1587_1_1_0 -> 6 in the cache */
   /* replace1587_1_1_1_0 -> 36 in the cache */
   /* replace1587_1_1_1 -> 4441 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 6, 4441 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4454, 4455 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4452, 4456 },
      -1,
   } },

   /* ('ilt', '#a', ('i2i32', 'b@8')) => ('iand', ('ilt', 'a', 127), ('ior', ('ilt', 'a', -128), ('ilt', ('i2i8', 'a'), 'b'))) */
   /* search1588_0 -> 286 in the cache */
   /* search1588_1_0 -> 2128 in the cache */
   /* search1588_1 -> 4431 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 286, 4431 },
      -1,
   } },

   /* replace1588_0_0 -> 16 in the cache */
   /* replace1588_0_1 -> 4453 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 16, 4453 },
      -1,
   } },
   /* replace1588_1_0_0 -> 16 in the cache */
   /* replace1588_1_0_1 -> 4451 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 16, 4451 },
      -1,
   } },
   /* replace1588_1_1_0_0 -> 16 in the cache */
   /* replace1588_1_1_0 -> 4367 in the cache */
   /* replace1588_1_1_1 -> 2128 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4367, 2128 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4460, 4461 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4459, 4462 },
      -1,
   } },

   /* ('ige', ('i2i32', 'a@8'), '#b') => ('iand', ('ige', 127, 'b'), ('ior', ('ige', -128, 'b'), ('ige', 'a', ('i2i8', 'b')))) */
   /* search1589_0_0 -> 6 in the cache */
   /* search1589_0 -> 4330 in the cache */
   /* search1589_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4330, 33 },
      -1,
   } },

   /* replace1589_0_0 -> 4453 in the cache */
   /* replace1589_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4453, 36 },
      -1,
   } },
   /* replace1589_1_0_0 -> 4451 in the cache */
   /* replace1589_1_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4451, 36 },
      -1,
   } },
   /* replace1589_1_1_0 -> 6 in the cache */
   /* replace1589_1_1_1_0 -> 36 in the cache */
   /* replace1589_1_1_1 -> 4441 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 6, 4441 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4466, 4467 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4465, 4468 },
      -1,
   } },

   /* ('ige', '#a', ('i2i32', 'b@8')) => ('iand', ('ige', 'a', -128), ('ior', ('ige', 'a', 127), ('ige', ('i2i8', 'a'), 'b'))) */
   /* search1590_0 -> 286 in the cache */
   /* search1590_1_0 -> 2128 in the cache */
   /* search1590_1 -> 4431 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 286, 4431 },
      -1,
   } },

   /* replace1590_0_0 -> 16 in the cache */
   /* replace1590_0_1 -> 4451 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 16, 4451 },
      -1,
   } },
   /* replace1590_1_0_0 -> 16 in the cache */
   /* replace1590_1_0_1 -> 4453 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 16, 4453 },
      -1,
   } },
   /* replace1590_1_1_0_0 -> 16 in the cache */
   /* replace1590_1_1_0 -> 4367 in the cache */
   /* replace1590_1_1_1 -> 2128 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4367, 2128 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4472, 4473 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4471, 4474 },
      -1,
   } },

   /* ('ieq', ('i2i64', 'a@8'), ('i2i64', 'b@8')) => ('ieq', 'a', ('i2i8', 'b')) */
   /* search1591_0_0 -> 6 in the cache */
   /* search1591_0 -> 4349 in the cache */
   /* search1591_1_0 -> 2128 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 2128 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 4349, 4476 },
      -1,
   } },

   /* replace1591_0 -> 6 in the cache */
   /* replace1591_1_0 -> 2128 in the cache */
   /* replace1591_1 -> 4376 in the cache */
   /* replace1591 -> 4377 in the cache */

   /* ('ine', ('i2i64', 'a@8'), ('i2i64', 'b@8')) => ('ine', 'a', ('i2i8', 'b')) */
   /* search1592_0_0 -> 6 in the cache */
   /* search1592_0 -> 4349 in the cache */
   /* search1592_1_0 -> 2128 in the cache */
   /* search1592_1 -> 4476 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 4349, 4476 },
      -1,
   } },

   /* replace1592_0 -> 6 in the cache */
   /* replace1592_1_0 -> 2128 in the cache */
   /* replace1592_1 -> 4376 in the cache */
   /* replace1592 -> 4379 in the cache */

   /* ('ige', ('i2i64', 'a@8'), ('i2i64', 'b@8')) => ('ige', 'a', ('i2i8', 'b')) */
   /* search1593_0_0 -> 6 in the cache */
   /* search1593_0 -> 4349 in the cache */
   /* search1593_1_0 -> 2128 in the cache */
   /* search1593_1 -> 4476 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4349, 4476 },
      -1,
   } },

   /* replace1593_0 -> 6 in the cache */
   /* replace1593_1_0 -> 2128 in the cache */
   /* replace1593_1 -> 4376 in the cache */
   /* replace1593 -> 4381 in the cache */

   /* ('ilt', ('i2i64', 'a@8'), ('i2i64', 'b@8')) => ('ilt', 'a', ('i2i8', 'b')) */
   /* search1594_0_0 -> 6 in the cache */
   /* search1594_0 -> 4349 in the cache */
   /* search1594_1_0 -> 2128 in the cache */
   /* search1594_1 -> 4476 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4349, 4476 },
      -1,
   } },

   /* replace1594_0 -> 6 in the cache */
   /* replace1594_1_0 -> 2128 in the cache */
   /* replace1594_1 -> 4376 in the cache */
   /* replace1594 -> 4383 in the cache */

   /* ('ige', ('i2i64', 'b@8'), ('i2i64', 'a@8')) => ('ige', ('i2i8', 'b'), 'a') */
   /* search1595_0_0 -> 4384 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 4384 },
      -1,
   } },
   /* search1595_1_0 -> 4386 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 4386 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4481, 4482 },
      -1,
   } },

   /* replace1595_0_0 -> 4384 in the cache */
   /* replace1595_0 -> 4389 in the cache */
   /* replace1595_1 -> 4386 in the cache */
   /* replace1595 -> 4390 in the cache */

   /* ('ilt', ('i2i64', 'b@8'), ('i2i64', 'a@8')) => ('ilt', ('i2i8', 'b'), 'a') */
   /* search1596_0_0 -> 4384 in the cache */
   /* search1596_0 -> 4481 in the cache */
   /* search1596_1_0 -> 4386 in the cache */
   /* search1596_1 -> 4482 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4481, 4482 },
      -1,
   } },

   /* replace1596_0_0 -> 4384 in the cache */
   /* replace1596_0 -> 4389 in the cache */
   /* replace1596_1 -> 4386 in the cache */
   /* replace1596 -> 4392 in the cache */

   /* ('ieq', ('i2i64', 'a@8'), '#b') => ('iand', ('ieq', 'a', ('i2i8', 'b')), ('ieq', ('i2i64', ('i2i8', 'b')), 'b')) */
   /* search1597_0_0 -> 6 in the cache */
   /* search1597_0 -> 4349 in the cache */
   { .variable = {
      { nir_search_value_variable, 64 },
      1, /* b */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 4349, 4485 },
      -1,
   } },

   /* replace1597_0_0 -> 6 in the cache */
   /* replace1597_0_1_0 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 6, 4487 },
      -1,
   } },
   /* replace1597_1_0_0_0 -> 41 in the cache */
   /* replace1597_1_0_0 -> 4487 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 4487 },
      -1,
   } },
   /* replace1597_1_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 4489, 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 4488, 4490 },
      -1,
   } },

   /* ('ine', ('i2i64', 'a@8'), '#b') => ('ior', ('ine', 'a', ('i2i8', 'b')), ('ine', ('i2i64', ('i2i8', 'b')), 'b')) */
   /* search1598_0_0 -> 6 in the cache */
   /* search1598_0 -> 4349 in the cache */
   /* search1598_1 -> 4485 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 4349, 4485 },
      -1,
   } },

   /* replace1598_0_0 -> 6 in the cache */
   /* replace1598_0_1_0 -> 41 in the cache */
   /* replace1598_0_1 -> 4487 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 6, 4487 },
      -1,
   } },
   /* replace1598_1_0_0_0 -> 41 in the cache */
   /* replace1598_1_0_0 -> 4487 in the cache */
   /* replace1598_1_0 -> 4489 in the cache */
   /* replace1598_1_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 4489, 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 4493, 4494 },
      -1,
   } },

   /* ('ilt', ('i2i64', 'a@8'), '#b') => ('iand', ('ilt', -128, 'b'), ('ior', ('ilt', 127, 'b'), ('ilt', 'a', ('i2i8', 'b')))) */
   /* search1599_0_0 -> 6 in the cache */
   /* search1599_0 -> 4349 in the cache */
   /* search1599_1 -> 4485 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4349, 4485 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { -0x80 /* -128 */ },
   } },
   /* replace1599_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4497, 41 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0x7f /* 127 */ },
   } },
   /* replace1599_1_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4499, 41 },
      -1,
   } },
   /* replace1599_1_1_0 -> 6 in the cache */
   /* replace1599_1_1_1_0 -> 41 in the cache */
   /* replace1599_1_1_1 -> 4487 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 6, 4487 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4500, 4501 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4498, 4502 },
      -1,
   } },

   /* ('ilt', '#a', ('i2i64', 'b@8')) => ('iand', ('ilt', 'a', 127), ('ior', ('ilt', 'a', -128), ('ilt', ('i2i8', 'a'), 'b'))) */
   { .variable = {
      { nir_search_value_variable, 64 },
      0, /* a */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search1600_1_0 -> 2128 in the cache */
   /* search1600_1 -> 4476 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4504, 4476 },
      -1,
   } },

   /* replace1600_0_0 -> 21 in the cache */
   /* replace1600_0_1 -> 4499 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 21, 4499 },
      -1,
   } },
   /* replace1600_1_0_0 -> 21 in the cache */
   /* replace1600_1_0_1 -> 4497 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 21, 4497 },
      -1,
   } },
   /* replace1600_1_1_0_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 21 },
      -1,
   } },
   /* replace1600_1_1_1 -> 2128 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4508, 2128 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4507, 4509 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4506, 4510 },
      -1,
   } },

   /* ('ige', ('i2i64', 'a@8'), '#b') => ('iand', ('ige', 127, 'b'), ('ior', ('ige', -128, 'b'), ('ige', 'a', ('i2i8', 'b')))) */
   /* search1601_0_0 -> 6 in the cache */
   /* search1601_0 -> 4349 in the cache */
   /* search1601_1 -> 4485 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4349, 4485 },
      -1,
   } },

   /* replace1601_0_0 -> 4499 in the cache */
   /* replace1601_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4499, 41 },
      -1,
   } },
   /* replace1601_1_0_0 -> 4497 in the cache */
   /* replace1601_1_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4497, 41 },
      -1,
   } },
   /* replace1601_1_1_0 -> 6 in the cache */
   /* replace1601_1_1_1_0 -> 41 in the cache */
   /* replace1601_1_1_1 -> 4487 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 6, 4487 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4514, 4515 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4513, 4516 },
      -1,
   } },

   /* ('ige', '#a', ('i2i64', 'b@8')) => ('iand', ('ige', 'a', -128), ('ior', ('ige', 'a', 127), ('ige', ('i2i8', 'a'), 'b'))) */
   /* search1602_0 -> 4504 in the cache */
   /* search1602_1_0 -> 2128 in the cache */
   /* search1602_1 -> 4476 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4504, 4476 },
      -1,
   } },

   /* replace1602_0_0 -> 21 in the cache */
   /* replace1602_0_1 -> 4497 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 21, 4497 },
      -1,
   } },
   /* replace1602_1_0_0 -> 21 in the cache */
   /* replace1602_1_0_1 -> 4499 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 21, 4499 },
      -1,
   } },
   /* replace1602_1_1_0_0 -> 21 in the cache */
   /* replace1602_1_1_0 -> 4508 in the cache */
   /* replace1602_1_1_1 -> 2128 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4508, 2128 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4520, 4521 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4519, 4522 },
      -1,
   } },

   /* ('ieq', ('i2i32', 'a@16'), ('i2i32', 'b@8')) => ('ieq', 'a', ('i2i16', 'b')) */
   /* search1603_0_0 -> 11 in the cache */
   /* search1603_0 -> 1815 in the cache */
   /* search1603_1_0 -> 2128 in the cache */
   /* search1603_1 -> 4431 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1815, 4431 },
      -1,
   } },

   /* replace1603_0 -> 11 in the cache */
   /* replace1603_1_0 -> 2128 in the cache */
   /* replace1603_1 -> 4374 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 11, 4374 },
      -1,
   } },

   /* ('ine', ('i2i32', 'a@16'), ('i2i32', 'b@8')) => ('ine', 'a', ('i2i16', 'b')) */
   /* search1604_0_0 -> 11 in the cache */
   /* search1604_0 -> 1815 in the cache */
   /* search1604_1_0 -> 2128 in the cache */
   /* search1604_1 -> 4431 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1815, 4431 },
      -1,
   } },

   /* replace1604_0 -> 11 in the cache */
   /* replace1604_1_0 -> 2128 in the cache */
   /* replace1604_1 -> 4374 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 11, 4374 },
      -1,
   } },

   /* ('ige', ('i2i32', 'a@16'), ('i2i32', 'b@8')) => ('ige', 'a', ('i2i16', 'b')) */
   /* search1605_0_0 -> 11 in the cache */
   /* search1605_0 -> 1815 in the cache */
   /* search1605_1_0 -> 2128 in the cache */
   /* search1605_1 -> 4431 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 1815, 4431 },
      -1,
   } },

   /* replace1605_0 -> 11 in the cache */
   /* replace1605_1_0 -> 2128 in the cache */
   /* replace1605_1 -> 4374 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 11, 4374 },
      -1,
   } },

   /* ('ilt', ('i2i32', 'a@16'), ('i2i32', 'b@8')) => ('ilt', 'a', ('i2i16', 'b')) */
   /* search1606_0_0 -> 11 in the cache */
   /* search1606_0 -> 1815 in the cache */
   /* search1606_1_0 -> 2128 in the cache */
   /* search1606_1 -> 4431 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 1815, 4431 },
      -1,
   } },

   /* replace1606_0 -> 11 in the cache */
   /* replace1606_1_0 -> 2128 in the cache */
   /* replace1606_1 -> 4374 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 11, 4374 },
      -1,
   } },

   /* ('ige', ('i2i32', 'b@8'), ('i2i32', 'a@16')) => ('ige', ('i2i16', 'b'), 'a') */
   /* search1607_0_0 -> 4384 in the cache */
   /* search1607_0 -> 4436 in the cache */
   /* search1607_1_0 -> 526 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 526 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4436, 4532 },
      -1,
   } },

   /* replace1607_0_0 -> 4384 in the cache */
   /* replace1607_0 -> 4385 in the cache */
   /* replace1607_1 -> 526 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4385, 526 },
      -1,
   } },

   /* ('ilt', ('i2i32', 'b@8'), ('i2i32', 'a@16')) => ('ilt', ('i2i16', 'b'), 'a') */
   /* search1608_0_0 -> 4384 in the cache */
   /* search1608_0 -> 4436 in the cache */
   /* search1608_1_0 -> 526 in the cache */
   /* search1608_1 -> 4532 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4436, 4532 },
      -1,
   } },

   /* replace1608_0_0 -> 4384 in the cache */
   /* replace1608_0 -> 4385 in the cache */
   /* replace1608_1 -> 526 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4385, 526 },
      -1,
   } },

   /* ('ieq', ('i2i32', 'a@16'), ('i2i32', 'b@16')) => ('ieq', 'a', ('i2i16', 'b')) */
   /* search1609_0_0 -> 11 in the cache */
   /* search1609_0 -> 1815 in the cache */
   /* search1609_1_0 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 258 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1815, 4537 },
      -1,
   } },

   /* replace1609_0 -> 11 in the cache */
   /* replace1609_1_0 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 258 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 11, 4539 },
      -1,
   } },

   /* ('ine', ('i2i32', 'a@16'), ('i2i32', 'b@16')) => ('ine', 'a', ('i2i16', 'b')) */
   /* search1610_0_0 -> 11 in the cache */
   /* search1610_0 -> 1815 in the cache */
   /* search1610_1_0 -> 258 in the cache */
   /* search1610_1 -> 4537 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1815, 4537 },
      -1,
   } },

   /* replace1610_0 -> 11 in the cache */
   /* replace1610_1_0 -> 258 in the cache */
   /* replace1610_1 -> 4539 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 11, 4539 },
      -1,
   } },

   /* ('ige', ('i2i32', 'a@16'), ('i2i32', 'b@16')) => ('ige', 'a', ('i2i16', 'b')) */
   /* search1611_0_0 -> 11 in the cache */
   /* search1611_0 -> 1815 in the cache */
   /* search1611_1_0 -> 258 in the cache */
   /* search1611_1 -> 4537 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 1815, 4537 },
      -1,
   } },

   /* replace1611_0 -> 11 in the cache */
   /* replace1611_1_0 -> 258 in the cache */
   /* replace1611_1 -> 4539 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 11, 4539 },
      -1,
   } },

   /* ('ilt', ('i2i32', 'a@16'), ('i2i32', 'b@16')) => ('ilt', 'a', ('i2i16', 'b')) */
   /* search1612_0_0 -> 11 in the cache */
   /* search1612_0 -> 1815 in the cache */
   /* search1612_1_0 -> 258 in the cache */
   /* search1612_1 -> 4537 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 1815, 4537 },
      -1,
   } },

   /* replace1612_0 -> 11 in the cache */
   /* replace1612_1_0 -> 258 in the cache */
   /* replace1612_1 -> 4539 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 11, 4539 },
      -1,
   } },

   /* ('ige', ('i2i32', 'b@16'), ('i2i32', 'a@16')) => ('ige', ('i2i16', 'b'), 'a') */
   /* search1613_0_0 -> 515 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 515 },
      -1,
   } },
   /* search1613_1_0 -> 526 in the cache */
   /* search1613_1 -> 4532 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4547, 4532 },
      -1,
   } },

   /* replace1613_0_0 -> 515 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 515 },
      -1,
   } },
   /* replace1613_1 -> 526 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4549, 526 },
      -1,
   } },

   /* ('ilt', ('i2i32', 'b@16'), ('i2i32', 'a@16')) => ('ilt', ('i2i16', 'b'), 'a') */
   /* search1614_0_0 -> 515 in the cache */
   /* search1614_0 -> 4547 in the cache */
   /* search1614_1_0 -> 526 in the cache */
   /* search1614_1 -> 4532 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4547, 4532 },
      -1,
   } },

   /* replace1614_0_0 -> 515 in the cache */
   /* replace1614_0 -> 4549 in the cache */
   /* replace1614_1 -> 526 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4549, 526 },
      -1,
   } },

   /* ('ieq', ('i2i32', 'a@16'), '#b') => ('iand', ('ieq', 'a', ('i2i16', 'b')), ('ieq', ('i2i32', ('i2i16', 'b')), 'b')) */
   /* search1615_0_0 -> 11 in the cache */
   /* search1615_0 -> 1815 in the cache */
   /* search1615_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1815, 33 },
      -1,
   } },

   /* replace1615_0_0 -> 11 in the cache */
   /* replace1615_0_1_0 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 11, 4554 },
      -1,
   } },
   /* replace1615_1_0_0_0 -> 36 in the cache */
   /* replace1615_1_0_0 -> 4554 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 4554 },
      -1,
   } },
   /* replace1615_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 4556, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 4555, 4557 },
      -1,
   } },

   /* ('ine', ('i2i32', 'a@16'), '#b') => ('ior', ('ine', 'a', ('i2i16', 'b')), ('ine', ('i2i32', ('i2i16', 'b')), 'b')) */
   /* search1616_0_0 -> 11 in the cache */
   /* search1616_0 -> 1815 in the cache */
   /* search1616_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1815, 33 },
      -1,
   } },

   /* replace1616_0_0 -> 11 in the cache */
   /* replace1616_0_1_0 -> 36 in the cache */
   /* replace1616_0_1 -> 4554 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 11, 4554 },
      -1,
   } },
   /* replace1616_1_0_0_0 -> 36 in the cache */
   /* replace1616_1_0_0 -> 4554 in the cache */
   /* replace1616_1_0 -> 4556 in the cache */
   /* replace1616_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 4556, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 4560, 4561 },
      -1,
   } },

   /* ('ilt', ('i2i32', 'a@16'), '#b') => ('iand', ('ilt', -32768, 'b'), ('ior', ('ilt', 32767, 'b'), ('ilt', 'a', ('i2i16', 'b')))) */
   /* search1617_0_0 -> 11 in the cache */
   /* search1617_0 -> 1815 in the cache */
   /* search1617_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 1815, 33 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { -0x8000 /* -32768 */ },
   } },
   /* replace1617_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4564, 36 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x7fff /* 32767 */ },
   } },
   /* replace1617_1_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4566, 36 },
      -1,
   } },
   /* replace1617_1_1_0 -> 11 in the cache */
   /* replace1617_1_1_1_0 -> 36 in the cache */
   /* replace1617_1_1_1 -> 4554 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 11, 4554 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4567, 4568 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4565, 4569 },
      -1,
   } },

   /* ('ilt', '#a', ('i2i32', 'b@16')) => ('iand', ('ilt', 'a', 32767), ('ior', ('ilt', 'a', -32768), ('ilt', ('i2i16', 'a'), 'b'))) */
   /* search1618_0 -> 286 in the cache */
   /* search1618_1_0 -> 258 in the cache */
   /* search1618_1 -> 4537 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 286, 4537 },
      -1,
   } },

   /* replace1618_0_0 -> 16 in the cache */
   /* replace1618_0_1 -> 4566 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 16, 4566 },
      -1,
   } },
   /* replace1618_1_0_0 -> 16 in the cache */
   /* replace1618_1_0_1 -> 4564 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 16, 4564 },
      -1,
   } },
   /* replace1618_1_1_0_0 -> 16 in the cache */
   /* replace1618_1_1_0 -> 4369 in the cache */
   /* replace1618_1_1_1 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4369, 258 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4573, 4574 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4572, 4575 },
      -1,
   } },

   /* ('ige', ('i2i32', 'a@16'), '#b') => ('iand', ('ige', 32767, 'b'), ('ior', ('ige', -32768, 'b'), ('ige', 'a', ('i2i16', 'b')))) */
   /* search1619_0_0 -> 11 in the cache */
   /* search1619_0 -> 1815 in the cache */
   /* search1619_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 1815, 33 },
      -1,
   } },

   /* replace1619_0_0 -> 4566 in the cache */
   /* replace1619_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4566, 36 },
      -1,
   } },
   /* replace1619_1_0_0 -> 4564 in the cache */
   /* replace1619_1_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4564, 36 },
      -1,
   } },
   /* replace1619_1_1_0 -> 11 in the cache */
   /* replace1619_1_1_1_0 -> 36 in the cache */
   /* replace1619_1_1_1 -> 4554 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 11, 4554 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4579, 4580 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4578, 4581 },
      -1,
   } },

   /* ('ige', '#a', ('i2i32', 'b@16')) => ('iand', ('ige', 'a', -32768), ('ior', ('ige', 'a', 32767), ('ige', ('i2i16', 'a'), 'b'))) */
   /* search1620_0 -> 286 in the cache */
   /* search1620_1_0 -> 258 in the cache */
   /* search1620_1 -> 4537 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 286, 4537 },
      -1,
   } },

   /* replace1620_0_0 -> 16 in the cache */
   /* replace1620_0_1 -> 4564 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 16, 4564 },
      -1,
   } },
   /* replace1620_1_0_0 -> 16 in the cache */
   /* replace1620_1_0_1 -> 4566 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 16, 4566 },
      -1,
   } },
   /* replace1620_1_1_0_0 -> 16 in the cache */
   /* replace1620_1_1_0 -> 4369 in the cache */
   /* replace1620_1_1_1 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4369, 258 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4585, 4586 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4584, 4587 },
      -1,
   } },

   /* ('ieq', ('i2i64', 'a@16'), ('i2i64', 'b@8')) => ('ieq', 'a', ('i2i16', 'b')) */
   /* search1621_0_0 -> 11 in the cache */
   /* search1621_0 -> 1833 in the cache */
   /* search1621_1_0 -> 2128 in the cache */
   /* search1621_1 -> 4476 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1833, 4476 },
      -1,
   } },

   /* replace1621_0 -> 11 in the cache */
   /* replace1621_1_0 -> 2128 in the cache */
   /* replace1621_1 -> 4374 in the cache */
   /* replace1621 -> 4525 in the cache */

   /* ('ine', ('i2i64', 'a@16'), ('i2i64', 'b@8')) => ('ine', 'a', ('i2i16', 'b')) */
   /* search1622_0_0 -> 11 in the cache */
   /* search1622_0 -> 1833 in the cache */
   /* search1622_1_0 -> 2128 in the cache */
   /* search1622_1 -> 4476 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1833, 4476 },
      -1,
   } },

   /* replace1622_0 -> 11 in the cache */
   /* replace1622_1_0 -> 2128 in the cache */
   /* replace1622_1 -> 4374 in the cache */
   /* replace1622 -> 4527 in the cache */

   /* ('ige', ('i2i64', 'a@16'), ('i2i64', 'b@8')) => ('ige', 'a', ('i2i16', 'b')) */
   /* search1623_0_0 -> 11 in the cache */
   /* search1623_0 -> 1833 in the cache */
   /* search1623_1_0 -> 2128 in the cache */
   /* search1623_1 -> 4476 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 1833, 4476 },
      -1,
   } },

   /* replace1623_0 -> 11 in the cache */
   /* replace1623_1_0 -> 2128 in the cache */
   /* replace1623_1 -> 4374 in the cache */
   /* replace1623 -> 4529 in the cache */

   /* ('ilt', ('i2i64', 'a@16'), ('i2i64', 'b@8')) => ('ilt', 'a', ('i2i16', 'b')) */
   /* search1624_0_0 -> 11 in the cache */
   /* search1624_0 -> 1833 in the cache */
   /* search1624_1_0 -> 2128 in the cache */
   /* search1624_1 -> 4476 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 1833, 4476 },
      -1,
   } },

   /* replace1624_0 -> 11 in the cache */
   /* replace1624_1_0 -> 2128 in the cache */
   /* replace1624_1 -> 4374 in the cache */
   /* replace1624 -> 4531 in the cache */

   /* ('ige', ('i2i64', 'b@8'), ('i2i64', 'a@16')) => ('ige', ('i2i16', 'b'), 'a') */
   /* search1625_0_0 -> 4384 in the cache */
   /* search1625_0 -> 4481 in the cache */
   /* search1625_1_0 -> 526 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 526 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4481, 4593 },
      -1,
   } },

   /* replace1625_0_0 -> 4384 in the cache */
   /* replace1625_0 -> 4385 in the cache */
   /* replace1625_1 -> 526 in the cache */
   /* replace1625 -> 4534 in the cache */

   /* ('ilt', ('i2i64', 'b@8'), ('i2i64', 'a@16')) => ('ilt', ('i2i16', 'b'), 'a') */
   /* search1626_0_0 -> 4384 in the cache */
   /* search1626_0 -> 4481 in the cache */
   /* search1626_1_0 -> 526 in the cache */
   /* search1626_1 -> 4593 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4481, 4593 },
      -1,
   } },

   /* replace1626_0_0 -> 4384 in the cache */
   /* replace1626_0 -> 4385 in the cache */
   /* replace1626_1 -> 526 in the cache */
   /* replace1626 -> 4536 in the cache */

   /* ('ieq', ('i2i64', 'a@16'), ('i2i64', 'b@16')) => ('ieq', 'a', ('i2i16', 'b')) */
   /* search1627_0_0 -> 11 in the cache */
   /* search1627_0 -> 1833 in the cache */
   /* search1627_1_0 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 258 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1833, 4596 },
      -1,
   } },

   /* replace1627_0 -> 11 in the cache */
   /* replace1627_1_0 -> 258 in the cache */
   /* replace1627_1 -> 4539 in the cache */
   /* replace1627 -> 4540 in the cache */

   /* ('ine', ('i2i64', 'a@16'), ('i2i64', 'b@16')) => ('ine', 'a', ('i2i16', 'b')) */
   /* search1628_0_0 -> 11 in the cache */
   /* search1628_0 -> 1833 in the cache */
   /* search1628_1_0 -> 258 in the cache */
   /* search1628_1 -> 4596 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1833, 4596 },
      -1,
   } },

   /* replace1628_0 -> 11 in the cache */
   /* replace1628_1_0 -> 258 in the cache */
   /* replace1628_1 -> 4539 in the cache */
   /* replace1628 -> 4542 in the cache */

   /* ('ige', ('i2i64', 'a@16'), ('i2i64', 'b@16')) => ('ige', 'a', ('i2i16', 'b')) */
   /* search1629_0_0 -> 11 in the cache */
   /* search1629_0 -> 1833 in the cache */
   /* search1629_1_0 -> 258 in the cache */
   /* search1629_1 -> 4596 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 1833, 4596 },
      -1,
   } },

   /* replace1629_0 -> 11 in the cache */
   /* replace1629_1_0 -> 258 in the cache */
   /* replace1629_1 -> 4539 in the cache */
   /* replace1629 -> 4544 in the cache */

   /* ('ilt', ('i2i64', 'a@16'), ('i2i64', 'b@16')) => ('ilt', 'a', ('i2i16', 'b')) */
   /* search1630_0_0 -> 11 in the cache */
   /* search1630_0 -> 1833 in the cache */
   /* search1630_1_0 -> 258 in the cache */
   /* search1630_1 -> 4596 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 1833, 4596 },
      -1,
   } },

   /* replace1630_0 -> 11 in the cache */
   /* replace1630_1_0 -> 258 in the cache */
   /* replace1630_1 -> 4539 in the cache */
   /* replace1630 -> 4546 in the cache */

   /* ('ige', ('i2i64', 'b@16'), ('i2i64', 'a@16')) => ('ige', ('i2i16', 'b'), 'a') */
   /* search1631_0_0 -> 515 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 515 },
      -1,
   } },
   /* search1631_1_0 -> 526 in the cache */
   /* search1631_1 -> 4593 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4601, 4593 },
      -1,
   } },

   /* replace1631_0_0 -> 515 in the cache */
   /* replace1631_0 -> 4549 in the cache */
   /* replace1631_1 -> 526 in the cache */
   /* replace1631 -> 4550 in the cache */

   /* ('ilt', ('i2i64', 'b@16'), ('i2i64', 'a@16')) => ('ilt', ('i2i16', 'b'), 'a') */
   /* search1632_0_0 -> 515 in the cache */
   /* search1632_0 -> 4601 in the cache */
   /* search1632_1_0 -> 526 in the cache */
   /* search1632_1 -> 4593 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4601, 4593 },
      -1,
   } },

   /* replace1632_0_0 -> 515 in the cache */
   /* replace1632_0 -> 4549 in the cache */
   /* replace1632_1 -> 526 in the cache */
   /* replace1632 -> 4552 in the cache */

   /* ('ieq', ('i2i64', 'a@16'), '#b') => ('iand', ('ieq', 'a', ('i2i16', 'b')), ('ieq', ('i2i64', ('i2i16', 'b')), 'b')) */
   /* search1633_0_0 -> 11 in the cache */
   /* search1633_0 -> 1833 in the cache */
   /* search1633_1 -> 4485 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1833, 4485 },
      -1,
   } },

   /* replace1633_0_0 -> 11 in the cache */
   /* replace1633_0_1_0 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 11, 4605 },
      -1,
   } },
   /* replace1633_1_0_0_0 -> 41 in the cache */
   /* replace1633_1_0_0 -> 4605 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 4605 },
      -1,
   } },
   /* replace1633_1_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 4607, 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 4606, 4608 },
      -1,
   } },

   /* ('ine', ('i2i64', 'a@16'), '#b') => ('ior', ('ine', 'a', ('i2i16', 'b')), ('ine', ('i2i64', ('i2i16', 'b')), 'b')) */
   /* search1634_0_0 -> 11 in the cache */
   /* search1634_0 -> 1833 in the cache */
   /* search1634_1 -> 4485 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1833, 4485 },
      -1,
   } },

   /* replace1634_0_0 -> 11 in the cache */
   /* replace1634_0_1_0 -> 41 in the cache */
   /* replace1634_0_1 -> 4605 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 11, 4605 },
      -1,
   } },
   /* replace1634_1_0_0_0 -> 41 in the cache */
   /* replace1634_1_0_0 -> 4605 in the cache */
   /* replace1634_1_0 -> 4607 in the cache */
   /* replace1634_1_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 4607, 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 4611, 4612 },
      -1,
   } },

   /* ('ilt', ('i2i64', 'a@16'), '#b') => ('iand', ('ilt', -32768, 'b'), ('ior', ('ilt', 32767, 'b'), ('ilt', 'a', ('i2i16', 'b')))) */
   /* search1635_0_0 -> 11 in the cache */
   /* search1635_0 -> 1833 in the cache */
   /* search1635_1 -> 4485 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 1833, 4485 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { -0x8000 /* -32768 */ },
   } },
   /* replace1635_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4615, 41 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0x7fff /* 32767 */ },
   } },
   /* replace1635_1_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4617, 41 },
      -1,
   } },
   /* replace1635_1_1_0 -> 11 in the cache */
   /* replace1635_1_1_1_0 -> 41 in the cache */
   /* replace1635_1_1_1 -> 4605 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 11, 4605 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4618, 4619 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4616, 4620 },
      -1,
   } },

   /* ('ilt', '#a', ('i2i64', 'b@16')) => ('iand', ('ilt', 'a', 32767), ('ior', ('ilt', 'a', -32768), ('ilt', ('i2i16', 'a'), 'b'))) */
   /* search1636_0 -> 4504 in the cache */
   /* search1636_1_0 -> 258 in the cache */
   /* search1636_1 -> 4596 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4504, 4596 },
      -1,
   } },

   /* replace1636_0_0 -> 21 in the cache */
   /* replace1636_0_1 -> 4617 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 21, 4617 },
      -1,
   } },
   /* replace1636_1_0_0 -> 21 in the cache */
   /* replace1636_1_0_1 -> 4615 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 21, 4615 },
      -1,
   } },
   /* replace1636_1_1_0_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 21 },
      -1,
   } },
   /* replace1636_1_1_1 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4625, 258 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4624, 4626 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4623, 4627 },
      -1,
   } },

   /* ('ige', ('i2i64', 'a@16'), '#b') => ('iand', ('ige', 32767, 'b'), ('ior', ('ige', -32768, 'b'), ('ige', 'a', ('i2i16', 'b')))) */
   /* search1637_0_0 -> 11 in the cache */
   /* search1637_0 -> 1833 in the cache */
   /* search1637_1 -> 4485 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 1833, 4485 },
      -1,
   } },

   /* replace1637_0_0 -> 4617 in the cache */
   /* replace1637_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4617, 41 },
      -1,
   } },
   /* replace1637_1_0_0 -> 4615 in the cache */
   /* replace1637_1_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4615, 41 },
      -1,
   } },
   /* replace1637_1_1_0 -> 11 in the cache */
   /* replace1637_1_1_1_0 -> 41 in the cache */
   /* replace1637_1_1_1 -> 4605 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 11, 4605 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4631, 4632 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4630, 4633 },
      -1,
   } },

   /* ('ige', '#a', ('i2i64', 'b@16')) => ('iand', ('ige', 'a', -32768), ('ior', ('ige', 'a', 32767), ('ige', ('i2i16', 'a'), 'b'))) */
   /* search1638_0 -> 4504 in the cache */
   /* search1638_1_0 -> 258 in the cache */
   /* search1638_1 -> 4596 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4504, 4596 },
      -1,
   } },

   /* replace1638_0_0 -> 21 in the cache */
   /* replace1638_0_1 -> 4615 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 21, 4615 },
      -1,
   } },
   /* replace1638_1_0_0 -> 21 in the cache */
   /* replace1638_1_0_1 -> 4617 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 21, 4617 },
      -1,
   } },
   /* replace1638_1_1_0_0 -> 21 in the cache */
   /* replace1638_1_1_0 -> 4625 in the cache */
   /* replace1638_1_1_1 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4625, 258 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4637, 4638 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4636, 4639 },
      -1,
   } },

   /* ('ieq', ('i2i64', 'a@32'), ('i2i64', 'b@8')) => ('ieq', 'a', ('i2i32', 'b')) */
   /* search1639_0_0 -> 16 in the cache */
   /* search1639_0 -> 1920 in the cache */
   /* search1639_1_0 -> 2128 in the cache */
   /* search1639_1 -> 4476 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1920, 4476 },
      -1,
   } },

   /* replace1639_0 -> 16 in the cache */
   /* replace1639_1_0 -> 2128 in the cache */
   /* replace1639_1 -> 4431 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 16, 4431 },
      -1,
   } },

   /* ('ine', ('i2i64', 'a@32'), ('i2i64', 'b@8')) => ('ine', 'a', ('i2i32', 'b')) */
   /* search1640_0_0 -> 16 in the cache */
   /* search1640_0 -> 1920 in the cache */
   /* search1640_1_0 -> 2128 in the cache */
   /* search1640_1 -> 4476 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1920, 4476 },
      -1,
   } },

   /* replace1640_0 -> 16 in the cache */
   /* replace1640_1_0 -> 2128 in the cache */
   /* replace1640_1 -> 4431 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 16, 4431 },
      -1,
   } },

   /* ('ige', ('i2i64', 'a@32'), ('i2i64', 'b@8')) => ('ige', 'a', ('i2i32', 'b')) */
   /* search1641_0_0 -> 16 in the cache */
   /* search1641_0 -> 1920 in the cache */
   /* search1641_1_0 -> 2128 in the cache */
   /* search1641_1 -> 4476 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 1920, 4476 },
      -1,
   } },

   /* replace1641_0 -> 16 in the cache */
   /* replace1641_1_0 -> 2128 in the cache */
   /* replace1641_1 -> 4431 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 16, 4431 },
      -1,
   } },

   /* ('ilt', ('i2i64', 'a@32'), ('i2i64', 'b@8')) => ('ilt', 'a', ('i2i32', 'b')) */
   /* search1642_0_0 -> 16 in the cache */
   /* search1642_0 -> 1920 in the cache */
   /* search1642_1_0 -> 2128 in the cache */
   /* search1642_1 -> 4476 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 1920, 4476 },
      -1,
   } },

   /* replace1642_0 -> 16 in the cache */
   /* replace1642_1_0 -> 2128 in the cache */
   /* replace1642_1 -> 4431 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 16, 4431 },
      -1,
   } },

   /* ('ige', ('i2i64', 'b@8'), ('i2i64', 'a@32')) => ('ige', ('i2i32', 'b'), 'a') */
   /* search1643_0_0 -> 4384 in the cache */
   /* search1643_0 -> 4481 in the cache */
   /* search1643_1_0 -> 183 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 183 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4481, 4649 },
      -1,
   } },

   /* replace1643_0_0 -> 4384 in the cache */
   /* replace1643_0 -> 4436 in the cache */
   /* replace1643_1 -> 183 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4436, 183 },
      -1,
   } },

   /* ('ilt', ('i2i64', 'b@8'), ('i2i64', 'a@32')) => ('ilt', ('i2i32', 'b'), 'a') */
   /* search1644_0_0 -> 4384 in the cache */
   /* search1644_0 -> 4481 in the cache */
   /* search1644_1_0 -> 183 in the cache */
   /* search1644_1 -> 4649 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4481, 4649 },
      -1,
   } },

   /* replace1644_0_0 -> 4384 in the cache */
   /* replace1644_0 -> 4436 in the cache */
   /* replace1644_1 -> 183 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4436, 183 },
      -1,
   } },

   /* ('ieq', ('i2i64', 'a@32'), ('i2i64', 'b@16')) => ('ieq', 'a', ('i2i32', 'b')) */
   /* search1645_0_0 -> 16 in the cache */
   /* search1645_0 -> 1920 in the cache */
   /* search1645_1_0 -> 258 in the cache */
   /* search1645_1 -> 4596 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1920, 4596 },
      -1,
   } },

   /* replace1645_0 -> 16 in the cache */
   /* replace1645_1_0 -> 258 in the cache */
   /* replace1645_1 -> 4537 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 16, 4537 },
      -1,
   } },

   /* ('ine', ('i2i64', 'a@32'), ('i2i64', 'b@16')) => ('ine', 'a', ('i2i32', 'b')) */
   /* search1646_0_0 -> 16 in the cache */
   /* search1646_0 -> 1920 in the cache */
   /* search1646_1_0 -> 258 in the cache */
   /* search1646_1 -> 4596 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1920, 4596 },
      -1,
   } },

   /* replace1646_0 -> 16 in the cache */
   /* replace1646_1_0 -> 258 in the cache */
   /* replace1646_1 -> 4537 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 16, 4537 },
      -1,
   } },

   /* ('ige', ('i2i64', 'a@32'), ('i2i64', 'b@16')) => ('ige', 'a', ('i2i32', 'b')) */
   /* search1647_0_0 -> 16 in the cache */
   /* search1647_0 -> 1920 in the cache */
   /* search1647_1_0 -> 258 in the cache */
   /* search1647_1 -> 4596 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 1920, 4596 },
      -1,
   } },

   /* replace1647_0 -> 16 in the cache */
   /* replace1647_1_0 -> 258 in the cache */
   /* replace1647_1 -> 4537 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 16, 4537 },
      -1,
   } },

   /* ('ilt', ('i2i64', 'a@32'), ('i2i64', 'b@16')) => ('ilt', 'a', ('i2i32', 'b')) */
   /* search1648_0_0 -> 16 in the cache */
   /* search1648_0 -> 1920 in the cache */
   /* search1648_1_0 -> 258 in the cache */
   /* search1648_1 -> 4596 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 1920, 4596 },
      -1,
   } },

   /* replace1648_0 -> 16 in the cache */
   /* replace1648_1_0 -> 258 in the cache */
   /* replace1648_1 -> 4537 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 16, 4537 },
      -1,
   } },

   /* ('ige', ('i2i64', 'b@16'), ('i2i64', 'a@32')) => ('ige', ('i2i32', 'b'), 'a') */
   /* search1649_0_0 -> 515 in the cache */
   /* search1649_0 -> 4601 in the cache */
   /* search1649_1_0 -> 183 in the cache */
   /* search1649_1 -> 4649 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4601, 4649 },
      -1,
   } },

   /* replace1649_0_0 -> 515 in the cache */
   /* replace1649_0 -> 4547 in the cache */
   /* replace1649_1 -> 183 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4547, 183 },
      -1,
   } },

   /* ('ilt', ('i2i64', 'b@16'), ('i2i64', 'a@32')) => ('ilt', ('i2i32', 'b'), 'a') */
   /* search1650_0_0 -> 515 in the cache */
   /* search1650_0 -> 4601 in the cache */
   /* search1650_1_0 -> 183 in the cache */
   /* search1650_1 -> 4649 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4601, 4649 },
      -1,
   } },

   /* replace1650_0_0 -> 515 in the cache */
   /* replace1650_0 -> 4547 in the cache */
   /* replace1650_1 -> 183 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4547, 183 },
      -1,
   } },

   /* ('ieq', ('i2i64', 'a@32'), ('i2i64', 'b@32')) => ('ieq', 'a', ('i2i32', 'b')) */
   /* search1651_0_0 -> 16 in the cache */
   /* search1651_0 -> 1920 in the cache */
   /* search1651_1_0 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1920, 4666 },
      -1,
   } },

   /* replace1651_0 -> 16 in the cache */
   /* replace1651_1_0 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 16, 4668 },
      -1,
   } },

   /* ('ine', ('i2i64', 'a@32'), ('i2i64', 'b@32')) => ('ine', 'a', ('i2i32', 'b')) */
   /* search1652_0_0 -> 16 in the cache */
   /* search1652_0 -> 1920 in the cache */
   /* search1652_1_0 -> 36 in the cache */
   /* search1652_1 -> 4666 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1920, 4666 },
      -1,
   } },

   /* replace1652_0 -> 16 in the cache */
   /* replace1652_1_0 -> 36 in the cache */
   /* replace1652_1 -> 4668 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 16, 4668 },
      -1,
   } },

   /* ('ige', ('i2i64', 'a@32'), ('i2i64', 'b@32')) => ('ige', 'a', ('i2i32', 'b')) */
   /* search1653_0_0 -> 16 in the cache */
   /* search1653_0 -> 1920 in the cache */
   /* search1653_1_0 -> 36 in the cache */
   /* search1653_1 -> 4666 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 1920, 4666 },
      -1,
   } },

   /* replace1653_0 -> 16 in the cache */
   /* replace1653_1_0 -> 36 in the cache */
   /* replace1653_1 -> 4668 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 16, 4668 },
      -1,
   } },

   /* ('ilt', ('i2i64', 'a@32'), ('i2i64', 'b@32')) => ('ilt', 'a', ('i2i32', 'b')) */
   /* search1654_0_0 -> 16 in the cache */
   /* search1654_0 -> 1920 in the cache */
   /* search1654_1_0 -> 36 in the cache */
   /* search1654_1 -> 4666 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 1920, 4666 },
      -1,
   } },

   /* replace1654_0 -> 16 in the cache */
   /* replace1654_1_0 -> 36 in the cache */
   /* replace1654_1 -> 4668 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 16, 4668 },
      -1,
   } },

   /* ('ige', ('i2i64', 'b@32'), ('i2i64', 'a@32')) => ('ige', ('i2i32', 'b'), 'a') */
   /* search1655_0_0 -> 373 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 373 },
      -1,
   } },
   /* search1655_1_0 -> 183 in the cache */
   /* search1655_1 -> 4649 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4676, 4649 },
      -1,
   } },

   /* replace1655_0_0 -> 373 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 373 },
      -1,
   } },
   /* replace1655_1 -> 183 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4678, 183 },
      -1,
   } },

   /* ('ilt', ('i2i64', 'b@32'), ('i2i64', 'a@32')) => ('ilt', ('i2i32', 'b'), 'a') */
   /* search1656_0_0 -> 373 in the cache */
   /* search1656_0 -> 4676 in the cache */
   /* search1656_1_0 -> 183 in the cache */
   /* search1656_1 -> 4649 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4676, 4649 },
      -1,
   } },

   /* replace1656_0_0 -> 373 in the cache */
   /* replace1656_0 -> 4678 in the cache */
   /* replace1656_1 -> 183 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4678, 183 },
      -1,
   } },

   /* ('ieq', ('i2i64', 'a@32'), '#b') => ('iand', ('ieq', 'a', ('i2i32', 'b')), ('ieq', ('i2i64', ('i2i32', 'b')), 'b')) */
   /* search1657_0_0 -> 16 in the cache */
   /* search1657_0 -> 1920 in the cache */
   /* search1657_1 -> 4485 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1920, 4485 },
      -1,
   } },

   /* replace1657_0_0 -> 16 in the cache */
   /* replace1657_0_1_0 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 16, 4683 },
      -1,
   } },
   /* replace1657_1_0_0_0 -> 41 in the cache */
   /* replace1657_1_0_0 -> 4683 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_i2i64,
      -1, 0,
      { 4683 },
      -1,
   } },
   /* replace1657_1_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 4685, 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 4684, 4686 },
      -1,
   } },

   /* ('ine', ('i2i64', 'a@32'), '#b') => ('ior', ('ine', 'a', ('i2i32', 'b')), ('ine', ('i2i64', ('i2i32', 'b')), 'b')) */
   /* search1658_0_0 -> 16 in the cache */
   /* search1658_0 -> 1920 in the cache */
   /* search1658_1 -> 4485 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1920, 4485 },
      -1,
   } },

   /* replace1658_0_0 -> 16 in the cache */
   /* replace1658_0_1_0 -> 41 in the cache */
   /* replace1658_0_1 -> 4683 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 16, 4683 },
      -1,
   } },
   /* replace1658_1_0_0_0 -> 41 in the cache */
   /* replace1658_1_0_0 -> 4683 in the cache */
   /* replace1658_1_0 -> 4685 in the cache */
   /* replace1658_1_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 4685, 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 4689, 4690 },
      -1,
   } },

   /* ('ilt', ('i2i64', 'a@32'), '#b') => ('iand', ('ilt', -2147483648, 'b'), ('ior', ('ilt', 2147483647, 'b'), ('ilt', 'a', ('i2i32', 'b')))) */
   /* search1659_0_0 -> 16 in the cache */
   /* search1659_0 -> 1920 in the cache */
   /* search1659_1 -> 4485 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 1920, 4485 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { -0x80000000 /* -2147483648 */ },
   } },
   /* replace1659_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4693, 41 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0x7fffffff /* 2147483647 */ },
   } },
   /* replace1659_1_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4695, 41 },
      -1,
   } },
   /* replace1659_1_1_0 -> 16 in the cache */
   /* replace1659_1_1_1_0 -> 41 in the cache */
   /* replace1659_1_1_1 -> 4683 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 16, 4683 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4696, 4697 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4694, 4698 },
      -1,
   } },

   /* ('ilt', '#a', ('i2i64', 'b@32')) => ('iand', ('ilt', 'a', 2147483647), ('ior', ('ilt', 'a', -2147483648), ('ilt', ('i2i32', 'a'), 'b'))) */
   /* search1660_0 -> 4504 in the cache */
   /* search1660_1_0 -> 36 in the cache */
   /* search1660_1 -> 4666 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4504, 4666 },
      -1,
   } },

   /* replace1660_0_0 -> 21 in the cache */
   /* replace1660_0_1 -> 4695 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 21, 4695 },
      -1,
   } },
   /* replace1660_1_0_0 -> 21 in the cache */
   /* replace1660_1_0_1 -> 4693 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 21, 4693 },
      -1,
   } },
   /* replace1660_1_1_0_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 21 },
      -1,
   } },
   /* replace1660_1_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 4703, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4702, 4704 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4701, 4705 },
      -1,
   } },

   /* ('ige', ('i2i64', 'a@32'), '#b') => ('iand', ('ige', 2147483647, 'b'), ('ior', ('ige', -2147483648, 'b'), ('ige', 'a', ('i2i32', 'b')))) */
   /* search1661_0_0 -> 16 in the cache */
   /* search1661_0 -> 1920 in the cache */
   /* search1661_1 -> 4485 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 1920, 4485 },
      -1,
   } },

   /* replace1661_0_0 -> 4695 in the cache */
   /* replace1661_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4695, 41 },
      -1,
   } },
   /* replace1661_1_0_0 -> 4693 in the cache */
   /* replace1661_1_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4693, 41 },
      -1,
   } },
   /* replace1661_1_1_0 -> 16 in the cache */
   /* replace1661_1_1_1_0 -> 41 in the cache */
   /* replace1661_1_1_1 -> 4683 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 16, 4683 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4709, 4710 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4708, 4711 },
      -1,
   } },

   /* ('ige', '#a', ('i2i64', 'b@32')) => ('iand', ('ige', 'a', -2147483648), ('ior', ('ige', 'a', 2147483647), ('ige', ('i2i32', 'a'), 'b'))) */
   /* search1662_0 -> 4504 in the cache */
   /* search1662_1_0 -> 36 in the cache */
   /* search1662_1 -> 4666 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4504, 4666 },
      -1,
   } },

   /* replace1662_0_0 -> 21 in the cache */
   /* replace1662_0_1 -> 4693 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 21, 4693 },
      -1,
   } },
   /* replace1662_1_0_0 -> 21 in the cache */
   /* replace1662_1_0_1 -> 4695 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 21, 4695 },
      -1,
   } },
   /* replace1662_1_1_0_0 -> 21 in the cache */
   /* replace1662_1_1_0 -> 4703 in the cache */
   /* replace1662_1_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 4703, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4715, 4716 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4714, 4717 },
      -1,
   } },

   /* ('ieq', ('u2u16', 'a@8'), ('u2u16', 'b@8')) => ('ieq', 'a', ('u2u8', 'b')) */
   /* search1663_0_0 -> 6 in the cache */
   /* search1663_0 -> 4314 in the cache */
   /* search1663_1_0 -> 2128 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 2128 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 4314, 4719 },
      -1,
   } },

   /* replace1663_0 -> 6 in the cache */
   /* replace1663_1_0 -> 2128 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 2128 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 6, 4721 },
      -1,
   } },

   /* ('ine', ('u2u16', 'a@8'), ('u2u16', 'b@8')) => ('ine', 'a', ('u2u8', 'b')) */
   /* search1664_0_0 -> 6 in the cache */
   /* search1664_0 -> 4314 in the cache */
   /* search1664_1_0 -> 2128 in the cache */
   /* search1664_1 -> 4719 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 4314, 4719 },
      -1,
   } },

   /* replace1664_0 -> 6 in the cache */
   /* replace1664_1_0 -> 2128 in the cache */
   /* replace1664_1 -> 4721 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 6, 4721 },
      -1,
   } },

   /* ('uge', ('u2u16', 'a@8'), ('u2u16', 'b@8')) => ('uge', 'a', ('u2u8', 'b')) */
   /* search1665_0_0 -> 6 in the cache */
   /* search1665_0 -> 4314 in the cache */
   /* search1665_1_0 -> 2128 in the cache */
   /* search1665_1 -> 4719 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4314, 4719 },
      -1,
   } },

   /* replace1665_0 -> 6 in the cache */
   /* replace1665_1_0 -> 2128 in the cache */
   /* replace1665_1 -> 4721 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 6, 4721 },
      -1,
   } },

   /* ('ult', ('u2u16', 'a@8'), ('u2u16', 'b@8')) => ('ult', 'a', ('u2u8', 'b')) */
   /* search1666_0_0 -> 6 in the cache */
   /* search1666_0 -> 4314 in the cache */
   /* search1666_1_0 -> 2128 in the cache */
   /* search1666_1 -> 4719 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4314, 4719 },
      -1,
   } },

   /* replace1666_0 -> 6 in the cache */
   /* replace1666_1_0 -> 2128 in the cache */
   /* replace1666_1 -> 4721 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 6, 4721 },
      -1,
   } },

   /* ('uge', ('u2u16', 'b@8'), ('u2u16', 'a@8')) => ('uge', ('u2u8', 'b'), 'a') */
   /* search1667_0_0 -> 4384 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 4384 },
      -1,
   } },
   /* search1667_1_0 -> 4386 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 4386 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4729, 4730 },
      -1,
   } },

   /* replace1667_0_0 -> 4384 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 4384 },
      -1,
   } },
   /* replace1667_1 -> 4386 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4732, 4386 },
      -1,
   } },

   /* ('ult', ('u2u16', 'b@8'), ('u2u16', 'a@8')) => ('ult', ('u2u8', 'b'), 'a') */
   /* search1668_0_0 -> 4384 in the cache */
   /* search1668_0 -> 4729 in the cache */
   /* search1668_1_0 -> 4386 in the cache */
   /* search1668_1 -> 4730 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4729, 4730 },
      -1,
   } },

   /* replace1668_0_0 -> 4384 in the cache */
   /* replace1668_0 -> 4732 in the cache */
   /* replace1668_1 -> 4386 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4732, 4386 },
      -1,
   } },

   /* ('ieq', ('u2u16', 'a@8'), '#b') => ('iand', ('ieq', 'a', ('u2u8', 'b')), ('ieq', ('u2u16', ('u2u8', 'b')), 'b')) */
   /* search1669_0_0 -> 6 in the cache */
   /* search1669_0 -> 4314 in the cache */
   /* search1669_1 -> 2027 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 4314, 2027 },
      -1,
   } },

   /* replace1669_0_0 -> 6 in the cache */
   /* replace1669_0_1_0 -> 258 in the cache */
   /* replace1669_0_1 -> 2035 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 6, 2035 },
      -1,
   } },
   /* replace1669_1_0_0_0 -> 258 in the cache */
   /* replace1669_1_0_0 -> 2035 in the cache */
   /* replace1669_1_0 -> 2036 in the cache */
   /* replace1669_1_1 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 2036, 258 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 4737, 4738 },
      -1,
   } },

   /* ('ine', ('u2u16', 'a@8'), '#b') => ('ior', ('ine', 'a', ('u2u8', 'b')), ('ine', ('u2u16', ('u2u8', 'b')), 'b')) */
   /* search1670_0_0 -> 6 in the cache */
   /* search1670_0 -> 4314 in the cache */
   /* search1670_1 -> 2027 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 4314, 2027 },
      -1,
   } },

   /* replace1670_0_0 -> 6 in the cache */
   /* replace1670_0_1_0 -> 258 in the cache */
   /* replace1670_0_1 -> 2035 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 6, 2035 },
      -1,
   } },
   /* replace1670_1_0_0_0 -> 258 in the cache */
   /* replace1670_1_0_0 -> 2035 in the cache */
   /* replace1670_1_0 -> 2036 in the cache */
   /* replace1670_1_1 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 2036, 258 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 4741, 4742 },
      -1,
   } },

   /* ('ult', ('u2u16', 'a@8'), '#b') => ('iand', ('ult', 0, 'b'), ('ior', ('ult', 255, 'b'), ('ult', 'a', ('u2u8', 'b')))) */
   /* search1671_0_0 -> 6 in the cache */
   /* search1671_0 -> 4314 in the cache */
   /* search1671_1 -> 2027 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4314, 2027 },
      -1,
   } },

   /* replace1671_0_0 -> 856 in the cache */
   /* replace1671_0_1 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 856, 258 },
      -1,
   } },
   /* replace1671_1_0_0 -> 2029 in the cache */
   /* replace1671_1_0_1 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 2029, 258 },
      -1,
   } },
   /* replace1671_1_1_0 -> 6 in the cache */
   /* replace1671_1_1_1_0 -> 258 in the cache */
   /* replace1671_1_1_1 -> 2035 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 6, 2035 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4746, 4747 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4745, 4748 },
      -1,
   } },

   /* ('ult', '#a', ('u2u16', 'b@8')) => ('iand', ('ult', 'a', 255), ('ior', ('ult', 'a', 0), ('ult', ('u2u8', 'a'), 'b'))) */
   /* search1672_0 -> 4411 in the cache */
   /* search1672_1_0 -> 2128 in the cache */
   /* search1672_1 -> 4719 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4411, 4719 },
      -1,
   } },

   /* replace1672_0_0 -> 11 in the cache */
   /* replace1672_0_1 -> 2029 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 11, 2029 },
      -1,
   } },
   /* replace1672_1_0_0 -> 11 in the cache */
   /* replace1672_1_0_1 -> 856 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 11, 856 },
      -1,
   } },
   /* replace1672_1_1_0_0 -> 11 in the cache */
   /* replace1672_1_1_0 -> 2025 in the cache */
   /* replace1672_1_1_1 -> 2128 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 2025, 2128 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4752, 4753 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4751, 4754 },
      -1,
   } },

   /* ('uge', ('u2u16', 'a@8'), '#b') => ('iand', ('uge', 255, 'b'), ('ior', ('uge', 0, 'b'), ('uge', 'a', ('u2u8', 'b')))) */
   /* search1673_0_0 -> 6 in the cache */
   /* search1673_0 -> 4314 in the cache */
   /* search1673_1 -> 2027 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4314, 2027 },
      -1,
   } },

   /* replace1673_0_0 -> 2029 in the cache */
   /* replace1673_0_1 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 2029, 258 },
      -1,
   } },
   /* replace1673_1_0_0 -> 856 in the cache */
   /* replace1673_1_0_1 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 856, 258 },
      -1,
   } },
   /* replace1673_1_1_0 -> 6 in the cache */
   /* replace1673_1_1_1_0 -> 258 in the cache */
   /* replace1673_1_1_1 -> 2035 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 6, 2035 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4758, 4759 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4757, 4760 },
      -1,
   } },

   /* ('uge', '#a', ('u2u16', 'b@8')) => ('iand', ('uge', 'a', 0), ('ior', ('uge', 'a', 255), ('uge', ('u2u8', 'a'), 'b'))) */
   /* search1674_0 -> 4411 in the cache */
   /* search1674_1_0 -> 2128 in the cache */
   /* search1674_1 -> 4719 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4411, 4719 },
      -1,
   } },

   /* replace1674_0_0 -> 11 in the cache */
   /* replace1674_0_1 -> 856 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 11, 856 },
      -1,
   } },
   /* replace1674_1_0_0 -> 11 in the cache */
   /* replace1674_1_0_1 -> 2029 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 11, 2029 },
      -1,
   } },
   /* replace1674_1_1_0_0 -> 11 in the cache */
   /* replace1674_1_1_0 -> 2025 in the cache */
   /* replace1674_1_1_1 -> 2128 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 2025, 2128 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4764, 4765 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4763, 4766 },
      -1,
   } },

   /* ('ieq', ('u2u32', 'a@8'), ('u2u32', 'b@8')) => ('ieq', 'a', ('u2u8', 'b')) */
   /* search1675_0_0 -> 6 in the cache */
   /* search1675_0 -> 3298 in the cache */
   /* search1675_1_0 -> 2128 in the cache */
   /* search1675_1 -> 3300 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 3298, 3300 },
      -1,
   } },

   /* replace1675_0 -> 6 in the cache */
   /* replace1675_1_0 -> 2128 in the cache */
   /* replace1675_1 -> 4721 in the cache */
   /* replace1675 -> 4722 in the cache */

   /* ('ine', ('u2u32', 'a@8'), ('u2u32', 'b@8')) => ('ine', 'a', ('u2u8', 'b')) */
   /* search1676_0_0 -> 6 in the cache */
   /* search1676_0 -> 3298 in the cache */
   /* search1676_1_0 -> 2128 in the cache */
   /* search1676_1 -> 3300 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 3298, 3300 },
      -1,
   } },

   /* replace1676_0 -> 6 in the cache */
   /* replace1676_1_0 -> 2128 in the cache */
   /* replace1676_1 -> 4721 in the cache */
   /* replace1676 -> 4724 in the cache */

   /* ('uge', ('u2u32', 'a@8'), ('u2u32', 'b@8')) => ('uge', 'a', ('u2u8', 'b')) */
   /* search1677_0_0 -> 6 in the cache */
   /* search1677_0 -> 3298 in the cache */
   /* search1677_1_0 -> 2128 in the cache */
   /* search1677_1 -> 3300 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 3298, 3300 },
      -1,
   } },

   /* replace1677_0 -> 6 in the cache */
   /* replace1677_1_0 -> 2128 in the cache */
   /* replace1677_1 -> 4721 in the cache */
   /* replace1677 -> 4726 in the cache */

   /* ('ult', ('u2u32', 'a@8'), ('u2u32', 'b@8')) => ('ult', 'a', ('u2u8', 'b')) */
   /* search1678_0_0 -> 6 in the cache */
   /* search1678_0 -> 3298 in the cache */
   /* search1678_1_0 -> 2128 in the cache */
   /* search1678_1 -> 3300 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 3298, 3300 },
      -1,
   } },

   /* replace1678_0 -> 6 in the cache */
   /* replace1678_1_0 -> 2128 in the cache */
   /* replace1678_1 -> 4721 in the cache */
   /* replace1678 -> 4728 in the cache */

   /* ('uge', ('u2u32', 'b@8'), ('u2u32', 'a@8')) => ('uge', ('u2u8', 'b'), 'a') */
   /* search1679_0_0 -> 4384 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 4384 },
      -1,
   } },
   /* search1679_1_0 -> 4386 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 4386 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4772, 4773 },
      -1,
   } },

   /* replace1679_0_0 -> 4384 in the cache */
   /* replace1679_0 -> 4732 in the cache */
   /* replace1679_1 -> 4386 in the cache */
   /* replace1679 -> 4733 in the cache */

   /* ('ult', ('u2u32', 'b@8'), ('u2u32', 'a@8')) => ('ult', ('u2u8', 'b'), 'a') */
   /* search1680_0_0 -> 4384 in the cache */
   /* search1680_0 -> 4772 in the cache */
   /* search1680_1_0 -> 4386 in the cache */
   /* search1680_1 -> 4773 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4772, 4773 },
      -1,
   } },

   /* replace1680_0_0 -> 4384 in the cache */
   /* replace1680_0 -> 4732 in the cache */
   /* replace1680_1 -> 4386 in the cache */
   /* replace1680 -> 4735 in the cache */

   /* ('ieq', ('u2u32', 'a@8'), '#b') => ('iand', ('ieq', 'a', ('u2u8', 'b')), ('ieq', ('u2u32', ('u2u8', 'b')), 'b')) */
   /* search1681_0_0 -> 6 in the cache */
   /* search1681_0 -> 3298 in the cache */
   /* search1681_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 3298, 33 },
      -1,
   } },

   /* replace1681_0_0 -> 6 in the cache */
   /* replace1681_0_1_0 -> 36 in the cache */
   /* replace1681_0_1 -> 2043 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 6, 2043 },
      -1,
   } },
   /* replace1681_1_0_0_0 -> 36 in the cache */
   /* replace1681_1_0_0 -> 2043 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 2043 },
      -1,
   } },
   /* replace1681_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 4778, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 4777, 4779 },
      -1,
   } },

   /* ('ine', ('u2u32', 'a@8'), '#b') => ('ior', ('ine', 'a', ('u2u8', 'b')), ('ine', ('u2u32', ('u2u8', 'b')), 'b')) */
   /* search1682_0_0 -> 6 in the cache */
   /* search1682_0 -> 3298 in the cache */
   /* search1682_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 3298, 33 },
      -1,
   } },

   /* replace1682_0_0 -> 6 in the cache */
   /* replace1682_0_1_0 -> 36 in the cache */
   /* replace1682_0_1 -> 2043 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 6, 2043 },
      -1,
   } },
   /* replace1682_1_0_0_0 -> 36 in the cache */
   /* replace1682_1_0_0 -> 2043 in the cache */
   /* replace1682_1_0 -> 4778 in the cache */
   /* replace1682_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 4778, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 4782, 4783 },
      -1,
   } },

   /* ('ult', ('u2u32', 'a@8'), '#b') => ('iand', ('ult', 0, 'b'), ('ior', ('ult', 255, 'b'), ('ult', 'a', ('u2u8', 'b')))) */
   /* search1683_0_0 -> 6 in the cache */
   /* search1683_0 -> 3298 in the cache */
   /* search1683_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 3298, 33 },
      -1,
   } },

   /* replace1683_0_0 -> 122 in the cache */
   /* replace1683_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 122, 36 },
      -1,
   } },
   /* replace1683_1_0_0 -> 1010 in the cache */
   /* replace1683_1_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 1010, 36 },
      -1,
   } },
   /* replace1683_1_1_0 -> 6 in the cache */
   /* replace1683_1_1_1_0 -> 36 in the cache */
   /* replace1683_1_1_1 -> 2043 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 6, 2043 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4787, 4788 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4786, 4789 },
      -1,
   } },

   /* ('ult', '#a', ('u2u32', 'b@8')) => ('iand', ('ult', 'a', 255), ('ior', ('ult', 'a', 0), ('ult', ('u2u8', 'a'), 'b'))) */
   /* search1684_0 -> 286 in the cache */
   /* search1684_1_0 -> 2128 in the cache */
   /* search1684_1 -> 3300 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 286, 3300 },
      -1,
   } },

   /* replace1684_0_0 -> 16 in the cache */
   /* replace1684_0_1 -> 1010 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 16, 1010 },
      -1,
   } },
   /* replace1684_1_0_0 -> 16 in the cache */
   /* replace1684_1_0_1 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 16, 122 },
      -1,
   } },
   /* replace1684_1_1_0_0 -> 16 in the cache */
   /* replace1684_1_1_0 -> 2041 in the cache */
   /* replace1684_1_1_1 -> 2128 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 2041, 2128 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4793, 4794 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4792, 4795 },
      -1,
   } },

   /* ('uge', ('u2u32', 'a@8'), '#b') => ('iand', ('uge', 255, 'b'), ('ior', ('uge', 0, 'b'), ('uge', 'a', ('u2u8', 'b')))) */
   /* search1685_0_0 -> 6 in the cache */
   /* search1685_0 -> 3298 in the cache */
   /* search1685_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 3298, 33 },
      -1,
   } },

   /* replace1685_0_0 -> 1010 in the cache */
   /* replace1685_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 1010, 36 },
      -1,
   } },
   /* replace1685_1_0_0 -> 122 in the cache */
   /* replace1685_1_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 122, 36 },
      -1,
   } },
   /* replace1685_1_1_0 -> 6 in the cache */
   /* replace1685_1_1_1_0 -> 36 in the cache */
   /* replace1685_1_1_1 -> 2043 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 6, 2043 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4799, 4800 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4798, 4801 },
      -1,
   } },

   /* ('uge', '#a', ('u2u32', 'b@8')) => ('iand', ('uge', 'a', 0), ('ior', ('uge', 'a', 255), ('uge', ('u2u8', 'a'), 'b'))) */
   /* search1686_0 -> 286 in the cache */
   /* search1686_1_0 -> 2128 in the cache */
   /* search1686_1 -> 3300 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 286, 3300 },
      -1,
   } },

   /* replace1686_0_0 -> 16 in the cache */
   /* replace1686_0_1 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 16, 122 },
      -1,
   } },
   /* replace1686_1_0_0 -> 16 in the cache */
   /* replace1686_1_0_1 -> 1010 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 16, 1010 },
      -1,
   } },
   /* replace1686_1_1_0_0 -> 16 in the cache */
   /* replace1686_1_1_0 -> 2041 in the cache */
   /* replace1686_1_1_1 -> 2128 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 2041, 2128 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4805, 4806 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4804, 4807 },
      -1,
   } },

   /* ('ieq', ('u2u64', 'a@8'), ('u2u64', 'b@8')) => ('ieq', 'a', ('u2u8', 'b')) */
   /* search1687_0_0 -> 6 in the cache */
   /* search1687_0 -> 4351 in the cache */
   /* search1687_1_0 -> 2128 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 2128 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 4351, 4809 },
      -1,
   } },

   /* replace1687_0 -> 6 in the cache */
   /* replace1687_1_0 -> 2128 in the cache */
   /* replace1687_1 -> 4721 in the cache */
   /* replace1687 -> 4722 in the cache */

   /* ('ine', ('u2u64', 'a@8'), ('u2u64', 'b@8')) => ('ine', 'a', ('u2u8', 'b')) */
   /* search1688_0_0 -> 6 in the cache */
   /* search1688_0 -> 4351 in the cache */
   /* search1688_1_0 -> 2128 in the cache */
   /* search1688_1 -> 4809 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 4351, 4809 },
      -1,
   } },

   /* replace1688_0 -> 6 in the cache */
   /* replace1688_1_0 -> 2128 in the cache */
   /* replace1688_1 -> 4721 in the cache */
   /* replace1688 -> 4724 in the cache */

   /* ('uge', ('u2u64', 'a@8'), ('u2u64', 'b@8')) => ('uge', 'a', ('u2u8', 'b')) */
   /* search1689_0_0 -> 6 in the cache */
   /* search1689_0 -> 4351 in the cache */
   /* search1689_1_0 -> 2128 in the cache */
   /* search1689_1 -> 4809 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4351, 4809 },
      -1,
   } },

   /* replace1689_0 -> 6 in the cache */
   /* replace1689_1_0 -> 2128 in the cache */
   /* replace1689_1 -> 4721 in the cache */
   /* replace1689 -> 4726 in the cache */

   /* ('ult', ('u2u64', 'a@8'), ('u2u64', 'b@8')) => ('ult', 'a', ('u2u8', 'b')) */
   /* search1690_0_0 -> 6 in the cache */
   /* search1690_0 -> 4351 in the cache */
   /* search1690_1_0 -> 2128 in the cache */
   /* search1690_1 -> 4809 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4351, 4809 },
      -1,
   } },

   /* replace1690_0 -> 6 in the cache */
   /* replace1690_1_0 -> 2128 in the cache */
   /* replace1690_1 -> 4721 in the cache */
   /* replace1690 -> 4728 in the cache */

   /* ('uge', ('u2u64', 'b@8'), ('u2u64', 'a@8')) => ('uge', ('u2u8', 'b'), 'a') */
   /* search1691_0_0 -> 4384 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 4384 },
      -1,
   } },
   /* search1691_1_0 -> 4386 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 4386 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4814, 4815 },
      -1,
   } },

   /* replace1691_0_0 -> 4384 in the cache */
   /* replace1691_0 -> 4732 in the cache */
   /* replace1691_1 -> 4386 in the cache */
   /* replace1691 -> 4733 in the cache */

   /* ('ult', ('u2u64', 'b@8'), ('u2u64', 'a@8')) => ('ult', ('u2u8', 'b'), 'a') */
   /* search1692_0_0 -> 4384 in the cache */
   /* search1692_0 -> 4814 in the cache */
   /* search1692_1_0 -> 4386 in the cache */
   /* search1692_1 -> 4815 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4814, 4815 },
      -1,
   } },

   /* replace1692_0_0 -> 4384 in the cache */
   /* replace1692_0 -> 4732 in the cache */
   /* replace1692_1 -> 4386 in the cache */
   /* replace1692 -> 4735 in the cache */

   /* ('ieq', ('u2u64', 'a@8'), '#b') => ('iand', ('ieq', 'a', ('u2u8', 'b')), ('ieq', ('u2u64', ('u2u8', 'b')), 'b')) */
   /* search1693_0_0 -> 6 in the cache */
   /* search1693_0 -> 4351 in the cache */
   /* search1693_1 -> 4485 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 4351, 4485 },
      -1,
   } },

   /* replace1693_0_0 -> 6 in the cache */
   /* replace1693_0_1_0 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 6, 4819 },
      -1,
   } },
   /* replace1693_1_0_0_0 -> 41 in the cache */
   /* replace1693_1_0_0 -> 4819 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 4819 },
      -1,
   } },
   /* replace1693_1_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 4821, 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 4820, 4822 },
      -1,
   } },

   /* ('ine', ('u2u64', 'a@8'), '#b') => ('ior', ('ine', 'a', ('u2u8', 'b')), ('ine', ('u2u64', ('u2u8', 'b')), 'b')) */
   /* search1694_0_0 -> 6 in the cache */
   /* search1694_0 -> 4351 in the cache */
   /* search1694_1 -> 4485 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 4351, 4485 },
      -1,
   } },

   /* replace1694_0_0 -> 6 in the cache */
   /* replace1694_0_1_0 -> 41 in the cache */
   /* replace1694_0_1 -> 4819 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 6, 4819 },
      -1,
   } },
   /* replace1694_1_0_0_0 -> 41 in the cache */
   /* replace1694_1_0_0 -> 4819 in the cache */
   /* replace1694_1_0 -> 4821 in the cache */
   /* replace1694_1_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 4821, 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 4825, 4826 },
      -1,
   } },

   /* ('ult', ('u2u64', 'a@8'), '#b') => ('iand', ('ult', 0, 'b'), ('ior', ('ult', 255, 'b'), ('ult', 'a', ('u2u8', 'b')))) */
   /* search1695_0_0 -> 6 in the cache */
   /* search1695_0 -> 4351 in the cache */
   /* search1695_1 -> 4485 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4351, 4485 },
      -1,
   } },

   /* replace1695_0_0 -> 897 in the cache */
   /* replace1695_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 897, 41 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0xff /* 255 */ },
   } },
   /* replace1695_1_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4830, 41 },
      -1,
   } },
   /* replace1695_1_1_0 -> 6 in the cache */
   /* replace1695_1_1_1_0 -> 41 in the cache */
   /* replace1695_1_1_1 -> 4819 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 6, 4819 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4831, 4832 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4829, 4833 },
      -1,
   } },

   /* ('ult', '#a', ('u2u64', 'b@8')) => ('iand', ('ult', 'a', 255), ('ior', ('ult', 'a', 0), ('ult', ('u2u8', 'a'), 'b'))) */
   /* search1696_0 -> 4504 in the cache */
   /* search1696_1_0 -> 2128 in the cache */
   /* search1696_1 -> 4809 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4504, 4809 },
      -1,
   } },

   /* replace1696_0_0 -> 21 in the cache */
   /* replace1696_0_1 -> 4830 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 21, 4830 },
      -1,
   } },
   /* replace1696_1_0_0 -> 21 in the cache */
   /* replace1696_1_0_1 -> 897 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 21, 897 },
      -1,
   } },
   /* replace1696_1_1_0_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 21 },
      -1,
   } },
   /* replace1696_1_1_1 -> 2128 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4838, 2128 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4837, 4839 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4836, 4840 },
      -1,
   } },

   /* ('uge', ('u2u64', 'a@8'), '#b') => ('iand', ('uge', 255, 'b'), ('ior', ('uge', 0, 'b'), ('uge', 'a', ('u2u8', 'b')))) */
   /* search1697_0_0 -> 6 in the cache */
   /* search1697_0 -> 4351 in the cache */
   /* search1697_1 -> 4485 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4351, 4485 },
      -1,
   } },

   /* replace1697_0_0 -> 4830 in the cache */
   /* replace1697_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4830, 41 },
      -1,
   } },
   /* replace1697_1_0_0 -> 897 in the cache */
   /* replace1697_1_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 897, 41 },
      -1,
   } },
   /* replace1697_1_1_0 -> 6 in the cache */
   /* replace1697_1_1_1_0 -> 41 in the cache */
   /* replace1697_1_1_1 -> 4819 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 6, 4819 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4844, 4845 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4843, 4846 },
      -1,
   } },

   /* ('uge', '#a', ('u2u64', 'b@8')) => ('iand', ('uge', 'a', 0), ('ior', ('uge', 'a', 255), ('uge', ('u2u8', 'a'), 'b'))) */
   /* search1698_0 -> 4504 in the cache */
   /* search1698_1_0 -> 2128 in the cache */
   /* search1698_1 -> 4809 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4504, 4809 },
      -1,
   } },

   /* replace1698_0_0 -> 21 in the cache */
   /* replace1698_0_1 -> 897 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 21, 897 },
      -1,
   } },
   /* replace1698_1_0_0 -> 21 in the cache */
   /* replace1698_1_0_1 -> 4830 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 21, 4830 },
      -1,
   } },
   /* replace1698_1_1_0_0 -> 21 in the cache */
   /* replace1698_1_1_0 -> 4838 in the cache */
   /* replace1698_1_1_1 -> 2128 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4838, 2128 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4850, 4851 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4849, 4852 },
      -1,
   } },

   /* ('ieq', ('u2u32', 'a@16'), ('u2u32', 'b@8')) => ('ieq', 'a', ('u2u16', 'b')) */
   /* search1699_0_0 -> 11 in the cache */
   /* search1699_0 -> 1817 in the cache */
   /* search1699_1_0 -> 2128 in the cache */
   /* search1699_1 -> 3300 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1817, 3300 },
      -1,
   } },

   /* replace1699_0 -> 11 in the cache */
   /* replace1699_1_0 -> 2128 in the cache */
   /* replace1699_1 -> 4719 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 11, 4719 },
      -1,
   } },

   /* ('ine', ('u2u32', 'a@16'), ('u2u32', 'b@8')) => ('ine', 'a', ('u2u16', 'b')) */
   /* search1700_0_0 -> 11 in the cache */
   /* search1700_0 -> 1817 in the cache */
   /* search1700_1_0 -> 2128 in the cache */
   /* search1700_1 -> 3300 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1817, 3300 },
      -1,
   } },

   /* replace1700_0 -> 11 in the cache */
   /* replace1700_1_0 -> 2128 in the cache */
   /* replace1700_1 -> 4719 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 11, 4719 },
      -1,
   } },

   /* ('uge', ('u2u32', 'a@16'), ('u2u32', 'b@8')) => ('uge', 'a', ('u2u16', 'b')) */
   /* search1701_0_0 -> 11 in the cache */
   /* search1701_0 -> 1817 in the cache */
   /* search1701_1_0 -> 2128 in the cache */
   /* search1701_1 -> 3300 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 1817, 3300 },
      -1,
   } },

   /* replace1701_0 -> 11 in the cache */
   /* replace1701_1_0 -> 2128 in the cache */
   /* replace1701_1 -> 4719 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 11, 4719 },
      -1,
   } },

   /* ('ult', ('u2u32', 'a@16'), ('u2u32', 'b@8')) => ('ult', 'a', ('u2u16', 'b')) */
   /* search1702_0_0 -> 11 in the cache */
   /* search1702_0 -> 1817 in the cache */
   /* search1702_1_0 -> 2128 in the cache */
   /* search1702_1 -> 3300 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 1817, 3300 },
      -1,
   } },

   /* replace1702_0 -> 11 in the cache */
   /* replace1702_1_0 -> 2128 in the cache */
   /* replace1702_1 -> 4719 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 11, 4719 },
      -1,
   } },

   /* ('uge', ('u2u32', 'b@8'), ('u2u32', 'a@16')) => ('uge', ('u2u16', 'b'), 'a') */
   /* search1703_0_0 -> 4384 in the cache */
   /* search1703_0 -> 4772 in the cache */
   /* search1703_1_0 -> 526 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 526 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4772, 4862 },
      -1,
   } },

   /* replace1703_0_0 -> 4384 in the cache */
   /* replace1703_0 -> 4729 in the cache */
   /* replace1703_1 -> 526 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4729, 526 },
      -1,
   } },

   /* ('ult', ('u2u32', 'b@8'), ('u2u32', 'a@16')) => ('ult', ('u2u16', 'b'), 'a') */
   /* search1704_0_0 -> 4384 in the cache */
   /* search1704_0 -> 4772 in the cache */
   /* search1704_1_0 -> 526 in the cache */
   /* search1704_1 -> 4862 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4772, 4862 },
      -1,
   } },

   /* replace1704_0_0 -> 4384 in the cache */
   /* replace1704_0 -> 4729 in the cache */
   /* replace1704_1 -> 526 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4729, 526 },
      -1,
   } },

   /* ('ieq', ('u2u32', 'a@16'), ('u2u32', 'b@16')) => ('ieq', 'a', ('u2u16', 'b')) */
   /* search1705_0_0 -> 11 in the cache */
   /* search1705_0 -> 1817 in the cache */
   /* search1705_1_0 -> 258 in the cache */
   /* search1705_1 -> 3320 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1817, 3320 },
      -1,
   } },

   /* replace1705_0 -> 11 in the cache */
   /* replace1705_1_0 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 258 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 11, 4868 },
      -1,
   } },

   /* ('ine', ('u2u32', 'a@16'), ('u2u32', 'b@16')) => ('ine', 'a', ('u2u16', 'b')) */
   /* search1706_0_0 -> 11 in the cache */
   /* search1706_0 -> 1817 in the cache */
   /* search1706_1_0 -> 258 in the cache */
   /* search1706_1 -> 3320 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1817, 3320 },
      -1,
   } },

   /* replace1706_0 -> 11 in the cache */
   /* replace1706_1_0 -> 258 in the cache */
   /* replace1706_1 -> 4868 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 11, 4868 },
      -1,
   } },

   /* ('uge', ('u2u32', 'a@16'), ('u2u32', 'b@16')) => ('uge', 'a', ('u2u16', 'b')) */
   /* search1707_0_0 -> 11 in the cache */
   /* search1707_0 -> 1817 in the cache */
   /* search1707_1_0 -> 258 in the cache */
   /* search1707_1 -> 3320 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 1817, 3320 },
      -1,
   } },

   /* replace1707_0 -> 11 in the cache */
   /* replace1707_1_0 -> 258 in the cache */
   /* replace1707_1 -> 4868 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 11, 4868 },
      -1,
   } },

   /* ('ult', ('u2u32', 'a@16'), ('u2u32', 'b@16')) => ('ult', 'a', ('u2u16', 'b')) */
   /* search1708_0_0 -> 11 in the cache */
   /* search1708_0 -> 1817 in the cache */
   /* search1708_1_0 -> 258 in the cache */
   /* search1708_1 -> 3320 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 1817, 3320 },
      -1,
   } },

   /* replace1708_0 -> 11 in the cache */
   /* replace1708_1_0 -> 258 in the cache */
   /* replace1708_1 -> 4868 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 11, 4868 },
      -1,
   } },

   /* ('uge', ('u2u32', 'b@16'), ('u2u32', 'a@16')) => ('uge', ('u2u16', 'b'), 'a') */
   /* search1709_0_0 -> 515 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 515 },
      -1,
   } },
   /* search1709_1_0 -> 526 in the cache */
   /* search1709_1 -> 4862 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4876, 4862 },
      -1,
   } },

   /* replace1709_0_0 -> 515 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 515 },
      -1,
   } },
   /* replace1709_1 -> 526 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4878, 526 },
      -1,
   } },

   /* ('ult', ('u2u32', 'b@16'), ('u2u32', 'a@16')) => ('ult', ('u2u16', 'b'), 'a') */
   /* search1710_0_0 -> 515 in the cache */
   /* search1710_0 -> 4876 in the cache */
   /* search1710_1_0 -> 526 in the cache */
   /* search1710_1 -> 4862 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4876, 4862 },
      -1,
   } },

   /* replace1710_0_0 -> 515 in the cache */
   /* replace1710_0 -> 4878 in the cache */
   /* replace1710_1 -> 526 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4878, 526 },
      -1,
   } },

   /* ('ieq', ('u2u32', 'a@16'), '#b') => ('iand', ('ieq', 'a', ('u2u16', 'b')), ('ieq', ('u2u32', ('u2u16', 'b')), 'b')) */
   /* search1711_0_0 -> 11 in the cache */
   /* search1711_0 -> 1817 in the cache */
   /* search1711_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1817, 33 },
      -1,
   } },

   /* replace1711_0_0 -> 11 in the cache */
   /* replace1711_0_1_0 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 11, 4883 },
      -1,
   } },
   /* replace1711_1_0_0_0 -> 36 in the cache */
   /* replace1711_1_0_0 -> 4883 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 4883 },
      -1,
   } },
   /* replace1711_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 4885, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 4884, 4886 },
      -1,
   } },

   /* ('ine', ('u2u32', 'a@16'), '#b') => ('ior', ('ine', 'a', ('u2u16', 'b')), ('ine', ('u2u32', ('u2u16', 'b')), 'b')) */
   /* search1712_0_0 -> 11 in the cache */
   /* search1712_0 -> 1817 in the cache */
   /* search1712_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1817, 33 },
      -1,
   } },

   /* replace1712_0_0 -> 11 in the cache */
   /* replace1712_0_1_0 -> 36 in the cache */
   /* replace1712_0_1 -> 4883 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 11, 4883 },
      -1,
   } },
   /* replace1712_1_0_0_0 -> 36 in the cache */
   /* replace1712_1_0_0 -> 4883 in the cache */
   /* replace1712_1_0 -> 4885 in the cache */
   /* replace1712_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 4885, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 4889, 4890 },
      -1,
   } },

   /* ('ult', ('u2u32', 'a@16'), '#b') => ('iand', ('ult', 0, 'b'), ('ior', ('ult', 65535, 'b'), ('ult', 'a', ('u2u16', 'b')))) */
   /* search1713_0_0 -> 11 in the cache */
   /* search1713_0 -> 1817 in the cache */
   /* search1713_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 1817, 33 },
      -1,
   } },

   /* replace1713_0_0 -> 122 in the cache */
   /* replace1713_0_1 -> 36 in the cache */
   /* replace1713_0 -> 4786 in the cache */
   /* replace1713_1_0_0 -> 1002 in the cache */
   /* replace1713_1_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 1002, 36 },
      -1,
   } },
   /* replace1713_1_1_0 -> 11 in the cache */
   /* replace1713_1_1_1_0 -> 36 in the cache */
   /* replace1713_1_1_1 -> 4883 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 11, 4883 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4893, 4894 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4786, 4895 },
      -1,
   } },

   /* ('ult', '#a', ('u2u32', 'b@16')) => ('iand', ('ult', 'a', 65535), ('ior', ('ult', 'a', 0), ('ult', ('u2u16', 'a'), 'b'))) */
   /* search1714_0 -> 286 in the cache */
   /* search1714_1_0 -> 258 in the cache */
   /* search1714_1 -> 3320 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 286, 3320 },
      -1,
   } },

   /* replace1714_0_0 -> 16 in the cache */
   /* replace1714_0_1 -> 1002 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 16, 1002 },
      -1,
   } },
   /* replace1714_1_0_0 -> 16 in the cache */
   /* replace1714_1_0_1 -> 122 in the cache */
   /* replace1714_1_0 -> 4793 in the cache */
   /* replace1714_1_1_0_0 -> 16 in the cache */
   /* replace1714_1_1_0 -> 3326 in the cache */
   /* replace1714_1_1_1 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 3326, 258 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4793, 4899 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4898, 4900 },
      -1,
   } },

   /* ('uge', ('u2u32', 'a@16'), '#b') => ('iand', ('uge', 65535, 'b'), ('ior', ('uge', 0, 'b'), ('uge', 'a', ('u2u16', 'b')))) */
   /* search1715_0_0 -> 11 in the cache */
   /* search1715_0 -> 1817 in the cache */
   /* search1715_1 -> 33 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 1817, 33 },
      -1,
   } },

   /* replace1715_0_0 -> 1002 in the cache */
   /* replace1715_0_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 1002, 36 },
      -1,
   } },
   /* replace1715_1_0_0 -> 122 in the cache */
   /* replace1715_1_0_1 -> 36 in the cache */
   /* replace1715_1_0 -> 4799 in the cache */
   /* replace1715_1_1_0 -> 11 in the cache */
   /* replace1715_1_1_1_0 -> 36 in the cache */
   /* replace1715_1_1_1 -> 4883 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 11, 4883 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4799, 4904 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4903, 4905 },
      -1,
   } },

   /* ('uge', '#a', ('u2u32', 'b@16')) => ('iand', ('uge', 'a', 0), ('ior', ('uge', 'a', 65535), ('uge', ('u2u16', 'a'), 'b'))) */
   /* search1716_0 -> 286 in the cache */
   /* search1716_1_0 -> 258 in the cache */
   /* search1716_1 -> 3320 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 286, 3320 },
      -1,
   } },

   /* replace1716_0_0 -> 16 in the cache */
   /* replace1716_0_1 -> 122 in the cache */
   /* replace1716_0 -> 4804 in the cache */
   /* replace1716_1_0_0 -> 16 in the cache */
   /* replace1716_1_0_1 -> 1002 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 16, 1002 },
      -1,
   } },
   /* replace1716_1_1_0_0 -> 16 in the cache */
   /* replace1716_1_1_0 -> 3326 in the cache */
   /* replace1716_1_1_1 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 3326, 258 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4908, 4909 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4804, 4910 },
      -1,
   } },

   /* ('ieq', ('u2u64', 'a@16'), ('u2u64', 'b@8')) => ('ieq', 'a', ('u2u16', 'b')) */
   /* search1717_0_0 -> 11 in the cache */
   /* search1717_0 -> 1835 in the cache */
   /* search1717_1_0 -> 2128 in the cache */
   /* search1717_1 -> 4809 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1835, 4809 },
      -1,
   } },

   /* replace1717_0 -> 11 in the cache */
   /* replace1717_1_0 -> 2128 in the cache */
   /* replace1717_1 -> 4719 in the cache */
   /* replace1717 -> 4855 in the cache */

   /* ('ine', ('u2u64', 'a@16'), ('u2u64', 'b@8')) => ('ine', 'a', ('u2u16', 'b')) */
   /* search1718_0_0 -> 11 in the cache */
   /* search1718_0 -> 1835 in the cache */
   /* search1718_1_0 -> 2128 in the cache */
   /* search1718_1 -> 4809 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1835, 4809 },
      -1,
   } },

   /* replace1718_0 -> 11 in the cache */
   /* replace1718_1_0 -> 2128 in the cache */
   /* replace1718_1 -> 4719 in the cache */
   /* replace1718 -> 4857 in the cache */

   /* ('uge', ('u2u64', 'a@16'), ('u2u64', 'b@8')) => ('uge', 'a', ('u2u16', 'b')) */
   /* search1719_0_0 -> 11 in the cache */
   /* search1719_0 -> 1835 in the cache */
   /* search1719_1_0 -> 2128 in the cache */
   /* search1719_1 -> 4809 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 1835, 4809 },
      -1,
   } },

   /* replace1719_0 -> 11 in the cache */
   /* replace1719_1_0 -> 2128 in the cache */
   /* replace1719_1 -> 4719 in the cache */
   /* replace1719 -> 4859 in the cache */

   /* ('ult', ('u2u64', 'a@16'), ('u2u64', 'b@8')) => ('ult', 'a', ('u2u16', 'b')) */
   /* search1720_0_0 -> 11 in the cache */
   /* search1720_0 -> 1835 in the cache */
   /* search1720_1_0 -> 2128 in the cache */
   /* search1720_1 -> 4809 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 1835, 4809 },
      -1,
   } },

   /* replace1720_0 -> 11 in the cache */
   /* replace1720_1_0 -> 2128 in the cache */
   /* replace1720_1 -> 4719 in the cache */
   /* replace1720 -> 4861 in the cache */

   /* ('uge', ('u2u64', 'b@8'), ('u2u64', 'a@16')) => ('uge', ('u2u16', 'b'), 'a') */
   /* search1721_0_0 -> 4384 in the cache */
   /* search1721_0 -> 4814 in the cache */
   /* search1721_1_0 -> 526 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 526 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4814, 4916 },
      -1,
   } },

   /* replace1721_0_0 -> 4384 in the cache */
   /* replace1721_0 -> 4729 in the cache */
   /* replace1721_1 -> 526 in the cache */
   /* replace1721 -> 4864 in the cache */

   /* ('ult', ('u2u64', 'b@8'), ('u2u64', 'a@16')) => ('ult', ('u2u16', 'b'), 'a') */
   /* search1722_0_0 -> 4384 in the cache */
   /* search1722_0 -> 4814 in the cache */
   /* search1722_1_0 -> 526 in the cache */
   /* search1722_1 -> 4916 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4814, 4916 },
      -1,
   } },

   /* replace1722_0_0 -> 4384 in the cache */
   /* replace1722_0 -> 4729 in the cache */
   /* replace1722_1 -> 526 in the cache */
   /* replace1722 -> 4866 in the cache */

   /* ('ieq', ('u2u64', 'a@16'), ('u2u64', 'b@16')) => ('ieq', 'a', ('u2u16', 'b')) */
   /* search1723_0_0 -> 11 in the cache */
   /* search1723_0 -> 1835 in the cache */
   /* search1723_1_0 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 258 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1835, 4919 },
      -1,
   } },

   /* replace1723_0 -> 11 in the cache */
   /* replace1723_1_0 -> 258 in the cache */
   /* replace1723_1 -> 4868 in the cache */
   /* replace1723 -> 4869 in the cache */

   /* ('ine', ('u2u64', 'a@16'), ('u2u64', 'b@16')) => ('ine', 'a', ('u2u16', 'b')) */
   /* search1724_0_0 -> 11 in the cache */
   /* search1724_0 -> 1835 in the cache */
   /* search1724_1_0 -> 258 in the cache */
   /* search1724_1 -> 4919 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1835, 4919 },
      -1,
   } },

   /* replace1724_0 -> 11 in the cache */
   /* replace1724_1_0 -> 258 in the cache */
   /* replace1724_1 -> 4868 in the cache */
   /* replace1724 -> 4871 in the cache */

   /* ('uge', ('u2u64', 'a@16'), ('u2u64', 'b@16')) => ('uge', 'a', ('u2u16', 'b')) */
   /* search1725_0_0 -> 11 in the cache */
   /* search1725_0 -> 1835 in the cache */
   /* search1725_1_0 -> 258 in the cache */
   /* search1725_1 -> 4919 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 1835, 4919 },
      -1,
   } },

   /* replace1725_0 -> 11 in the cache */
   /* replace1725_1_0 -> 258 in the cache */
   /* replace1725_1 -> 4868 in the cache */
   /* replace1725 -> 4873 in the cache */

   /* ('ult', ('u2u64', 'a@16'), ('u2u64', 'b@16')) => ('ult', 'a', ('u2u16', 'b')) */
   /* search1726_0_0 -> 11 in the cache */
   /* search1726_0 -> 1835 in the cache */
   /* search1726_1_0 -> 258 in the cache */
   /* search1726_1 -> 4919 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 1835, 4919 },
      -1,
   } },

   /* replace1726_0 -> 11 in the cache */
   /* replace1726_1_0 -> 258 in the cache */
   /* replace1726_1 -> 4868 in the cache */
   /* replace1726 -> 4875 in the cache */

   /* ('uge', ('u2u64', 'b@16'), ('u2u64', 'a@16')) => ('uge', ('u2u16', 'b'), 'a') */
   /* search1727_0_0 -> 515 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 515 },
      -1,
   } },
   /* search1727_1_0 -> 526 in the cache */
   /* search1727_1 -> 4916 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4924, 4916 },
      -1,
   } },

   /* replace1727_0_0 -> 515 in the cache */
   /* replace1727_0 -> 4878 in the cache */
   /* replace1727_1 -> 526 in the cache */
   /* replace1727 -> 4879 in the cache */

   /* ('ult', ('u2u64', 'b@16'), ('u2u64', 'a@16')) => ('ult', ('u2u16', 'b'), 'a') */
   /* search1728_0_0 -> 515 in the cache */
   /* search1728_0 -> 4924 in the cache */
   /* search1728_1_0 -> 526 in the cache */
   /* search1728_1 -> 4916 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4924, 4916 },
      -1,
   } },

   /* replace1728_0_0 -> 515 in the cache */
   /* replace1728_0 -> 4878 in the cache */
   /* replace1728_1 -> 526 in the cache */
   /* replace1728 -> 4881 in the cache */

   /* ('ieq', ('u2u64', 'a@16'), '#b') => ('iand', ('ieq', 'a', ('u2u16', 'b')), ('ieq', ('u2u64', ('u2u16', 'b')), 'b')) */
   /* search1729_0_0 -> 11 in the cache */
   /* search1729_0 -> 1835 in the cache */
   /* search1729_1 -> 4485 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1835, 4485 },
      -1,
   } },

   /* replace1729_0_0 -> 11 in the cache */
   /* replace1729_0_1_0 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 11, 4928 },
      -1,
   } },
   /* replace1729_1_0_0_0 -> 41 in the cache */
   /* replace1729_1_0_0 -> 4928 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 4928 },
      -1,
   } },
   /* replace1729_1_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 4930, 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 4929, 4931 },
      -1,
   } },

   /* ('ine', ('u2u64', 'a@16'), '#b') => ('ior', ('ine', 'a', ('u2u16', 'b')), ('ine', ('u2u64', ('u2u16', 'b')), 'b')) */
   /* search1730_0_0 -> 11 in the cache */
   /* search1730_0 -> 1835 in the cache */
   /* search1730_1 -> 4485 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1835, 4485 },
      -1,
   } },

   /* replace1730_0_0 -> 11 in the cache */
   /* replace1730_0_1_0 -> 41 in the cache */
   /* replace1730_0_1 -> 4928 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 11, 4928 },
      -1,
   } },
   /* replace1730_1_0_0_0 -> 41 in the cache */
   /* replace1730_1_0_0 -> 4928 in the cache */
   /* replace1730_1_0 -> 4930 in the cache */
   /* replace1730_1_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 4930, 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 4934, 4935 },
      -1,
   } },

   /* ('ult', ('u2u64', 'a@16'), '#b') => ('iand', ('ult', 0, 'b'), ('ior', ('ult', 65535, 'b'), ('ult', 'a', ('u2u16', 'b')))) */
   /* search1731_0_0 -> 11 in the cache */
   /* search1731_0 -> 1835 in the cache */
   /* search1731_1 -> 4485 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 1835, 4485 },
      -1,
   } },

   /* replace1731_0_0 -> 897 in the cache */
   /* replace1731_0_1 -> 41 in the cache */
   /* replace1731_0 -> 4829 in the cache */
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0xffff /* 65535 */ },
   } },
   /* replace1731_1_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4938, 41 },
      -1,
   } },
   /* replace1731_1_1_0 -> 11 in the cache */
   /* replace1731_1_1_1_0 -> 41 in the cache */
   /* replace1731_1_1_1 -> 4928 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 11, 4928 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4939, 4940 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4829, 4941 },
      -1,
   } },

   /* ('ult', '#a', ('u2u64', 'b@16')) => ('iand', ('ult', 'a', 65535), ('ior', ('ult', 'a', 0), ('ult', ('u2u16', 'a'), 'b'))) */
   /* search1732_0 -> 4504 in the cache */
   /* search1732_1_0 -> 258 in the cache */
   /* search1732_1 -> 4919 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4504, 4919 },
      -1,
   } },

   /* replace1732_0_0 -> 21 in the cache */
   /* replace1732_0_1 -> 4938 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 21, 4938 },
      -1,
   } },
   /* replace1732_1_0_0 -> 21 in the cache */
   /* replace1732_1_0_1 -> 897 in the cache */
   /* replace1732_1_0 -> 4837 in the cache */
   /* replace1732_1_1_0_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 21 },
      -1,
   } },
   /* replace1732_1_1_1 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4945, 258 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4837, 4946 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4944, 4947 },
      -1,
   } },

   /* ('uge', ('u2u64', 'a@16'), '#b') => ('iand', ('uge', 65535, 'b'), ('ior', ('uge', 0, 'b'), ('uge', 'a', ('u2u16', 'b')))) */
   /* search1733_0_0 -> 11 in the cache */
   /* search1733_0 -> 1835 in the cache */
   /* search1733_1 -> 4485 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 1835, 4485 },
      -1,
   } },

   /* replace1733_0_0 -> 4938 in the cache */
   /* replace1733_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4938, 41 },
      -1,
   } },
   /* replace1733_1_0_0 -> 897 in the cache */
   /* replace1733_1_0_1 -> 41 in the cache */
   /* replace1733_1_0 -> 4844 in the cache */
   /* replace1733_1_1_0 -> 11 in the cache */
   /* replace1733_1_1_1_0 -> 41 in the cache */
   /* replace1733_1_1_1 -> 4928 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 11, 4928 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4844, 4951 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4950, 4952 },
      -1,
   } },

   /* ('uge', '#a', ('u2u64', 'b@16')) => ('iand', ('uge', 'a', 0), ('ior', ('uge', 'a', 65535), ('uge', ('u2u16', 'a'), 'b'))) */
   /* search1734_0 -> 4504 in the cache */
   /* search1734_1_0 -> 258 in the cache */
   /* search1734_1 -> 4919 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4504, 4919 },
      -1,
   } },

   /* replace1734_0_0 -> 21 in the cache */
   /* replace1734_0_1 -> 897 in the cache */
   /* replace1734_0 -> 4849 in the cache */
   /* replace1734_1_0_0 -> 21 in the cache */
   /* replace1734_1_0_1 -> 4938 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 21, 4938 },
      -1,
   } },
   /* replace1734_1_1_0_0 -> 21 in the cache */
   /* replace1734_1_1_0 -> 4945 in the cache */
   /* replace1734_1_1_1 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4945, 258 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4955, 4956 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4849, 4957 },
      -1,
   } },

   /* ('ieq', ('u2u64', 'a@32'), ('u2u64', 'b@8')) => ('ieq', 'a', ('u2u32', 'b')) */
   /* search1735_0_0 -> 16 in the cache */
   /* search1735_0 -> 1922 in the cache */
   /* search1735_1_0 -> 2128 in the cache */
   /* search1735_1 -> 4809 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1922, 4809 },
      -1,
   } },

   /* replace1735_0 -> 16 in the cache */
   /* replace1735_1_0 -> 2128 in the cache */
   /* replace1735_1 -> 3300 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 16, 3300 },
      -1,
   } },

   /* ('ine', ('u2u64', 'a@32'), ('u2u64', 'b@8')) => ('ine', 'a', ('u2u32', 'b')) */
   /* search1736_0_0 -> 16 in the cache */
   /* search1736_0 -> 1922 in the cache */
   /* search1736_1_0 -> 2128 in the cache */
   /* search1736_1 -> 4809 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1922, 4809 },
      -1,
   } },

   /* replace1736_0 -> 16 in the cache */
   /* replace1736_1_0 -> 2128 in the cache */
   /* replace1736_1 -> 3300 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 16, 3300 },
      -1,
   } },

   /* ('uge', ('u2u64', 'a@32'), ('u2u64', 'b@8')) => ('uge', 'a', ('u2u32', 'b')) */
   /* search1737_0_0 -> 16 in the cache */
   /* search1737_0 -> 1922 in the cache */
   /* search1737_1_0 -> 2128 in the cache */
   /* search1737_1 -> 4809 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 1922, 4809 },
      -1,
   } },

   /* replace1737_0 -> 16 in the cache */
   /* replace1737_1_0 -> 2128 in the cache */
   /* replace1737_1 -> 3300 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 16, 3300 },
      -1,
   } },

   /* ('ult', ('u2u64', 'a@32'), ('u2u64', 'b@8')) => ('ult', 'a', ('u2u32', 'b')) */
   /* search1738_0_0 -> 16 in the cache */
   /* search1738_0 -> 1922 in the cache */
   /* search1738_1_0 -> 2128 in the cache */
   /* search1738_1 -> 4809 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 1922, 4809 },
      -1,
   } },

   /* replace1738_0 -> 16 in the cache */
   /* replace1738_1_0 -> 2128 in the cache */
   /* replace1738_1 -> 3300 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 16, 3300 },
      -1,
   } },

   /* ('uge', ('u2u64', 'b@8'), ('u2u64', 'a@32')) => ('uge', ('u2u32', 'b'), 'a') */
   /* search1739_0_0 -> 4384 in the cache */
   /* search1739_0 -> 4814 in the cache */
   /* search1739_1_0 -> 183 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 183 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4814, 4967 },
      -1,
   } },

   /* replace1739_0_0 -> 4384 in the cache */
   /* replace1739_0 -> 4772 in the cache */
   /* replace1739_1 -> 183 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4772, 183 },
      -1,
   } },

   /* ('ult', ('u2u64', 'b@8'), ('u2u64', 'a@32')) => ('ult', ('u2u32', 'b'), 'a') */
   /* search1740_0_0 -> 4384 in the cache */
   /* search1740_0 -> 4814 in the cache */
   /* search1740_1_0 -> 183 in the cache */
   /* search1740_1 -> 4967 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4814, 4967 },
      -1,
   } },

   /* replace1740_0_0 -> 4384 in the cache */
   /* replace1740_0 -> 4772 in the cache */
   /* replace1740_1 -> 183 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4772, 183 },
      -1,
   } },

   /* ('ieq', ('u2u64', 'a@32'), ('u2u64', 'b@16')) => ('ieq', 'a', ('u2u32', 'b')) */
   /* search1741_0_0 -> 16 in the cache */
   /* search1741_0 -> 1922 in the cache */
   /* search1741_1_0 -> 258 in the cache */
   /* search1741_1 -> 4919 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1922, 4919 },
      -1,
   } },

   /* replace1741_0 -> 16 in the cache */
   /* replace1741_1_0 -> 258 in the cache */
   /* replace1741_1 -> 3320 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 16, 3320 },
      -1,
   } },

   /* ('ine', ('u2u64', 'a@32'), ('u2u64', 'b@16')) => ('ine', 'a', ('u2u32', 'b')) */
   /* search1742_0_0 -> 16 in the cache */
   /* search1742_0 -> 1922 in the cache */
   /* search1742_1_0 -> 258 in the cache */
   /* search1742_1 -> 4919 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1922, 4919 },
      -1,
   } },

   /* replace1742_0 -> 16 in the cache */
   /* replace1742_1_0 -> 258 in the cache */
   /* replace1742_1 -> 3320 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 16, 3320 },
      -1,
   } },

   /* ('uge', ('u2u64', 'a@32'), ('u2u64', 'b@16')) => ('uge', 'a', ('u2u32', 'b')) */
   /* search1743_0_0 -> 16 in the cache */
   /* search1743_0 -> 1922 in the cache */
   /* search1743_1_0 -> 258 in the cache */
   /* search1743_1 -> 4919 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 1922, 4919 },
      -1,
   } },

   /* replace1743_0 -> 16 in the cache */
   /* replace1743_1_0 -> 258 in the cache */
   /* replace1743_1 -> 3320 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 16, 3320 },
      -1,
   } },

   /* ('ult', ('u2u64', 'a@32'), ('u2u64', 'b@16')) => ('ult', 'a', ('u2u32', 'b')) */
   /* search1744_0_0 -> 16 in the cache */
   /* search1744_0 -> 1922 in the cache */
   /* search1744_1_0 -> 258 in the cache */
   /* search1744_1 -> 4919 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 1922, 4919 },
      -1,
   } },

   /* replace1744_0 -> 16 in the cache */
   /* replace1744_1_0 -> 258 in the cache */
   /* replace1744_1 -> 3320 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 16, 3320 },
      -1,
   } },

   /* ('uge', ('u2u64', 'b@16'), ('u2u64', 'a@32')) => ('uge', ('u2u32', 'b'), 'a') */
   /* search1745_0_0 -> 515 in the cache */
   /* search1745_0 -> 4924 in the cache */
   /* search1745_1_0 -> 183 in the cache */
   /* search1745_1 -> 4967 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4924, 4967 },
      -1,
   } },

   /* replace1745_0_0 -> 515 in the cache */
   /* replace1745_0 -> 4876 in the cache */
   /* replace1745_1 -> 183 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4876, 183 },
      -1,
   } },

   /* ('ult', ('u2u64', 'b@16'), ('u2u64', 'a@32')) => ('ult', ('u2u32', 'b'), 'a') */
   /* search1746_0_0 -> 515 in the cache */
   /* search1746_0 -> 4924 in the cache */
   /* search1746_1_0 -> 183 in the cache */
   /* search1746_1 -> 4967 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4924, 4967 },
      -1,
   } },

   /* replace1746_0_0 -> 515 in the cache */
   /* replace1746_0 -> 4876 in the cache */
   /* replace1746_1 -> 183 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4876, 183 },
      -1,
   } },

   /* ('ieq', ('u2u64', 'a@32'), ('u2u64', 'b@32')) => ('ieq', 'a', ('u2u32', 'b')) */
   /* search1747_0_0 -> 16 in the cache */
   /* search1747_0 -> 1922 in the cache */
   /* search1747_1_0 -> 36 in the cache */
   /* search1747_1 -> 3316 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1922, 3316 },
      -1,
   } },

   /* replace1747_0 -> 16 in the cache */
   /* replace1747_1_0 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 16, 4985 },
      -1,
   } },

   /* ('ine', ('u2u64', 'a@32'), ('u2u64', 'b@32')) => ('ine', 'a', ('u2u32', 'b')) */
   /* search1748_0_0 -> 16 in the cache */
   /* search1748_0 -> 1922 in the cache */
   /* search1748_1_0 -> 36 in the cache */
   /* search1748_1 -> 3316 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1922, 3316 },
      -1,
   } },

   /* replace1748_0 -> 16 in the cache */
   /* replace1748_1_0 -> 36 in the cache */
   /* replace1748_1 -> 4985 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 16, 4985 },
      -1,
   } },

   /* ('uge', ('u2u64', 'a@32'), ('u2u64', 'b@32')) => ('uge', 'a', ('u2u32', 'b')) */
   /* search1749_0_0 -> 16 in the cache */
   /* search1749_0 -> 1922 in the cache */
   /* search1749_1_0 -> 36 in the cache */
   /* search1749_1 -> 3316 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 1922, 3316 },
      -1,
   } },

   /* replace1749_0 -> 16 in the cache */
   /* replace1749_1_0 -> 36 in the cache */
   /* replace1749_1 -> 4985 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 16, 4985 },
      -1,
   } },

   /* ('ult', ('u2u64', 'a@32'), ('u2u64', 'b@32')) => ('ult', 'a', ('u2u32', 'b')) */
   /* search1750_0_0 -> 16 in the cache */
   /* search1750_0 -> 1922 in the cache */
   /* search1750_1_0 -> 36 in the cache */
   /* search1750_1 -> 3316 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 1922, 3316 },
      -1,
   } },

   /* replace1750_0 -> 16 in the cache */
   /* replace1750_1_0 -> 36 in the cache */
   /* replace1750_1 -> 4985 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 16, 4985 },
      -1,
   } },

   /* ('uge', ('u2u64', 'b@32'), ('u2u64', 'a@32')) => ('uge', ('u2u32', 'b'), 'a') */
   /* search1751_0_0 -> 373 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 373 },
      -1,
   } },
   /* search1751_1_0 -> 183 in the cache */
   /* search1751_1 -> 4967 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4993, 4967 },
      -1,
   } },

   /* replace1751_0_0 -> 373 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 373 },
      -1,
   } },
   /* replace1751_1 -> 183 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4995, 183 },
      -1,
   } },

   /* ('ult', ('u2u64', 'b@32'), ('u2u64', 'a@32')) => ('ult', ('u2u32', 'b'), 'a') */
   /* search1752_0_0 -> 373 in the cache */
   /* search1752_0 -> 4993 in the cache */
   /* search1752_1_0 -> 183 in the cache */
   /* search1752_1 -> 4967 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4993, 4967 },
      -1,
   } },

   /* replace1752_0_0 -> 373 in the cache */
   /* replace1752_0 -> 4995 in the cache */
   /* replace1752_1 -> 183 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4995, 183 },
      -1,
   } },

   /* ('ieq', ('u2u64', 'a@32'), '#b') => ('iand', ('ieq', 'a', ('u2u32', 'b')), ('ieq', ('u2u64', ('u2u32', 'b')), 'b')) */
   /* search1753_0_0 -> 16 in the cache */
   /* search1753_0 -> 1922 in the cache */
   /* search1753_1 -> 4485 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 1922, 4485 },
      -1,
   } },

   /* replace1753_0_0 -> 16 in the cache */
   /* replace1753_0_1_0 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 16, 5000 },
      -1,
   } },
   /* replace1753_1_0_0_0 -> 41 in the cache */
   /* replace1753_1_0_0 -> 5000 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_u2u64,
      -1, 0,
      { 5000 },
      -1,
   } },
   /* replace1753_1_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 5002, 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 5001, 5003 },
      -1,
   } },

   /* ('ine', ('u2u64', 'a@32'), '#b') => ('ior', ('ine', 'a', ('u2u32', 'b')), ('ine', ('u2u64', ('u2u32', 'b')), 'b')) */
   /* search1754_0_0 -> 16 in the cache */
   /* search1754_0 -> 1922 in the cache */
   /* search1754_1 -> 4485 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 1922, 4485 },
      -1,
   } },

   /* replace1754_0_0 -> 16 in the cache */
   /* replace1754_0_1_0 -> 41 in the cache */
   /* replace1754_0_1 -> 5000 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 16, 5000 },
      -1,
   } },
   /* replace1754_1_0_0_0 -> 41 in the cache */
   /* replace1754_1_0_0 -> 5000 in the cache */
   /* replace1754_1_0 -> 5002 in the cache */
   /* replace1754_1_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 5002, 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 5006, 5007 },
      -1,
   } },

   /* ('ult', ('u2u64', 'a@32'), '#b') => ('iand', ('ult', 0, 'b'), ('ior', ('ult', 4294967295, 'b'), ('ult', 'a', ('u2u32', 'b')))) */
   /* search1755_0_0 -> 16 in the cache */
   /* search1755_0 -> 1922 in the cache */
   /* search1755_1 -> 4485 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 1922, 4485 },
      -1,
   } },

   /* replace1755_0_0 -> 897 in the cache */
   /* replace1755_0_1 -> 41 in the cache */
   /* replace1755_0 -> 4829 in the cache */
   /* replace1755_1_0_0 -> 3331 in the cache */
   /* replace1755_1_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 3331, 41 },
      -1,
   } },
   /* replace1755_1_1_0 -> 16 in the cache */
   /* replace1755_1_1_1_0 -> 41 in the cache */
   /* replace1755_1_1_1 -> 5000 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 16, 5000 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 5010, 5011 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4829, 5012 },
      -1,
   } },

   /* ('ult', '#a', ('u2u64', 'b@32')) => ('iand', ('ult', 'a', 4294967295), ('ior', ('ult', 'a', 0), ('ult', ('u2u32', 'a'), 'b'))) */
   /* search1756_0 -> 4504 in the cache */
   /* search1756_1_0 -> 36 in the cache */
   /* search1756_1 -> 3316 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 4504, 3316 },
      -1,
   } },

   /* replace1756_0_0 -> 21 in the cache */
   /* replace1756_0_1 -> 3331 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 21, 3331 },
      -1,
   } },
   /* replace1756_1_0_0 -> 21 in the cache */
   /* replace1756_1_0_1 -> 897 in the cache */
   /* replace1756_1_0 -> 4837 in the cache */
   /* replace1756_1_1_0_0 -> 21 in the cache */
   /* replace1756_1_1_0 -> 3323 in the cache */
   /* replace1756_1_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 3323, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4837, 5016 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 5015, 5017 },
      -1,
   } },

   /* ('uge', ('u2u64', 'a@32'), '#b') => ('iand', ('uge', 4294967295, 'b'), ('ior', ('uge', 0, 'b'), ('uge', 'a', ('u2u32', 'b')))) */
   /* search1757_0_0 -> 16 in the cache */
   /* search1757_0 -> 1922 in the cache */
   /* search1757_1 -> 4485 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 1922, 4485 },
      -1,
   } },

   /* replace1757_0_0 -> 3331 in the cache */
   /* replace1757_0_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 3331, 41 },
      -1,
   } },
   /* replace1757_1_0_0 -> 897 in the cache */
   /* replace1757_1_0_1 -> 41 in the cache */
   /* replace1757_1_0 -> 4844 in the cache */
   /* replace1757_1_1_0 -> 16 in the cache */
   /* replace1757_1_1_1_0 -> 41 in the cache */
   /* replace1757_1_1_1 -> 5000 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 16, 5000 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 4844, 5021 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 5020, 5022 },
      -1,
   } },

   /* ('uge', '#a', ('u2u64', 'b@32')) => ('iand', ('uge', 'a', 0), ('ior', ('uge', 'a', 4294967295), ('uge', ('u2u32', 'a'), 'b'))) */
   /* search1758_0 -> 4504 in the cache */
   /* search1758_1_0 -> 36 in the cache */
   /* search1758_1 -> 3316 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 4504, 3316 },
      -1,
   } },

   /* replace1758_0_0 -> 21 in the cache */
   /* replace1758_0_1 -> 897 in the cache */
   /* replace1758_0 -> 4849 in the cache */
   /* replace1758_1_0_0 -> 21 in the cache */
   /* replace1758_1_0_1 -> 3331 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 21, 3331 },
      -1,
   } },
   /* replace1758_1_1_0_0 -> 21 in the cache */
   /* replace1758_1_1_0 -> 3323 in the cache */
   /* replace1758_1_1_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 3323, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 5025, 5026 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 4849, 5027 },
      -1,
   } },

   /* ('feq', ('f2f32', 'a@16'), ('f2f32', 'b@16')) => ('feq', 'a', ('f2f16', 'b')) */
   /* search1759_0_0 -> 11 in the cache */
   /* search1759_0 -> 1813 in the cache */
   /* search1759_1_0 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 258 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 1813, 5029 },
      -1,
   } },

   /* replace1759_0 -> 11 in the cache */
   /* replace1759_1_0 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 258 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 11, 5031 },
      -1,
   } },

   /* ('fneu', ('f2f32', 'a@16'), ('f2f32', 'b@16')) => ('fneu', 'a', ('f2f16', 'b')) */
   /* search1760_0_0 -> 11 in the cache */
   /* search1760_0 -> 1813 in the cache */
   /* search1760_1_0 -> 258 in the cache */
   /* search1760_1 -> 5029 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 1813, 5029 },
      -1,
   } },

   /* replace1760_0 -> 11 in the cache */
   /* replace1760_1_0 -> 258 in the cache */
   /* replace1760_1 -> 5031 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 11, 5031 },
      -1,
   } },

   /* ('fge', ('f2f32', 'a@16'), ('f2f32', 'b@16')) => ('fge', 'a', ('f2f16', 'b')) */
   /* search1761_0_0 -> 11 in the cache */
   /* search1761_0 -> 1813 in the cache */
   /* search1761_1_0 -> 258 in the cache */
   /* search1761_1 -> 5029 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1813, 5029 },
      -1,
   } },

   /* replace1761_0 -> 11 in the cache */
   /* replace1761_1_0 -> 258 in the cache */
   /* replace1761_1 -> 5031 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 11, 5031 },
      -1,
   } },

   /* ('flt', ('f2f32', 'a@16'), ('f2f32', 'b@16')) => ('flt', 'a', ('f2f16', 'b')) */
   /* search1762_0_0 -> 11 in the cache */
   /* search1762_0 -> 1813 in the cache */
   /* search1762_1_0 -> 258 in the cache */
   /* search1762_1 -> 5029 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1813, 5029 },
      -1,
   } },

   /* replace1762_0 -> 11 in the cache */
   /* replace1762_1_0 -> 258 in the cache */
   /* replace1762_1 -> 5031 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 11, 5031 },
      -1,
   } },

   /* ('fge', ('f2f32', 'b@16'), ('f2f32', 'a@16')) => ('fge', ('f2f16', 'b'), 'a') */
   /* search1763_0_0 -> 515 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 515 },
      -1,
   } },
   /* search1763_1_0 -> 526 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 526 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 5039, 5040 },
      -1,
   } },

   /* replace1763_0_0 -> 515 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 515 },
      -1,
   } },
   /* replace1763_1 -> 526 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 5042, 526 },
      -1,
   } },

   /* ('flt', ('f2f32', 'b@16'), ('f2f32', 'a@16')) => ('flt', ('f2f16', 'b'), 'a') */
   /* search1764_0_0 -> 515 in the cache */
   /* search1764_0 -> 5039 in the cache */
   /* search1764_1_0 -> 526 in the cache */
   /* search1764_1 -> 5040 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 5039, 5040 },
      -1,
   } },

   /* replace1764_0_0 -> 515 in the cache */
   /* replace1764_0 -> 5042 in the cache */
   /* replace1764_1 -> 526 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 5042, 526 },
      -1,
   } },

   /* ('feq', ('f2f64', 'a@16'), ('f2f64', 'b@16')) => ('feq', 'a', ('f2f16', 'b')) */
   /* search1765_0_0 -> 11 in the cache */
   /* search1765_0 -> 1831 in the cache */
   /* search1765_1_0 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_f2f64,
      -1, 0,
      { 258 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 1831, 5046 },
      -1,
   } },

   /* replace1765_0 -> 11 in the cache */
   /* replace1765_1_0 -> 258 in the cache */
   /* replace1765_1 -> 5031 in the cache */
   /* replace1765 -> 5032 in the cache */

   /* ('fneu', ('f2f64', 'a@16'), ('f2f64', 'b@16')) => ('fneu', 'a', ('f2f16', 'b')) */
   /* search1766_0_0 -> 11 in the cache */
   /* search1766_0 -> 1831 in the cache */
   /* search1766_1_0 -> 258 in the cache */
   /* search1766_1 -> 5046 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 1831, 5046 },
      -1,
   } },

   /* replace1766_0 -> 11 in the cache */
   /* replace1766_1_0 -> 258 in the cache */
   /* replace1766_1 -> 5031 in the cache */
   /* replace1766 -> 5034 in the cache */

   /* ('fge', ('f2f64', 'a@16'), ('f2f64', 'b@16')) => ('fge', 'a', ('f2f16', 'b')) */
   /* search1767_0_0 -> 11 in the cache */
   /* search1767_0 -> 1831 in the cache */
   /* search1767_1_0 -> 258 in the cache */
   /* search1767_1 -> 5046 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1831, 5046 },
      -1,
   } },

   /* replace1767_0 -> 11 in the cache */
   /* replace1767_1_0 -> 258 in the cache */
   /* replace1767_1 -> 5031 in the cache */
   /* replace1767 -> 5036 in the cache */

   /* ('flt', ('f2f64', 'a@16'), ('f2f64', 'b@16')) => ('flt', 'a', ('f2f16', 'b')) */
   /* search1768_0_0 -> 11 in the cache */
   /* search1768_0 -> 1831 in the cache */
   /* search1768_1_0 -> 258 in the cache */
   /* search1768_1 -> 5046 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1831, 5046 },
      -1,
   } },

   /* replace1768_0 -> 11 in the cache */
   /* replace1768_1_0 -> 258 in the cache */
   /* replace1768_1 -> 5031 in the cache */
   /* replace1768 -> 5038 in the cache */

   /* ('fge', ('f2f64', 'b@16'), ('f2f64', 'a@16')) => ('fge', ('f2f16', 'b'), 'a') */
   /* search1769_0_0 -> 515 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_f2f64,
      -1, 0,
      { 515 },
      -1,
   } },
   /* search1769_1_0 -> 526 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_f2f64,
      -1, 0,
      { 526 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 5051, 5052 },
      -1,
   } },

   /* replace1769_0_0 -> 515 in the cache */
   /* replace1769_0 -> 5042 in the cache */
   /* replace1769_1 -> 526 in the cache */
   /* replace1769 -> 5043 in the cache */

   /* ('flt', ('f2f64', 'b@16'), ('f2f64', 'a@16')) => ('flt', ('f2f16', 'b'), 'a') */
   /* search1770_0_0 -> 515 in the cache */
   /* search1770_0 -> 5051 in the cache */
   /* search1770_1_0 -> 526 in the cache */
   /* search1770_1 -> 5052 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 5051, 5052 },
      -1,
   } },

   /* replace1770_0_0 -> 515 in the cache */
   /* replace1770_0 -> 5042 in the cache */
   /* replace1770_1 -> 526 in the cache */
   /* replace1770 -> 5045 in the cache */

   /* ('feq', ('f2f64', 'a@32'), ('f2f64', 'b@16')) => ('feq', 'a', ('f2f32', 'b')) */
   /* search1771_0_0 -> 16 in the cache */
   /* search1771_0 -> 1918 in the cache */
   /* search1771_1_0 -> 258 in the cache */
   /* search1771_1 -> 5046 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 1918, 5046 },
      -1,
   } },

   /* replace1771_0 -> 16 in the cache */
   /* replace1771_1_0 -> 258 in the cache */
   /* replace1771_1 -> 5029 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 16, 5029 },
      -1,
   } },

   /* ('fneu', ('f2f64', 'a@32'), ('f2f64', 'b@16')) => ('fneu', 'a', ('f2f32', 'b')) */
   /* search1772_0_0 -> 16 in the cache */
   /* search1772_0 -> 1918 in the cache */
   /* search1772_1_0 -> 258 in the cache */
   /* search1772_1 -> 5046 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 1918, 5046 },
      -1,
   } },

   /* replace1772_0 -> 16 in the cache */
   /* replace1772_1_0 -> 258 in the cache */
   /* replace1772_1 -> 5029 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 16, 5029 },
      -1,
   } },

   /* ('fge', ('f2f64', 'a@32'), ('f2f64', 'b@16')) => ('fge', 'a', ('f2f32', 'b')) */
   /* search1773_0_0 -> 16 in the cache */
   /* search1773_0 -> 1918 in the cache */
   /* search1773_1_0 -> 258 in the cache */
   /* search1773_1 -> 5046 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1918, 5046 },
      -1,
   } },

   /* replace1773_0 -> 16 in the cache */
   /* replace1773_1_0 -> 258 in the cache */
   /* replace1773_1 -> 5029 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 16, 5029 },
      -1,
   } },

   /* ('flt', ('f2f64', 'a@32'), ('f2f64', 'b@16')) => ('flt', 'a', ('f2f32', 'b')) */
   /* search1774_0_0 -> 16 in the cache */
   /* search1774_0 -> 1918 in the cache */
   /* search1774_1_0 -> 258 in the cache */
   /* search1774_1 -> 5046 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1918, 5046 },
      -1,
   } },

   /* replace1774_0 -> 16 in the cache */
   /* replace1774_1_0 -> 258 in the cache */
   /* replace1774_1 -> 5029 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 16, 5029 },
      -1,
   } },

   /* ('fge', ('f2f64', 'b@16'), ('f2f64', 'a@32')) => ('fge', ('f2f32', 'b'), 'a') */
   /* search1775_0_0 -> 515 in the cache */
   /* search1775_0 -> 5051 in the cache */
   /* search1775_1_0 -> 183 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_f2f64,
      -1, 0,
      { 183 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 5051, 5063 },
      -1,
   } },

   /* replace1775_0_0 -> 515 in the cache */
   /* replace1775_0 -> 5039 in the cache */
   /* replace1775_1 -> 183 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 5039, 183 },
      -1,
   } },

   /* ('flt', ('f2f64', 'b@16'), ('f2f64', 'a@32')) => ('flt', ('f2f32', 'b'), 'a') */
   /* search1776_0_0 -> 515 in the cache */
   /* search1776_0 -> 5051 in the cache */
   /* search1776_1_0 -> 183 in the cache */
   /* search1776_1 -> 5063 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 5051, 5063 },
      -1,
   } },

   /* replace1776_0_0 -> 515 in the cache */
   /* replace1776_0 -> 5039 in the cache */
   /* replace1776_1 -> 183 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 5039, 183 },
      -1,
   } },

   /* ('feq', ('f2f64', 'a@32'), ('f2f64', 'b@32')) => ('feq', 'a', ('f2f32', 'b')) */
   /* search1777_0_0 -> 16 in the cache */
   /* search1777_0 -> 1918 in the cache */
   /* search1777_1_0 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_f2f64,
      -1, 0,
      { 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 1918, 5068 },
      -1,
   } },

   /* replace1777_0 -> 16 in the cache */
   /* replace1777_1_0 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 16, 5070 },
      -1,
   } },

   /* ('fneu', ('f2f64', 'a@32'), ('f2f64', 'b@32')) => ('fneu', 'a', ('f2f32', 'b')) */
   /* search1778_0_0 -> 16 in the cache */
   /* search1778_0 -> 1918 in the cache */
   /* search1778_1_0 -> 36 in the cache */
   /* search1778_1 -> 5068 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 1918, 5068 },
      -1,
   } },

   /* replace1778_0 -> 16 in the cache */
   /* replace1778_1_0 -> 36 in the cache */
   /* replace1778_1 -> 5070 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 16, 5070 },
      -1,
   } },

   /* ('fge', ('f2f64', 'a@32'), ('f2f64', 'b@32')) => ('fge', 'a', ('f2f32', 'b')) */
   /* search1779_0_0 -> 16 in the cache */
   /* search1779_0 -> 1918 in the cache */
   /* search1779_1_0 -> 36 in the cache */
   /* search1779_1 -> 5068 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1918, 5068 },
      -1,
   } },

   /* replace1779_0 -> 16 in the cache */
   /* replace1779_1_0 -> 36 in the cache */
   /* replace1779_1 -> 5070 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 16, 5070 },
      -1,
   } },

   /* ('flt', ('f2f64', 'a@32'), ('f2f64', 'b@32')) => ('flt', 'a', ('f2f32', 'b')) */
   /* search1780_0_0 -> 16 in the cache */
   /* search1780_0 -> 1918 in the cache */
   /* search1780_1_0 -> 36 in the cache */
   /* search1780_1 -> 5068 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1918, 5068 },
      -1,
   } },

   /* replace1780_0 -> 16 in the cache */
   /* replace1780_1_0 -> 36 in the cache */
   /* replace1780_1 -> 5070 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 16, 5070 },
      -1,
   } },

   /* ('fge', ('f2f64', 'b@32'), ('f2f64', 'a@32')) => ('fge', ('f2f32', 'b'), 'a') */
   /* search1781_0_0 -> 373 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_f2f64,
      -1, 0,
      { 373 },
      -1,
   } },
   /* search1781_1_0 -> 183 in the cache */
   /* search1781_1 -> 5063 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 5078, 5063 },
      -1,
   } },

   /* replace1781_0_0 -> 373 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 373 },
      -1,
   } },
   /* replace1781_1 -> 183 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 5080, 183 },
      -1,
   } },

   /* ('flt', ('f2f64', 'b@32'), ('f2f64', 'a@32')) => ('flt', ('f2f32', 'b'), 'a') */
   /* search1782_0_0 -> 373 in the cache */
   /* search1782_0 -> 5078 in the cache */
   /* search1782_1_0 -> 183 in the cache */
   /* search1782_1 -> 5063 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 5078, 5063 },
      -1,
   } },

   /* replace1782_0_0 -> 373 in the cache */
   /* replace1782_0 -> 5080 in the cache */
   /* replace1782_1 -> 183 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 5080, 183 },
      -1,
   } },

   /* ('i2i32', ('iand', 'a@64', 4294967295)) => ('u2u32', 'a') */
   /* search1783_0_0 -> 21 in the cache */
   /* search1783_0_1 -> 3331 in the cache */
   /* search1783_0 -> 3332 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 1,
      { 3332 },
      -1,
   } },

   /* replace1783_0 -> 21 in the cache */
   /* replace1783 -> 3323 in the cache */

   /* ('i2i16', ('iand', 'a@32', 65535)) => ('u2u16', 'a') */
   /* search1784_0_0 -> 16 in the cache */
   /* search1784_0_1 -> 1002 in the cache */
   /* search1784_0 -> 1003 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 1,
      { 1003 },
      -1,
   } },

   /* replace1784_0 -> 16 in the cache */
   /* replace1784 -> 3326 in the cache */

   /* ('i2i16', ('iand', 'a@64', 65535)) => ('u2u16', 'a') */
   /* search1785_0_0 -> 21 in the cache */
   /* search1785_0_1 -> 4938 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 21, 4938 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 1,
      { 5086 },
      -1,
   } },

   /* replace1785_0 -> 21 in the cache */
   /* replace1785 -> 4945 in the cache */

   /* ('i2i8', ('iand', 'a@16', 255)) => ('u2u8', 'a') */
   /* search1786_0_0 -> 11 in the cache */
   /* search1786_0_1 -> 2029 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 11, 2029 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 1,
      { 5088 },
      -1,
   } },

   /* replace1786_0 -> 11 in the cache */
   /* replace1786 -> 2025 in the cache */

   /* ('i2i8', ('iand', 'a@32', 255)) => ('u2u8', 'a') */
   /* search1787_0_0 -> 16 in the cache */
   /* search1787_0_1 -> 1010 in the cache */
   /* search1787_0 -> 1011 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 1,
      { 1011 },
      -1,
   } },

   /* replace1787_0 -> 16 in the cache */
   /* replace1787 -> 2041 in the cache */

   /* ('i2i8', ('iand', 'a@64', 255)) => ('u2u8', 'a') */
   /* search1788_0_0 -> 21 in the cache */
   /* search1788_0_1 -> 4830 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 21, 4830 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 1,
      { 5091 },
      -1,
   } },

   /* replace1788_0 -> 21 in the cache */
   /* replace1788 -> 4838 in the cache */

   /* ('u2u16(only_lower_8_bits_used)', ('u2u8', 'a@16')) => a */
   /* search1789_0_0 -> 11 in the cache */
   /* search1789_0 -> 2025 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 2025 },
      5,
   } },

   /* replace1789 -> 11 in the cache */

   /* ('extract_u8(only_lower_8_bits_used)', 'a@16', 0) => a */
   /* search1790_0 -> 11 in the cache */
   /* search1790_1 -> 856 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 11, 856 },
      5,
   } },

   /* replace1790 -> 11 in the cache */

   /* ('bcsel(only_lower_8_bits_used)', 'c', ('u2u16', ('u2u8', 'a@16')), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search1791_0 -> 521 in the cache */
   /* search1791_1_0_0 -> 526 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 526 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 5095 },
      -1,
   } },
   /* search1791_2 -> 488 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 521, 5096, 488 },
      5,
   } },

   /* replace1791_0 -> 521 in the cache */
   /* replace1791_1 -> 526 in the cache */
   /* replace1791_2 -> 488 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 521, 526, 488 },
      -1,
   } },

   /* ('bcsel(only_lower_8_bits_used)', 'c', ('u2u16', ('i2i8', 'a@16')), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search1792_0 -> 521 in the cache */
   /* search1792_1_0_0 -> 526 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 526 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 5099 },
      -1,
   } },
   /* search1792_2 -> 488 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 521, 5100, 488 },
      5,
   } },

   /* replace1792_0 -> 521 in the cache */
   /* replace1792_1 -> 526 in the cache */
   /* replace1792_2 -> 488 in the cache */
   /* replace1792 -> 5098 in the cache */

   /* ('bcsel(only_lower_8_bits_used)', 'c', ('extract_u8', 'a@16', 0), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search1793_0 -> 521 in the cache */
   /* search1793_1_0 -> 526 in the cache */
   /* search1793_1_1 -> 856 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 526, 856 },
      -1,
   } },
   /* search1793_2 -> 488 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 521, 5102, 488 },
      5,
   } },

   /* replace1793_0 -> 521 in the cache */
   /* replace1793_1 -> 526 in the cache */
   /* replace1793_2 -> 488 in the cache */
   /* replace1793 -> 5098 in the cache */

   /* ('iadd(only_lower_8_bits_used)', ('u2u16', ('u2u8', 'a@16')), 'b') => ('iadd', 'a', 'b') */
   /* search1794_0_0_0 -> 11 in the cache */
   /* search1794_0_0 -> 2025 in the cache */
   /* search1794_0 -> 2026 in the cache */
   /* search1794_1 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 2026, 258 },
      5,
   } },

   /* replace1794_0 -> 11 in the cache */
   /* replace1794_1 -> 258 in the cache */
   /* replace1794 -> 4068 in the cache */

   /* ('iadd(only_lower_8_bits_used)', ('u2u16', ('i2i8', 'a@16')), 'b') => ('iadd', 'a', 'b') */
   /* search1795_0_0_0 -> 11 in the cache */
   /* search1795_0_0 -> 4415 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 4415 },
      -1,
   } },
   /* search1795_1 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 5105, 258 },
      5,
   } },

   /* replace1795_0 -> 11 in the cache */
   /* replace1795_1 -> 258 in the cache */
   /* replace1795 -> 4068 in the cache */

   /* ('iadd(only_lower_8_bits_used)', ('extract_u8', 'a@16', 0), 'b') => ('iadd', 'a', 'b') */
   /* search1796_0_0 -> 11 in the cache */
   /* search1796_0_1 -> 856 in the cache */
   /* search1796_0 -> 3434 in the cache */
   /* search1796_1 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 3434, 258 },
      5,
   } },

   /* replace1796_0 -> 11 in the cache */
   /* replace1796_1 -> 258 in the cache */
   /* replace1796 -> 4068 in the cache */

   /* ('imul(only_lower_8_bits_used)', ('u2u16', ('u2u8', 'a@16')), 'b') => ('imul', 'a', 'b') */
   /* search1797_0_0_0 -> 11 in the cache */
   /* search1797_0_0 -> 2025 in the cache */
   /* search1797_0 -> 2026 in the cache */
   /* search1797_1 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 2026, 258 },
      5,
   } },

   /* replace1797_0 -> 11 in the cache */
   /* replace1797_1 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 11, 258 },
      -1,
   } },

   /* ('imul(only_lower_8_bits_used)', ('u2u16', ('i2i8', 'a@16')), 'b') => ('imul', 'a', 'b') */
   /* search1798_0_0_0 -> 11 in the cache */
   /* search1798_0_0 -> 4415 in the cache */
   /* search1798_0 -> 5105 in the cache */
   /* search1798_1 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 5105, 258 },
      5,
   } },

   /* replace1798_0 -> 11 in the cache */
   /* replace1798_1 -> 258 in the cache */
   /* replace1798 -> 5109 in the cache */

   /* ('imul(only_lower_8_bits_used)', ('extract_u8', 'a@16', 0), 'b') => ('imul', 'a', 'b') */
   /* search1799_0_0 -> 11 in the cache */
   /* search1799_0_1 -> 856 in the cache */
   /* search1799_0 -> 3434 in the cache */
   /* search1799_1 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 3434, 258 },
      5,
   } },

   /* replace1799_0 -> 11 in the cache */
   /* replace1799_1 -> 258 in the cache */
   /* replace1799 -> 5109 in the cache */

   /* ('iand(only_lower_8_bits_used)', ('u2u16', ('u2u8', 'a@16')), 'b') => ('iand', 'a', 'b') */
   /* search1800_0_0_0 -> 11 in the cache */
   /* search1800_0_0 -> 2025 in the cache */
   /* search1800_0 -> 2026 in the cache */
   /* search1800_1 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 2026, 258 },
      5,
   } },

   /* replace1800_0 -> 11 in the cache */
   /* replace1800_1 -> 258 in the cache */
   /* replace1800 -> 2039 in the cache */

   /* ('iand(only_lower_8_bits_used)', ('u2u16', ('i2i8', 'a@16')), 'b') => ('iand', 'a', 'b') */
   /* search1801_0_0_0 -> 11 in the cache */
   /* search1801_0_0 -> 4415 in the cache */
   /* search1801_0 -> 5105 in the cache */
   /* search1801_1 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 5105, 258 },
      5,
   } },

   /* replace1801_0 -> 11 in the cache */
   /* replace1801_1 -> 258 in the cache */
   /* replace1801 -> 2039 in the cache */

   /* ('iand(only_lower_8_bits_used)', ('extract_u8', 'a@16', 0), 'b') => ('iand', 'a', 'b') */
   /* search1802_0_0 -> 11 in the cache */
   /* search1802_0_1 -> 856 in the cache */
   /* search1802_0 -> 3434 in the cache */
   /* search1802_1 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 3434, 258 },
      5,
   } },

   /* replace1802_0 -> 11 in the cache */
   /* replace1802_1 -> 258 in the cache */
   /* replace1802 -> 2039 in the cache */

   /* ('ior(only_lower_8_bits_used)', ('u2u16', ('u2u8', 'a@16')), 'b') => ('ior', 'a', 'b') */
   /* search1803_0_0_0 -> 11 in the cache */
   /* search1803_0_0 -> 2025 in the cache */
   /* search1803_0 -> 2026 in the cache */
   /* search1803_1 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 2026, 258 },
      5,
   } },

   /* replace1803_0 -> 11 in the cache */
   /* replace1803_1 -> 258 in the cache */
   /* replace1803 -> 2081 in the cache */

   /* ('ior(only_lower_8_bits_used)', ('u2u16', ('i2i8', 'a@16')), 'b') => ('ior', 'a', 'b') */
   /* search1804_0_0_0 -> 11 in the cache */
   /* search1804_0_0 -> 4415 in the cache */
   /* search1804_0 -> 5105 in the cache */
   /* search1804_1 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 5105, 258 },
      5,
   } },

   /* replace1804_0 -> 11 in the cache */
   /* replace1804_1 -> 258 in the cache */
   /* replace1804 -> 2081 in the cache */

   /* ('ior(only_lower_8_bits_used)', ('extract_u8', 'a@16', 0), 'b') => ('ior', 'a', 'b') */
   /* search1805_0_0 -> 11 in the cache */
   /* search1805_0_1 -> 856 in the cache */
   /* search1805_0 -> 3434 in the cache */
   /* search1805_1 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 3434, 258 },
      5,
   } },

   /* replace1805_0 -> 11 in the cache */
   /* replace1805_1 -> 258 in the cache */
   /* replace1805 -> 2081 in the cache */

   /* ('ixor(only_lower_8_bits_used)', ('u2u16', ('u2u8', 'a@16')), 'b') => ('ixor', 'a', 'b') */
   /* search1806_0_0_0 -> 11 in the cache */
   /* search1806_0_0 -> 2025 in the cache */
   /* search1806_0 -> 2026 in the cache */
   /* search1806_1 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 2026, 258 },
      5,
   } },

   /* replace1806_0 -> 11 in the cache */
   /* replace1806_1 -> 258 in the cache */
   /* replace1806 -> 2105 in the cache */

   /* ('ixor(only_lower_8_bits_used)', ('u2u16', ('i2i8', 'a@16')), 'b') => ('ixor', 'a', 'b') */
   /* search1807_0_0_0 -> 11 in the cache */
   /* search1807_0_0 -> 4415 in the cache */
   /* search1807_0 -> 5105 in the cache */
   /* search1807_1 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 5105, 258 },
      5,
   } },

   /* replace1807_0 -> 11 in the cache */
   /* replace1807_1 -> 258 in the cache */
   /* replace1807 -> 2105 in the cache */

   /* ('ixor(only_lower_8_bits_used)', ('extract_u8', 'a@16', 0), 'b') => ('ixor', 'a', 'b') */
   /* search1808_0_0 -> 11 in the cache */
   /* search1808_0_1 -> 856 in the cache */
   /* search1808_0 -> 3434 in the cache */
   /* search1808_1 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 3434, 258 },
      5,
   } },

   /* replace1808_0 -> 11 in the cache */
   /* replace1808_1 -> 258 in the cache */
   /* replace1808 -> 2105 in the cache */

   /* ('i2i16(only_lower_8_bits_used)', ('u2u8', 'a@16')) => a */
   /* search1809_0_0 -> 11 in the cache */
   /* search1809_0 -> 2025 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 2025 },
      5,
   } },

   /* replace1809 -> 11 in the cache */

   /* ('extract_i8(only_lower_8_bits_used)', 'a@16', 0) => a */
   /* search1810_0 -> 11 in the cache */
   /* search1810_1 -> 856 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 11, 856 },
      5,
   } },

   /* replace1810 -> 11 in the cache */

   /* ('bcsel(only_lower_8_bits_used)', 'c', ('i2i16', ('u2u8', 'a@16')), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search1811_0 -> 521 in the cache */
   /* search1811_1_0_0 -> 526 in the cache */
   /* search1811_1_0 -> 5095 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 5095 },
      -1,
   } },
   /* search1811_2 -> 488 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 521, 5123, 488 },
      5,
   } },

   /* replace1811_0 -> 521 in the cache */
   /* replace1811_1 -> 526 in the cache */
   /* replace1811_2 -> 488 in the cache */
   /* replace1811 -> 5098 in the cache */

   /* ('bcsel(only_lower_8_bits_used)', 'c', ('i2i16', ('i2i8', 'a@16')), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search1812_0 -> 521 in the cache */
   /* search1812_1_0_0 -> 526 in the cache */
   /* search1812_1_0 -> 5099 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 5099 },
      -1,
   } },
   /* search1812_2 -> 488 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 521, 5125, 488 },
      5,
   } },

   /* replace1812_0 -> 521 in the cache */
   /* replace1812_1 -> 526 in the cache */
   /* replace1812_2 -> 488 in the cache */
   /* replace1812 -> 5098 in the cache */

   /* ('bcsel(only_lower_8_bits_used)', 'c', ('extract_i8', 'a@16', 0), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search1813_0 -> 521 in the cache */
   /* search1813_1_0 -> 526 in the cache */
   /* search1813_1_1 -> 856 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 526, 856 },
      -1,
   } },
   /* search1813_2 -> 488 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 521, 5127, 488 },
      5,
   } },

   /* replace1813_0 -> 521 in the cache */
   /* replace1813_1 -> 526 in the cache */
   /* replace1813_2 -> 488 in the cache */
   /* replace1813 -> 5098 in the cache */

   /* ('iadd(only_lower_8_bits_used)', ('i2i16', ('u2u8', 'a@16')), 'b') => ('iadd', 'a', 'b') */
   /* search1814_0_0_0 -> 11 in the cache */
   /* search1814_0_0 -> 2025 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 2025 },
      -1,
   } },
   /* search1814_1 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 5129, 258 },
      5,
   } },

   /* replace1814_0 -> 11 in the cache */
   /* replace1814_1 -> 258 in the cache */
   /* replace1814 -> 4068 in the cache */

   /* ('iadd(only_lower_8_bits_used)', ('i2i16', ('i2i8', 'a@16')), 'b') => ('iadd', 'a', 'b') */
   /* search1815_0_0_0 -> 11 in the cache */
   /* search1815_0_0 -> 4415 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 4415 },
      -1,
   } },
   /* search1815_1 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 5131, 258 },
      5,
   } },

   /* replace1815_0 -> 11 in the cache */
   /* replace1815_1 -> 258 in the cache */
   /* replace1815 -> 4068 in the cache */

   /* ('iadd(only_lower_8_bits_used)', ('extract_i8', 'a@16', 0), 'b') => ('iadd', 'a', 'b') */
   /* search1816_0_0 -> 11 in the cache */
   /* search1816_0_1 -> 856 in the cache */
   /* search1816_0 -> 3455 in the cache */
   /* search1816_1 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 3455, 258 },
      5,
   } },

   /* replace1816_0 -> 11 in the cache */
   /* replace1816_1 -> 258 in the cache */
   /* replace1816 -> 4068 in the cache */

   /* ('imul(only_lower_8_bits_used)', ('i2i16', ('u2u8', 'a@16')), 'b') => ('imul', 'a', 'b') */
   /* search1817_0_0_0 -> 11 in the cache */
   /* search1817_0_0 -> 2025 in the cache */
   /* search1817_0 -> 5129 in the cache */
   /* search1817_1 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 5129, 258 },
      5,
   } },

   /* replace1817_0 -> 11 in the cache */
   /* replace1817_1 -> 258 in the cache */
   /* replace1817 -> 5109 in the cache */

   /* ('imul(only_lower_8_bits_used)', ('i2i16', ('i2i8', 'a@16')), 'b') => ('imul', 'a', 'b') */
   /* search1818_0_0_0 -> 11 in the cache */
   /* search1818_0_0 -> 4415 in the cache */
   /* search1818_0 -> 5131 in the cache */
   /* search1818_1 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 5131, 258 },
      5,
   } },

   /* replace1818_0 -> 11 in the cache */
   /* replace1818_1 -> 258 in the cache */
   /* replace1818 -> 5109 in the cache */

   /* ('imul(only_lower_8_bits_used)', ('extract_i8', 'a@16', 0), 'b') => ('imul', 'a', 'b') */
   /* search1819_0_0 -> 11 in the cache */
   /* search1819_0_1 -> 856 in the cache */
   /* search1819_0 -> 3455 in the cache */
   /* search1819_1 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 3455, 258 },
      5,
   } },

   /* replace1819_0 -> 11 in the cache */
   /* replace1819_1 -> 258 in the cache */
   /* replace1819 -> 5109 in the cache */

   /* ('iand(only_lower_8_bits_used)', ('i2i16', ('u2u8', 'a@16')), 'b') => ('iand', 'a', 'b') */
   /* search1820_0_0_0 -> 11 in the cache */
   /* search1820_0_0 -> 2025 in the cache */
   /* search1820_0 -> 5129 in the cache */
   /* search1820_1 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 5129, 258 },
      5,
   } },

   /* replace1820_0 -> 11 in the cache */
   /* replace1820_1 -> 258 in the cache */
   /* replace1820 -> 2039 in the cache */

   /* ('iand(only_lower_8_bits_used)', ('i2i16', ('i2i8', 'a@16')), 'b') => ('iand', 'a', 'b') */
   /* search1821_0_0_0 -> 11 in the cache */
   /* search1821_0_0 -> 4415 in the cache */
   /* search1821_0 -> 5131 in the cache */
   /* search1821_1 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 5131, 258 },
      5,
   } },

   /* replace1821_0 -> 11 in the cache */
   /* replace1821_1 -> 258 in the cache */
   /* replace1821 -> 2039 in the cache */

   /* ('iand(only_lower_8_bits_used)', ('extract_i8', 'a@16', 0), 'b') => ('iand', 'a', 'b') */
   /* search1822_0_0 -> 11 in the cache */
   /* search1822_0_1 -> 856 in the cache */
   /* search1822_0 -> 3455 in the cache */
   /* search1822_1 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 3455, 258 },
      5,
   } },

   /* replace1822_0 -> 11 in the cache */
   /* replace1822_1 -> 258 in the cache */
   /* replace1822 -> 2039 in the cache */

   /* ('ior(only_lower_8_bits_used)', ('i2i16', ('u2u8', 'a@16')), 'b') => ('ior', 'a', 'b') */
   /* search1823_0_0_0 -> 11 in the cache */
   /* search1823_0_0 -> 2025 in the cache */
   /* search1823_0 -> 5129 in the cache */
   /* search1823_1 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 5129, 258 },
      5,
   } },

   /* replace1823_0 -> 11 in the cache */
   /* replace1823_1 -> 258 in the cache */
   /* replace1823 -> 2081 in the cache */

   /* ('ior(only_lower_8_bits_used)', ('i2i16', ('i2i8', 'a@16')), 'b') => ('ior', 'a', 'b') */
   /* search1824_0_0_0 -> 11 in the cache */
   /* search1824_0_0 -> 4415 in the cache */
   /* search1824_0 -> 5131 in the cache */
   /* search1824_1 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 5131, 258 },
      5,
   } },

   /* replace1824_0 -> 11 in the cache */
   /* replace1824_1 -> 258 in the cache */
   /* replace1824 -> 2081 in the cache */

   /* ('ior(only_lower_8_bits_used)', ('extract_i8', 'a@16', 0), 'b') => ('ior', 'a', 'b') */
   /* search1825_0_0 -> 11 in the cache */
   /* search1825_0_1 -> 856 in the cache */
   /* search1825_0 -> 3455 in the cache */
   /* search1825_1 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 3455, 258 },
      5,
   } },

   /* replace1825_0 -> 11 in the cache */
   /* replace1825_1 -> 258 in the cache */
   /* replace1825 -> 2081 in the cache */

   /* ('ixor(only_lower_8_bits_used)', ('i2i16', ('u2u8', 'a@16')), 'b') => ('ixor', 'a', 'b') */
   /* search1826_0_0_0 -> 11 in the cache */
   /* search1826_0_0 -> 2025 in the cache */
   /* search1826_0 -> 5129 in the cache */
   /* search1826_1 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 5129, 258 },
      5,
   } },

   /* replace1826_0 -> 11 in the cache */
   /* replace1826_1 -> 258 in the cache */
   /* replace1826 -> 2105 in the cache */

   /* ('ixor(only_lower_8_bits_used)', ('i2i16', ('i2i8', 'a@16')), 'b') => ('ixor', 'a', 'b') */
   /* search1827_0_0_0 -> 11 in the cache */
   /* search1827_0_0 -> 4415 in the cache */
   /* search1827_0 -> 5131 in the cache */
   /* search1827_1 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 5131, 258 },
      5,
   } },

   /* replace1827_0 -> 11 in the cache */
   /* replace1827_1 -> 258 in the cache */
   /* replace1827 -> 2105 in the cache */

   /* ('ixor(only_lower_8_bits_used)', ('extract_i8', 'a@16', 0), 'b') => ('ixor', 'a', 'b') */
   /* search1828_0_0 -> 11 in the cache */
   /* search1828_0_1 -> 856 in the cache */
   /* search1828_0 -> 3455 in the cache */
   /* search1828_1 -> 258 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 3455, 258 },
      5,
   } },

   /* replace1828_0 -> 11 in the cache */
   /* replace1828_1 -> 258 in the cache */
   /* replace1828 -> 2105 in the cache */

   /* ('u2u32(only_lower_8_bits_used)', ('u2u8', 'a@32')) => a */
   /* search1829_0_0 -> 16 in the cache */
   /* search1829_0 -> 2041 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 2041 },
      5,
   } },

   /* replace1829 -> 16 in the cache */

   /* ('extract_u8(only_lower_8_bits_used)', 'a@32', 0) => a */
   /* search1830_0 -> 16 in the cache */
   /* search1830_1 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 16, 122 },
      5,
   } },

   /* replace1830 -> 16 in the cache */

   /* ('bcsel(only_lower_8_bits_used)', 'c', ('u2u32', ('u2u8', 'a@32')), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search1831_0 -> 521 in the cache */
   /* search1831_1_0_0 -> 183 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 183 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 5148 },
      -1,
   } },
   /* search1831_2 -> 559 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 521, 5149, 559 },
      5,
   } },

   /* replace1831_0 -> 521 in the cache */
   /* replace1831_1 -> 183 in the cache */
   /* replace1831_2 -> 559 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 521, 183, 559 },
      -1,
   } },

   /* ('bcsel(only_lower_8_bits_used)', 'c', ('u2u32', ('i2i8', 'a@32')), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search1832_0 -> 521 in the cache */
   /* search1832_1_0_0 -> 183 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 183 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 5152 },
      -1,
   } },
   /* search1832_2 -> 559 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 521, 5153, 559 },
      5,
   } },

   /* replace1832_0 -> 521 in the cache */
   /* replace1832_1 -> 183 in the cache */
   /* replace1832_2 -> 559 in the cache */
   /* replace1832 -> 5151 in the cache */

   /* ('bcsel(only_lower_8_bits_used)', 'c', ('extract_u8', 'a@32', 0), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search1833_0 -> 521 in the cache */
   /* search1833_1_0 -> 183 in the cache */
   /* search1833_1_1 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 183, 122 },
      -1,
   } },
   /* search1833_2 -> 559 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 521, 5155, 559 },
      5,
   } },

   /* replace1833_0 -> 521 in the cache */
   /* replace1833_1 -> 183 in the cache */
   /* replace1833_2 -> 559 in the cache */
   /* replace1833 -> 5151 in the cache */

   /* ('iadd(only_lower_8_bits_used)', ('u2u32', ('u2u8', 'a@32')), 'b') => ('iadd', 'a', 'b') */
   /* search1834_0_0_0 -> 16 in the cache */
   /* search1834_0_0 -> 2041 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 2041 },
      -1,
   } },
   /* search1834_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 5157, 36 },
      5,
   } },

   /* replace1834_0 -> 16 in the cache */
   /* replace1834_1 -> 36 in the cache */
   /* replace1834 -> 4081 in the cache */

   /* ('iadd(only_lower_8_bits_used)', ('u2u32', ('i2i8', 'a@32')), 'b') => ('iadd', 'a', 'b') */
   /* search1835_0_0_0 -> 16 in the cache */
   /* search1835_0_0 -> 4367 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 4367 },
      -1,
   } },
   /* search1835_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 5159, 36 },
      5,
   } },

   /* replace1835_0 -> 16 in the cache */
   /* replace1835_1 -> 36 in the cache */
   /* replace1835 -> 4081 in the cache */

   /* ('iadd(only_lower_8_bits_used)', ('extract_u8', 'a@32', 0), 'b') => ('iadd', 'a', 'b') */
   /* search1836_0_0 -> 16 in the cache */
   /* search1836_0_1 -> 122 in the cache */
   /* search1836_0 -> 412 in the cache */
   /* search1836_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 412, 36 },
      5,
   } },

   /* replace1836_0 -> 16 in the cache */
   /* replace1836_1 -> 36 in the cache */
   /* replace1836 -> 4081 in the cache */

   /* ('imul(only_lower_8_bits_used)', ('u2u32', ('u2u8', 'a@32')), 'b') => ('imul', 'a', 'b') */
   /* search1837_0_0_0 -> 16 in the cache */
   /* search1837_0_0 -> 2041 in the cache */
   /* search1837_0 -> 5157 in the cache */
   /* search1837_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 5157, 36 },
      5,
   } },

   /* replace1837_0 -> 16 in the cache */
   /* replace1837_1 -> 36 in the cache */
   /* replace1837 -> 49 in the cache */

   /* ('imul(only_lower_8_bits_used)', ('u2u32', ('i2i8', 'a@32')), 'b') => ('imul', 'a', 'b') */
   /* search1838_0_0_0 -> 16 in the cache */
   /* search1838_0_0 -> 4367 in the cache */
   /* search1838_0 -> 5159 in the cache */
   /* search1838_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 5159, 36 },
      5,
   } },

   /* replace1838_0 -> 16 in the cache */
   /* replace1838_1 -> 36 in the cache */
   /* replace1838 -> 49 in the cache */

   /* ('imul(only_lower_8_bits_used)', ('extract_u8', 'a@32', 0), 'b') => ('imul', 'a', 'b') */
   /* search1839_0_0 -> 16 in the cache */
   /* search1839_0_1 -> 122 in the cache */
   /* search1839_0 -> 412 in the cache */
   /* search1839_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 412, 36 },
      5,
   } },

   /* replace1839_0 -> 16 in the cache */
   /* replace1839_1 -> 36 in the cache */
   /* replace1839 -> 49 in the cache */

   /* ('iand(only_lower_8_bits_used)', ('u2u32', ('u2u8', 'a@32')), 'b') => ('iand', 'a', 'b') */
   /* search1840_0_0_0 -> 16 in the cache */
   /* search1840_0_0 -> 2041 in the cache */
   /* search1840_0 -> 5157 in the cache */
   /* search1840_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 5157, 36 },
      5,
   } },

   /* replace1840_0 -> 16 in the cache */
   /* replace1840_1 -> 36 in the cache */
   /* replace1840 -> 2047 in the cache */

   /* ('iand(only_lower_8_bits_used)', ('u2u32', ('i2i8', 'a@32')), 'b') => ('iand', 'a', 'b') */
   /* search1841_0_0_0 -> 16 in the cache */
   /* search1841_0_0 -> 4367 in the cache */
   /* search1841_0 -> 5159 in the cache */
   /* search1841_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 5159, 36 },
      5,
   } },

   /* replace1841_0 -> 16 in the cache */
   /* replace1841_1 -> 36 in the cache */
   /* replace1841 -> 2047 in the cache */

   /* ('iand(only_lower_8_bits_used)', ('extract_u8', 'a@32', 0), 'b') => ('iand', 'a', 'b') */
   /* search1842_0_0 -> 16 in the cache */
   /* search1842_0_1 -> 122 in the cache */
   /* search1842_0 -> 412 in the cache */
   /* search1842_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 412, 36 },
      5,
   } },

   /* replace1842_0 -> 16 in the cache */
   /* replace1842_1 -> 36 in the cache */
   /* replace1842 -> 2047 in the cache */

   /* ('ior(only_lower_8_bits_used)', ('u2u32', ('u2u8', 'a@32')), 'b') => ('ior', 'a', 'b') */
   /* search1843_0_0_0 -> 16 in the cache */
   /* search1843_0_0 -> 2041 in the cache */
   /* search1843_0 -> 5157 in the cache */
   /* search1843_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 5157, 36 },
      5,
   } },

   /* replace1843_0 -> 16 in the cache */
   /* replace1843_1 -> 36 in the cache */
   /* replace1843 -> 2085 in the cache */

   /* ('ior(only_lower_8_bits_used)', ('u2u32', ('i2i8', 'a@32')), 'b') => ('ior', 'a', 'b') */
   /* search1844_0_0_0 -> 16 in the cache */
   /* search1844_0_0 -> 4367 in the cache */
   /* search1844_0 -> 5159 in the cache */
   /* search1844_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 5159, 36 },
      5,
   } },

   /* replace1844_0 -> 16 in the cache */
   /* replace1844_1 -> 36 in the cache */
   /* replace1844 -> 2085 in the cache */

   /* ('ior(only_lower_8_bits_used)', ('extract_u8', 'a@32', 0), 'b') => ('ior', 'a', 'b') */
   /* search1845_0_0 -> 16 in the cache */
   /* search1845_0_1 -> 122 in the cache */
   /* search1845_0 -> 412 in the cache */
   /* search1845_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 412, 36 },
      5,
   } },

   /* replace1845_0 -> 16 in the cache */
   /* replace1845_1 -> 36 in the cache */
   /* replace1845 -> 2085 in the cache */

   /* ('ixor(only_lower_8_bits_used)', ('u2u32', ('u2u8', 'a@32')), 'b') => ('ixor', 'a', 'b') */
   /* search1846_0_0_0 -> 16 in the cache */
   /* search1846_0_0 -> 2041 in the cache */
   /* search1846_0 -> 5157 in the cache */
   /* search1846_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 5157, 36 },
      5,
   } },

   /* replace1846_0 -> 16 in the cache */
   /* replace1846_1 -> 36 in the cache */
   /* replace1846 -> 2109 in the cache */

   /* ('ixor(only_lower_8_bits_used)', ('u2u32', ('i2i8', 'a@32')), 'b') => ('ixor', 'a', 'b') */
   /* search1847_0_0_0 -> 16 in the cache */
   /* search1847_0_0 -> 4367 in the cache */
   /* search1847_0 -> 5159 in the cache */
   /* search1847_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 5159, 36 },
      5,
   } },

   /* replace1847_0 -> 16 in the cache */
   /* replace1847_1 -> 36 in the cache */
   /* replace1847 -> 2109 in the cache */

   /* ('ixor(only_lower_8_bits_used)', ('extract_u8', 'a@32', 0), 'b') => ('ixor', 'a', 'b') */
   /* search1848_0_0 -> 16 in the cache */
   /* search1848_0_1 -> 122 in the cache */
   /* search1848_0 -> 412 in the cache */
   /* search1848_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 412, 36 },
      5,
   } },

   /* replace1848_0 -> 16 in the cache */
   /* replace1848_1 -> 36 in the cache */
   /* replace1848 -> 2109 in the cache */

   /* ('i2i32(only_lower_8_bits_used)', ('u2u8', 'a@32')) => a */
   /* search1849_0_0 -> 16 in the cache */
   /* search1849_0 -> 2041 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 2041 },
      5,
   } },

   /* replace1849 -> 16 in the cache */

   /* ('extract_i8(only_lower_8_bits_used)', 'a@32', 0) => a */
   /* search1850_0 -> 16 in the cache */
   /* search1850_1 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 16, 122 },
      5,
   } },

   /* replace1850 -> 16 in the cache */

   /* ('bcsel(only_lower_8_bits_used)', 'c', ('i2i32', ('u2u8', 'a@32')), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search1851_0 -> 521 in the cache */
   /* search1851_1_0_0 -> 183 in the cache */
   /* search1851_1_0 -> 5148 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 5148 },
      -1,
   } },
   /* search1851_2 -> 559 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 521, 5176, 559 },
      5,
   } },

   /* replace1851_0 -> 521 in the cache */
   /* replace1851_1 -> 183 in the cache */
   /* replace1851_2 -> 559 in the cache */
   /* replace1851 -> 5151 in the cache */

   /* ('bcsel(only_lower_8_bits_used)', 'c', ('i2i32', ('i2i8', 'a@32')), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search1852_0 -> 521 in the cache */
   /* search1852_1_0_0 -> 183 in the cache */
   /* search1852_1_0 -> 5152 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 5152 },
      -1,
   } },
   /* search1852_2 -> 559 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 521, 5178, 559 },
      5,
   } },

   /* replace1852_0 -> 521 in the cache */
   /* replace1852_1 -> 183 in the cache */
   /* replace1852_2 -> 559 in the cache */
   /* replace1852 -> 5151 in the cache */

   /* ('bcsel(only_lower_8_bits_used)', 'c', ('extract_i8', 'a@32', 0), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search1853_0 -> 521 in the cache */
   /* search1853_1_0 -> 183 in the cache */
   /* search1853_1_1 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 183, 122 },
      -1,
   } },
   /* search1853_2 -> 559 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 521, 5180, 559 },
      5,
   } },

   /* replace1853_0 -> 521 in the cache */
   /* replace1853_1 -> 183 in the cache */
   /* replace1853_2 -> 559 in the cache */
   /* replace1853 -> 5151 in the cache */

   /* ('iadd(only_lower_8_bits_used)', ('i2i32', ('u2u8', 'a@32')), 'b') => ('iadd', 'a', 'b') */
   /* search1854_0_0_0 -> 16 in the cache */
   /* search1854_0_0 -> 2041 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 2041 },
      -1,
   } },
   /* search1854_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 5182, 36 },
      5,
   } },

   /* replace1854_0 -> 16 in the cache */
   /* replace1854_1 -> 36 in the cache */
   /* replace1854 -> 4081 in the cache */

   /* ('iadd(only_lower_8_bits_used)', ('i2i32', ('i2i8', 'a@32')), 'b') => ('iadd', 'a', 'b') */
   /* search1855_0_0_0 -> 16 in the cache */
   /* search1855_0_0 -> 4367 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 4367 },
      -1,
   } },
   /* search1855_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 5184, 36 },
      5,
   } },

   /* replace1855_0 -> 16 in the cache */
   /* replace1855_1 -> 36 in the cache */
   /* replace1855 -> 4081 in the cache */

   /* ('iadd(only_lower_8_bits_used)', ('extract_i8', 'a@32', 0), 'b') => ('iadd', 'a', 'b') */
   /* search1856_0_0 -> 16 in the cache */
   /* search1856_0_1 -> 122 in the cache */
   /* search1856_0 -> 393 in the cache */
   /* search1856_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 393, 36 },
      5,
   } },

   /* replace1856_0 -> 16 in the cache */
   /* replace1856_1 -> 36 in the cache */
   /* replace1856 -> 4081 in the cache */

   /* ('imul(only_lower_8_bits_used)', ('i2i32', ('u2u8', 'a@32')), 'b') => ('imul', 'a', 'b') */
   /* search1857_0_0_0 -> 16 in the cache */
   /* search1857_0_0 -> 2041 in the cache */
   /* search1857_0 -> 5182 in the cache */
   /* search1857_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 5182, 36 },
      5,
   } },

   /* replace1857_0 -> 16 in the cache */
   /* replace1857_1 -> 36 in the cache */
   /* replace1857 -> 49 in the cache */

   /* ('imul(only_lower_8_bits_used)', ('i2i32', ('i2i8', 'a@32')), 'b') => ('imul', 'a', 'b') */
   /* search1858_0_0_0 -> 16 in the cache */
   /* search1858_0_0 -> 4367 in the cache */
   /* search1858_0 -> 5184 in the cache */
   /* search1858_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 5184, 36 },
      5,
   } },

   /* replace1858_0 -> 16 in the cache */
   /* replace1858_1 -> 36 in the cache */
   /* replace1858 -> 49 in the cache */

   /* ('imul(only_lower_8_bits_used)', ('extract_i8', 'a@32', 0), 'b') => ('imul', 'a', 'b') */
   /* search1859_0_0 -> 16 in the cache */
   /* search1859_0_1 -> 122 in the cache */
   /* search1859_0 -> 393 in the cache */
   /* search1859_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 393, 36 },
      5,
   } },

   /* replace1859_0 -> 16 in the cache */
   /* replace1859_1 -> 36 in the cache */
   /* replace1859 -> 49 in the cache */

   /* ('iand(only_lower_8_bits_used)', ('i2i32', ('u2u8', 'a@32')), 'b') => ('iand', 'a', 'b') */
   /* search1860_0_0_0 -> 16 in the cache */
   /* search1860_0_0 -> 2041 in the cache */
   /* search1860_0 -> 5182 in the cache */
   /* search1860_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 5182, 36 },
      5,
   } },

   /* replace1860_0 -> 16 in the cache */
   /* replace1860_1 -> 36 in the cache */
   /* replace1860 -> 2047 in the cache */

   /* ('iand(only_lower_8_bits_used)', ('i2i32', ('i2i8', 'a@32')), 'b') => ('iand', 'a', 'b') */
   /* search1861_0_0_0 -> 16 in the cache */
   /* search1861_0_0 -> 4367 in the cache */
   /* search1861_0 -> 5184 in the cache */
   /* search1861_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 5184, 36 },
      5,
   } },

   /* replace1861_0 -> 16 in the cache */
   /* replace1861_1 -> 36 in the cache */
   /* replace1861 -> 2047 in the cache */

   /* ('iand(only_lower_8_bits_used)', ('extract_i8', 'a@32', 0), 'b') => ('iand', 'a', 'b') */
   /* search1862_0_0 -> 16 in the cache */
   /* search1862_0_1 -> 122 in the cache */
   /* search1862_0 -> 393 in the cache */
   /* search1862_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 393, 36 },
      5,
   } },

   /* replace1862_0 -> 16 in the cache */
   /* replace1862_1 -> 36 in the cache */
   /* replace1862 -> 2047 in the cache */

   /* ('ior(only_lower_8_bits_used)', ('i2i32', ('u2u8', 'a@32')), 'b') => ('ior', 'a', 'b') */
   /* search1863_0_0_0 -> 16 in the cache */
   /* search1863_0_0 -> 2041 in the cache */
   /* search1863_0 -> 5182 in the cache */
   /* search1863_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 5182, 36 },
      5,
   } },

   /* replace1863_0 -> 16 in the cache */
   /* replace1863_1 -> 36 in the cache */
   /* replace1863 -> 2085 in the cache */

   /* ('ior(only_lower_8_bits_used)', ('i2i32', ('i2i8', 'a@32')), 'b') => ('ior', 'a', 'b') */
   /* search1864_0_0_0 -> 16 in the cache */
   /* search1864_0_0 -> 4367 in the cache */
   /* search1864_0 -> 5184 in the cache */
   /* search1864_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 5184, 36 },
      5,
   } },

   /* replace1864_0 -> 16 in the cache */
   /* replace1864_1 -> 36 in the cache */
   /* replace1864 -> 2085 in the cache */

   /* ('ior(only_lower_8_bits_used)', ('extract_i8', 'a@32', 0), 'b') => ('ior', 'a', 'b') */
   /* search1865_0_0 -> 16 in the cache */
   /* search1865_0_1 -> 122 in the cache */
   /* search1865_0 -> 393 in the cache */
   /* search1865_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 393, 36 },
      5,
   } },

   /* replace1865_0 -> 16 in the cache */
   /* replace1865_1 -> 36 in the cache */
   /* replace1865 -> 2085 in the cache */

   /* ('ixor(only_lower_8_bits_used)', ('i2i32', ('u2u8', 'a@32')), 'b') => ('ixor', 'a', 'b') */
   /* search1866_0_0_0 -> 16 in the cache */
   /* search1866_0_0 -> 2041 in the cache */
   /* search1866_0 -> 5182 in the cache */
   /* search1866_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 5182, 36 },
      5,
   } },

   /* replace1866_0 -> 16 in the cache */
   /* replace1866_1 -> 36 in the cache */
   /* replace1866 -> 2109 in the cache */

   /* ('ixor(only_lower_8_bits_used)', ('i2i32', ('i2i8', 'a@32')), 'b') => ('ixor', 'a', 'b') */
   /* search1867_0_0_0 -> 16 in the cache */
   /* search1867_0_0 -> 4367 in the cache */
   /* search1867_0 -> 5184 in the cache */
   /* search1867_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 5184, 36 },
      5,
   } },

   /* replace1867_0 -> 16 in the cache */
   /* replace1867_1 -> 36 in the cache */
   /* replace1867 -> 2109 in the cache */

   /* ('ixor(only_lower_8_bits_used)', ('extract_i8', 'a@32', 0), 'b') => ('ixor', 'a', 'b') */
   /* search1868_0_0 -> 16 in the cache */
   /* search1868_0_1 -> 122 in the cache */
   /* search1868_0 -> 393 in the cache */
   /* search1868_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 393, 36 },
      5,
   } },

   /* replace1868_0 -> 16 in the cache */
   /* replace1868_1 -> 36 in the cache */
   /* replace1868 -> 2109 in the cache */

   /* ('u2u32(only_lower_16_bits_used)', ('u2u16', 'a@32')) => a */
   /* search1869_0_0 -> 16 in the cache */
   /* search1869_0 -> 3326 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 3326 },
      6,
   } },

   /* replace1869 -> 16 in the cache */

   /* ('extract_u16(only_lower_16_bits_used)', 'a@32', 0) => a */
   /* search1870_0 -> 16 in the cache */
   /* search1870_1 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 0,
      { 16, 122 },
      6,
   } },

   /* replace1870 -> 16 in the cache */

   /* ('bcsel(only_lower_16_bits_used)', 'c', ('u2u32', ('u2u16', 'a@32')), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search1871_0 -> 521 in the cache */
   /* search1871_1_0_0 -> 183 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 183 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 5201 },
      -1,
   } },
   /* search1871_2 -> 559 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 521, 5202, 559 },
      6,
   } },

   /* replace1871_0 -> 521 in the cache */
   /* replace1871_1 -> 183 in the cache */
   /* replace1871_2 -> 559 in the cache */
   /* replace1871 -> 5151 in the cache */

   /* ('bcsel(only_lower_16_bits_used)', 'c', ('u2u32', ('i2i16', 'a@32')), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search1872_0 -> 521 in the cache */
   /* search1872_1_0_0 -> 183 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 183 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 5204 },
      -1,
   } },
   /* search1872_2 -> 559 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 521, 5205, 559 },
      6,
   } },

   /* replace1872_0 -> 521 in the cache */
   /* replace1872_1 -> 183 in the cache */
   /* replace1872_2 -> 559 in the cache */
   /* replace1872 -> 5151 in the cache */

   /* ('bcsel(only_lower_16_bits_used)', 'c', ('extract_u16', 'a@32', 0), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search1873_0 -> 521 in the cache */
   /* search1873_1_0 -> 183 in the cache */
   /* search1873_1_1 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 0,
      { 183, 122 },
      -1,
   } },
   /* search1873_2 -> 559 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 521, 5207, 559 },
      6,
   } },

   /* replace1873_0 -> 521 in the cache */
   /* replace1873_1 -> 183 in the cache */
   /* replace1873_2 -> 559 in the cache */
   /* replace1873 -> 5151 in the cache */

   /* ('iadd(only_lower_16_bits_used)', ('u2u32', ('u2u16', 'a@32')), 'b') => ('iadd', 'a', 'b') */
   /* search1874_0_0_0 -> 16 in the cache */
   /* search1874_0_0 -> 3326 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 3326 },
      -1,
   } },
   /* search1874_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 5209, 36 },
      6,
   } },

   /* replace1874_0 -> 16 in the cache */
   /* replace1874_1 -> 36 in the cache */
   /* replace1874 -> 4081 in the cache */

   /* ('iadd(only_lower_16_bits_used)', ('u2u32', ('i2i16', 'a@32')), 'b') => ('iadd', 'a', 'b') */
   /* search1875_0_0_0 -> 16 in the cache */
   /* search1875_0_0 -> 4369 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 4369 },
      -1,
   } },
   /* search1875_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 5211, 36 },
      6,
   } },

   /* replace1875_0 -> 16 in the cache */
   /* replace1875_1 -> 36 in the cache */
   /* replace1875 -> 4081 in the cache */

   /* ('iadd(only_lower_16_bits_used)', ('extract_u16', 'a@32', 0), 'b') => ('iadd', 'a', 'b') */
   /* search1876_0_0 -> 16 in the cache */
   /* search1876_0_1 -> 122 in the cache */
   /* search1876_0 -> 444 in the cache */
   /* search1876_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 444, 36 },
      6,
   } },

   /* replace1876_0 -> 16 in the cache */
   /* replace1876_1 -> 36 in the cache */
   /* replace1876 -> 4081 in the cache */

   /* ('imul(only_lower_16_bits_used)', ('u2u32', ('u2u16', 'a@32')), 'b') => ('imul', 'a', 'b') */
   /* search1877_0_0_0 -> 16 in the cache */
   /* search1877_0_0 -> 3326 in the cache */
   /* search1877_0 -> 5209 in the cache */
   /* search1877_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 5209, 36 },
      6,
   } },

   /* replace1877_0 -> 16 in the cache */
   /* replace1877_1 -> 36 in the cache */
   /* replace1877 -> 49 in the cache */

   /* ('imul(only_lower_16_bits_used)', ('u2u32', ('i2i16', 'a@32')), 'b') => ('imul', 'a', 'b') */
   /* search1878_0_0_0 -> 16 in the cache */
   /* search1878_0_0 -> 4369 in the cache */
   /* search1878_0 -> 5211 in the cache */
   /* search1878_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 5211, 36 },
      6,
   } },

   /* replace1878_0 -> 16 in the cache */
   /* replace1878_1 -> 36 in the cache */
   /* replace1878 -> 49 in the cache */

   /* ('imul(only_lower_16_bits_used)', ('extract_u16', 'a@32', 0), 'b') => ('imul', 'a', 'b') */
   /* search1879_0_0 -> 16 in the cache */
   /* search1879_0_1 -> 122 in the cache */
   /* search1879_0 -> 444 in the cache */
   /* search1879_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 444, 36 },
      6,
   } },

   /* replace1879_0 -> 16 in the cache */
   /* replace1879_1 -> 36 in the cache */
   /* replace1879 -> 49 in the cache */

   /* ('iand(only_lower_16_bits_used)', ('u2u32', ('u2u16', 'a@32')), 'b') => ('iand', 'a', 'b') */
   /* search1880_0_0_0 -> 16 in the cache */
   /* search1880_0_0 -> 3326 in the cache */
   /* search1880_0 -> 5209 in the cache */
   /* search1880_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 5209, 36 },
      6,
   } },

   /* replace1880_0 -> 16 in the cache */
   /* replace1880_1 -> 36 in the cache */
   /* replace1880 -> 2047 in the cache */

   /* ('iand(only_lower_16_bits_used)', ('u2u32', ('i2i16', 'a@32')), 'b') => ('iand', 'a', 'b') */
   /* search1881_0_0_0 -> 16 in the cache */
   /* search1881_0_0 -> 4369 in the cache */
   /* search1881_0 -> 5211 in the cache */
   /* search1881_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 5211, 36 },
      6,
   } },

   /* replace1881_0 -> 16 in the cache */
   /* replace1881_1 -> 36 in the cache */
   /* replace1881 -> 2047 in the cache */

   /* ('iand(only_lower_16_bits_used)', ('extract_u16', 'a@32', 0), 'b') => ('iand', 'a', 'b') */
   /* search1882_0_0 -> 16 in the cache */
   /* search1882_0_1 -> 122 in the cache */
   /* search1882_0 -> 444 in the cache */
   /* search1882_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 444, 36 },
      6,
   } },

   /* replace1882_0 -> 16 in the cache */
   /* replace1882_1 -> 36 in the cache */
   /* replace1882 -> 2047 in the cache */

   /* ('ior(only_lower_16_bits_used)', ('u2u32', ('u2u16', 'a@32')), 'b') => ('ior', 'a', 'b') */
   /* search1883_0_0_0 -> 16 in the cache */
   /* search1883_0_0 -> 3326 in the cache */
   /* search1883_0 -> 5209 in the cache */
   /* search1883_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 5209, 36 },
      6,
   } },

   /* replace1883_0 -> 16 in the cache */
   /* replace1883_1 -> 36 in the cache */
   /* replace1883 -> 2085 in the cache */

   /* ('ior(only_lower_16_bits_used)', ('u2u32', ('i2i16', 'a@32')), 'b') => ('ior', 'a', 'b') */
   /* search1884_0_0_0 -> 16 in the cache */
   /* search1884_0_0 -> 4369 in the cache */
   /* search1884_0 -> 5211 in the cache */
   /* search1884_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 5211, 36 },
      6,
   } },

   /* replace1884_0 -> 16 in the cache */
   /* replace1884_1 -> 36 in the cache */
   /* replace1884 -> 2085 in the cache */

   /* ('ior(only_lower_16_bits_used)', ('extract_u16', 'a@32', 0), 'b') => ('ior', 'a', 'b') */
   /* search1885_0_0 -> 16 in the cache */
   /* search1885_0_1 -> 122 in the cache */
   /* search1885_0 -> 444 in the cache */
   /* search1885_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 444, 36 },
      6,
   } },

   /* replace1885_0 -> 16 in the cache */
   /* replace1885_1 -> 36 in the cache */
   /* replace1885 -> 2085 in the cache */

   /* ('ixor(only_lower_16_bits_used)', ('u2u32', ('u2u16', 'a@32')), 'b') => ('ixor', 'a', 'b') */
   /* search1886_0_0_0 -> 16 in the cache */
   /* search1886_0_0 -> 3326 in the cache */
   /* search1886_0 -> 5209 in the cache */
   /* search1886_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 5209, 36 },
      6,
   } },

   /* replace1886_0 -> 16 in the cache */
   /* replace1886_1 -> 36 in the cache */
   /* replace1886 -> 2109 in the cache */

   /* ('ixor(only_lower_16_bits_used)', ('u2u32', ('i2i16', 'a@32')), 'b') => ('ixor', 'a', 'b') */
   /* search1887_0_0_0 -> 16 in the cache */
   /* search1887_0_0 -> 4369 in the cache */
   /* search1887_0 -> 5211 in the cache */
   /* search1887_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 5211, 36 },
      6,
   } },

   /* replace1887_0 -> 16 in the cache */
   /* replace1887_1 -> 36 in the cache */
   /* replace1887 -> 2109 in the cache */

   /* ('ixor(only_lower_16_bits_used)', ('extract_u16', 'a@32', 0), 'b') => ('ixor', 'a', 'b') */
   /* search1888_0_0 -> 16 in the cache */
   /* search1888_0_1 -> 122 in the cache */
   /* search1888_0 -> 444 in the cache */
   /* search1888_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 444, 36 },
      6,
   } },

   /* replace1888_0 -> 16 in the cache */
   /* replace1888_1 -> 36 in the cache */
   /* replace1888 -> 2109 in the cache */

   /* ('i2i32(only_lower_16_bits_used)', ('u2u16', 'a@32')) => a */
   /* search1889_0_0 -> 16 in the cache */
   /* search1889_0 -> 3326 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 3326 },
      6,
   } },

   /* replace1889 -> 16 in the cache */

   /* ('extract_i16(only_lower_16_bits_used)', 'a@32', 0) => a */
   /* search1890_0 -> 16 in the cache */
   /* search1890_1 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i16,
      -1, 0,
      { 16, 122 },
      6,
   } },

   /* replace1890 -> 16 in the cache */

   /* ('bcsel(only_lower_16_bits_used)', 'c', ('i2i32', ('u2u16', 'a@32')), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search1891_0 -> 521 in the cache */
   /* search1891_1_0_0 -> 183 in the cache */
   /* search1891_1_0 -> 5201 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 5201 },
      -1,
   } },
   /* search1891_2 -> 559 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 521, 5228, 559 },
      6,
   } },

   /* replace1891_0 -> 521 in the cache */
   /* replace1891_1 -> 183 in the cache */
   /* replace1891_2 -> 559 in the cache */
   /* replace1891 -> 5151 in the cache */

   /* ('bcsel(only_lower_16_bits_used)', 'c', ('i2i32', ('i2i16', 'a@32')), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search1892_0 -> 521 in the cache */
   /* search1892_1_0_0 -> 183 in the cache */
   /* search1892_1_0 -> 5204 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 5204 },
      -1,
   } },
   /* search1892_2 -> 559 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 521, 5230, 559 },
      6,
   } },

   /* replace1892_0 -> 521 in the cache */
   /* replace1892_1 -> 183 in the cache */
   /* replace1892_2 -> 559 in the cache */
   /* replace1892 -> 5151 in the cache */

   /* ('bcsel(only_lower_16_bits_used)', 'c', ('extract_i16', 'a@32', 0), 'b') => ('bcsel', 'c', 'a', 'b') */
   /* search1893_0 -> 521 in the cache */
   /* search1893_1_0 -> 183 in the cache */
   /* search1893_1_1 -> 122 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i16,
      -1, 0,
      { 183, 122 },
      -1,
   } },
   /* search1893_2 -> 559 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 521, 5232, 559 },
      6,
   } },

   /* replace1893_0 -> 521 in the cache */
   /* replace1893_1 -> 183 in the cache */
   /* replace1893_2 -> 559 in the cache */
   /* replace1893 -> 5151 in the cache */

   /* ('iadd(only_lower_16_bits_used)', ('i2i32', ('u2u16', 'a@32')), 'b') => ('iadd', 'a', 'b') */
   /* search1894_0_0_0 -> 16 in the cache */
   /* search1894_0_0 -> 3326 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 3326 },
      -1,
   } },
   /* search1894_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 5234, 36 },
      6,
   } },

   /* replace1894_0 -> 16 in the cache */
   /* replace1894_1 -> 36 in the cache */
   /* replace1894 -> 4081 in the cache */

   /* ('iadd(only_lower_16_bits_used)', ('i2i32', ('i2i16', 'a@32')), 'b') => ('iadd', 'a', 'b') */
   /* search1895_0_0_0 -> 16 in the cache */
   /* search1895_0_0 -> 4369 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 4369 },
      -1,
   } },
   /* search1895_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 5236, 36 },
      6,
   } },

   /* replace1895_0 -> 16 in the cache */
   /* replace1895_1 -> 36 in the cache */
   /* replace1895 -> 4081 in the cache */

   /* ('iadd(only_lower_16_bits_used)', ('extract_i16', 'a@32', 0), 'b') => ('iadd', 'a', 'b') */
   /* search1896_0_0 -> 16 in the cache */
   /* search1896_0_1 -> 122 in the cache */
   /* search1896_0 -> 436 in the cache */
   /* search1896_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 436, 36 },
      6,
   } },

   /* replace1896_0 -> 16 in the cache */
   /* replace1896_1 -> 36 in the cache */
   /* replace1896 -> 4081 in the cache */

   /* ('imul(only_lower_16_bits_used)', ('i2i32', ('u2u16', 'a@32')), 'b') => ('imul', 'a', 'b') */
   /* search1897_0_0_0 -> 16 in the cache */
   /* search1897_0_0 -> 3326 in the cache */
   /* search1897_0 -> 5234 in the cache */
   /* search1897_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 5234, 36 },
      6,
   } },

   /* replace1897_0 -> 16 in the cache */
   /* replace1897_1 -> 36 in the cache */
   /* replace1897 -> 49 in the cache */

   /* ('imul(only_lower_16_bits_used)', ('i2i32', ('i2i16', 'a@32')), 'b') => ('imul', 'a', 'b') */
   /* search1898_0_0_0 -> 16 in the cache */
   /* search1898_0_0 -> 4369 in the cache */
   /* search1898_0 -> 5236 in the cache */
   /* search1898_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 5236, 36 },
      6,
   } },

   /* replace1898_0 -> 16 in the cache */
   /* replace1898_1 -> 36 in the cache */
   /* replace1898 -> 49 in the cache */

   /* ('imul(only_lower_16_bits_used)', ('extract_i16', 'a@32', 0), 'b') => ('imul', 'a', 'b') */
   /* search1899_0_0 -> 16 in the cache */
   /* search1899_0_1 -> 122 in the cache */
   /* search1899_0 -> 436 in the cache */
   /* search1899_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 436, 36 },
      6,
   } },

   /* replace1899_0 -> 16 in the cache */
   /* replace1899_1 -> 36 in the cache */
   /* replace1899 -> 49 in the cache */

   /* ('iand(only_lower_16_bits_used)', ('i2i32', ('u2u16', 'a@32')), 'b') => ('iand', 'a', 'b') */
   /* search1900_0_0_0 -> 16 in the cache */
   /* search1900_0_0 -> 3326 in the cache */
   /* search1900_0 -> 5234 in the cache */
   /* search1900_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 5234, 36 },
      6,
   } },

   /* replace1900_0 -> 16 in the cache */
   /* replace1900_1 -> 36 in the cache */
   /* replace1900 -> 2047 in the cache */

   /* ('iand(only_lower_16_bits_used)', ('i2i32', ('i2i16', 'a@32')), 'b') => ('iand', 'a', 'b') */
   /* search1901_0_0_0 -> 16 in the cache */
   /* search1901_0_0 -> 4369 in the cache */
   /* search1901_0 -> 5236 in the cache */
   /* search1901_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 5236, 36 },
      6,
   } },

   /* replace1901_0 -> 16 in the cache */
   /* replace1901_1 -> 36 in the cache */
   /* replace1901 -> 2047 in the cache */

   /* ('iand(only_lower_16_bits_used)', ('extract_i16', 'a@32', 0), 'b') => ('iand', 'a', 'b') */
   /* search1902_0_0 -> 16 in the cache */
   /* search1902_0_1 -> 122 in the cache */
   /* search1902_0 -> 436 in the cache */
   /* search1902_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 436, 36 },
      6,
   } },

   /* replace1902_0 -> 16 in the cache */
   /* replace1902_1 -> 36 in the cache */
   /* replace1902 -> 2047 in the cache */

   /* ('ior(only_lower_16_bits_used)', ('i2i32', ('u2u16', 'a@32')), 'b') => ('ior', 'a', 'b') */
   /* search1903_0_0_0 -> 16 in the cache */
   /* search1903_0_0 -> 3326 in the cache */
   /* search1903_0 -> 5234 in the cache */
   /* search1903_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 5234, 36 },
      6,
   } },

   /* replace1903_0 -> 16 in the cache */
   /* replace1903_1 -> 36 in the cache */
   /* replace1903 -> 2085 in the cache */

   /* ('ior(only_lower_16_bits_used)', ('i2i32', ('i2i16', 'a@32')), 'b') => ('ior', 'a', 'b') */
   /* search1904_0_0_0 -> 16 in the cache */
   /* search1904_0_0 -> 4369 in the cache */
   /* search1904_0 -> 5236 in the cache */
   /* search1904_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 5236, 36 },
      6,
   } },

   /* replace1904_0 -> 16 in the cache */
   /* replace1904_1 -> 36 in the cache */
   /* replace1904 -> 2085 in the cache */

   /* ('ior(only_lower_16_bits_used)', ('extract_i16', 'a@32', 0), 'b') => ('ior', 'a', 'b') */
   /* search1905_0_0 -> 16 in the cache */
   /* search1905_0_1 -> 122 in the cache */
   /* search1905_0 -> 436 in the cache */
   /* search1905_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 436, 36 },
      6,
   } },

   /* replace1905_0 -> 16 in the cache */
   /* replace1905_1 -> 36 in the cache */
   /* replace1905 -> 2085 in the cache */

   /* ('ixor(only_lower_16_bits_used)', ('i2i32', ('u2u16', 'a@32')), 'b') => ('ixor', 'a', 'b') */
   /* search1906_0_0_0 -> 16 in the cache */
   /* search1906_0_0 -> 3326 in the cache */
   /* search1906_0 -> 5234 in the cache */
   /* search1906_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 5234, 36 },
      6,
   } },

   /* replace1906_0 -> 16 in the cache */
   /* replace1906_1 -> 36 in the cache */
   /* replace1906 -> 2109 in the cache */

   /* ('ixor(only_lower_16_bits_used)', ('i2i32', ('i2i16', 'a@32')), 'b') => ('ixor', 'a', 'b') */
   /* search1907_0_0_0 -> 16 in the cache */
   /* search1907_0_0 -> 4369 in the cache */
   /* search1907_0 -> 5236 in the cache */
   /* search1907_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 5236, 36 },
      6,
   } },

   /* replace1907_0 -> 16 in the cache */
   /* replace1907_1 -> 36 in the cache */
   /* replace1907 -> 2109 in the cache */

   /* ('ixor(only_lower_16_bits_used)', ('extract_i16', 'a@32', 0), 'b') => ('ixor', 'a', 'b') */
   /* search1908_0_0 -> 16 in the cache */
   /* search1908_0_1 -> 122 in the cache */
   /* search1908_0 -> 436 in the cache */
   /* search1908_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 436, 36 },
      6,
   } },

   /* replace1908_0 -> 16 in the cache */
   /* replace1908_1 -> 36 in the cache */
   /* replace1908 -> 2109 in the cache */

   /* ('ldexp@16', 'x', 'exp') => ('fmul', ('fmul', 'x', ('i2i16', ('ishl', ('iadd', ('ishr', ('imin', ('imax', 'exp', -30), 30), 1), 15), 10))), ('i2i16', ('ishl', ('iadd', ('isub', ('imin', ('imax', 'exp', -30), 30), ('ishr', ('imin', ('imax', 'exp', -30), 30), 1)), 15), 10))) */
   { .variable = {
      { nir_search_value_variable, 16 },
      0, /* x */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* exp */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ldexp,
      -1, 0,
      { 5251, 5252 },
      -1,
   } },

   /* replace1909_0_0 -> 5251 in the cache */
   /* replace1909_0_1_0_0_0_0_0_0 -> 5252 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { -0x1e /* -30 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imax,
      4, 1,
      { 5252, 5254 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x1e /* 30 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imin,
      3, 2,
      { 5255, 5256 },
      -1,
   } },
   /* replace1909_0_1_0_0_0_1 -> 396 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 2,
      { 5257, 396 },
      -1,
   } },
   /* replace1909_0_1_0_0_1 -> 14 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      2, 3,
      { 5258, 14 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xa /* 10 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 3,
      { 5259, 5260 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 3,
      { 5261 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 4,
      { 5251, 5262 },
      -1,
   } },
   /* replace1909_1_0_0_0_0_0_0 -> 5252 in the cache */
   /* replace1909_1_0_0_0_0_0_1 -> 5254 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imax,
      7, 1,
      { 5252, 5254 },
      -1,
   } },
   /* replace1909_1_0_0_0_0_1 -> 5256 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imin,
      6, 2,
      { 5264, 5256 },
      -1,
   } },
   /* replace1909_1_0_0_0_1_0_0_0 -> 5252 in the cache */
   /* replace1909_1_0_0_0_1_0_0_1 -> 5254 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imax,
      9, 1,
      { 5252, 5254 },
      -1,
   } },
   /* replace1909_1_0_0_0_1_0_1 -> 5256 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imin,
      8, 2,
      { 5266, 5256 },
      -1,
   } },
   /* replace1909_1_0_0_0_1_1 -> 396 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 2,
      { 5267, 396 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 4,
      { 5265, 5268 },
      -1,
   } },
   /* replace1909_1_0_0_1 -> 14 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      5, 5,
      { 5269, 14 },
      -1,
   } },
   /* replace1909_1_0_1 -> 5260 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 5,
      { 5270, 5260 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 5,
      { 5271 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 10,
      { 5263, 5272 },
      -1,
   } },

   /* ('ldexp@32', 'x', 'exp') => ('fmul', ('fmul', 'x', ('ishl', ('iadd', ('ishr', ('imin', ('imax', 'exp', -254), 254), 1), 127), 23)), ('ishl', ('iadd', ('isub', ('imin', ('imax', 'exp', -254), 254), ('ishr', ('imin', ('imax', 'exp', -254), 254), 1)), 127), 23)) */
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* x */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search1910_1 -> 5252 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ldexp,
      -1, 0,
      { 5274, 5252 },
      -1,
   } },

   /* replace1910_0_0 -> 5274 in the cache */
   /* replace1910_0_1_0_0_0_0_0 -> 5252 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { -0xfe /* -254 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imax,
      4, 1,
      { 5252, 5276 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xfe /* 254 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imin,
      3, 2,
      { 5277, 5278 },
      -1,
   } },
   /* replace1910_0_1_0_0_1 -> 396 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 2,
      { 5279, 396 },
      -1,
   } },
   /* replace1910_0_1_0_1 -> 4453 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      2, 3,
      { 5280, 4453 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x17 /* 23 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 3,
      { 5281, 5282 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 4,
      { 5274, 5283 },
      -1,
   } },
   /* replace1910_1_0_0_0_0_0 -> 5252 in the cache */
   /* replace1910_1_0_0_0_0_1 -> 5276 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imax,
      7, 1,
      { 5252, 5276 },
      -1,
   } },
   /* replace1910_1_0_0_0_1 -> 5278 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imin,
      6, 2,
      { 5285, 5278 },
      -1,
   } },
   /* replace1910_1_0_0_1_0_0_0 -> 5252 in the cache */
   /* replace1910_1_0_0_1_0_0_1 -> 5276 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imax,
      9, 1,
      { 5252, 5276 },
      -1,
   } },
   /* replace1910_1_0_0_1_0_1 -> 5278 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imin,
      8, 2,
      { 5287, 5278 },
      -1,
   } },
   /* replace1910_1_0_0_1_1 -> 396 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 2,
      { 5288, 396 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 4,
      { 5286, 5289 },
      -1,
   } },
   /* replace1910_1_0_1 -> 4453 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      5, 5,
      { 5290, 4453 },
      -1,
   } },
   /* replace1910_1_1 -> 5282 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 5,
      { 5291, 5282 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 10,
      { 5284, 5292 },
      -1,
   } },

   /* ('ldexp@64', 'x', 'exp') => ('fmul', ('fmul', 'x', ('pack_64_2x32_split', 0, ('ishl', ('iadd', ('ishr', ('imin', ('imax', 'exp', -2046), 2046), 1), 1023), 20))), ('pack_64_2x32_split', 0, ('ishl', ('iadd', ('isub', ('imin', ('imax', 'exp', -2046), 2046), ('ishr', ('imin', ('imax', 'exp', -2046), 2046), 1)), 1023), 20))) */
   { .variable = {
      { nir_search_value_variable, 64 },
      0, /* x */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search1911_1 -> 5252 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ldexp,
      -1, 0,
      { 5294, 5252 },
      -1,
   } },

   /* replace1911_0_0 -> 5294 in the cache */
   /* replace1911_0_1_0 -> 122 in the cache */
   /* replace1911_0_1_1_0_0_0_0_0 -> 5252 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { -0x7fe /* -2046 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imax,
      4, 1,
      { 5252, 5296 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x7fe /* 2046 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imin,
      3, 2,
      { 5297, 5298 },
      -1,
   } },
   /* replace1911_0_1_1_0_0_1 -> 396 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 2,
      { 5299, 396 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x3ff /* 1023 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      2, 3,
      { 5300, 5301 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x14 /* 20 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 3,
      { 5302, 5303 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_pack_64_2x32_split,
      -1, 3,
      { 122, 5304 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 4,
      { 5294, 5305 },
      -1,
   } },
   /* replace1911_1_0 -> 122 in the cache */
   /* replace1911_1_1_0_0_0_0_0 -> 5252 in the cache */
   /* replace1911_1_1_0_0_0_0_1 -> 5296 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imax,
      7, 1,
      { 5252, 5296 },
      -1,
   } },
   /* replace1911_1_1_0_0_0_1 -> 5298 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imin,
      6, 2,
      { 5307, 5298 },
      -1,
   } },
   /* replace1911_1_1_0_0_1_0_0_0 -> 5252 in the cache */
   /* replace1911_1_1_0_0_1_0_0_1 -> 5296 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imax,
      9, 1,
      { 5252, 5296 },
      -1,
   } },
   /* replace1911_1_1_0_0_1_0_1 -> 5298 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imin,
      8, 2,
      { 5309, 5298 },
      -1,
   } },
   /* replace1911_1_1_0_0_1_1 -> 396 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 2,
      { 5310, 396 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 4,
      { 5308, 5311 },
      -1,
   } },
   /* replace1911_1_1_0_1 -> 5301 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      5, 5,
      { 5312, 5301 },
      -1,
   } },
   /* replace1911_1_1_1 -> 5303 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 5,
      { 5313, 5303 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_pack_64_2x32_split,
      -1, 5,
      { 122, 5314 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 10,
      { 5306, 5315 },
      -1,
   } },

   /* ('ior(many-comm-expr)', ('ishl', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 16711935), 8), ('ushr', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 4278255360), 8)), 252645135), 4), ('ushr', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 16711935), 8), ('ushr', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 4278255360), 8)), 4042322160), 4)), 858993459), 2), ('ushr', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 16711935), 8), ('ushr', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 4278255360), 8)), 252645135), 4), ('ushr', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 16711935), 8), ('ushr', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 4278255360), 8)), 4042322160), 4)), 3435973836), 2)), 1431655765), 1), ('ushr', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 16711935), 8), ('ushr', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 4278255360), 8)), 252645135), 4), ('ushr', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 16711935), 8), ('ushr', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 4278255360), 8)), 4042322160), 4)), 858993459), 2), ('ushr', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 16711935), 8), ('ushr', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 4278255360), 8)), 252645135), 4), ('ushr', ('iand', ('ior', ('ishl', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 16711935), 8), ('ushr', ('iand', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 4278255360), 8)), 4042322160), 4)), 3435973836), 2)), 2863311530), 1)) => ('bitfield_reverse', 'x') */
   /* search1912_0_0_0_0_0_0_0_0_0_0_0_0_0_0 -> 5274 in the cache */
   /* search1912_0_0_0_0_0_0_0_0_0_0_0_0_0_1 -> 853 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 5274, 853 },
      -1,
   } },
   /* search1912_0_0_0_0_0_0_0_0_0_0_0_0_1_0 -> 5274 in the cache */
   /* search1912_0_0_0_0_0_0_0_0_0_0_0_0_1_1 -> 853 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 5274, 853 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      8, 1,
      { 5317, 5318 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xff00ff /* 16711935 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      7, 2,
      { 5319, 5320 },
      -1,
   } },
   /* search1912_0_0_0_0_0_0_0_0_0_0_1 -> 831 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 2,
      { 5321, 831 },
      -1,
   } },
   /* search1912_0_0_0_0_0_0_0_0_0_1_0_0_0_0 -> 5274 in the cache */
   /* search1912_0_0_0_0_0_0_0_0_0_1_0_0_0_1 -> 853 in the cache */
   /* search1912_0_0_0_0_0_0_0_0_0_1_0_0_0 -> 5317 in the cache */
   /* search1912_0_0_0_0_0_0_0_0_0_1_0_0_1_0 -> 5274 in the cache */
   /* search1912_0_0_0_0_0_0_0_0_0_1_0_0_1_1 -> 853 in the cache */
   /* search1912_0_0_0_0_0_0_0_0_0_1_0_0_1 -> 5318 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      10, 1,
      { 5317, 5318 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xff00ff00 /* 4278255360 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      9, 2,
      { 5323, 5324 },
      -1,
   } },
   /* search1912_0_0_0_0_0_0_0_0_0_1_1 -> 831 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 2,
      { 5325, 831 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      6, 5,
      { 5322, 5326 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xf0f0f0f /* 252645135 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      5, 6,
      { 5327, 5328 },
      -1,
   } },
   /* search1912_0_0_0_0_0_0_0_1 -> 2214 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 6,
      { 5329, 2214 },
      -1,
   } },
   /* search1912_0_0_0_0_0_0_1_0_0_0_0_0_0_0 -> 5274 in the cache */
   /* search1912_0_0_0_0_0_0_1_0_0_0_0_0_0_1 -> 853 in the cache */
   /* search1912_0_0_0_0_0_0_1_0_0_0_0_0_0 -> 5317 in the cache */
   /* search1912_0_0_0_0_0_0_1_0_0_0_0_0_1_0 -> 5274 in the cache */
   /* search1912_0_0_0_0_0_0_1_0_0_0_0_0_1_1 -> 853 in the cache */
   /* search1912_0_0_0_0_0_0_1_0_0_0_0_0_1 -> 5318 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      14, 1,
      { 5317, 5318 },
      -1,
   } },
   /* search1912_0_0_0_0_0_0_1_0_0_0_0_1 -> 5320 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      13, 2,
      { 5331, 5320 },
      -1,
   } },
   /* search1912_0_0_0_0_0_0_1_0_0_0_1 -> 831 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 2,
      { 5332, 831 },
      -1,
   } },
   /* search1912_0_0_0_0_0_0_1_0_0_1_0_0_0_0 -> 5274 in the cache */
   /* search1912_0_0_0_0_0_0_1_0_0_1_0_0_0_1 -> 853 in the cache */
   /* search1912_0_0_0_0_0_0_1_0_0_1_0_0_0 -> 5317 in the cache */
   /* search1912_0_0_0_0_0_0_1_0_0_1_0_0_1_0 -> 5274 in the cache */
   /* search1912_0_0_0_0_0_0_1_0_0_1_0_0_1_1 -> 853 in the cache */
   /* search1912_0_0_0_0_0_0_1_0_0_1_0_0_1 -> 5318 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      16, 1,
      { 5317, 5318 },
      -1,
   } },
   /* search1912_0_0_0_0_0_0_1_0_0_1_0_1 -> 5324 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      15, 2,
      { 5334, 5324 },
      -1,
   } },
   /* search1912_0_0_0_0_0_0_1_0_0_1_1 -> 831 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 2,
      { 5335, 831 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      12, 5,
      { 5333, 5336 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xf0f0f0f0 /* 4042322160 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      11, 6,
      { 5337, 5338 },
      -1,
   } },
   /* search1912_0_0_0_0_0_0_1_1 -> 2214 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 6,
      { 5339, 2214 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      4, 13,
      { 5330, 5340 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x33333333 /* 858993459 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      3, 14,
      { 5341, 5342 },
      -1,
   } },
   /* search1912_0_0_0_0_1 -> 401 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 14,
      { 5343, 401 },
      -1,
   } },
   /* search1912_0_0_0_1_0_0_0_0_0_0_0_0_0_0 -> 5274 in the cache */
   /* search1912_0_0_0_1_0_0_0_0_0_0_0_0_0_1 -> 853 in the cache */
   /* search1912_0_0_0_1_0_0_0_0_0_0_0_0_0 -> 5317 in the cache */
   /* search1912_0_0_0_1_0_0_0_0_0_0_0_0_1_0 -> 5274 in the cache */
   /* search1912_0_0_0_1_0_0_0_0_0_0_0_0_1_1 -> 853 in the cache */
   /* search1912_0_0_0_1_0_0_0_0_0_0_0_0_1 -> 5318 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      22, 1,
      { 5317, 5318 },
      -1,
   } },
   /* search1912_0_0_0_1_0_0_0_0_0_0_0_1 -> 5320 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      21, 2,
      { 5345, 5320 },
      -1,
   } },
   /* search1912_0_0_0_1_0_0_0_0_0_0_1 -> 831 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 2,
      { 5346, 831 },
      -1,
   } },
   /* search1912_0_0_0_1_0_0_0_0_0_1_0_0_0_0 -> 5274 in the cache */
   /* search1912_0_0_0_1_0_0_0_0_0_1_0_0_0_1 -> 853 in the cache */
   /* search1912_0_0_0_1_0_0_0_0_0_1_0_0_0 -> 5317 in the cache */
   /* search1912_0_0_0_1_0_0_0_0_0_1_0_0_1_0 -> 5274 in the cache */
   /* search1912_0_0_0_1_0_0_0_0_0_1_0_0_1_1 -> 853 in the cache */
   /* search1912_0_0_0_1_0_0_0_0_0_1_0_0_1 -> 5318 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      24, 1,
      { 5317, 5318 },
      -1,
   } },
   /* search1912_0_0_0_1_0_0_0_0_0_1_0_1 -> 5324 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      23, 2,
      { 5348, 5324 },
      -1,
   } },
   /* search1912_0_0_0_1_0_0_0_0_0_1_1 -> 831 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 2,
      { 5349, 831 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      20, 5,
      { 5347, 5350 },
      -1,
   } },
   /* search1912_0_0_0_1_0_0_0_0_1 -> 5328 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      19, 6,
      { 5351, 5328 },
      -1,
   } },
   /* search1912_0_0_0_1_0_0_0_1 -> 2214 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 6,
      { 5352, 2214 },
      -1,
   } },
   /* search1912_0_0_0_1_0_0_1_0_0_0_0_0_0_0 -> 5274 in the cache */
   /* search1912_0_0_0_1_0_0_1_0_0_0_0_0_0_1 -> 853 in the cache */
   /* search1912_0_0_0_1_0_0_1_0_0_0_0_0_0 -> 5317 in the cache */
   /* search1912_0_0_0_1_0_0_1_0_0_0_0_0_1_0 -> 5274 in the cache */
   /* search1912_0_0_0_1_0_0_1_0_0_0_0_0_1_1 -> 853 in the cache */
   /* search1912_0_0_0_1_0_0_1_0_0_0_0_0_1 -> 5318 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      28, 1,
      { 5317, 5318 },
      -1,
   } },
   /* search1912_0_0_0_1_0_0_1_0_0_0_0_1 -> 5320 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      27, 2,
      { 5354, 5320 },
      -1,
   } },
   /* search1912_0_0_0_1_0_0_1_0_0_0_1 -> 831 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 2,
      { 5355, 831 },
      -1,
   } },
   /* search1912_0_0_0_1_0_0_1_0_0_1_0_0_0_0 -> 5274 in the cache */
   /* search1912_0_0_0_1_0_0_1_0_0_1_0_0_0_1 -> 853 in the cache */
   /* search1912_0_0_0_1_0_0_1_0_0_1_0_0_0 -> 5317 in the cache */
   /* search1912_0_0_0_1_0_0_1_0_0_1_0_0_1_0 -> 5274 in the cache */
   /* search1912_0_0_0_1_0_0_1_0_0_1_0_0_1_1 -> 853 in the cache */
   /* search1912_0_0_0_1_0_0_1_0_0_1_0_0_1 -> 5318 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      30, 1,
      { 5317, 5318 },
      -1,
   } },
   /* search1912_0_0_0_1_0_0_1_0_0_1_0_1 -> 5324 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      29, 2,
      { 5357, 5324 },
      -1,
   } },
   /* search1912_0_0_0_1_0_0_1_0_0_1_1 -> 831 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 2,
      { 5358, 831 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      26, 5,
      { 5356, 5359 },
      -1,
   } },
   /* search1912_0_0_0_1_0_0_1_0_1 -> 5338 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      25, 6,
      { 5360, 5338 },
      -1,
   } },
   /* search1912_0_0_0_1_0_0_1_1 -> 2214 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 6,
      { 5361, 2214 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      18, 13,
      { 5353, 5362 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xcccccccc /* 3435973836 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      17, 14,
      { 5363, 5364 },
      -1,
   } },
   /* search1912_0_0_0_1_1 -> 401 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 14,
      { 5365, 401 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      2, 29,
      { 5344, 5366 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x55555555 /* 1431655765 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      1, 30,
      { 5367, 5368 },
      -1,
   } },
   /* search1912_0_1 -> 396 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 30,
      { 5369, 396 },
      -1,
   } },
   /* search1912_1_0_0_0_0_0_0_0_0_0_0_0_0_0 -> 5274 in the cache */
   /* search1912_1_0_0_0_0_0_0_0_0_0_0_0_0_1 -> 853 in the cache */
   /* search1912_1_0_0_0_0_0_0_0_0_0_0_0_0 -> 5317 in the cache */
   /* search1912_1_0_0_0_0_0_0_0_0_0_0_0_1_0 -> 5274 in the cache */
   /* search1912_1_0_0_0_0_0_0_0_0_0_0_0_1_1 -> 853 in the cache */
   /* search1912_1_0_0_0_0_0_0_0_0_0_0_0_1 -> 5318 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      38, 1,
      { 5317, 5318 },
      -1,
   } },
   /* search1912_1_0_0_0_0_0_0_0_0_0_0_1 -> 5320 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      37, 2,
      { 5371, 5320 },
      -1,
   } },
   /* search1912_1_0_0_0_0_0_0_0_0_0_1 -> 831 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 2,
      { 5372, 831 },
      -1,
   } },
   /* search1912_1_0_0_0_0_0_0_0_0_1_0_0_0_0 -> 5274 in the cache */
   /* search1912_1_0_0_0_0_0_0_0_0_1_0_0_0_1 -> 853 in the cache */
   /* search1912_1_0_0_0_0_0_0_0_0_1_0_0_0 -> 5317 in the cache */
   /* search1912_1_0_0_0_0_0_0_0_0_1_0_0_1_0 -> 5274 in the cache */
   /* search1912_1_0_0_0_0_0_0_0_0_1_0_0_1_1 -> 853 in the cache */
   /* search1912_1_0_0_0_0_0_0_0_0_1_0_0_1 -> 5318 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      40, 1,
      { 5317, 5318 },
      -1,
   } },
   /* search1912_1_0_0_0_0_0_0_0_0_1_0_1 -> 5324 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      39, 2,
      { 5374, 5324 },
      -1,
   } },
   /* search1912_1_0_0_0_0_0_0_0_0_1_1 -> 831 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 2,
      { 5375, 831 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      36, 5,
      { 5373, 5376 },
      -1,
   } },
   /* search1912_1_0_0_0_0_0_0_0_1 -> 5328 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      35, 6,
      { 5377, 5328 },
      -1,
   } },
   /* search1912_1_0_0_0_0_0_0_1 -> 2214 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 6,
      { 5378, 2214 },
      -1,
   } },
   /* search1912_1_0_0_0_0_0_1_0_0_0_0_0_0_0 -> 5274 in the cache */
   /* search1912_1_0_0_0_0_0_1_0_0_0_0_0_0_1 -> 853 in the cache */
   /* search1912_1_0_0_0_0_0_1_0_0_0_0_0_0 -> 5317 in the cache */
   /* search1912_1_0_0_0_0_0_1_0_0_0_0_0_1_0 -> 5274 in the cache */
   /* search1912_1_0_0_0_0_0_1_0_0_0_0_0_1_1 -> 853 in the cache */
   /* search1912_1_0_0_0_0_0_1_0_0_0_0_0_1 -> 5318 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      44, 1,
      { 5317, 5318 },
      -1,
   } },
   /* search1912_1_0_0_0_0_0_1_0_0_0_0_1 -> 5320 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      43, 2,
      { 5380, 5320 },
      -1,
   } },
   /* search1912_1_0_0_0_0_0_1_0_0_0_1 -> 831 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 2,
      { 5381, 831 },
      -1,
   } },
   /* search1912_1_0_0_0_0_0_1_0_0_1_0_0_0_0 -> 5274 in the cache */
   /* search1912_1_0_0_0_0_0_1_0_0_1_0_0_0_1 -> 853 in the cache */
   /* search1912_1_0_0_0_0_0_1_0_0_1_0_0_0 -> 5317 in the cache */
   /* search1912_1_0_0_0_0_0_1_0_0_1_0_0_1_0 -> 5274 in the cache */
   /* search1912_1_0_0_0_0_0_1_0_0_1_0_0_1_1 -> 853 in the cache */
   /* search1912_1_0_0_0_0_0_1_0_0_1_0_0_1 -> 5318 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      46, 1,
      { 5317, 5318 },
      -1,
   } },
   /* search1912_1_0_0_0_0_0_1_0_0_1_0_1 -> 5324 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      45, 2,
      { 5383, 5324 },
      -1,
   } },
   /* search1912_1_0_0_0_0_0_1_0_0_1_1 -> 831 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 2,
      { 5384, 831 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      42, 5,
      { 5382, 5385 },
      -1,
   } },
   /* search1912_1_0_0_0_0_0_1_0_1 -> 5338 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      41, 6,
      { 5386, 5338 },
      -1,
   } },
   /* search1912_1_0_0_0_0_0_1_1 -> 2214 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 6,
      { 5387, 2214 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      34, 13,
      { 5379, 5388 },
      -1,
   } },
   /* search1912_1_0_0_0_0_1 -> 5342 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      33, 14,
      { 5389, 5342 },
      -1,
   } },
   /* search1912_1_0_0_0_1 -> 401 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 14,
      { 5390, 401 },
      -1,
   } },
   /* search1912_1_0_0_1_0_0_0_0_0_0_0_0_0_0 -> 5274 in the cache */
   /* search1912_1_0_0_1_0_0_0_0_0_0_0_0_0_1 -> 853 in the cache */
   /* search1912_1_0_0_1_0_0_0_0_0_0_0_0_0 -> 5317 in the cache */
   /* search1912_1_0_0_1_0_0_0_0_0_0_0_0_1_0 -> 5274 in the cache */
   /* search1912_1_0_0_1_0_0_0_0_0_0_0_0_1_1 -> 853 in the cache */
   /* search1912_1_0_0_1_0_0_0_0_0_0_0_0_1 -> 5318 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      52, 1,
      { 5317, 5318 },
      -1,
   } },
   /* search1912_1_0_0_1_0_0_0_0_0_0_0_1 -> 5320 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      51, 2,
      { 5392, 5320 },
      -1,
   } },
   /* search1912_1_0_0_1_0_0_0_0_0_0_1 -> 831 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 2,
      { 5393, 831 },
      -1,
   } },
   /* search1912_1_0_0_1_0_0_0_0_0_1_0_0_0_0 -> 5274 in the cache */
   /* search1912_1_0_0_1_0_0_0_0_0_1_0_0_0_1 -> 853 in the cache */
   /* search1912_1_0_0_1_0_0_0_0_0_1_0_0_0 -> 5317 in the cache */
   /* search1912_1_0_0_1_0_0_0_0_0_1_0_0_1_0 -> 5274 in the cache */
   /* search1912_1_0_0_1_0_0_0_0_0_1_0_0_1_1 -> 853 in the cache */
   /* search1912_1_0_0_1_0_0_0_0_0_1_0_0_1 -> 5318 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      54, 1,
      { 5317, 5318 },
      -1,
   } },
   /* search1912_1_0_0_1_0_0_0_0_0_1_0_1 -> 5324 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      53, 2,
      { 5395, 5324 },
      -1,
   } },
   /* search1912_1_0_0_1_0_0_0_0_0_1_1 -> 831 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 2,
      { 5396, 831 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      50, 5,
      { 5394, 5397 },
      -1,
   } },
   /* search1912_1_0_0_1_0_0_0_0_1 -> 5328 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      49, 6,
      { 5398, 5328 },
      -1,
   } },
   /* search1912_1_0_0_1_0_0_0_1 -> 2214 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 6,
      { 5399, 2214 },
      -1,
   } },
   /* search1912_1_0_0_1_0_0_1_0_0_0_0_0_0_0 -> 5274 in the cache */
   /* search1912_1_0_0_1_0_0_1_0_0_0_0_0_0_1 -> 853 in the cache */
   /* search1912_1_0_0_1_0_0_1_0_0_0_0_0_0 -> 5317 in the cache */
   /* search1912_1_0_0_1_0_0_1_0_0_0_0_0_1_0 -> 5274 in the cache */
   /* search1912_1_0_0_1_0_0_1_0_0_0_0_0_1_1 -> 853 in the cache */
   /* search1912_1_0_0_1_0_0_1_0_0_0_0_0_1 -> 5318 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      58, 1,
      { 5317, 5318 },
      -1,
   } },
   /* search1912_1_0_0_1_0_0_1_0_0_0_0_1 -> 5320 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      57, 2,
      { 5401, 5320 },
      -1,
   } },
   /* search1912_1_0_0_1_0_0_1_0_0_0_1 -> 831 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 2,
      { 5402, 831 },
      -1,
   } },
   /* search1912_1_0_0_1_0_0_1_0_0_1_0_0_0_0 -> 5274 in the cache */
   /* search1912_1_0_0_1_0_0_1_0_0_1_0_0_0_1 -> 853 in the cache */
   /* search1912_1_0_0_1_0_0_1_0_0_1_0_0_0 -> 5317 in the cache */
   /* search1912_1_0_0_1_0_0_1_0_0_1_0_0_1_0 -> 5274 in the cache */
   /* search1912_1_0_0_1_0_0_1_0_0_1_0_0_1_1 -> 853 in the cache */
   /* search1912_1_0_0_1_0_0_1_0_0_1_0_0_1 -> 5318 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      60, 1,
      { 5317, 5318 },
      -1,
   } },
   /* search1912_1_0_0_1_0_0_1_0_0_1_0_1 -> 5324 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      59, 2,
      { 5404, 5324 },
      -1,
   } },
   /* search1912_1_0_0_1_0_0_1_0_0_1_1 -> 831 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 2,
      { 5405, 831 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      56, 5,
      { 5403, 5406 },
      -1,
   } },
   /* search1912_1_0_0_1_0_0_1_0_1 -> 5338 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      55, 6,
      { 5407, 5338 },
      -1,
   } },
   /* search1912_1_0_0_1_0_0_1_1 -> 2214 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 6,
      { 5408, 2214 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      48, 13,
      { 5400, 5409 },
      -1,
   } },
   /* search1912_1_0_0_1_0_1 -> 5364 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      47, 14,
      { 5410, 5364 },
      -1,
   } },
   /* search1912_1_0_0_1_1 -> 401 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 14,
      { 5411, 401 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      32, 29,
      { 5391, 5412 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xaaaaaaaa /* 2863311530 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      31, 30,
      { 5413, 5414 },
      -1,
   } },
   /* search1912_1_1 -> 396 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 30,
      { 5415, 396 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 61,
      { 5370, 5416 },
      -1,
   } },

   /* replace1912_0 -> 5274 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bitfield_reverse,
      -1, 0,
      { 5274 },
      -1,
   } },

   /* ('ior(many-comm-expr)', ('iand', ('ishl', ('ior', ('iand', ('ishl', ('ior', ('iand', ('ishl', ('ior', ('iand', ('ishl', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 2863311530), ('iand', ('ushr', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 1431655765)), 2), 3435973836), ('iand', ('ushr', ('ior', ('iand', ('ishl', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 2863311530), ('iand', ('ushr', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 1431655765)), 2), 858993459)), 4), 4042322160), ('iand', ('ushr', ('ior', ('iand', ('ishl', ('ior', ('iand', ('ishl', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 2863311530), ('iand', ('ushr', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 1431655765)), 2), 3435973836), ('iand', ('ushr', ('ior', ('iand', ('ishl', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 2863311530), ('iand', ('ushr', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 1431655765)), 2), 858993459)), 4), 252645135)), 8), 4278255360), ('iand', ('ushr', ('ior', ('iand', ('ishl', ('ior', ('iand', ('ishl', ('ior', ('iand', ('ishl', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 2863311530), ('iand', ('ushr', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 1431655765)), 2), 3435973836), ('iand', ('ushr', ('ior', ('iand', ('ishl', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 2863311530), ('iand', ('ushr', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 1431655765)), 2), 858993459)), 4), 4042322160), ('iand', ('ushr', ('ior', ('iand', ('ishl', ('ior', ('iand', ('ishl', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 2863311530), ('iand', ('ushr', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 1431655765)), 2), 3435973836), ('iand', ('ushr', ('ior', ('iand', ('ishl', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 2863311530), ('iand', ('ushr', ('ior', ('ishl', 'x@32', 16), ('ushr', 'x@32', 16)), 1), 1431655765)), 2), 858993459)), 4), 252645135)), 8), 16711935)) => ('bitfield_reverse', 'x') */
   /* search1913_0_0_0_0_0_0_0_0_0_0_0_0_0_0 -> 5274 in the cache */
   /* search1913_0_0_0_0_0_0_0_0_0_0_0_0_0_1 -> 853 in the cache */
   /* search1913_0_0_0_0_0_0_0_0_0_0_0_0_0 -> 5317 in the cache */
   /* search1913_0_0_0_0_0_0_0_0_0_0_0_0_1_0 -> 5274 in the cache */
   /* search1913_0_0_0_0_0_0_0_0_0_0_0_0_1_1 -> 853 in the cache */
   /* search1913_0_0_0_0_0_0_0_0_0_0_0_0_1 -> 5318 in the cache */
   /* search1913_0_0_0_0_0_0_0_0_0_0_0_0 -> 5319 in the cache */
   /* search1913_0_0_0_0_0_0_0_0_0_0_0_1 -> 396 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 5319, 396 },
      -1,
   } },
   /* search1913_0_0_0_0_0_0_0_0_0_0_1 -> 5414 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      7, 2,
      { 5419, 5414 },
      -1,
   } },
   /* search1913_0_0_0_0_0_0_0_0_0_1_0_0_0_0 -> 5274 in the cache */
   /* search1913_0_0_0_0_0_0_0_0_0_1_0_0_0_1 -> 853 in the cache */
   /* search1913_0_0_0_0_0_0_0_0_0_1_0_0_0 -> 5317 in the cache */
   /* search1913_0_0_0_0_0_0_0_0_0_1_0_0_1_0 -> 5274 in the cache */
   /* search1913_0_0_0_0_0_0_0_0_0_1_0_0_1_1 -> 853 in the cache */
   /* search1913_0_0_0_0_0_0_0_0_0_1_0_0_1 -> 5318 in the cache */
   /* search1913_0_0_0_0_0_0_0_0_0_1_0_0 -> 5323 in the cache */
   /* search1913_0_0_0_0_0_0_0_0_0_1_0_1 -> 396 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 5323, 396 },
      -1,
   } },
   /* search1913_0_0_0_0_0_0_0_0_0_1_1 -> 5368 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      9, 2,
      { 5421, 5368 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      6, 5,
      { 5420, 5422 },
      -1,
   } },
   /* search1913_0_0_0_0_0_0_0_0_1 -> 401 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 5,
      { 5423, 401 },
      -1,
   } },
   /* search1913_0_0_0_0_0_0_0_1 -> 5364 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      5, 6,
      { 5424, 5364 },
      -1,
   } },
   /* search1913_0_0_0_0_0_0_1_0_0_0_0_0_0_0 -> 5274 in the cache */
   /* search1913_0_0_0_0_0_0_1_0_0_0_0_0_0_1 -> 853 in the cache */
   /* search1913_0_0_0_0_0_0_1_0_0_0_0_0_0 -> 5317 in the cache */
   /* search1913_0_0_0_0_0_0_1_0_0_0_0_0_1_0 -> 5274 in the cache */
   /* search1913_0_0_0_0_0_0_1_0_0_0_0_0_1_1 -> 853 in the cache */
   /* search1913_0_0_0_0_0_0_1_0_0_0_0_0_1 -> 5318 in the cache */
   /* search1913_0_0_0_0_0_0_1_0_0_0_0_0 -> 5331 in the cache */
   /* search1913_0_0_0_0_0_0_1_0_0_0_0_1 -> 396 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 5331, 396 },
      -1,
   } },
   /* search1913_0_0_0_0_0_0_1_0_0_0_1 -> 5414 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      13, 2,
      { 5426, 5414 },
      -1,
   } },
   /* search1913_0_0_0_0_0_0_1_0_0_1_0_0_0_0 -> 5274 in the cache */
   /* search1913_0_0_0_0_0_0_1_0_0_1_0_0_0_1 -> 853 in the cache */
   /* search1913_0_0_0_0_0_0_1_0_0_1_0_0_0 -> 5317 in the cache */
   /* search1913_0_0_0_0_0_0_1_0_0_1_0_0_1_0 -> 5274 in the cache */
   /* search1913_0_0_0_0_0_0_1_0_0_1_0_0_1_1 -> 853 in the cache */
   /* search1913_0_0_0_0_0_0_1_0_0_1_0_0_1 -> 5318 in the cache */
   /* search1913_0_0_0_0_0_0_1_0_0_1_0_0 -> 5334 in the cache */
   /* search1913_0_0_0_0_0_0_1_0_0_1_0_1 -> 396 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 5334, 396 },
      -1,
   } },
   /* search1913_0_0_0_0_0_0_1_0_0_1_1 -> 5368 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      15, 2,
      { 5428, 5368 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      12, 5,
      { 5427, 5429 },
      -1,
   } },
   /* search1913_0_0_0_0_0_0_1_0_1 -> 401 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 5,
      { 5430, 401 },
      -1,
   } },
   /* search1913_0_0_0_0_0_0_1_1 -> 5342 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      11, 6,
      { 5431, 5342 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      4, 13,
      { 5425, 5432 },
      -1,
   } },
   /* search1913_0_0_0_0_0_1 -> 2214 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 13,
      { 5433, 2214 },
      -1,
   } },
   /* search1913_0_0_0_0_1 -> 5338 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      3, 14,
      { 5434, 5338 },
      -1,
   } },
   /* search1913_0_0_0_1_0_0_0_0_0_0_0_0_0_0 -> 5274 in the cache */
   /* search1913_0_0_0_1_0_0_0_0_0_0_0_0_0_1 -> 853 in the cache */
   /* search1913_0_0_0_1_0_0_0_0_0_0_0_0_0 -> 5317 in the cache */
   /* search1913_0_0_0_1_0_0_0_0_0_0_0_0_1_0 -> 5274 in the cache */
   /* search1913_0_0_0_1_0_0_0_0_0_0_0_0_1_1 -> 853 in the cache */
   /* search1913_0_0_0_1_0_0_0_0_0_0_0_0_1 -> 5318 in the cache */
   /* search1913_0_0_0_1_0_0_0_0_0_0_0_0 -> 5345 in the cache */
   /* search1913_0_0_0_1_0_0_0_0_0_0_0_1 -> 396 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 5345, 396 },
      -1,
   } },
   /* search1913_0_0_0_1_0_0_0_0_0_0_1 -> 5414 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      21, 2,
      { 5436, 5414 },
      -1,
   } },
   /* search1913_0_0_0_1_0_0_0_0_0_1_0_0_0_0 -> 5274 in the cache */
   /* search1913_0_0_0_1_0_0_0_0_0_1_0_0_0_1 -> 853 in the cache */
   /* search1913_0_0_0_1_0_0_0_0_0_1_0_0_0 -> 5317 in the cache */
   /* search1913_0_0_0_1_0_0_0_0_0_1_0_0_1_0 -> 5274 in the cache */
   /* search1913_0_0_0_1_0_0_0_0_0_1_0_0_1_1 -> 853 in the cache */
   /* search1913_0_0_0_1_0_0_0_0_0_1_0_0_1 -> 5318 in the cache */
   /* search1913_0_0_0_1_0_0_0_0_0_1_0_0 -> 5348 in the cache */
   /* search1913_0_0_0_1_0_0_0_0_0_1_0_1 -> 396 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 5348, 396 },
      -1,
   } },
   /* search1913_0_0_0_1_0_0_0_0_0_1_1 -> 5368 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      23, 2,
      { 5438, 5368 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      20, 5,
      { 5437, 5439 },
      -1,
   } },
   /* search1913_0_0_0_1_0_0_0_0_1 -> 401 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 5,
      { 5440, 401 },
      -1,
   } },
   /* search1913_0_0_0_1_0_0_0_1 -> 5364 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      19, 6,
      { 5441, 5364 },
      -1,
   } },
   /* search1913_0_0_0_1_0_0_1_0_0_0_0_0_0_0 -> 5274 in the cache */
   /* search1913_0_0_0_1_0_0_1_0_0_0_0_0_0_1 -> 853 in the cache */
   /* search1913_0_0_0_1_0_0_1_0_0_0_0_0_0 -> 5317 in the cache */
   /* search1913_0_0_0_1_0_0_1_0_0_0_0_0_1_0 -> 5274 in the cache */
   /* search1913_0_0_0_1_0_0_1_0_0_0_0_0_1_1 -> 853 in the cache */
   /* search1913_0_0_0_1_0_0_1_0_0_0_0_0_1 -> 5318 in the cache */
   /* search1913_0_0_0_1_0_0_1_0_0_0_0_0 -> 5354 in the cache */
   /* search1913_0_0_0_1_0_0_1_0_0_0_0_1 -> 396 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 5354, 396 },
      -1,
   } },
   /* search1913_0_0_0_1_0_0_1_0_0_0_1 -> 5414 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      27, 2,
      { 5443, 5414 },
      -1,
   } },
   /* search1913_0_0_0_1_0_0_1_0_0_1_0_0_0_0 -> 5274 in the cache */
   /* search1913_0_0_0_1_0_0_1_0_0_1_0_0_0_1 -> 853 in the cache */
   /* search1913_0_0_0_1_0_0_1_0_0_1_0_0_0 -> 5317 in the cache */
   /* search1913_0_0_0_1_0_0_1_0_0_1_0_0_1_0 -> 5274 in the cache */
   /* search1913_0_0_0_1_0_0_1_0_0_1_0_0_1_1 -> 853 in the cache */
   /* search1913_0_0_0_1_0_0_1_0_0_1_0_0_1 -> 5318 in the cache */
   /* search1913_0_0_0_1_0_0_1_0_0_1_0_0 -> 5357 in the cache */
   /* search1913_0_0_0_1_0_0_1_0_0_1_0_1 -> 396 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 5357, 396 },
      -1,
   } },
   /* search1913_0_0_0_1_0_0_1_0_0_1_1 -> 5368 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      29, 2,
      { 5445, 5368 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      26, 5,
      { 5444, 5446 },
      -1,
   } },
   /* search1913_0_0_0_1_0_0_1_0_1 -> 401 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 5,
      { 5447, 401 },
      -1,
   } },
   /* search1913_0_0_0_1_0_0_1_1 -> 5342 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      25, 6,
      { 5448, 5342 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      18, 13,
      { 5442, 5449 },
      -1,
   } },
   /* search1913_0_0_0_1_0_1 -> 2214 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 13,
      { 5450, 2214 },
      -1,
   } },
   /* search1913_0_0_0_1_1 -> 5328 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      17, 14,
      { 5451, 5328 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      2, 29,
      { 5435, 5452 },
      -1,
   } },
   /* search1913_0_0_1 -> 831 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 29,
      { 5453, 831 },
      -1,
   } },
   /* search1913_0_1 -> 5324 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      1, 30,
      { 5454, 5324 },
      -1,
   } },
   /* search1913_1_0_0_0_0_0_0_0_0_0_0_0_0_0 -> 5274 in the cache */
   /* search1913_1_0_0_0_0_0_0_0_0_0_0_0_0_1 -> 853 in the cache */
   /* search1913_1_0_0_0_0_0_0_0_0_0_0_0_0 -> 5317 in the cache */
   /* search1913_1_0_0_0_0_0_0_0_0_0_0_0_1_0 -> 5274 in the cache */
   /* search1913_1_0_0_0_0_0_0_0_0_0_0_0_1_1 -> 853 in the cache */
   /* search1913_1_0_0_0_0_0_0_0_0_0_0_0_1 -> 5318 in the cache */
   /* search1913_1_0_0_0_0_0_0_0_0_0_0_0 -> 5371 in the cache */
   /* search1913_1_0_0_0_0_0_0_0_0_0_0_1 -> 396 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 5371, 396 },
      -1,
   } },
   /* search1913_1_0_0_0_0_0_0_0_0_0_1 -> 5414 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      37, 2,
      { 5456, 5414 },
      -1,
   } },
   /* search1913_1_0_0_0_0_0_0_0_0_1_0_0_0_0 -> 5274 in the cache */
   /* search1913_1_0_0_0_0_0_0_0_0_1_0_0_0_1 -> 853 in the cache */
   /* search1913_1_0_0_0_0_0_0_0_0_1_0_0_0 -> 5317 in the cache */
   /* search1913_1_0_0_0_0_0_0_0_0_1_0_0_1_0 -> 5274 in the cache */
   /* search1913_1_0_0_0_0_0_0_0_0_1_0_0_1_1 -> 853 in the cache */
   /* search1913_1_0_0_0_0_0_0_0_0_1_0_0_1 -> 5318 in the cache */
   /* search1913_1_0_0_0_0_0_0_0_0_1_0_0 -> 5374 in the cache */
   /* search1913_1_0_0_0_0_0_0_0_0_1_0_1 -> 396 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 5374, 396 },
      -1,
   } },
   /* search1913_1_0_0_0_0_0_0_0_0_1_1 -> 5368 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      39, 2,
      { 5458, 5368 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      36, 5,
      { 5457, 5459 },
      -1,
   } },
   /* search1913_1_0_0_0_0_0_0_0_1 -> 401 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 5,
      { 5460, 401 },
      -1,
   } },
   /* search1913_1_0_0_0_0_0_0_1 -> 5364 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      35, 6,
      { 5461, 5364 },
      -1,
   } },
   /* search1913_1_0_0_0_0_0_1_0_0_0_0_0_0_0 -> 5274 in the cache */
   /* search1913_1_0_0_0_0_0_1_0_0_0_0_0_0_1 -> 853 in the cache */
   /* search1913_1_0_0_0_0_0_1_0_0_0_0_0_0 -> 5317 in the cache */
   /* search1913_1_0_0_0_0_0_1_0_0_0_0_0_1_0 -> 5274 in the cache */
   /* search1913_1_0_0_0_0_0_1_0_0_0_0_0_1_1 -> 853 in the cache */
   /* search1913_1_0_0_0_0_0_1_0_0_0_0_0_1 -> 5318 in the cache */
   /* search1913_1_0_0_0_0_0_1_0_0_0_0_0 -> 5380 in the cache */
   /* search1913_1_0_0_0_0_0_1_0_0_0_0_1 -> 396 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 5380, 396 },
      -1,
   } },
   /* search1913_1_0_0_0_0_0_1_0_0_0_1 -> 5414 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      43, 2,
      { 5463, 5414 },
      -1,
   } },
   /* search1913_1_0_0_0_0_0_1_0_0_1_0_0_0_0 -> 5274 in the cache */
   /* search1913_1_0_0_0_0_0_1_0_0_1_0_0_0_1 -> 853 in the cache */
   /* search1913_1_0_0_0_0_0_1_0_0_1_0_0_0 -> 5317 in the cache */
   /* search1913_1_0_0_0_0_0_1_0_0_1_0_0_1_0 -> 5274 in the cache */
   /* search1913_1_0_0_0_0_0_1_0_0_1_0_0_1_1 -> 853 in the cache */
   /* search1913_1_0_0_0_0_0_1_0_0_1_0_0_1 -> 5318 in the cache */
   /* search1913_1_0_0_0_0_0_1_0_0_1_0_0 -> 5383 in the cache */
   /* search1913_1_0_0_0_0_0_1_0_0_1_0_1 -> 396 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 5383, 396 },
      -1,
   } },
   /* search1913_1_0_0_0_0_0_1_0_0_1_1 -> 5368 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      45, 2,
      { 5465, 5368 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      42, 5,
      { 5464, 5466 },
      -1,
   } },
   /* search1913_1_0_0_0_0_0_1_0_1 -> 401 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 5,
      { 5467, 401 },
      -1,
   } },
   /* search1913_1_0_0_0_0_0_1_1 -> 5342 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      41, 6,
      { 5468, 5342 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      34, 13,
      { 5462, 5469 },
      -1,
   } },
   /* search1913_1_0_0_0_0_1 -> 2214 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 13,
      { 5470, 2214 },
      -1,
   } },
   /* search1913_1_0_0_0_1 -> 5338 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      33, 14,
      { 5471, 5338 },
      -1,
   } },
   /* search1913_1_0_0_1_0_0_0_0_0_0_0_0_0_0 -> 5274 in the cache */
   /* search1913_1_0_0_1_0_0_0_0_0_0_0_0_0_1 -> 853 in the cache */
   /* search1913_1_0_0_1_0_0_0_0_0_0_0_0_0 -> 5317 in the cache */
   /* search1913_1_0_0_1_0_0_0_0_0_0_0_0_1_0 -> 5274 in the cache */
   /* search1913_1_0_0_1_0_0_0_0_0_0_0_0_1_1 -> 853 in the cache */
   /* search1913_1_0_0_1_0_0_0_0_0_0_0_0_1 -> 5318 in the cache */
   /* search1913_1_0_0_1_0_0_0_0_0_0_0_0 -> 5392 in the cache */
   /* search1913_1_0_0_1_0_0_0_0_0_0_0_1 -> 396 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 5392, 396 },
      -1,
   } },
   /* search1913_1_0_0_1_0_0_0_0_0_0_1 -> 5414 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      51, 2,
      { 5473, 5414 },
      -1,
   } },
   /* search1913_1_0_0_1_0_0_0_0_0_1_0_0_0_0 -> 5274 in the cache */
   /* search1913_1_0_0_1_0_0_0_0_0_1_0_0_0_1 -> 853 in the cache */
   /* search1913_1_0_0_1_0_0_0_0_0_1_0_0_0 -> 5317 in the cache */
   /* search1913_1_0_0_1_0_0_0_0_0_1_0_0_1_0 -> 5274 in the cache */
   /* search1913_1_0_0_1_0_0_0_0_0_1_0_0_1_1 -> 853 in the cache */
   /* search1913_1_0_0_1_0_0_0_0_0_1_0_0_1 -> 5318 in the cache */
   /* search1913_1_0_0_1_0_0_0_0_0_1_0_0 -> 5395 in the cache */
   /* search1913_1_0_0_1_0_0_0_0_0_1_0_1 -> 396 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 5395, 396 },
      -1,
   } },
   /* search1913_1_0_0_1_0_0_0_0_0_1_1 -> 5368 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      53, 2,
      { 5475, 5368 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      50, 5,
      { 5474, 5476 },
      -1,
   } },
   /* search1913_1_0_0_1_0_0_0_0_1 -> 401 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 5,
      { 5477, 401 },
      -1,
   } },
   /* search1913_1_0_0_1_0_0_0_1 -> 5364 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      49, 6,
      { 5478, 5364 },
      -1,
   } },
   /* search1913_1_0_0_1_0_0_1_0_0_0_0_0_0_0 -> 5274 in the cache */
   /* search1913_1_0_0_1_0_0_1_0_0_0_0_0_0_1 -> 853 in the cache */
   /* search1913_1_0_0_1_0_0_1_0_0_0_0_0_0 -> 5317 in the cache */
   /* search1913_1_0_0_1_0_0_1_0_0_0_0_0_1_0 -> 5274 in the cache */
   /* search1913_1_0_0_1_0_0_1_0_0_0_0_0_1_1 -> 853 in the cache */
   /* search1913_1_0_0_1_0_0_1_0_0_0_0_0_1 -> 5318 in the cache */
   /* search1913_1_0_0_1_0_0_1_0_0_0_0_0 -> 5401 in the cache */
   /* search1913_1_0_0_1_0_0_1_0_0_0_0_1 -> 396 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 5401, 396 },
      -1,
   } },
   /* search1913_1_0_0_1_0_0_1_0_0_0_1 -> 5414 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      57, 2,
      { 5480, 5414 },
      -1,
   } },
   /* search1913_1_0_0_1_0_0_1_0_0_1_0_0_0_0 -> 5274 in the cache */
   /* search1913_1_0_0_1_0_0_1_0_0_1_0_0_0_1 -> 853 in the cache */
   /* search1913_1_0_0_1_0_0_1_0_0_1_0_0_0 -> 5317 in the cache */
   /* search1913_1_0_0_1_0_0_1_0_0_1_0_0_1_0 -> 5274 in the cache */
   /* search1913_1_0_0_1_0_0_1_0_0_1_0_0_1_1 -> 853 in the cache */
   /* search1913_1_0_0_1_0_0_1_0_0_1_0_0_1 -> 5318 in the cache */
   /* search1913_1_0_0_1_0_0_1_0_0_1_0_0 -> 5404 in the cache */
   /* search1913_1_0_0_1_0_0_1_0_0_1_0_1 -> 396 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 1,
      { 5404, 396 },
      -1,
   } },
   /* search1913_1_0_0_1_0_0_1_0_0_1_1 -> 5368 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      59, 2,
      { 5482, 5368 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      56, 5,
      { 5481, 5483 },
      -1,
   } },
   /* search1913_1_0_0_1_0_0_1_0_1 -> 401 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 5,
      { 5484, 401 },
      -1,
   } },
   /* search1913_1_0_0_1_0_0_1_1 -> 5342 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      55, 6,
      { 5485, 5342 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      48, 13,
      { 5479, 5486 },
      -1,
   } },
   /* search1913_1_0_0_1_0_1 -> 2214 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 13,
      { 5487, 2214 },
      -1,
   } },
   /* search1913_1_0_0_1_1 -> 5328 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      47, 14,
      { 5488, 5328 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      32, 29,
      { 5472, 5489 },
      -1,
   } },
   /* search1913_1_0_1 -> 831 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 29,
      { 5490, 831 },
      -1,
   } },
   /* search1913_1_1 -> 5320 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      31, 30,
      { 5491, 5320 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ior,
      0, 61,
      { 5455, 5492 },
      -1,
   } },

   /* replace1913_0 -> 5274 in the cache */
   /* replace1913 -> 5418 in the cache */

   /* ('ball_iequal2', ('ieq', 'a', 'b'), -1) => ('ball_iequal2', 'a', 'b') */
   /* search1914_0_0 -> 0 in the cache */
   /* search1914_0_1 -> 3 in the cache */
   /* search1914_0 -> 1080 in the cache */
   { .constant = {
      { nir_search_value_constant, 1 },
      nir_type_int, { -0x1 /* -1 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ball_iequal2,
      0, 2,
      { 1080, 5494 },
      -1,
   } },

   /* replace1914_0 -> 0 in the cache */
   /* replace1914_1 -> 3 in the cache */
   /* replace1914 -> 2480 in the cache */

   /* ('ball_iequal2', ('feq', 'a', 'b'), -1) => ('ball_fequal2', 'a', 'b') */
   /* search1915_0_0 -> 0 in the cache */
   /* search1915_0_1 -> 3 in the cache */
   /* search1915_0 -> 1074 in the cache */
   /* search1915_1 -> 5494 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ball_iequal2,
      0, 2,
      { 1074, 5494 },
      -1,
   } },

   /* replace1915_0 -> 0 in the cache */
   /* replace1915_1 -> 3 in the cache */
   /* replace1915 -> 2550 in the cache */

   /* ('bany_inequal2', ('ine', 'a', 'b'), 0) => ('bany_inequal2', 'a', 'b') */
   /* search1916_0_0 -> 0 in the cache */
   /* search1916_0_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 0, 3 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 1 },
      nir_type_int, { 0x0 /* 0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bany_inequal2,
      0, 2,
      { 5497, 5498 },
      -1,
   } },

   /* replace1916_0 -> 0 in the cache */
   /* replace1916_1 -> 3 in the cache */
   /* replace1916 -> 2591 in the cache */

   /* ('bany_inequal2', ('fneu', 'a', 'b'), 0) => ('bany_fnequal2', 'a', 'b') */
   /* search1917_0_0 -> 0 in the cache */
   /* search1917_0_1 -> 3 in the cache */
   /* search1917_0 -> 4215 in the cache */
   /* search1917_1 -> 5498 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bany_inequal2,
      0, 2,
      { 4215, 5498 },
      -1,
   } },

   /* replace1917_0 -> 0 in the cache */
   /* replace1917_1 -> 3 in the cache */
   /* replace1917 -> 2632 in the cache */

   /* ('ball_iequal3', ('ieq', 'a', 'b'), -1) => ('ball_iequal3', 'a', 'b') */
   /* search1918_0_0 -> 0 in the cache */
   /* search1918_0_1 -> 3 in the cache */
   /* search1918_0 -> 1080 in the cache */
   /* search1918_1 -> 5494 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ball_iequal3,
      0, 2,
      { 1080, 5494 },
      -1,
   } },

   /* replace1918_0 -> 0 in the cache */
   /* replace1918_1 -> 3 in the cache */
   /* replace1918 -> 2486 in the cache */

   /* ('ball_iequal3', ('feq', 'a', 'b'), -1) => ('ball_fequal3', 'a', 'b') */
   /* search1919_0_0 -> 0 in the cache */
   /* search1919_0_1 -> 3 in the cache */
   /* search1919_0 -> 1074 in the cache */
   /* search1919_1 -> 5494 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ball_iequal3,
      0, 2,
      { 1074, 5494 },
      -1,
   } },

   /* replace1919_0 -> 0 in the cache */
   /* replace1919_1 -> 3 in the cache */
   /* replace1919 -> 2554 in the cache */

   /* ('bany_inequal3', ('ine', 'a', 'b'), 0) => ('bany_inequal3', 'a', 'b') */
   /* search1920_0_0 -> 0 in the cache */
   /* search1920_0_1 -> 3 in the cache */
   /* search1920_0 -> 5497 in the cache */
   /* search1920_1 -> 5498 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bany_inequal3,
      0, 2,
      { 5497, 5498 },
      -1,
   } },

   /* replace1920_0 -> 0 in the cache */
   /* replace1920_1 -> 3 in the cache */
   /* replace1920 -> 2595 in the cache */

   /* ('bany_inequal3', ('fneu', 'a', 'b'), 0) => ('bany_fnequal3', 'a', 'b') */
   /* search1921_0_0 -> 0 in the cache */
   /* search1921_0_1 -> 3 in the cache */
   /* search1921_0 -> 4215 in the cache */
   /* search1921_1 -> 5498 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bany_inequal3,
      0, 2,
      { 4215, 5498 },
      -1,
   } },

   /* replace1921_0 -> 0 in the cache */
   /* replace1921_1 -> 3 in the cache */
   /* replace1921 -> 2636 in the cache */

   /* ('ball_iequal4', ('ieq', 'a', 'b'), -1) => ('ball_iequal4', 'a', 'b') */
   /* search1922_0_0 -> 0 in the cache */
   /* search1922_0_1 -> 3 in the cache */
   /* search1922_0 -> 1080 in the cache */
   /* search1922_1 -> 5494 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ball_iequal4,
      0, 2,
      { 1080, 5494 },
      -1,
   } },

   /* replace1922_0 -> 0 in the cache */
   /* replace1922_1 -> 3 in the cache */
   /* replace1922 -> 2493 in the cache */

   /* ('ball_iequal4', ('feq', 'a', 'b'), -1) => ('ball_fequal4', 'a', 'b') */
   /* search1923_0_0 -> 0 in the cache */
   /* search1923_0_1 -> 3 in the cache */
   /* search1923_0 -> 1074 in the cache */
   /* search1923_1 -> 5494 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ball_iequal4,
      0, 2,
      { 1074, 5494 },
      -1,
   } },

   /* replace1923_0 -> 0 in the cache */
   /* replace1923_1 -> 3 in the cache */
   /* replace1923 -> 2560 in the cache */

   /* ('bany_inequal4', ('ine', 'a', 'b'), 0) => ('bany_inequal4', 'a', 'b') */
   /* search1924_0_0 -> 0 in the cache */
   /* search1924_0_1 -> 3 in the cache */
   /* search1924_0 -> 5497 in the cache */
   /* search1924_1 -> 5498 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bany_inequal4,
      0, 2,
      { 5497, 5498 },
      -1,
   } },

   /* replace1924_0 -> 0 in the cache */
   /* replace1924_1 -> 3 in the cache */
   /* replace1924 -> 2601 in the cache */

   /* ('bany_inequal4', ('fneu', 'a', 'b'), 0) => ('bany_fnequal4', 'a', 'b') */
   /* search1925_0_0 -> 0 in the cache */
   /* search1925_0_1 -> 3 in the cache */
   /* search1925_0 -> 4215 in the cache */
   /* search1925_1 -> 5498 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bany_inequal4,
      0, 2,
      { 4215, 5498 },
      -1,
   } },

   /* replace1925_0 -> 0 in the cache */
   /* replace1925_1 -> 3 in the cache */
   /* replace1925 -> 2642 in the cache */

   /* ('ball_iequal8', ('ieq', 'a', 'b'), -1) => ('ball_iequal8', 'a', 'b') */
   /* search1926_0_0 -> 0 in the cache */
   /* search1926_0_1 -> 3 in the cache */
   /* search1926_0 -> 1080 in the cache */
   /* search1926_1 -> 5494 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ball_iequal8,
      0, 2,
      { 1080, 5494 },
      -1,
   } },

   /* replace1926_0 -> 0 in the cache */
   /* replace1926_1 -> 3 in the cache */
   /* replace1926 -> 2500 in the cache */

   /* ('ball_iequal8', ('feq', 'a', 'b'), -1) => ('ball_fequal8', 'a', 'b') */
   /* search1927_0_0 -> 0 in the cache */
   /* search1927_0_1 -> 3 in the cache */
   /* search1927_0 -> 1074 in the cache */
   /* search1927_1 -> 5494 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ball_iequal8,
      0, 2,
      { 1074, 5494 },
      -1,
   } },

   /* replace1927_0 -> 0 in the cache */
   /* replace1927_1 -> 3 in the cache */
   /* replace1927 -> 2565 in the cache */

   /* ('bany_inequal8', ('ine', 'a', 'b'), 0) => ('bany_inequal8', 'a', 'b') */
   /* search1928_0_0 -> 0 in the cache */
   /* search1928_0_1 -> 3 in the cache */
   /* search1928_0 -> 5497 in the cache */
   /* search1928_1 -> 5498 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bany_inequal8,
      0, 2,
      { 5497, 5498 },
      -1,
   } },

   /* replace1928_0 -> 0 in the cache */
   /* replace1928_1 -> 3 in the cache */
   /* replace1928 -> 2606 in the cache */

   /* ('bany_inequal8', ('fneu', 'a', 'b'), 0) => ('bany_fnequal8', 'a', 'b') */
   /* search1929_0_0 -> 0 in the cache */
   /* search1929_0_1 -> 3 in the cache */
   /* search1929_0 -> 4215 in the cache */
   /* search1929_1 -> 5498 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bany_inequal8,
      0, 2,
      { 4215, 5498 },
      -1,
   } },

   /* replace1929_0 -> 0 in the cache */
   /* replace1929_1 -> 3 in the cache */
   /* replace1929 -> 2647 in the cache */

   /* ('ball_iequal16', ('ieq', 'a', 'b'), -1) => ('ball_iequal16', 'a', 'b') */
   /* search1930_0_0 -> 0 in the cache */
   /* search1930_0_1 -> 3 in the cache */
   /* search1930_0 -> 1080 in the cache */
   /* search1930_1 -> 5494 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ball_iequal16,
      0, 2,
      { 1080, 5494 },
      -1,
   } },

   /* replace1930_0 -> 0 in the cache */
   /* replace1930_1 -> 3 in the cache */
   /* replace1930 -> 2517 in the cache */

   /* ('ball_iequal16', ('feq', 'a', 'b'), -1) => ('ball_fequal16', 'a', 'b') */
   /* search1931_0_0 -> 0 in the cache */
   /* search1931_0_1 -> 3 in the cache */
   /* search1931_0 -> 1074 in the cache */
   /* search1931_1 -> 5494 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ball_iequal16,
      0, 2,
      { 1074, 5494 },
      -1,
   } },

   /* replace1931_0 -> 0 in the cache */
   /* replace1931_1 -> 3 in the cache */
   /* replace1931 -> 2574 in the cache */

   /* ('bany_inequal16', ('ine', 'a', 'b'), 0) => ('bany_inequal16', 'a', 'b') */
   /* search1932_0_0 -> 0 in the cache */
   /* search1932_0_1 -> 3 in the cache */
   /* search1932_0 -> 5497 in the cache */
   /* search1932_1 -> 5498 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bany_inequal16,
      0, 2,
      { 5497, 5498 },
      -1,
   } },

   /* replace1932_0 -> 0 in the cache */
   /* replace1932_1 -> 3 in the cache */
   /* replace1932 -> 2615 in the cache */

   /* ('bany_inequal16', ('fneu', 'a', 'b'), 0) => ('bany_fnequal16', 'a', 'b') */
   /* search1933_0_0 -> 0 in the cache */
   /* search1933_0_1 -> 3 in the cache */
   /* search1933_0 -> 4215 in the cache */
   /* search1933_1 -> 5498 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bany_inequal16,
      0, 2,
      { 4215, 5498 },
      -1,
   } },

   /* replace1933_0 -> 0 in the cache */
   /* replace1933_1 -> 3 in the cache */
   /* replace1933 -> 2656 in the cache */

   /* ('iand', ('feq', 'a', 'a'), ('flt', 'a', 'b')) => ('!flt', 'a', 'b') */
   /* search1934_0_0 -> 0 in the cache */
   /* search1934_0_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      -1, 0,
      { 0, 0 },
      -1,
   } },
   /* search1934_1_0 -> 0 in the cache */
   /* search1934_1_1 -> 3 in the cache */
   /* search1934_1 -> 1049 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 5517, 1049 },
      -1,
   } },

   /* replace1934_0 -> 0 in the cache */
   /* replace1934_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      nir_op_flt,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* ('iand', ('feq', 'a', 'a'), ('flt', 'b', 'a')) => ('!flt', 'b', 'a') */
   /* search1935_0_0 -> 32 in the cache */
   /* search1935_0_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      -1, 0,
      { 32, 32 },
      -1,
   } },
   /* search1935_1_0 -> 2313 in the cache */
   /* search1935_1_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 2313, 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 5520, 5521 },
      -1,
   } },

   /* replace1935_0 -> 2313 in the cache */
   /* replace1935_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      nir_op_flt,
      -1, 0,
      { 2313, 32 },
      -1,
   } },

   /* ('iand', ('feq', 'a', 'a'), ('fge', 'a', 'b')) => ('!fge', 'a', 'b') */
   /* search1936_0_0 -> 0 in the cache */
   /* search1936_0_1 -> 0 in the cache */
   /* search1936_0 -> 5517 in the cache */
   /* search1936_1_0 -> 0 in the cache */
   /* search1936_1_1 -> 3 in the cache */
   /* search1936_1 -> 1046 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 5517, 1046 },
      -1,
   } },

   /* replace1936_0 -> 0 in the cache */
   /* replace1936_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      nir_op_fge,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* ('iand', ('feq', 'a', 'a'), ('fge', 'b', 'a')) => ('!fge', 'b', 'a') */
   /* search1937_0_0 -> 32 in the cache */
   /* search1937_0_1 -> 32 in the cache */
   /* search1937_0 -> 5520 in the cache */
   /* search1937_1_0 -> 2313 in the cache */
   /* search1937_1_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 2313, 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 5520, 5526 },
      -1,
   } },

   /* replace1937_0 -> 2313 in the cache */
   /* replace1937_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      nir_op_fge,
      -1, 0,
      { 2313, 32 },
      -1,
   } },

   /* ('iand', ('feq', 'a', 'a'), ('feq', 'a', 'b')) => ('!feq', 'a', 'b') */
   /* search1938_0_0 -> 0 in the cache */
   /* search1938_0_1 -> 0 in the cache */
   /* search1938_0 -> 5517 in the cache */
   /* search1938_1_0 -> 0 in the cache */
   /* search1938_1_1 -> 3 in the cache */
   /* search1938_1 -> 1074 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 5517, 1074 },
      -1,
   } },

   /* replace1938_0 -> 0 in the cache */
   /* replace1938_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      nir_op_feq,
      0, 1,
      { 0, 3 },
      -1,
   } },

   /* ('iand', ('feq', 'a', 'a'), ('feq', 'b', 'a')) => ('!feq', 'b', 'a') */
   /* search1939_0_0 -> 32 in the cache */
   /* search1939_0_1 -> 32 in the cache */
   /* search1939_0 -> 5520 in the cache */
   /* search1939_1_0 -> 2313 in the cache */
   /* search1939_1_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      1, 1,
      { 2313, 32 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 5520, 5531 },
      -1,
   } },

   /* replace1939_0 -> 2313 in the cache */
   /* replace1939_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      nir_op_feq,
      0, 1,
      { 2313, 32 },
      -1,
   } },

   /* ('feq', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('feq', 'b', 'd'), ('feq', 'c', 'd')) */
   /* search1940_0_0 -> 760 in the cache */
   /* search1940_0_1 -> 1028 in the cache */
   /* search1940_0_2 -> 3514 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 760, 1028, 3514 },
      -1,
   } },
   /* search1940_1 -> 1031 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 5534, 1031 },
      -1,
   } },

   /* replace1940_0 -> 760 in the cache */
   /* replace1940_1_0 -> 150 in the cache */
   /* replace1940_1_1 -> 153 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 150, 153 },
      -1,
   } },
   /* replace1940_2_0 -> 152 in the cache */
   /* replace1940_2_1 -> 153 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      1, 1,
      { 152, 153 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 760, 5536, 5537 },
      -1,
   } },

   /* ('fneu', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('fneu', 'b', 'd'), ('fneu', 'c', 'd')) */
   /* search1941_0_0 -> 760 in the cache */
   /* search1941_0_1 -> 1028 in the cache */
   /* search1941_0_2 -> 3514 in the cache */
   /* search1941_0 -> 5534 in the cache */
   /* search1941_1 -> 1031 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 5534, 1031 },
      -1,
   } },

   /* replace1941_0 -> 760 in the cache */
   /* replace1941_1_0 -> 150 in the cache */
   /* replace1941_1_1 -> 153 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 150, 153 },
      -1,
   } },
   /* replace1941_2_0 -> 152 in the cache */
   /* replace1941_2_1 -> 153 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      1, 1,
      { 152, 153 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 760, 5540, 5541 },
      -1,
   } },

   /* ('ieq', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('ieq', 'b', 'd'), ('ieq', 'c', 'd')) */
   /* search1942_0_0 -> 760 in the cache */
   /* search1942_0_1 -> 1028 in the cache */
   /* search1942_0_2 -> 3514 in the cache */
   /* search1942_0 -> 5534 in the cache */
   /* search1942_1 -> 1031 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 5534, 1031 },
      -1,
   } },

   /* replace1942_0 -> 760 in the cache */
   /* replace1942_1_0 -> 150 in the cache */
   /* replace1942_1_1 -> 153 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 1,
      { 150, 153 },
      -1,
   } },
   /* replace1942_2_0 -> 152 in the cache */
   /* replace1942_2_1 -> 153 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 152, 153 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 760, 5544, 5545 },
      -1,
   } },

   /* ('ine', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('ine', 'b', 'd'), ('ine', 'c', 'd')) */
   /* search1943_0_0 -> 760 in the cache */
   /* search1943_0_1 -> 1028 in the cache */
   /* search1943_0_2 -> 3514 in the cache */
   /* search1943_0 -> 5534 in the cache */
   /* search1943_1 -> 1031 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 5534, 1031 },
      -1,
   } },

   /* replace1943_0 -> 760 in the cache */
   /* replace1943_1_0 -> 150 in the cache */
   /* replace1943_1_1 -> 153 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 1,
      { 150, 153 },
      -1,
   } },
   /* replace1943_2_0 -> 152 in the cache */
   /* replace1943_2_1 -> 153 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 152, 153 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 760, 5548, 5549 },
      -1,
   } },

   /* ('flt', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('flt', 'b', 'd'), ('flt', 'c', 'd')) */
   /* search1944_0_0 -> 760 in the cache */
   /* search1944_0_1 -> 1028 in the cache */
   /* search1944_0_2 -> 3514 in the cache */
   /* search1944_0 -> 5534 in the cache */
   /* search1944_1 -> 1031 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 5534, 1031 },
      -1,
   } },

   /* replace1944_0 -> 760 in the cache */
   /* replace1944_1_0 -> 150 in the cache */
   /* replace1944_1_1 -> 153 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 150, 153 },
      -1,
   } },
   /* replace1944_2_0 -> 152 in the cache */
   /* replace1944_2_1 -> 153 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 152, 153 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 760, 5552, 5553 },
      -1,
   } },

   /* ('flt', '#d', ('bcsel', 'a', '#b', '#c')) => ('bcsel', 'a', ('flt', 'd', 'b'), ('flt', 'd', 'c')) */
   { .variable = {
      { nir_search_value_variable, -4 },
      0, /* d */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search1945_1_0 -> 1176 in the cache */
   { .variable = {
      { nir_search_value_variable, -4 },
      2, /* b */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -4 },
      3, /* c */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1176, 5556, 5557 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 5555, 5558 },
      -1,
   } },

   /* replace1945_0 -> 1176 in the cache */
   { .variable = {
      { nir_search_value_variable, -4 },
      0, /* d */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -4 },
      2, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 5560, 5561 },
      -1,
   } },
   /* replace1945_2_0 -> 5560 in the cache */
   /* replace1945_2_1 -> 1726 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 5560, 1726 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1176, 5562, 5563 },
      -1,
   } },

   /* ('fge', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('fge', 'b', 'd'), ('fge', 'c', 'd')) */
   /* search1946_0_0 -> 760 in the cache */
   /* search1946_0_1 -> 1028 in the cache */
   /* search1946_0_2 -> 3514 in the cache */
   /* search1946_0 -> 5534 in the cache */
   /* search1946_1 -> 1031 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 5534, 1031 },
      -1,
   } },

   /* replace1946_0 -> 760 in the cache */
   /* replace1946_1_0 -> 150 in the cache */
   /* replace1946_1_1 -> 153 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 150, 153 },
      -1,
   } },
   /* replace1946_2_0 -> 152 in the cache */
   /* replace1946_2_1 -> 153 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 152, 153 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 760, 5566, 5567 },
      -1,
   } },

   /* ('fge', '#d', ('bcsel', 'a', '#b', '#c')) => ('bcsel', 'a', ('fge', 'd', 'b'), ('fge', 'd', 'c')) */
   /* search1947_0 -> 5555 in the cache */
   /* search1947_1_0 -> 1176 in the cache */
   /* search1947_1_1 -> 5556 in the cache */
   /* search1947_1_2 -> 5557 in the cache */
   /* search1947_1 -> 5558 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 5555, 5558 },
      -1,
   } },

   /* replace1947_0 -> 1176 in the cache */
   /* replace1947_1_0 -> 5560 in the cache */
   /* replace1947_1_1 -> 5561 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 5560, 5561 },
      -1,
   } },
   /* replace1947_2_0 -> 5560 in the cache */
   /* replace1947_2_1 -> 1726 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 5560, 1726 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1176, 5570, 5571 },
      -1,
   } },

   /* ('ilt', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('ilt', 'b', 'd'), ('ilt', 'c', 'd')) */
   /* search1948_0_0 -> 760 in the cache */
   /* search1948_0_1 -> 1028 in the cache */
   /* search1948_0_2 -> 3514 in the cache */
   /* search1948_0 -> 5534 in the cache */
   /* search1948_1 -> 1031 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 5534, 1031 },
      -1,
   } },

   /* replace1948_0 -> 760 in the cache */
   /* replace1948_1_0 -> 150 in the cache */
   /* replace1948_1_1 -> 153 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 150, 153 },
      -1,
   } },
   /* replace1948_2_0 -> 152 in the cache */
   /* replace1948_2_1 -> 153 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 152, 153 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 760, 5574, 5575 },
      -1,
   } },

   /* ('ilt', '#d', ('bcsel', 'a', '#b', '#c')) => ('bcsel', 'a', ('ilt', 'd', 'b'), ('ilt', 'd', 'c')) */
   /* search1949_0 -> 5555 in the cache */
   /* search1949_1_0 -> 1176 in the cache */
   /* search1949_1_1 -> 5556 in the cache */
   /* search1949_1_2 -> 5557 in the cache */
   /* search1949_1 -> 5558 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 5555, 5558 },
      -1,
   } },

   /* replace1949_0 -> 1176 in the cache */
   /* replace1949_1_0 -> 5560 in the cache */
   /* replace1949_1_1 -> 5561 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 5560, 5561 },
      -1,
   } },
   /* replace1949_2_0 -> 5560 in the cache */
   /* replace1949_2_1 -> 1726 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 5560, 1726 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1176, 5578, 5579 },
      -1,
   } },

   /* ('ige', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('ige', 'b', 'd'), ('ige', 'c', 'd')) */
   /* search1950_0_0 -> 760 in the cache */
   /* search1950_0_1 -> 1028 in the cache */
   /* search1950_0_2 -> 3514 in the cache */
   /* search1950_0 -> 5534 in the cache */
   /* search1950_1 -> 1031 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 5534, 1031 },
      -1,
   } },

   /* replace1950_0 -> 760 in the cache */
   /* replace1950_1_0 -> 150 in the cache */
   /* replace1950_1_1 -> 153 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 150, 153 },
      -1,
   } },
   /* replace1950_2_0 -> 152 in the cache */
   /* replace1950_2_1 -> 153 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 152, 153 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 760, 5582, 5583 },
      -1,
   } },

   /* ('ige', '#d', ('bcsel', 'a', '#b', '#c')) => ('bcsel', 'a', ('ige', 'd', 'b'), ('ige', 'd', 'c')) */
   /* search1951_0 -> 5555 in the cache */
   /* search1951_1_0 -> 1176 in the cache */
   /* search1951_1_1 -> 5556 in the cache */
   /* search1951_1_2 -> 5557 in the cache */
   /* search1951_1 -> 5558 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 5555, 5558 },
      -1,
   } },

   /* replace1951_0 -> 1176 in the cache */
   /* replace1951_1_0 -> 5560 in the cache */
   /* replace1951_1_1 -> 5561 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 5560, 5561 },
      -1,
   } },
   /* replace1951_2_0 -> 5560 in the cache */
   /* replace1951_2_1 -> 1726 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 5560, 1726 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1176, 5586, 5587 },
      -1,
   } },

   /* ('ult', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('ult', 'b', 'd'), ('ult', 'c', 'd')) */
   /* search1952_0_0 -> 760 in the cache */
   /* search1952_0_1 -> 1028 in the cache */
   /* search1952_0_2 -> 3514 in the cache */
   /* search1952_0 -> 5534 in the cache */
   /* search1952_1 -> 1031 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 5534, 1031 },
      -1,
   } },

   /* replace1952_0 -> 760 in the cache */
   /* replace1952_1_0 -> 150 in the cache */
   /* replace1952_1_1 -> 153 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 150, 153 },
      -1,
   } },
   /* replace1952_2_0 -> 152 in the cache */
   /* replace1952_2_1 -> 153 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 152, 153 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 760, 5590, 5591 },
      -1,
   } },

   /* ('ult', '#d', ('bcsel', 'a', '#b', '#c')) => ('bcsel', 'a', ('ult', 'd', 'b'), ('ult', 'd', 'c')) */
   /* search1953_0 -> 5555 in the cache */
   /* search1953_1_0 -> 1176 in the cache */
   /* search1953_1_1 -> 5556 in the cache */
   /* search1953_1_2 -> 5557 in the cache */
   /* search1953_1 -> 5558 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 5555, 5558 },
      -1,
   } },

   /* replace1953_0 -> 1176 in the cache */
   /* replace1953_1_0 -> 5560 in the cache */
   /* replace1953_1_1 -> 5561 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 5560, 5561 },
      -1,
   } },
   /* replace1953_2_0 -> 5560 in the cache */
   /* replace1953_2_1 -> 1726 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 0,
      { 5560, 1726 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1176, 5594, 5595 },
      -1,
   } },

   /* ('uge', ('bcsel', 'a', '#b', '#c'), '#d') => ('bcsel', 'a', ('uge', 'b', 'd'), ('uge', 'c', 'd')) */
   /* search1954_0_0 -> 760 in the cache */
   /* search1954_0_1 -> 1028 in the cache */
   /* search1954_0_2 -> 3514 in the cache */
   /* search1954_0 -> 5534 in the cache */
   /* search1954_1 -> 1031 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 5534, 1031 },
      -1,
   } },

   /* replace1954_0 -> 760 in the cache */
   /* replace1954_1_0 -> 150 in the cache */
   /* replace1954_1_1 -> 153 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 150, 153 },
      -1,
   } },
   /* replace1954_2_0 -> 152 in the cache */
   /* replace1954_2_1 -> 153 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 152, 153 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 760, 5598, 5599 },
      -1,
   } },

   /* ('uge', '#d', ('bcsel', 'a', '#b', '#c')) => ('bcsel', 'a', ('uge', 'd', 'b'), ('uge', 'd', 'c')) */
   /* search1955_0 -> 5555 in the cache */
   /* search1955_1_0 -> 1176 in the cache */
   /* search1955_1_1 -> 5556 in the cache */
   /* search1955_1_2 -> 5557 in the cache */
   /* search1955_1 -> 5558 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 5555, 5558 },
      -1,
   } },

   /* replace1955_0 -> 1176 in the cache */
   /* replace1955_1_0 -> 5560 in the cache */
   /* replace1955_1_1 -> 5561 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 5560, 5561 },
      -1,
   } },
   /* replace1955_2_0 -> 5560 in the cache */
   /* replace1955_2_1 -> 1726 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_uge,
      -1, 0,
      { 5560, 1726 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 1176, 5602, 5603 },
      -1,
   } },

   /* ('fadd', ('bcsel(is_used_once)', 'a', '#b', 'c'), '#d') => ('bcsel', 'a', ('fadd', 'b', 'd'), ('fadd', 'c', 'd')) */
   /* search1956_0_0 -> 760 in the cache */
   /* search1956_0_1 -> 1028 in the cache */
   /* search1956_0_2 -> 152 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 760, 1028, 152 },
      0,
   } },
   /* search1956_1 -> 1031 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 5605, 1031 },
      -1,
   } },

   /* replace1956_0 -> 760 in the cache */
   /* replace1956_1_0 -> 150 in the cache */
   /* replace1956_1_1 -> 153 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 150, 153 },
      -1,
   } },
   /* replace1956_2_0 -> 152 in the cache */
   /* replace1956_2_1 -> 153 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 152, 153 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 760, 5607, 5608 },
      -1,
   } },

   /* ('fmul', ('bcsel(is_used_once)', 'a', '#b', 'c'), '#d') => ('bcsel', 'a', ('fmul', 'b', 'd'), ('fmul', 'c', 'd')) */
   /* search1957_0_0 -> 760 in the cache */
   /* search1957_0_1 -> 1028 in the cache */
   /* search1957_0_2 -> 152 in the cache */
   /* search1957_0 -> 5605 in the cache */
   /* search1957_1 -> 1031 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 5605, 1031 },
      -1,
   } },

   /* replace1957_0 -> 760 in the cache */
   /* replace1957_1_0 -> 150 in the cache */
   /* replace1957_1_1 -> 153 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 150, 153 },
      -1,
   } },
   /* replace1957_2_0 -> 152 in the cache */
   /* replace1957_2_1 -> 153 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 152, 153 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 760, 5611, 5612 },
      -1,
   } },

   /* ('fmulz', ('bcsel(is_used_once)', 'a', '#b', 'c'), '#d') => ('bcsel', 'a', ('fmulz', 'b', 'd'), ('fmulz', 'c', 'd')) */
   /* search1958_0_0 -> 760 in the cache */
   /* search1958_0_1 -> 33 in the cache */
   /* search1958_0_2 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 760, 33, 135 },
      0,
   } },
   /* search1958_1 -> 311 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 5614, 311 },
      -1,
   } },

   /* replace1958_0 -> 760 in the cache */
   /* replace1958_1_0 -> 36 in the cache */
   /* replace1958_1_1 -> 163 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 36, 163 },
      -1,
   } },
   /* replace1958_2_0 -> 135 in the cache */
   /* replace1958_2_1 -> 163 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      1, 1,
      { 135, 163 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 760, 5616, 5617 },
      -1,
   } },

   /* ('iadd', ('bcsel(is_used_once)', 'a', '#b', 'c'), '#d') => ('bcsel', 'a', ('iadd', 'b', 'd'), ('iadd', 'c', 'd')) */
   /* search1959_0_0 -> 760 in the cache */
   /* search1959_0_1 -> 1028 in the cache */
   /* search1959_0_2 -> 152 in the cache */
   /* search1959_0 -> 5605 in the cache */
   /* search1959_1 -> 1031 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 5605, 1031 },
      -1,
   } },

   /* replace1959_0 -> 760 in the cache */
   /* replace1959_1_0 -> 150 in the cache */
   /* replace1959_1_1 -> 153 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 150, 153 },
      -1,
   } },
   /* replace1959_2_0 -> 152 in the cache */
   /* replace1959_2_1 -> 153 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 152, 153 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 760, 5620, 5621 },
      -1,
   } },

   /* ('imul', ('bcsel(is_used_once)', 'a', '#b', 'c'), '#d') => ('bcsel', 'a', ('imul', 'b', 'd'), ('imul', 'c', 'd')) */
   /* search1960_0_0 -> 760 in the cache */
   /* search1960_0_1 -> 1028 in the cache */
   /* search1960_0_2 -> 152 in the cache */
   /* search1960_0 -> 5605 in the cache */
   /* search1960_1 -> 1031 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 5605, 1031 },
      -1,
   } },

   /* replace1960_0 -> 760 in the cache */
   /* replace1960_1_0 -> 150 in the cache */
   /* replace1960_1_1 -> 153 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 150, 153 },
      -1,
   } },
   /* replace1960_2_0 -> 152 in the cache */
   /* replace1960_2_1 -> 153 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imul,
      1, 1,
      { 152, 153 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 760, 5624, 5625 },
      -1,
   } },

   /* ('fddx', 'a') => 0.0 */
   /* search1961_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fddx,
      -1, 0,
      { 32 },
      -1,
   } },

   /* replace1961 -> 111 in the cache */

   /* ('fddx_fine', 'a') => 0.0 */
   /* search1962_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fddx_fine,
      -1, 0,
      { 32 },
      -1,
   } },

   /* replace1962 -> 111 in the cache */

   /* ('fddx_coarse', 'a') => 0.0 */
   /* search1963_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fddx_coarse,
      -1, 0,
      { 32 },
      -1,
   } },

   /* replace1963 -> 111 in the cache */

   /* ('fddy', 'a') => 0.0 */
   /* search1964_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fddy,
      -1, 0,
      { 32 },
      -1,
   } },

   /* replace1964 -> 111 in the cache */

   /* ('fddy_fine', 'a') => 0.0 */
   /* search1965_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fddy_fine,
      -1, 0,
      { 32 },
      -1,
   } },

   /* replace1965 -> 111 in the cache */

   /* ('fddy_coarse', 'a') => 0.0 */
   /* search1966_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fddy_coarse,
      -1, 0,
      { 32 },
      -1,
   } },

   /* replace1966 -> 111 in the cache */

   /* ('umul_low', '#a(is_lower_half_zero)', 'b') => 0 */
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* a */
      true,
      nir_type_invalid,
      20,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search1967_1 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_umul_low,
      0, 1,
      { 5633, 36 },
      -1,
   } },

   /* replace1967 -> 122 in the cache */

   /* ('imadsh_mix16', '#a@32(is_lower_half_zero)', 'b@32', 'c@32') => c */
   /* search1968_0 -> 5633 in the cache */
   /* search1968_1 -> 36 in the cache */
   /* search1968_2 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imadsh_mix16,
      -1, 0,
      { 5633, 36, 135 },
      -1,
   } },

   /* replace1968 -> 135 in the cache */

   /* ('imadsh_mix16', 'a@32', '#b@32(is_upper_half_zero)', 'c@32') => c */
   /* search1969_0 -> 16 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      true,
      nir_type_invalid,
      21,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search1969_2 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_imadsh_mix16,
      -1, 0,
      { 16, 5636, 135 },
      -1,
   } },

   /* replace1969 -> 135 in the cache */

   /* ('bcsel', 'a', ('flrp(is_used_once)', 'b', 'c', 'd'), ('flrp', 'b', 'c', 'e')) => ('flrp', 'b', 'c', ('bcsel', 'a', 'd', 'e')) */
   /* search1970_0 -> 760 in the cache */
   /* search1970_1_0 -> 752 in the cache */
   /* search1970_1_1 -> 753 in the cache */
   /* search1970_1_2 -> 762 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 752, 753, 762 },
      0,
   } },
   /* search1970_2_0 -> 752 in the cache */
   /* search1970_2_1 -> 753 in the cache */
   /* search1970_2_2 -> 764 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 752, 753, 764 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 760, 5638, 5639 },
      -1,
   } },

   /* replace1970_0 -> 752 in the cache */
   /* replace1970_1 -> 753 in the cache */
   /* replace1970_2_0 -> 760 in the cache */
   /* replace1970_2_1 -> 762 in the cache */
   /* replace1970_2_2 -> 764 in the cache */
   /* replace1970_2 -> 1317 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 752, 753, 1317 },
      -1,
   } },

   /* ('bcsel', 'a', ('flrp', 'b', 'c', 'd'), ('flrp(is_used_once)', 'b', 'c', 'e')) => ('flrp', 'b', 'c', ('bcsel', 'a', 'd', 'e')) */
   /* search1971_0 -> 760 in the cache */
   /* search1971_1_0 -> 752 in the cache */
   /* search1971_1_1 -> 753 in the cache */
   /* search1971_1_2 -> 762 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 752, 753, 762 },
      -1,
   } },
   /* search1971_2_0 -> 752 in the cache */
   /* search1971_2_1 -> 753 in the cache */
   /* search1971_2_2 -> 764 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 752, 753, 764 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 760, 5642, 5643 },
      -1,
   } },

   /* replace1971_0 -> 752 in the cache */
   /* replace1971_1 -> 753 in the cache */
   /* replace1971_2_0 -> 760 in the cache */
   /* replace1971_2_1 -> 762 in the cache */
   /* replace1971_2_2 -> 764 in the cache */
   /* replace1971_2 -> 1317 in the cache */
   /* replace1971 -> 5641 in the cache */

   /* ('bcsel', 'a', ('flrp(is_used_once)', 'b', 'c', 'd'), ('flrp', 'b', 'e', 'd')) => ('flrp', 'b', ('bcsel', 'a', 'c', 'e'), 'd') */
   /* search1972_0 -> 760 in the cache */
   /* search1972_1_0 -> 752 in the cache */
   /* search1972_1_1 -> 753 in the cache */
   /* search1972_1_2 -> 762 in the cache */
   /* search1972_1 -> 5638 in the cache */
   /* search1972_2_0 -> 752 in the cache */
   /* search1972_2_1 -> 764 in the cache */
   /* search1972_2_2 -> 762 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 752, 764, 762 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 760, 5638, 5645 },
      -1,
   } },

   /* replace1972_0 -> 752 in the cache */
   /* replace1972_1_0 -> 760 in the cache */
   /* replace1972_1_1 -> 753 in the cache */
   /* replace1972_1_2 -> 764 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 760, 753, 764 },
      -1,
   } },
   /* replace1972_2 -> 762 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 752, 5647, 762 },
      -1,
   } },

   /* ('bcsel', 'a', ('flrp', 'b', 'c', 'd'), ('flrp(is_used_once)', 'b', 'e', 'd')) => ('flrp', 'b', ('bcsel', 'a', 'c', 'e'), 'd') */
   /* search1973_0 -> 760 in the cache */
   /* search1973_1_0 -> 752 in the cache */
   /* search1973_1_1 -> 753 in the cache */
   /* search1973_1_2 -> 762 in the cache */
   /* search1973_1 -> 5642 in the cache */
   /* search1973_2_0 -> 752 in the cache */
   /* search1973_2_1 -> 764 in the cache */
   /* search1973_2_2 -> 762 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 752, 764, 762 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 760, 5642, 5649 },
      -1,
   } },

   /* replace1973_0 -> 752 in the cache */
   /* replace1973_1_0 -> 760 in the cache */
   /* replace1973_1_1 -> 753 in the cache */
   /* replace1973_1_2 -> 764 in the cache */
   /* replace1973_1 -> 5647 in the cache */
   /* replace1973_2 -> 762 in the cache */
   /* replace1973 -> 5648 in the cache */

   /* ('bcsel', 'a', ('flrp(is_used_once)', 'b', 'c', 'd'), ('flrp', 'e', 'c', 'd')) => ('flrp', ('bcsel', 'a', 'b', 'e'), 'c', 'd') */
   /* search1974_0 -> 760 in the cache */
   /* search1974_1_0 -> 150 in the cache */
   /* search1974_1_1 -> 152 in the cache */
   /* search1974_1_2 -> 153 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 150, 152, 153 },
      0,
   } },
   /* search1974_2_0 -> 1323 in the cache */
   /* search1974_2_1 -> 152 in the cache */
   /* search1974_2_2 -> 153 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 1323, 152, 153 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 760, 5651, 5652 },
      -1,
   } },

   /* replace1974_0_0 -> 760 in the cache */
   /* replace1974_0_1 -> 150 in the cache */
   /* replace1974_0_2 -> 1323 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 760, 150, 1323 },
      -1,
   } },
   /* replace1974_1 -> 152 in the cache */
   /* replace1974_2 -> 153 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 5654, 152, 153 },
      -1,
   } },

   /* ('bcsel', 'a', ('flrp', 'b', 'c', 'd'), ('flrp(is_used_once)', 'e', 'c', 'd')) => ('flrp', ('bcsel', 'a', 'b', 'e'), 'c', 'd') */
   /* search1975_0 -> 760 in the cache */
   /* search1975_1_0 -> 150 in the cache */
   /* search1975_1_1 -> 152 in the cache */
   /* search1975_1_2 -> 153 in the cache */
   /* search1975_1 -> 682 in the cache */
   /* search1975_2_0 -> 1323 in the cache */
   /* search1975_2_1 -> 152 in the cache */
   /* search1975_2_2 -> 153 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 1323, 152, 153 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 760, 682, 5656 },
      -1,
   } },

   /* replace1975_0_0 -> 760 in the cache */
   /* replace1975_0_1 -> 150 in the cache */
   /* replace1975_0_2 -> 1323 in the cache */
   /* replace1975_0 -> 5654 in the cache */
   /* replace1975_1 -> 152 in the cache */
   /* replace1975_2 -> 153 in the cache */
   /* replace1975 -> 5655 in the cache */

   /* ('bcsel', 'a', ('fmulz(is_used_once)', 'b', 'c'), ('fmulz', 'b', 'd(is_not_const)')) => ('fmulz', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1976_0 -> 760 in the cache */
   /* search1976_1_0 -> 36 in the cache */
   /* search1976_1_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 36, 135 },
      0,
   } },
   /* search1976_2_0 -> 36 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      3, /* d */
      false,
      nir_type_invalid,
      5,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      1, 1,
      { 36, 5659 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 760, 5658, 5660 },
      -1,
   } },

   /* replace1976_0 -> 36 in the cache */
   /* replace1976_1_0 -> 760 in the cache */
   /* replace1976_1_1 -> 135 in the cache */
   /* replace1976_1_2 -> 163 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 760, 135, 163 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 36, 5662 },
      -1,
   } },

   /* ('bcsel', 'a', ('fmulz(is_used_once)', 'b', 'c(is_not_const)'), ('fmulz', 'b', 'd')) => ('fmulz', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1977_0 -> 760 in the cache */
   /* search1977_1_0 -> 36 in the cache */
   /* search1977_1_1 -> 347 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 36, 347 },
      0,
   } },
   /* search1977_2_0 -> 36 in the cache */
   /* search1977_2_1 -> 163 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      1, 1,
      { 36, 163 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 760, 5664, 5665 },
      -1,
   } },

   /* replace1977_0 -> 36 in the cache */
   /* replace1977_1_0 -> 760 in the cache */
   /* replace1977_1_1 -> 135 in the cache */
   /* replace1977_1_2 -> 163 in the cache */
   /* replace1977_1 -> 5662 in the cache */
   /* replace1977 -> 5663 in the cache */

   /* ('bcsel', 'a', ('fmulz', 'b', 'c(is_not_const)'), ('fmulz(is_used_once)', 'b', 'd')) => ('fmulz', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1978_0 -> 760 in the cache */
   /* search1978_1_0 -> 36 in the cache */
   /* search1978_1_1 -> 347 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 36, 347 },
      -1,
   } },
   /* search1978_2_0 -> 36 in the cache */
   /* search1978_2_1 -> 163 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      1, 1,
      { 36, 163 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 760, 5667, 5668 },
      -1,
   } },

   /* replace1978_0 -> 36 in the cache */
   /* replace1978_1_0 -> 760 in the cache */
   /* replace1978_1_1 -> 135 in the cache */
   /* replace1978_1_2 -> 163 in the cache */
   /* replace1978_1 -> 5662 in the cache */
   /* replace1978 -> 5663 in the cache */

   /* ('bcsel', 'a', ('fmulz', 'b', 'c'), ('fmulz(is_used_once)', 'b', 'd(is_not_const)')) => ('fmulz', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1979_0 -> 760 in the cache */
   /* search1979_1_0 -> 36 in the cache */
   /* search1979_1_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      0, 1,
      { 36, 135 },
      -1,
   } },
   /* search1979_2_0 -> 36 in the cache */
   /* search1979_2_1 -> 5659 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      1, 1,
      { 36, 5659 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 760, 5670, 5671 },
      -1,
   } },

   /* replace1979_0 -> 36 in the cache */
   /* replace1979_1_0 -> 760 in the cache */
   /* replace1979_1_1 -> 135 in the cache */
   /* replace1979_1_2 -> 163 in the cache */
   /* replace1979_1 -> 5662 in the cache */
   /* replace1979 -> 5663 in the cache */

   /* ('bcsel', 'a', ('fmul(is_used_once)', 'b', 'c'), ('fmul', 'b', 'd(is_not_const)')) => ('fmul', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1980_0 -> 760 in the cache */
   /* search1980_1_0 -> 150 in the cache */
   /* search1980_1_1 -> 152 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 150, 152 },
      0,
   } },
   /* search1980_2_0 -> 150 in the cache */
   { .variable = {
      { nir_search_value_variable, -4 },
      3, /* d */
      false,
      nir_type_invalid,
      5,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 150, 5674 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 760, 5673, 5675 },
      -1,
   } },

   /* replace1980_0 -> 150 in the cache */
   /* replace1980_1_0 -> 760 in the cache */
   /* replace1980_1_1 -> 152 in the cache */
   /* replace1980_1_2 -> 153 in the cache */
   /* replace1980_1 -> 1312 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 150, 1312 },
      -1,
   } },

   /* ('bcsel', 'a', ('fmul(is_used_once)', 'b', 'c(is_not_const)'), ('fmul', 'b', 'd')) => ('fmul', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1981_0 -> 760 in the cache */
   /* search1981_1_0 -> 150 in the cache */
   /* search1981_1_1 -> 3529 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 150, 3529 },
      0,
   } },
   /* search1981_2_0 -> 150 in the cache */
   /* search1981_2_1 -> 153 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 150, 153 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 760, 5678, 5679 },
      -1,
   } },

   /* replace1981_0 -> 150 in the cache */
   /* replace1981_1_0 -> 760 in the cache */
   /* replace1981_1_1 -> 152 in the cache */
   /* replace1981_1_2 -> 153 in the cache */
   /* replace1981_1 -> 1312 in the cache */
   /* replace1981 -> 5677 in the cache */

   /* ('bcsel', 'a', ('fmul', 'b', 'c(is_not_const)'), ('fmul(is_used_once)', 'b', 'd')) => ('fmul', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1982_0 -> 760 in the cache */
   /* search1982_1_0 -> 150 in the cache */
   /* search1982_1_1 -> 3529 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 150, 3529 },
      -1,
   } },
   /* search1982_2_0 -> 150 in the cache */
   /* search1982_2_1 -> 153 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 150, 153 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 760, 5681, 5682 },
      -1,
   } },

   /* replace1982_0 -> 150 in the cache */
   /* replace1982_1_0 -> 760 in the cache */
   /* replace1982_1_1 -> 152 in the cache */
   /* replace1982_1_2 -> 153 in the cache */
   /* replace1982_1 -> 1312 in the cache */
   /* replace1982 -> 5677 in the cache */

   /* ('bcsel', 'a', ('fmul', 'b', 'c'), ('fmul(is_used_once)', 'b', 'd(is_not_const)')) => ('fmul', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1983_0 -> 760 in the cache */
   /* search1983_1_0 -> 150 in the cache */
   /* search1983_1_1 -> 152 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 150, 152 },
      -1,
   } },
   /* search1983_2_0 -> 150 in the cache */
   /* search1983_2_1 -> 5674 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 150, 5674 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 760, 5684, 5685 },
      -1,
   } },

   /* replace1983_0 -> 150 in the cache */
   /* replace1983_1_0 -> 760 in the cache */
   /* replace1983_1_1 -> 152 in the cache */
   /* replace1983_1_2 -> 153 in the cache */
   /* replace1983_1 -> 1312 in the cache */
   /* replace1983 -> 5677 in the cache */

   /* ('bcsel', 'a', ('iadd(is_used_once)', 'b', 'c'), ('iadd', 'b', 'd(is_not_const)')) => ('iadd', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1984_0 -> 760 in the cache */
   /* search1984_1_0 -> 150 in the cache */
   /* search1984_1_1 -> 152 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 150, 152 },
      0,
   } },
   /* search1984_2_0 -> 150 in the cache */
   /* search1984_2_1 -> 5674 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 150, 5674 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 760, 5687, 5688 },
      -1,
   } },

   /* replace1984_0 -> 150 in the cache */
   /* replace1984_1_0 -> 760 in the cache */
   /* replace1984_1_1 -> 152 in the cache */
   /* replace1984_1_2 -> 153 in the cache */
   /* replace1984_1 -> 1312 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 150, 1312 },
      -1,
   } },

   /* ('bcsel', 'a', ('iadd(is_used_once)', 'b', 'c(is_not_const)'), ('iadd', 'b', 'd')) => ('iadd', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1985_0 -> 760 in the cache */
   /* search1985_1_0 -> 150 in the cache */
   /* search1985_1_1 -> 3529 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 150, 3529 },
      0,
   } },
   /* search1985_2_0 -> 150 in the cache */
   /* search1985_2_1 -> 153 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 150, 153 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 760, 5691, 5692 },
      -1,
   } },

   /* replace1985_0 -> 150 in the cache */
   /* replace1985_1_0 -> 760 in the cache */
   /* replace1985_1_1 -> 152 in the cache */
   /* replace1985_1_2 -> 153 in the cache */
   /* replace1985_1 -> 1312 in the cache */
   /* replace1985 -> 5690 in the cache */

   /* ('bcsel', 'a', ('iadd', 'b', 'c(is_not_const)'), ('iadd(is_used_once)', 'b', 'd')) => ('iadd', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1986_0 -> 760 in the cache */
   /* search1986_1_0 -> 150 in the cache */
   /* search1986_1_1 -> 3529 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 150, 3529 },
      -1,
   } },
   /* search1986_2_0 -> 150 in the cache */
   /* search1986_2_1 -> 153 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 150, 153 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 760, 5694, 5695 },
      -1,
   } },

   /* replace1986_0 -> 150 in the cache */
   /* replace1986_1_0 -> 760 in the cache */
   /* replace1986_1_1 -> 152 in the cache */
   /* replace1986_1_2 -> 153 in the cache */
   /* replace1986_1 -> 1312 in the cache */
   /* replace1986 -> 5690 in the cache */

   /* ('bcsel', 'a', ('iadd', 'b', 'c'), ('iadd(is_used_once)', 'b', 'd(is_not_const)')) => ('iadd', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1987_0 -> 760 in the cache */
   /* search1987_1_0 -> 150 in the cache */
   /* search1987_1_1 -> 152 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 150, 152 },
      -1,
   } },
   /* search1987_2_0 -> 150 in the cache */
   /* search1987_2_1 -> 5674 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 150, 5674 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 760, 5697, 5698 },
      -1,
   } },

   /* replace1987_0 -> 150 in the cache */
   /* replace1987_1_0 -> 760 in the cache */
   /* replace1987_1_1 -> 152 in the cache */
   /* replace1987_1_2 -> 153 in the cache */
   /* replace1987_1 -> 1312 in the cache */
   /* replace1987 -> 5690 in the cache */

   /* ('bcsel', 'a', ('imul(is_used_once)', 'b', 'c'), ('imul', 'b', 'd(is_not_const)')) => ('imul', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1988_0 -> 760 in the cache */
   /* search1988_1_0 -> 150 in the cache */
   /* search1988_1_1 -> 152 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 150, 152 },
      0,
   } },
   /* search1988_2_0 -> 150 in the cache */
   /* search1988_2_1 -> 5674 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imul,
      1, 1,
      { 150, 5674 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 760, 5700, 5701 },
      -1,
   } },

   /* replace1988_0 -> 150 in the cache */
   /* replace1988_1_0 -> 760 in the cache */
   /* replace1988_1_1 -> 152 in the cache */
   /* replace1988_1_2 -> 153 in the cache */
   /* replace1988_1 -> 1312 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 150, 1312 },
      -1,
   } },

   /* ('bcsel', 'a', ('imul(is_used_once)', 'b', 'c(is_not_const)'), ('imul', 'b', 'd')) => ('imul', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1989_0 -> 760 in the cache */
   /* search1989_1_0 -> 150 in the cache */
   /* search1989_1_1 -> 3529 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 150, 3529 },
      0,
   } },
   /* search1989_2_0 -> 150 in the cache */
   /* search1989_2_1 -> 153 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imul,
      1, 1,
      { 150, 153 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 760, 5704, 5705 },
      -1,
   } },

   /* replace1989_0 -> 150 in the cache */
   /* replace1989_1_0 -> 760 in the cache */
   /* replace1989_1_1 -> 152 in the cache */
   /* replace1989_1_2 -> 153 in the cache */
   /* replace1989_1 -> 1312 in the cache */
   /* replace1989 -> 5703 in the cache */

   /* ('bcsel', 'a', ('imul', 'b', 'c(is_not_const)'), ('imul(is_used_once)', 'b', 'd')) => ('imul', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1990_0 -> 760 in the cache */
   /* search1990_1_0 -> 150 in the cache */
   /* search1990_1_1 -> 3529 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 150, 3529 },
      -1,
   } },
   /* search1990_2_0 -> 150 in the cache */
   /* search1990_2_1 -> 153 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imul,
      1, 1,
      { 150, 153 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 760, 5707, 5708 },
      -1,
   } },

   /* replace1990_0 -> 150 in the cache */
   /* replace1990_1_0 -> 760 in the cache */
   /* replace1990_1_1 -> 152 in the cache */
   /* replace1990_1_2 -> 153 in the cache */
   /* replace1990_1 -> 1312 in the cache */
   /* replace1990 -> 5703 in the cache */

   /* ('bcsel', 'a', ('imul', 'b', 'c'), ('imul(is_used_once)', 'b', 'd(is_not_const)')) => ('imul', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1991_0 -> 760 in the cache */
   /* search1991_1_0 -> 150 in the cache */
   /* search1991_1_1 -> 152 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imul,
      0, 1,
      { 150, 152 },
      -1,
   } },
   /* search1991_2_0 -> 150 in the cache */
   /* search1991_2_1 -> 5674 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imul,
      1, 1,
      { 150, 5674 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 760, 5710, 5711 },
      -1,
   } },

   /* replace1991_0 -> 150 in the cache */
   /* replace1991_1_0 -> 760 in the cache */
   /* replace1991_1_1 -> 152 in the cache */
   /* replace1991_1_2 -> 153 in the cache */
   /* replace1991_1 -> 1312 in the cache */
   /* replace1991 -> 5703 in the cache */

   /* ('bcsel', 'a', ('iand(is_used_once)', 'b', 'c'), ('iand', 'b', 'd(is_not_const)')) => ('iand', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1992_0 -> 760 in the cache */
   /* search1992_1_0 -> 150 in the cache */
   /* search1992_1_1 -> 152 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 150, 152 },
      0,
   } },
   /* search1992_2_0 -> 150 in the cache */
   /* search1992_2_1 -> 5674 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 150, 5674 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 760, 5713, 5714 },
      -1,
   } },

   /* replace1992_0 -> 150 in the cache */
   /* replace1992_1_0 -> 760 in the cache */
   /* replace1992_1_1 -> 152 in the cache */
   /* replace1992_1_2 -> 153 in the cache */
   /* replace1992_1 -> 1312 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 150, 1312 },
      -1,
   } },

   /* ('bcsel', 'a', ('iand(is_used_once)', 'b', 'c(is_not_const)'), ('iand', 'b', 'd')) => ('iand', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1993_0 -> 760 in the cache */
   /* search1993_1_0 -> 150 in the cache */
   /* search1993_1_1 -> 3529 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 150, 3529 },
      0,
   } },
   /* search1993_2_0 -> 150 in the cache */
   /* search1993_2_1 -> 153 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 150, 153 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 760, 5717, 5718 },
      -1,
   } },

   /* replace1993_0 -> 150 in the cache */
   /* replace1993_1_0 -> 760 in the cache */
   /* replace1993_1_1 -> 152 in the cache */
   /* replace1993_1_2 -> 153 in the cache */
   /* replace1993_1 -> 1312 in the cache */
   /* replace1993 -> 5716 in the cache */

   /* ('bcsel', 'a', ('iand', 'b', 'c(is_not_const)'), ('iand(is_used_once)', 'b', 'd')) => ('iand', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1994_0 -> 760 in the cache */
   /* search1994_1_0 -> 150 in the cache */
   /* search1994_1_1 -> 3529 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 150, 3529 },
      -1,
   } },
   /* search1994_2_0 -> 150 in the cache */
   /* search1994_2_1 -> 153 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 150, 153 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 760, 5720, 5721 },
      -1,
   } },

   /* replace1994_0 -> 150 in the cache */
   /* replace1994_1_0 -> 760 in the cache */
   /* replace1994_1_1 -> 152 in the cache */
   /* replace1994_1_2 -> 153 in the cache */
   /* replace1994_1 -> 1312 in the cache */
   /* replace1994 -> 5716 in the cache */

   /* ('bcsel', 'a', ('iand', 'b', 'c'), ('iand(is_used_once)', 'b', 'd(is_not_const)')) => ('iand', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1995_0 -> 760 in the cache */
   /* search1995_1_0 -> 150 in the cache */
   /* search1995_1_1 -> 152 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 150, 152 },
      -1,
   } },
   /* search1995_2_0 -> 150 in the cache */
   /* search1995_2_1 -> 5674 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_iand,
      1, 1,
      { 150, 5674 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 760, 5723, 5724 },
      -1,
   } },

   /* replace1995_0 -> 150 in the cache */
   /* replace1995_1_0 -> 760 in the cache */
   /* replace1995_1_1 -> 152 in the cache */
   /* replace1995_1_2 -> 153 in the cache */
   /* replace1995_1 -> 1312 in the cache */
   /* replace1995 -> 5716 in the cache */

   /* ('bcsel', 'a', ('ior(is_used_once)', 'b', 'c'), ('ior', 'b', 'd(is_not_const)')) => ('ior', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1996_0 -> 760 in the cache */
   /* search1996_1_0 -> 150 in the cache */
   /* search1996_1_1 -> 152 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 150, 152 },
      0,
   } },
   /* search1996_2_0 -> 150 in the cache */
   /* search1996_2_1 -> 5674 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 150, 5674 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 760, 5726, 5727 },
      -1,
   } },

   /* replace1996_0 -> 150 in the cache */
   /* replace1996_1_0 -> 760 in the cache */
   /* replace1996_1_1 -> 152 in the cache */
   /* replace1996_1_2 -> 153 in the cache */
   /* replace1996_1 -> 1312 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 150, 1312 },
      -1,
   } },

   /* ('bcsel', 'a', ('ior(is_used_once)', 'b', 'c(is_not_const)'), ('ior', 'b', 'd')) => ('ior', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1997_0 -> 760 in the cache */
   /* search1997_1_0 -> 150 in the cache */
   /* search1997_1_1 -> 3529 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 150, 3529 },
      0,
   } },
   /* search1997_2_0 -> 150 in the cache */
   /* search1997_2_1 -> 153 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 150, 153 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 760, 5730, 5731 },
      -1,
   } },

   /* replace1997_0 -> 150 in the cache */
   /* replace1997_1_0 -> 760 in the cache */
   /* replace1997_1_1 -> 152 in the cache */
   /* replace1997_1_2 -> 153 in the cache */
   /* replace1997_1 -> 1312 in the cache */
   /* replace1997 -> 5729 in the cache */

   /* ('bcsel', 'a', ('ior', 'b', 'c(is_not_const)'), ('ior(is_used_once)', 'b', 'd')) => ('ior', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1998_0 -> 760 in the cache */
   /* search1998_1_0 -> 150 in the cache */
   /* search1998_1_1 -> 3529 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 150, 3529 },
      -1,
   } },
   /* search1998_2_0 -> 150 in the cache */
   /* search1998_2_1 -> 153 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 150, 153 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 760, 5733, 5734 },
      -1,
   } },

   /* replace1998_0 -> 150 in the cache */
   /* replace1998_1_0 -> 760 in the cache */
   /* replace1998_1_1 -> 152 in the cache */
   /* replace1998_1_2 -> 153 in the cache */
   /* replace1998_1 -> 1312 in the cache */
   /* replace1998 -> 5729 in the cache */

   /* ('bcsel', 'a', ('ior', 'b', 'c'), ('ior(is_used_once)', 'b', 'd(is_not_const)')) => ('ior', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search1999_0 -> 760 in the cache */
   /* search1999_1_0 -> 150 in the cache */
   /* search1999_1_1 -> 152 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 150, 152 },
      -1,
   } },
   /* search1999_2_0 -> 150 in the cache */
   /* search1999_2_1 -> 5674 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ior,
      1, 1,
      { 150, 5674 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 760, 5736, 5737 },
      -1,
   } },

   /* replace1999_0 -> 150 in the cache */
   /* replace1999_1_0 -> 760 in the cache */
   /* replace1999_1_1 -> 152 in the cache */
   /* replace1999_1_2 -> 153 in the cache */
   /* replace1999_1 -> 1312 in the cache */
   /* replace1999 -> 5729 in the cache */

   /* ('bcsel', 'a', ('ixor(is_used_once)', 'b', 'c'), ('ixor', 'b', 'd(is_not_const)')) => ('ixor', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search2000_0 -> 760 in the cache */
   /* search2000_1_0 -> 150 in the cache */
   /* search2000_1_1 -> 152 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 150, 152 },
      0,
   } },
   /* search2000_2_0 -> 150 in the cache */
   /* search2000_2_1 -> 5674 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ixor,
      1, 1,
      { 150, 5674 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 760, 5739, 5740 },
      -1,
   } },

   /* replace2000_0 -> 150 in the cache */
   /* replace2000_1_0 -> 760 in the cache */
   /* replace2000_1_1 -> 152 in the cache */
   /* replace2000_1_2 -> 153 in the cache */
   /* replace2000_1 -> 1312 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 150, 1312 },
      -1,
   } },

   /* ('bcsel', 'a', ('ixor(is_used_once)', 'b', 'c(is_not_const)'), ('ixor', 'b', 'd')) => ('ixor', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search2001_0 -> 760 in the cache */
   /* search2001_1_0 -> 150 in the cache */
   /* search2001_1_1 -> 3529 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 150, 3529 },
      0,
   } },
   /* search2001_2_0 -> 150 in the cache */
   /* search2001_2_1 -> 153 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ixor,
      1, 1,
      { 150, 153 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 760, 5743, 5744 },
      -1,
   } },

   /* replace2001_0 -> 150 in the cache */
   /* replace2001_1_0 -> 760 in the cache */
   /* replace2001_1_1 -> 152 in the cache */
   /* replace2001_1_2 -> 153 in the cache */
   /* replace2001_1 -> 1312 in the cache */
   /* replace2001 -> 5742 in the cache */

   /* ('bcsel', 'a', ('ixor', 'b', 'c(is_not_const)'), ('ixor(is_used_once)', 'b', 'd')) => ('ixor', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search2002_0 -> 760 in the cache */
   /* search2002_1_0 -> 150 in the cache */
   /* search2002_1_1 -> 3529 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 150, 3529 },
      -1,
   } },
   /* search2002_2_0 -> 150 in the cache */
   /* search2002_2_1 -> 153 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ixor,
      1, 1,
      { 150, 153 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 760, 5746, 5747 },
      -1,
   } },

   /* replace2002_0 -> 150 in the cache */
   /* replace2002_1_0 -> 760 in the cache */
   /* replace2002_1_1 -> 152 in the cache */
   /* replace2002_1_2 -> 153 in the cache */
   /* replace2002_1 -> 1312 in the cache */
   /* replace2002 -> 5742 in the cache */

   /* ('bcsel', 'a', ('ixor', 'b', 'c'), ('ixor(is_used_once)', 'b', 'd(is_not_const)')) => ('ixor', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search2003_0 -> 760 in the cache */
   /* search2003_1_0 -> 150 in the cache */
   /* search2003_1_1 -> 152 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ixor,
      0, 1,
      { 150, 152 },
      -1,
   } },
   /* search2003_2_0 -> 150 in the cache */
   /* search2003_2_1 -> 5674 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_ixor,
      1, 1,
      { 150, 5674 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 760, 5749, 5750 },
      -1,
   } },

   /* replace2003_0 -> 150 in the cache */
   /* replace2003_1_0 -> 760 in the cache */
   /* replace2003_1_1 -> 152 in the cache */
   /* replace2003_1_2 -> 153 in the cache */
   /* replace2003_1 -> 1312 in the cache */
   /* replace2003 -> 5742 in the cache */

   /* ('bcsel', 'a', ('fmin(is_used_once)', 'b', 'c'), ('fmin', 'b', 'd(is_not_const)')) => ('fmin', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search2004_0 -> 760 in the cache */
   /* search2004_1_0 -> 150 in the cache */
   /* search2004_1_1 -> 152 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 150, 152 },
      0,
   } },
   /* search2004_2_0 -> 150 in the cache */
   /* search2004_2_1 -> 5674 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmin,
      1, 1,
      { 150, 5674 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 760, 5752, 5753 },
      -1,
   } },

   /* replace2004_0 -> 150 in the cache */
   /* replace2004_1_0 -> 760 in the cache */
   /* replace2004_1_1 -> 152 in the cache */
   /* replace2004_1_2 -> 153 in the cache */
   /* replace2004_1 -> 1312 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 150, 1312 },
      -1,
   } },

   /* ('bcsel', 'a', ('fmin(is_used_once)', 'b', 'c(is_not_const)'), ('fmin', 'b', 'd')) => ('fmin', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search2005_0 -> 760 in the cache */
   /* search2005_1_0 -> 150 in the cache */
   /* search2005_1_1 -> 3529 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 150, 3529 },
      0,
   } },
   /* search2005_2_0 -> 150 in the cache */
   /* search2005_2_1 -> 153 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmin,
      1, 1,
      { 150, 153 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 760, 5756, 5757 },
      -1,
   } },

   /* replace2005_0 -> 150 in the cache */
   /* replace2005_1_0 -> 760 in the cache */
   /* replace2005_1_1 -> 152 in the cache */
   /* replace2005_1_2 -> 153 in the cache */
   /* replace2005_1 -> 1312 in the cache */
   /* replace2005 -> 5755 in the cache */

   /* ('bcsel', 'a', ('fmin', 'b', 'c(is_not_const)'), ('fmin(is_used_once)', 'b', 'd')) => ('fmin', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search2006_0 -> 760 in the cache */
   /* search2006_1_0 -> 150 in the cache */
   /* search2006_1_1 -> 3529 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 150, 3529 },
      -1,
   } },
   /* search2006_2_0 -> 150 in the cache */
   /* search2006_2_1 -> 153 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmin,
      1, 1,
      { 150, 153 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 760, 5759, 5760 },
      -1,
   } },

   /* replace2006_0 -> 150 in the cache */
   /* replace2006_1_0 -> 760 in the cache */
   /* replace2006_1_1 -> 152 in the cache */
   /* replace2006_1_2 -> 153 in the cache */
   /* replace2006_1 -> 1312 in the cache */
   /* replace2006 -> 5755 in the cache */

   /* ('bcsel', 'a', ('fmin', 'b', 'c'), ('fmin(is_used_once)', 'b', 'd(is_not_const)')) => ('fmin', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search2007_0 -> 760 in the cache */
   /* search2007_1_0 -> 150 in the cache */
   /* search2007_1_1 -> 152 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 150, 152 },
      -1,
   } },
   /* search2007_2_0 -> 150 in the cache */
   /* search2007_2_1 -> 5674 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmin,
      1, 1,
      { 150, 5674 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 760, 5762, 5763 },
      -1,
   } },

   /* replace2007_0 -> 150 in the cache */
   /* replace2007_1_0 -> 760 in the cache */
   /* replace2007_1_1 -> 152 in the cache */
   /* replace2007_1_2 -> 153 in the cache */
   /* replace2007_1 -> 1312 in the cache */
   /* replace2007 -> 5755 in the cache */

   /* ('bcsel', 'a', ('fmax(is_used_once)', 'b', 'c'), ('fmax', 'b', 'd(is_not_const)')) => ('fmax', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search2008_0 -> 760 in the cache */
   /* search2008_1_0 -> 150 in the cache */
   /* search2008_1_1 -> 152 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 150, 152 },
      0,
   } },
   /* search2008_2_0 -> 150 in the cache */
   /* search2008_2_1 -> 5674 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmax,
      1, 1,
      { 150, 5674 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 760, 5765, 5766 },
      -1,
   } },

   /* replace2008_0 -> 150 in the cache */
   /* replace2008_1_0 -> 760 in the cache */
   /* replace2008_1_1 -> 152 in the cache */
   /* replace2008_1_2 -> 153 in the cache */
   /* replace2008_1 -> 1312 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 150, 1312 },
      -1,
   } },

   /* ('bcsel', 'a', ('fmax(is_used_once)', 'b', 'c(is_not_const)'), ('fmax', 'b', 'd')) => ('fmax', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search2009_0 -> 760 in the cache */
   /* search2009_1_0 -> 150 in the cache */
   /* search2009_1_1 -> 3529 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 150, 3529 },
      0,
   } },
   /* search2009_2_0 -> 150 in the cache */
   /* search2009_2_1 -> 153 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmax,
      1, 1,
      { 150, 153 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 760, 5769, 5770 },
      -1,
   } },

   /* replace2009_0 -> 150 in the cache */
   /* replace2009_1_0 -> 760 in the cache */
   /* replace2009_1_1 -> 152 in the cache */
   /* replace2009_1_2 -> 153 in the cache */
   /* replace2009_1 -> 1312 in the cache */
   /* replace2009 -> 5768 in the cache */

   /* ('bcsel', 'a', ('fmax', 'b', 'c(is_not_const)'), ('fmax(is_used_once)', 'b', 'd')) => ('fmax', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search2010_0 -> 760 in the cache */
   /* search2010_1_0 -> 150 in the cache */
   /* search2010_1_1 -> 3529 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 150, 3529 },
      -1,
   } },
   /* search2010_2_0 -> 150 in the cache */
   /* search2010_2_1 -> 153 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmax,
      1, 1,
      { 150, 153 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 760, 5772, 5773 },
      -1,
   } },

   /* replace2010_0 -> 150 in the cache */
   /* replace2010_1_0 -> 760 in the cache */
   /* replace2010_1_1 -> 152 in the cache */
   /* replace2010_1_2 -> 153 in the cache */
   /* replace2010_1 -> 1312 in the cache */
   /* replace2010 -> 5768 in the cache */

   /* ('bcsel', 'a', ('fmax', 'b', 'c'), ('fmax(is_used_once)', 'b', 'd(is_not_const)')) => ('fmax', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search2011_0 -> 760 in the cache */
   /* search2011_1_0 -> 150 in the cache */
   /* search2011_1_1 -> 152 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 150, 152 },
      -1,
   } },
   /* search2011_2_0 -> 150 in the cache */
   /* search2011_2_1 -> 5674 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmax,
      1, 1,
      { 150, 5674 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 760, 5775, 5776 },
      -1,
   } },

   /* replace2011_0 -> 150 in the cache */
   /* replace2011_1_0 -> 760 in the cache */
   /* replace2011_1_1 -> 152 in the cache */
   /* replace2011_1_2 -> 153 in the cache */
   /* replace2011_1 -> 1312 in the cache */
   /* replace2011 -> 5768 in the cache */

   /* ('bcsel', 'a', ('imin(is_used_once)', 'b', 'c'), ('imin', 'b', 'd(is_not_const)')) => ('imin', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search2012_0 -> 760 in the cache */
   /* search2012_1_0 -> 150 in the cache */
   /* search2012_1_1 -> 152 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imin,
      0, 1,
      { 150, 152 },
      0,
   } },
   /* search2012_2_0 -> 150 in the cache */
   /* search2012_2_1 -> 5674 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imin,
      1, 1,
      { 150, 5674 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 760, 5778, 5779 },
      -1,
   } },

   /* replace2012_0 -> 150 in the cache */
   /* replace2012_1_0 -> 760 in the cache */
   /* replace2012_1_1 -> 152 in the cache */
   /* replace2012_1_2 -> 153 in the cache */
   /* replace2012_1 -> 1312 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imin,
      0, 1,
      { 150, 1312 },
      -1,
   } },

   /* ('bcsel', 'a', ('imin(is_used_once)', 'b', 'c(is_not_const)'), ('imin', 'b', 'd')) => ('imin', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search2013_0 -> 760 in the cache */
   /* search2013_1_0 -> 150 in the cache */
   /* search2013_1_1 -> 3529 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imin,
      0, 1,
      { 150, 3529 },
      0,
   } },
   /* search2013_2_0 -> 150 in the cache */
   /* search2013_2_1 -> 153 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imin,
      1, 1,
      { 150, 153 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 760, 5782, 5783 },
      -1,
   } },

   /* replace2013_0 -> 150 in the cache */
   /* replace2013_1_0 -> 760 in the cache */
   /* replace2013_1_1 -> 152 in the cache */
   /* replace2013_1_2 -> 153 in the cache */
   /* replace2013_1 -> 1312 in the cache */
   /* replace2013 -> 5781 in the cache */

   /* ('bcsel', 'a', ('imin', 'b', 'c(is_not_const)'), ('imin(is_used_once)', 'b', 'd')) => ('imin', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search2014_0 -> 760 in the cache */
   /* search2014_1_0 -> 150 in the cache */
   /* search2014_1_1 -> 3529 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imin,
      0, 1,
      { 150, 3529 },
      -1,
   } },
   /* search2014_2_0 -> 150 in the cache */
   /* search2014_2_1 -> 153 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imin,
      1, 1,
      { 150, 153 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 760, 5785, 5786 },
      -1,
   } },

   /* replace2014_0 -> 150 in the cache */
   /* replace2014_1_0 -> 760 in the cache */
   /* replace2014_1_1 -> 152 in the cache */
   /* replace2014_1_2 -> 153 in the cache */
   /* replace2014_1 -> 1312 in the cache */
   /* replace2014 -> 5781 in the cache */

   /* ('bcsel', 'a', ('imin', 'b', 'c'), ('imin(is_used_once)', 'b', 'd(is_not_const)')) => ('imin', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search2015_0 -> 760 in the cache */
   /* search2015_1_0 -> 150 in the cache */
   /* search2015_1_1 -> 152 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imin,
      0, 1,
      { 150, 152 },
      -1,
   } },
   /* search2015_2_0 -> 150 in the cache */
   /* search2015_2_1 -> 5674 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imin,
      1, 1,
      { 150, 5674 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 760, 5788, 5789 },
      -1,
   } },

   /* replace2015_0 -> 150 in the cache */
   /* replace2015_1_0 -> 760 in the cache */
   /* replace2015_1_1 -> 152 in the cache */
   /* replace2015_1_2 -> 153 in the cache */
   /* replace2015_1 -> 1312 in the cache */
   /* replace2015 -> 5781 in the cache */

   /* ('bcsel', 'a', ('imax(is_used_once)', 'b', 'c'), ('imax', 'b', 'd(is_not_const)')) => ('imax', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search2016_0 -> 760 in the cache */
   /* search2016_1_0 -> 150 in the cache */
   /* search2016_1_1 -> 152 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 150, 152 },
      0,
   } },
   /* search2016_2_0 -> 150 in the cache */
   /* search2016_2_1 -> 5674 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imax,
      1, 1,
      { 150, 5674 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 760, 5791, 5792 },
      -1,
   } },

   /* replace2016_0 -> 150 in the cache */
   /* replace2016_1_0 -> 760 in the cache */
   /* replace2016_1_1 -> 152 in the cache */
   /* replace2016_1_2 -> 153 in the cache */
   /* replace2016_1 -> 1312 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 150, 1312 },
      -1,
   } },

   /* ('bcsel', 'a', ('imax(is_used_once)', 'b', 'c(is_not_const)'), ('imax', 'b', 'd')) => ('imax', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search2017_0 -> 760 in the cache */
   /* search2017_1_0 -> 150 in the cache */
   /* search2017_1_1 -> 3529 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 150, 3529 },
      0,
   } },
   /* search2017_2_0 -> 150 in the cache */
   /* search2017_2_1 -> 153 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imax,
      1, 1,
      { 150, 153 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 760, 5795, 5796 },
      -1,
   } },

   /* replace2017_0 -> 150 in the cache */
   /* replace2017_1_0 -> 760 in the cache */
   /* replace2017_1_1 -> 152 in the cache */
   /* replace2017_1_2 -> 153 in the cache */
   /* replace2017_1 -> 1312 in the cache */
   /* replace2017 -> 5794 in the cache */

   /* ('bcsel', 'a', ('imax', 'b', 'c(is_not_const)'), ('imax(is_used_once)', 'b', 'd')) => ('imax', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search2018_0 -> 760 in the cache */
   /* search2018_1_0 -> 150 in the cache */
   /* search2018_1_1 -> 3529 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 150, 3529 },
      -1,
   } },
   /* search2018_2_0 -> 150 in the cache */
   /* search2018_2_1 -> 153 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imax,
      1, 1,
      { 150, 153 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 760, 5798, 5799 },
      -1,
   } },

   /* replace2018_0 -> 150 in the cache */
   /* replace2018_1_0 -> 760 in the cache */
   /* replace2018_1_1 -> 152 in the cache */
   /* replace2018_1_2 -> 153 in the cache */
   /* replace2018_1 -> 1312 in the cache */
   /* replace2018 -> 5794 in the cache */

   /* ('bcsel', 'a', ('imax', 'b', 'c'), ('imax(is_used_once)', 'b', 'd(is_not_const)')) => ('imax', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search2019_0 -> 760 in the cache */
   /* search2019_1_0 -> 150 in the cache */
   /* search2019_1_1 -> 152 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 150, 152 },
      -1,
   } },
   /* search2019_2_0 -> 150 in the cache */
   /* search2019_2_1 -> 5674 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_imax,
      1, 1,
      { 150, 5674 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 760, 5801, 5802 },
      -1,
   } },

   /* replace2019_0 -> 150 in the cache */
   /* replace2019_1_0 -> 760 in the cache */
   /* replace2019_1_1 -> 152 in the cache */
   /* replace2019_1_2 -> 153 in the cache */
   /* replace2019_1 -> 1312 in the cache */
   /* replace2019 -> 5794 in the cache */

   /* ('bcsel', 'a', ('umin(is_used_once)', 'b', 'c'), ('umin', 'b', 'd(is_not_const)')) => ('umin', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search2020_0 -> 760 in the cache */
   /* search2020_1_0 -> 150 in the cache */
   /* search2020_1_1 -> 152 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_umin,
      0, 1,
      { 150, 152 },
      0,
   } },
   /* search2020_2_0 -> 150 in the cache */
   /* search2020_2_1 -> 5674 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_umin,
      1, 1,
      { 150, 5674 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 760, 5804, 5805 },
      -1,
   } },

   /* replace2020_0 -> 150 in the cache */
   /* replace2020_1_0 -> 760 in the cache */
   /* replace2020_1_1 -> 152 in the cache */
   /* replace2020_1_2 -> 153 in the cache */
   /* replace2020_1 -> 1312 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_umin,
      0, 1,
      { 150, 1312 },
      -1,
   } },

   /* ('bcsel', 'a', ('umin(is_used_once)', 'b', 'c(is_not_const)'), ('umin', 'b', 'd')) => ('umin', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search2021_0 -> 760 in the cache */
   /* search2021_1_0 -> 150 in the cache */
   /* search2021_1_1 -> 3529 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_umin,
      0, 1,
      { 150, 3529 },
      0,
   } },
   /* search2021_2_0 -> 150 in the cache */
   /* search2021_2_1 -> 153 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_umin,
      1, 1,
      { 150, 153 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 760, 5808, 5809 },
      -1,
   } },

   /* replace2021_0 -> 150 in the cache */
   /* replace2021_1_0 -> 760 in the cache */
   /* replace2021_1_1 -> 152 in the cache */
   /* replace2021_1_2 -> 153 in the cache */
   /* replace2021_1 -> 1312 in the cache */
   /* replace2021 -> 5807 in the cache */

   /* ('bcsel', 'a', ('umin', 'b', 'c(is_not_const)'), ('umin(is_used_once)', 'b', 'd')) => ('umin', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search2022_0 -> 760 in the cache */
   /* search2022_1_0 -> 150 in the cache */
   /* search2022_1_1 -> 3529 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_umin,
      0, 1,
      { 150, 3529 },
      -1,
   } },
   /* search2022_2_0 -> 150 in the cache */
   /* search2022_2_1 -> 153 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_umin,
      1, 1,
      { 150, 153 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 760, 5811, 5812 },
      -1,
   } },

   /* replace2022_0 -> 150 in the cache */
   /* replace2022_1_0 -> 760 in the cache */
   /* replace2022_1_1 -> 152 in the cache */
   /* replace2022_1_2 -> 153 in the cache */
   /* replace2022_1 -> 1312 in the cache */
   /* replace2022 -> 5807 in the cache */

   /* ('bcsel', 'a', ('umin', 'b', 'c'), ('umin(is_used_once)', 'b', 'd(is_not_const)')) => ('umin', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search2023_0 -> 760 in the cache */
   /* search2023_1_0 -> 150 in the cache */
   /* search2023_1_1 -> 152 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_umin,
      0, 1,
      { 150, 152 },
      -1,
   } },
   /* search2023_2_0 -> 150 in the cache */
   /* search2023_2_1 -> 5674 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_umin,
      1, 1,
      { 150, 5674 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 760, 5814, 5815 },
      -1,
   } },

   /* replace2023_0 -> 150 in the cache */
   /* replace2023_1_0 -> 760 in the cache */
   /* replace2023_1_1 -> 152 in the cache */
   /* replace2023_1_2 -> 153 in the cache */
   /* replace2023_1 -> 1312 in the cache */
   /* replace2023 -> 5807 in the cache */

   /* ('bcsel', 'a', ('umax(is_used_once)', 'b', 'c'), ('umax', 'b', 'd(is_not_const)')) => ('umax', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search2024_0 -> 760 in the cache */
   /* search2024_1_0 -> 150 in the cache */
   /* search2024_1_1 -> 152 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_umax,
      0, 1,
      { 150, 152 },
      0,
   } },
   /* search2024_2_0 -> 150 in the cache */
   /* search2024_2_1 -> 5674 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_umax,
      1, 1,
      { 150, 5674 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 760, 5817, 5818 },
      -1,
   } },

   /* replace2024_0 -> 150 in the cache */
   /* replace2024_1_0 -> 760 in the cache */
   /* replace2024_1_1 -> 152 in the cache */
   /* replace2024_1_2 -> 153 in the cache */
   /* replace2024_1 -> 1312 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_umax,
      0, 1,
      { 150, 1312 },
      -1,
   } },

   /* ('bcsel', 'a', ('umax(is_used_once)', 'b', 'c(is_not_const)'), ('umax', 'b', 'd')) => ('umax', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search2025_0 -> 760 in the cache */
   /* search2025_1_0 -> 150 in the cache */
   /* search2025_1_1 -> 3529 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_umax,
      0, 1,
      { 150, 3529 },
      0,
   } },
   /* search2025_2_0 -> 150 in the cache */
   /* search2025_2_1 -> 153 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_umax,
      1, 1,
      { 150, 153 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 760, 5821, 5822 },
      -1,
   } },

   /* replace2025_0 -> 150 in the cache */
   /* replace2025_1_0 -> 760 in the cache */
   /* replace2025_1_1 -> 152 in the cache */
   /* replace2025_1_2 -> 153 in the cache */
   /* replace2025_1 -> 1312 in the cache */
   /* replace2025 -> 5820 in the cache */

   /* ('bcsel', 'a', ('umax', 'b', 'c(is_not_const)'), ('umax(is_used_once)', 'b', 'd')) => ('umax', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search2026_0 -> 760 in the cache */
   /* search2026_1_0 -> 150 in the cache */
   /* search2026_1_1 -> 3529 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_umax,
      0, 1,
      { 150, 3529 },
      -1,
   } },
   /* search2026_2_0 -> 150 in the cache */
   /* search2026_2_1 -> 153 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_umax,
      1, 1,
      { 150, 153 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 760, 5824, 5825 },
      -1,
   } },

   /* replace2026_0 -> 150 in the cache */
   /* replace2026_1_0 -> 760 in the cache */
   /* replace2026_1_1 -> 152 in the cache */
   /* replace2026_1_2 -> 153 in the cache */
   /* replace2026_1 -> 1312 in the cache */
   /* replace2026 -> 5820 in the cache */

   /* ('bcsel', 'a', ('umax', 'b', 'c'), ('umax(is_used_once)', 'b', 'd(is_not_const)')) => ('umax', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search2027_0 -> 760 in the cache */
   /* search2027_1_0 -> 150 in the cache */
   /* search2027_1_1 -> 152 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_umax,
      0, 1,
      { 150, 152 },
      -1,
   } },
   /* search2027_2_0 -> 150 in the cache */
   /* search2027_2_1 -> 5674 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_umax,
      1, 1,
      { 150, 5674 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 760, 5827, 5828 },
      -1,
   } },

   /* replace2027_0 -> 150 in the cache */
   /* replace2027_1_0 -> 760 in the cache */
   /* replace2027_1_1 -> 152 in the cache */
   /* replace2027_1_2 -> 153 in the cache */
   /* replace2027_1 -> 1312 in the cache */
   /* replace2027 -> 5820 in the cache */

   /* ('bcsel', 'a', ('fpow(is_used_once)', 'b', 'c'), ('fpow', 'b', 'd')) => ('fpow', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search2028_0 -> 760 in the cache */
   /* search2028_1_0 -> 150 in the cache */
   /* search2028_1_1 -> 152 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 150, 152 },
      0,
   } },
   /* search2028_2_0 -> 150 in the cache */
   /* search2028_2_1 -> 153 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 150, 153 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 760, 5830, 5831 },
      -1,
   } },

   /* replace2028_0 -> 150 in the cache */
   /* replace2028_1_0 -> 760 in the cache */
   /* replace2028_1_1 -> 152 in the cache */
   /* replace2028_1_2 -> 153 in the cache */
   /* replace2028_1 -> 1312 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 150, 1312 },
      -1,
   } },

   /* ('bcsel', 'a', ('fpow', 'b', 'c'), ('fpow(is_used_once)', 'b', 'd')) => ('fpow', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search2029_0 -> 760 in the cache */
   /* search2029_1_0 -> 150 in the cache */
   /* search2029_1_1 -> 152 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 150, 152 },
      -1,
   } },
   /* search2029_2_0 -> 150 in the cache */
   /* search2029_2_1 -> 153 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 150, 153 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 760, 5834, 5835 },
      -1,
   } },

   /* replace2029_0 -> 150 in the cache */
   /* replace2029_1_0 -> 760 in the cache */
   /* replace2029_1_1 -> 152 in the cache */
   /* replace2029_1_2 -> 153 in the cache */
   /* replace2029_1 -> 1312 in the cache */
   /* replace2029 -> 5833 in the cache */

   /* ('bcsel', 'a', ('fpow(is_used_once)', 'b', 'c'), ('fpow', 'd', 'c')) => ('fpow', ('bcsel', 'a', 'b', 'd'), 'c') */
   /* search2030_0 -> 760 in the cache */
   /* search2030_1_0 -> 127 in the cache */
   /* search2030_1_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 127, 129 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      3, /* d */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search2030_2_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 5838, 129 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 760, 5837, 5839 },
      -1,
   } },

   /* replace2030_0_0 -> 760 in the cache */
   /* replace2030_0_1 -> 127 in the cache */
   /* replace2030_0_2 -> 5838 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 760, 127, 5838 },
      -1,
   } },
   /* replace2030_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 5841, 129 },
      -1,
   } },

   /* ('bcsel', 'a', ('fpow', 'b', 'c'), ('fpow(is_used_once)', 'd', 'c')) => ('fpow', ('bcsel', 'a', 'b', 'd'), 'c') */
   /* search2031_0 -> 760 in the cache */
   /* search2031_1_0 -> 127 in the cache */
   /* search2031_1_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 127, 129 },
      -1,
   } },
   /* search2031_2_0 -> 5838 in the cache */
   /* search2031_2_1 -> 129 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 5838, 129 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 760, 5843, 5844 },
      -1,
   } },

   /* replace2031_0_0 -> 760 in the cache */
   /* replace2031_0_1 -> 127 in the cache */
   /* replace2031_0_2 -> 5838 in the cache */
   /* replace2031_0 -> 5841 in the cache */
   /* replace2031_1 -> 129 in the cache */
   /* replace2031 -> 5842 in the cache */

   /* ('bcsel', 'c', ('frcp(is_used_once)', 'a'), ('frcp(is_used_once)', 'b')) => ('frcp', ('bcsel', 'c', 'a', 'b')) */
   /* search2032_0 -> 521 in the cache */
   { .variable = {
      { nir_search_value_variable, -3 },
      1, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_frcp,
      -1, 0,
      { 5846 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      2, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_frcp,
      -1, 0,
      { 5848 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 521, 5847, 5849 },
      -1,
   } },

   /* replace2032_0_0 -> 521 in the cache */
   /* replace2032_0_1 -> 5846 in the cache */
   /* replace2032_0_2 -> 5848 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 521, 5846, 5848 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_frcp,
      -1, 0,
      { 5851 },
      -1,
   } },

   /* ('bcsel', 'c', ('frsq(is_used_once)', 'a'), ('frsq(is_used_once)', 'b')) => ('frsq', ('bcsel', 'c', 'a', 'b')) */
   /* search2033_0 -> 521 in the cache */
   /* search2033_1_0 -> 5846 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_frsq,
      -1, 0,
      { 5846 },
      0,
   } },
   /* search2033_2_0 -> 5848 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_frsq,
      -1, 0,
      { 5848 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 521, 5853, 5854 },
      -1,
   } },

   /* replace2033_0_0 -> 521 in the cache */
   /* replace2033_0_1 -> 5846 in the cache */
   /* replace2033_0_2 -> 5848 in the cache */
   /* replace2033_0 -> 5851 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_frsq,
      -1, 0,
      { 5851 },
      -1,
   } },

   /* ('bcsel', 'c', ('fsqrt(is_used_once)', 'a'), ('fsqrt(is_used_once)', 'b')) => ('fsqrt', ('bcsel', 'c', 'a', 'b')) */
   /* search2034_0 -> 521 in the cache */
   /* search2034_1_0 -> 5846 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fsqrt,
      -1, 0,
      { 5846 },
      0,
   } },
   /* search2034_2_0 -> 5848 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fsqrt,
      -1, 0,
      { 5848 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 521, 5857, 5858 },
      -1,
   } },

   /* replace2034_0_0 -> 521 in the cache */
   /* replace2034_0_1 -> 5846 in the cache */
   /* replace2034_0_2 -> 5848 in the cache */
   /* replace2034_0 -> 5851 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fsqrt,
      -1, 0,
      { 5851 },
      -1,
   } },

   /* ('bcsel', 'c', ('fexp2(is_used_once)', 'a'), ('fexp2(is_used_once)', 'b')) => ('fexp2', ('bcsel', 'c', 'a', 'b')) */
   /* search2035_0 -> 521 in the cache */
   /* search2035_1_0 -> 5846 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fexp2,
      -1, 0,
      { 5846 },
      0,
   } },
   /* search2035_2_0 -> 5848 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fexp2,
      -1, 0,
      { 5848 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 521, 5861, 5862 },
      -1,
   } },

   /* replace2035_0_0 -> 521 in the cache */
   /* replace2035_0_1 -> 5846 in the cache */
   /* replace2035_0_2 -> 5848 in the cache */
   /* replace2035_0 -> 5851 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fexp2,
      -1, 0,
      { 5851 },
      -1,
   } },

   /* ('bcsel', 'c', ('flog2(is_used_once)', 'a'), ('flog2(is_used_once)', 'b')) => ('flog2', ('bcsel', 'c', 'a', 'b')) */
   /* search2036_0 -> 521 in the cache */
   /* search2036_1_0 -> 5846 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_flog2,
      -1, 0,
      { 5846 },
      0,
   } },
   /* search2036_2_0 -> 5848 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_flog2,
      -1, 0,
      { 5848 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 521, 5865, 5866 },
      -1,
   } },

   /* replace2036_0_0 -> 521 in the cache */
   /* replace2036_0_1 -> 5846 in the cache */
   /* replace2036_0_2 -> 5848 in the cache */
   /* replace2036_0 -> 5851 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_flog2,
      -1, 0,
      { 5851 },
      -1,
   } },

   /* ('bcsel', 'c', ('fsign(is_used_once)', 'a'), ('fsign(is_used_once)', 'b')) => ('fsign', ('bcsel', 'c', 'a', 'b')) */
   /* search2037_0 -> 521 in the cache */
   /* search2037_1_0 -> 5846 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fsign,
      -1, 0,
      { 5846 },
      0,
   } },
   /* search2037_2_0 -> 5848 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fsign,
      -1, 0,
      { 5848 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 521, 5869, 5870 },
      -1,
   } },

   /* replace2037_0_0 -> 521 in the cache */
   /* replace2037_0_1 -> 5846 in the cache */
   /* replace2037_0_2 -> 5848 in the cache */
   /* replace2037_0 -> 5851 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fsign,
      -1, 0,
      { 5851 },
      -1,
   } },

   /* ('bcsel', 'c', ('fsin(is_used_once)', 'a'), ('fsin(is_used_once)', 'b')) => ('fsin', ('bcsel', 'c', 'a', 'b')) */
   /* search2038_0 -> 521 in the cache */
   /* search2038_1_0 -> 5846 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fsin,
      -1, 0,
      { 5846 },
      0,
   } },
   /* search2038_2_0 -> 5848 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fsin,
      -1, 0,
      { 5848 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 521, 5873, 5874 },
      -1,
   } },

   /* replace2038_0_0 -> 521 in the cache */
   /* replace2038_0_1 -> 5846 in the cache */
   /* replace2038_0_2 -> 5848 in the cache */
   /* replace2038_0 -> 5851 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fsin,
      -1, 0,
      { 5851 },
      -1,
   } },

   /* ('bcsel', 'c', ('fcos(is_used_once)', 'a'), ('fcos(is_used_once)', 'b')) => ('fcos', ('bcsel', 'c', 'a', 'b')) */
   /* search2039_0 -> 521 in the cache */
   /* search2039_1_0 -> 5846 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fcos,
      -1, 0,
      { 5846 },
      0,
   } },
   /* search2039_2_0 -> 5848 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fcos,
      -1, 0,
      { 5848 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 521, 5877, 5878 },
      -1,
   } },

   /* replace2039_0_0 -> 521 in the cache */
   /* replace2039_0_1 -> 5846 in the cache */
   /* replace2039_0_2 -> 5848 in the cache */
   /* replace2039_0 -> 5851 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fcos,
      -1, 0,
      { 5851 },
      -1,
   } },

   /* ('bcsel', 'c', ('fsin_amd(is_used_once)', 'a'), ('fsin_amd(is_used_once)', 'b')) => ('fsin_amd', ('bcsel', 'c', 'a', 'b')) */
   /* search2040_0 -> 521 in the cache */
   /* search2040_1_0 -> 5846 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fsin_amd,
      -1, 0,
      { 5846 },
      0,
   } },
   /* search2040_2_0 -> 5848 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fsin_amd,
      -1, 0,
      { 5848 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 521, 5881, 5882 },
      -1,
   } },

   /* replace2040_0_0 -> 521 in the cache */
   /* replace2040_0_1 -> 5846 in the cache */
   /* replace2040_0_2 -> 5848 in the cache */
   /* replace2040_0 -> 5851 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fsin_amd,
      -1, 0,
      { 5851 },
      -1,
   } },

   /* ('bcsel', 'c', ('fcos_amd(is_used_once)', 'a'), ('fcos_amd(is_used_once)', 'b')) => ('fcos_amd', ('bcsel', 'c', 'a', 'b')) */
   /* search2041_0 -> 521 in the cache */
   /* search2041_1_0 -> 5846 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fcos_amd,
      -1, 0,
      { 5846 },
      0,
   } },
   /* search2041_2_0 -> 5848 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fcos_amd,
      -1, 0,
      { 5848 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 521, 5885, 5886 },
      -1,
   } },

   /* replace2041_0_0 -> 521 in the cache */
   /* replace2041_0_1 -> 5846 in the cache */
   /* replace2041_0_2 -> 5848 in the cache */
   /* replace2041_0 -> 5851 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fcos_amd,
      -1, 0,
      { 5851 },
      -1,
   } },

   /* ('bcsel', 'c', ('fneg(is_used_once)', 'a'), ('fneg(is_used_once)', 'b')) => ('fneg', ('bcsel', 'c', 'a', 'b')) */
   /* search2042_0 -> 521 in the cache */
   /* search2042_1_0 -> 5846 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 5846 },
      0,
   } },
   /* search2042_2_0 -> 5848 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 5848 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 521, 5889, 5890 },
      -1,
   } },

   /* replace2042_0_0 -> 521 in the cache */
   /* replace2042_0_1 -> 5846 in the cache */
   /* replace2042_0_2 -> 5848 in the cache */
   /* replace2042_0 -> 5851 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 5851 },
      -1,
   } },

   /* ('bcsel', 'c', ('fabs(is_used_once)', 'a'), ('fabs(is_used_once)', 'b')) => ('fabs', ('bcsel', 'c', 'a', 'b')) */
   /* search2043_0 -> 521 in the cache */
   /* search2043_1_0 -> 5846 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 5846 },
      0,
   } },
   /* search2043_2_0 -> 5848 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 5848 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 521, 5893, 5894 },
      -1,
   } },

   /* replace2043_0_0 -> 521 in the cache */
   /* replace2043_0_1 -> 5846 in the cache */
   /* replace2043_0_2 -> 5848 in the cache */
   /* replace2043_0 -> 5851 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 5851 },
      -1,
   } },

   /* ('bcsel', 'c', ('fsign(is_used_once)', 'a'), ('fsign(is_used_once)', 'b')) => ('fsign', ('bcsel', 'c', 'a', 'b')) */
   /* search2044_0 -> 521 in the cache */
   /* search2044_1_0 -> 5846 in the cache */
   /* search2044_1 -> 5869 in the cache */
   /* search2044_2_0 -> 5848 in the cache */
   /* search2044_2 -> 5870 in the cache */
   /* search2044 -> 5871 in the cache */

   /* replace2044_0_0 -> 521 in the cache */
   /* replace2044_0_1 -> 5846 in the cache */
   /* replace2044_0_2 -> 5848 in the cache */
   /* replace2044_0 -> 5851 in the cache */
   /* replace2044 -> 5872 in the cache */

   /* ('ineg', ('bcsel', 'c', '#a', '#b')) => ('bcsel', 'c', ('ineg', 'a'), ('ineg', 'b')) */
   /* search2045_0_0 -> 521 in the cache */
   { .variable = {
      { nir_search_value_variable, -3 },
      1, /* a */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      2, /* b */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 521, 5897, 5898 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 5899 },
      -1,
   } },

   /* replace2045_0 -> 521 in the cache */
   /* replace2045_1_0 -> 5846 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 5846 },
      -1,
   } },
   /* replace2045_2_0 -> 5848 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 5848 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 521, 5901, 5902 },
      -1,
   } },

   /* ('iabs', ('bcsel', 'c', '#a', '#b')) => ('bcsel', 'c', ('iabs', 'a'), ('iabs', 'b')) */
   /* search2046_0_0 -> 521 in the cache */
   /* search2046_0_1 -> 5897 in the cache */
   /* search2046_0_2 -> 5898 in the cache */
   /* search2046_0 -> 5899 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iabs,
      -1, 0,
      { 5899 },
      -1,
   } },

   /* replace2046_0 -> 521 in the cache */
   /* replace2046_1_0 -> 5846 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iabs,
      -1, 0,
      { 5846 },
      -1,
   } },
   /* replace2046_2_0 -> 5848 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iabs,
      -1, 0,
      { 5848 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 521, 5905, 5906 },
      -1,
   } },

   /* ('inot', ('bcsel', 'c', '#a', '#b')) => ('bcsel', 'c', ('inot', 'a'), ('inot', 'b')) */
   /* search2047_0_0 -> 521 in the cache */
   /* search2047_0_1 -> 5897 in the cache */
   /* search2047_0_2 -> 5898 in the cache */
   /* search2047_0 -> 5899 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 5899 },
      -1,
   } },

   /* replace2047_0 -> 521 in the cache */
   /* replace2047_1_0 -> 5846 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 5846 },
      -1,
   } },
   /* replace2047_2_0 -> 5848 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 5848 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 521, 5909, 5910 },
      -1,
   } },

   /* ('isign', ('bcsel', 'c', '#a', '#b')) => ('bcsel', 'c', ('isign', 'a'), ('isign', 'b')) */
   /* search2048_0_0 -> 521 in the cache */
   /* search2048_0_1 -> 5897 in the cache */
   /* search2048_0_2 -> 5898 in the cache */
   /* search2048_0 -> 5899 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_isign,
      -1, 0,
      { 5899 },
      -1,
   } },

   /* replace2048_0 -> 521 in the cache */
   /* replace2048_1_0 -> 5846 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_isign,
      -1, 0,
      { 5846 },
      -1,
   } },
   /* replace2048_2_0 -> 5848 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_isign,
      -1, 0,
      { 5848 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 521, 5913, 5914 },
      -1,
   } },

   /* ('fisnormal', 'a@16') => ('ult', 4095, ('iadd', ('ishl', 'a', 1), 2048)) */
   /* search2049_0 -> 11 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fisnormal,
      -1, 0,
      { 11 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, 16 },
      nir_type_int, { 0xfff /* 4095 */ },
   } },
   /* replace2049_1_0_0 -> 11 in the cache */
   /* replace2049_1_0_1 -> 396 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 11, 396 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 16 },
      nir_type_int, { 0x800 /* 2048 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 5918, 5919 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 1,
      { 5917, 5920 },
      -1,
   } },

   /* ('fisnormal', 'a@32') => ('ult', 33554431, ('iadd', ('ishl', 'a', 1), 16777216)) */
   /* search2050_0 -> 16 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fisnormal,
      -1, 0,
      { 16 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x1ffffff /* 33554431 */ },
   } },
   /* replace2050_1_0_0 -> 16 in the cache */
   /* replace2050_1_0_1 -> 396 in the cache */
   /* replace2050_1_0 -> 991 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x1000000 /* 16777216 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 991, 5924 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 1,
      { 5923, 5925 },
      -1,
   } },

   /* ('fisnormal', 'a@64') => ('ult', 18014398509481983, ('iadd', ('ishl', 'a', 1), 9007199254740992)) */
   /* search2051_0 -> 21 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fisnormal,
      -1, 0,
      { 21 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0x3fffffffffffff /* 18014398509481983 */ },
   } },
   /* replace2051_1_0_0 -> 21 in the cache */
   /* replace2051_1_0_1 -> 396 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 21, 396 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0x20000000000000 /* 9007199254740992 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 5929, 5930 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ult,
      -1, 1,
      { 5928, 5931 },
      -1,
   } },

   /* ('f2f16', ('vec2', 'a@32', 'b@32')) => ('vec2', ('f2f16', 'a'), ('f2f16', 'b')) */
   /* search2052_0_0 -> 16 in the cache */
   /* search2052_0_1 -> 36 in the cache */
   /* search2052_0 -> 3231 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 3231 },
      -1,
   } },

   /* replace2052_0_0 -> 16 in the cache */
   /* replace2052_0 -> 4008 in the cache */
   /* replace2052_1_0 -> 36 in the cache */
   /* replace2052_1 -> 4005 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_vec2,
      -1, 0,
      { 4008, 4005 },
      -1,
   } },

   /* ('f2fmp', ('vec2', 'a@32', 'b@32')) => ('vec2', ('f2fmp', 'a'), ('f2fmp', 'b')) */
   /* search2053_0_0 -> 16 in the cache */
   /* search2053_0_1 -> 36 in the cache */
   /* search2053_0 -> 3231 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2fmp,
      -1, 0,
      { 3231 },
      -1,
   } },

   /* replace2053_0_0 -> 16 in the cache */
   /* replace2053_0 -> 2009 in the cache */
   /* replace2053_1_0 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2fmp,
      -1, 0,
      { 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_vec2,
      -1, 0,
      { 2009, 5936 },
      -1,
   } },

   /* ('u2u16', ('vec2', 'a@32', 'b@32')) => ('vec2', ('u2u16', 'a'), ('u2u16', 'b')) */
   /* search2054_0_0 -> 16 in the cache */
   /* search2054_0_1 -> 36 in the cache */
   /* search2054_0 -> 3231 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 3231 },
      -1,
   } },

   /* replace2054_0_0 -> 16 in the cache */
   /* replace2054_0 -> 3326 in the cache */
   /* replace2054_1_0 -> 36 in the cache */
   /* replace2054_1 -> 4883 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_vec2,
      -1, 0,
      { 3326, 4883 },
      -1,
   } },

   /* ('i2i16', ('vec2', 'a@32', 'b@32')) => ('vec2', ('i2i16', 'a'), ('i2i16', 'b')) */
   /* search2055_0_0 -> 16 in the cache */
   /* search2055_0_1 -> 36 in the cache */
   /* search2055_0 -> 3231 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 3231 },
      -1,
   } },

   /* replace2055_0_0 -> 16 in the cache */
   /* replace2055_0 -> 4369 in the cache */
   /* replace2055_1_0 -> 36 in the cache */
   /* replace2055_1 -> 4554 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_vec2,
      -1, 0,
      { 4369, 4554 },
      -1,
   } },

   /* ('i2imp', ('vec2', 'a@32', 'b@32')) => ('vec2', ('i2imp', 'a'), ('i2imp', 'b')) */
   /* search2056_0_0 -> 16 in the cache */
   /* search2056_0_1 -> 36 in the cache */
   /* search2056_0 -> 3231 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2imp,
      -1, 0,
      { 3231 },
      -1,
   } },

   /* replace2056_0_0 -> 16 in the cache */
   /* replace2056_0 -> 2020 in the cache */
   /* replace2056_1_0 -> 36 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2imp,
      -1, 0,
      { 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_vec2,
      -1, 0,
      { 2020, 5943 },
      -1,
   } },

   /* ('f2f16', ('vec3', 'a@32', 'b@32', 'c@32')) => ('vec3', ('f2f16', 'a'), ('f2f16', 'b'), ('f2f16', 'c')) */
   /* search2057_0_0 -> 16 in the cache */
   /* search2057_0_1 -> 36 in the cache */
   /* search2057_0_2 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_vec3,
      -1, 0,
      { 16, 36, 135 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 5945 },
      -1,
   } },

   /* replace2057_0_0 -> 16 in the cache */
   /* replace2057_0 -> 4008 in the cache */
   /* replace2057_1_0 -> 36 in the cache */
   /* replace2057_1 -> 4005 in the cache */
   /* replace2057_2_0 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 135 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_vec3,
      -1, 0,
      { 4008, 4005, 5947 },
      -1,
   } },

   /* ('f2fmp', ('vec3', 'a@32', 'b@32', 'c@32')) => ('vec3', ('f2fmp', 'a'), ('f2fmp', 'b'), ('f2fmp', 'c')) */
   /* search2058_0_0 -> 16 in the cache */
   /* search2058_0_1 -> 36 in the cache */
   /* search2058_0_2 -> 135 in the cache */
   /* search2058_0 -> 5945 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2fmp,
      -1, 0,
      { 5945 },
      -1,
   } },

   /* replace2058_0_0 -> 16 in the cache */
   /* replace2058_0 -> 2009 in the cache */
   /* replace2058_1_0 -> 36 in the cache */
   /* replace2058_1 -> 5936 in the cache */
   /* replace2058_2_0 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2fmp,
      -1, 0,
      { 135 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_vec3,
      -1, 0,
      { 2009, 5936, 5950 },
      -1,
   } },

   /* ('u2u16', ('vec3', 'a@32', 'b@32', 'c@32')) => ('vec3', ('u2u16', 'a'), ('u2u16', 'b'), ('u2u16', 'c')) */
   /* search2059_0_0 -> 16 in the cache */
   /* search2059_0_1 -> 36 in the cache */
   /* search2059_0_2 -> 135 in the cache */
   /* search2059_0 -> 5945 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 5945 },
      -1,
   } },

   /* replace2059_0_0 -> 16 in the cache */
   /* replace2059_0 -> 3326 in the cache */
   /* replace2059_1_0 -> 36 in the cache */
   /* replace2059_1 -> 4883 in the cache */
   /* replace2059_2_0 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 135 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_vec3,
      -1, 0,
      { 3326, 4883, 5953 },
      -1,
   } },

   /* ('i2i16', ('vec3', 'a@32', 'b@32', 'c@32')) => ('vec3', ('i2i16', 'a'), ('i2i16', 'b'), ('i2i16', 'c')) */
   /* search2060_0_0 -> 16 in the cache */
   /* search2060_0_1 -> 36 in the cache */
   /* search2060_0_2 -> 135 in the cache */
   /* search2060_0 -> 5945 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 5945 },
      -1,
   } },

   /* replace2060_0_0 -> 16 in the cache */
   /* replace2060_0 -> 4369 in the cache */
   /* replace2060_1_0 -> 36 in the cache */
   /* replace2060_1 -> 4554 in the cache */
   /* replace2060_2_0 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 135 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_vec3,
      -1, 0,
      { 4369, 4554, 5956 },
      -1,
   } },

   /* ('i2imp', ('vec3', 'a@32', 'b@32', 'c@32')) => ('vec3', ('i2imp', 'a'), ('i2imp', 'b'), ('i2imp', 'c')) */
   /* search2061_0_0 -> 16 in the cache */
   /* search2061_0_1 -> 36 in the cache */
   /* search2061_0_2 -> 135 in the cache */
   /* search2061_0 -> 5945 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2imp,
      -1, 0,
      { 5945 },
      -1,
   } },

   /* replace2061_0_0 -> 16 in the cache */
   /* replace2061_0 -> 2020 in the cache */
   /* replace2061_1_0 -> 36 in the cache */
   /* replace2061_1 -> 5943 in the cache */
   /* replace2061_2_0 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2imp,
      -1, 0,
      { 135 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_vec3,
      -1, 0,
      { 2020, 5943, 5959 },
      -1,
   } },

   /* ('f2f16', ('vec4', 'a@32', 'b@32', 'c@32', 'd@32')) => ('vec4', ('f2f16', 'a'), ('f2f16', 'b'), ('f2f16', 'c'), ('f2f16', 'd')) */
   /* search2062_0_0 -> 16 in the cache */
   /* search2062_0_1 -> 36 in the cache */
   /* search2062_0_2 -> 135 in the cache */
   /* search2062_0_3 -> 163 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_vec4,
      -1, 0,
      { 16, 36, 135, 163 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 5961 },
      -1,
   } },

   /* replace2062_0_0 -> 16 in the cache */
   /* replace2062_0 -> 4008 in the cache */
   /* replace2062_1_0 -> 36 in the cache */
   /* replace2062_1 -> 4005 in the cache */
   /* replace2062_2_0 -> 135 in the cache */
   /* replace2062_2 -> 5947 in the cache */
   /* replace2062_3_0 -> 163 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 163 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_vec4,
      -1, 0,
      { 4008, 4005, 5947, 5963 },
      -1,
   } },

   /* ('f2fmp', ('vec4', 'a@32', 'b@32', 'c@32', 'd@32')) => ('vec4', ('f2fmp', 'a'), ('f2fmp', 'b'), ('f2fmp', 'c'), ('f2fmp', 'd')) */
   /* search2063_0_0 -> 16 in the cache */
   /* search2063_0_1 -> 36 in the cache */
   /* search2063_0_2 -> 135 in the cache */
   /* search2063_0_3 -> 163 in the cache */
   /* search2063_0 -> 5961 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2fmp,
      -1, 0,
      { 5961 },
      -1,
   } },

   /* replace2063_0_0 -> 16 in the cache */
   /* replace2063_0 -> 2009 in the cache */
   /* replace2063_1_0 -> 36 in the cache */
   /* replace2063_1 -> 5936 in the cache */
   /* replace2063_2_0 -> 135 in the cache */
   /* replace2063_2 -> 5950 in the cache */
   /* replace2063_3_0 -> 163 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2fmp,
      -1, 0,
      { 163 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_vec4,
      -1, 0,
      { 2009, 5936, 5950, 5966 },
      -1,
   } },

   /* ('u2u16', ('vec4', 'a@32', 'b@32', 'c@32', 'd@32')) => ('vec4', ('u2u16', 'a'), ('u2u16', 'b'), ('u2u16', 'c'), ('u2u16', 'd')) */
   /* search2064_0_0 -> 16 in the cache */
   /* search2064_0_1 -> 36 in the cache */
   /* search2064_0_2 -> 135 in the cache */
   /* search2064_0_3 -> 163 in the cache */
   /* search2064_0 -> 5961 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 5961 },
      -1,
   } },

   /* replace2064_0_0 -> 16 in the cache */
   /* replace2064_0 -> 3326 in the cache */
   /* replace2064_1_0 -> 36 in the cache */
   /* replace2064_1 -> 4883 in the cache */
   /* replace2064_2_0 -> 135 in the cache */
   /* replace2064_2 -> 5953 in the cache */
   /* replace2064_3_0 -> 163 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 163 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_vec4,
      -1, 0,
      { 3326, 4883, 5953, 5969 },
      -1,
   } },

   /* ('i2i16', ('vec4', 'a@32', 'b@32', 'c@32', 'd@32')) => ('vec4', ('i2i16', 'a'), ('i2i16', 'b'), ('i2i16', 'c'), ('i2i16', 'd')) */
   /* search2065_0_0 -> 16 in the cache */
   /* search2065_0_1 -> 36 in the cache */
   /* search2065_0_2 -> 135 in the cache */
   /* search2065_0_3 -> 163 in the cache */
   /* search2065_0 -> 5961 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 5961 },
      -1,
   } },

   /* replace2065_0_0 -> 16 in the cache */
   /* replace2065_0 -> 4369 in the cache */
   /* replace2065_1_0 -> 36 in the cache */
   /* replace2065_1 -> 4554 in the cache */
   /* replace2065_2_0 -> 135 in the cache */
   /* replace2065_2 -> 5956 in the cache */
   /* replace2065_3_0 -> 163 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 163 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_vec4,
      -1, 0,
      { 4369, 4554, 5956, 5972 },
      -1,
   } },

   /* ('i2imp', ('vec4', 'a@32', 'b@32', 'c@32', 'd@32')) => ('vec4', ('i2imp', 'a'), ('i2imp', 'b'), ('i2imp', 'c'), ('i2imp', 'd')) */
   /* search2066_0_0 -> 16 in the cache */
   /* search2066_0_1 -> 36 in the cache */
   /* search2066_0_2 -> 135 in the cache */
   /* search2066_0_3 -> 163 in the cache */
   /* search2066_0 -> 5961 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2imp,
      -1, 0,
      { 5961 },
      -1,
   } },

   /* replace2066_0_0 -> 16 in the cache */
   /* replace2066_0 -> 2020 in the cache */
   /* replace2066_1_0 -> 36 in the cache */
   /* replace2066_1 -> 5943 in the cache */
   /* replace2066_2_0 -> 135 in the cache */
   /* replace2066_2 -> 5959 in the cache */
   /* replace2066_3_0 -> 163 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2imp,
      -1, 0,
      { 163 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_vec4,
      -1, 0,
      { 2020, 5943, 5959, 5975 },
      -1,
   } },

};

static const nir_search_expression_cond nir_opt_algebraic_expression_cond[] = {
   (is_used_once),
   (is_only_used_as_float),
   (is_not_used_by_if),
   (is_used_by_non_fsat),
   (no_signed_wrap),
   (only_lower_8_bits_used),
   (only_lower_16_bits_used),
};

static const nir_search_variable_cond nir_opt_algebraic_variable_cond[] = {
   (is_pos_power_of_two),
   (is_neg_power_of_two),
   (is_bitcount2),
   (is_finite_not_zero),
   (is_finite),
   (is_not_const),
   (is_not_const_zero),
   (is_ult_0xfffc07fc),
   (is_not_fmul),
   (is_first_5_bits_uge_2),
   (is_unsigned_multiple_of_4),
   (is_unsigned_multiple_of_2),
   (is_unsigned_multiple_of_8),
   (is_unsigned_multiple_of_16),
   (is_unsigned_multiple_of_32),
   (is_unsigned_multiple_of_64),
   (is_a_number),
   (is_gt_0_and_lt_1),
   (is_zero_to_one),
   (is_not_negative),
   (is_lower_half_zero),
   (is_upper_half_zero),
   (is_lower_half_negative_one),
   (is_upper_half_negative_one),
   (is_integral),
   (is_not_positive),
   (is_not_zero),
   (is_a_number_not_negative),
   (is_a_number_not_positive),
   (is_gt_zero),
   (is_lt_zero),
   (is_a_number_gt_zero),
   (is_a_number_lt_zero),
   (is_fmul),
   (is_ult_32),
};

static const struct transform nir_opt_algebraic_transforms[] = {
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2, 5, 1 },
   { 8, 10, 1 },
   { 13, 15, 1 },
   { 18, 20, 1 },
   { 23, 25, 1 },
   { 27, 31, 1 },
   { 40, 46, 3 },
   { 238, 61, 0 },
   { 246, 32, 0 },
   { 249, 100, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 2781, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2780, 1229, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 2780, 1229, 0 },
   { 2781, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2748, 3323, 63 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 52, 54, 4 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 55, 57, 4 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 58, 32, 0 },
   { 67, 68, 1 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 59, 32, 0 },
   { 69, 73, 1 },
   { 74, 77, 1 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 60, 61, 0 },
   { 78, 81, 1 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 62, 61, 0 },
   { 64, 61, 0 },
   { 82, 81, 1 },
   { 83, 88, 1 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 65, 61, 0 },
   { 66, 61, 0 },
   { 89, 95, 1 },
   { 96, 97, 1 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3169, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3170, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 112, 32, 0 },
   { 114, 11, 5 },
   { 116, 16, 6 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 117, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3768, 3781, 79 },
   { 4150, 4158, 114 },
   { 4167, 4175, 114 },
   { 4184, 4191, 114 },
   { 3768, 4206, 114 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 118, 32, 0 },
   { 3768, 3781, 79 },
   { 4150, 4158, 114 },
   { 4167, 4175, 114 },
   { 4184, 4191, 114 },
   { 3768, 4206, 114 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3782, 3790, 79 },
   { 4159, 4166, 114 },
   { 4176, 4183, 114 },
   { 4192, 4199, 114 },
   { 3782, 4211, 114 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 119, 32, 0 },
   { 3782, 3790, 79 },
   { 4159, 4166, 114 },
   { 4176, 4183, 114 },
   { 4192, 4199, 114 },
   { 3782, 4211, 114 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3754, 3758, 75 },
   { 3759, 3761, 76 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 120, 32, 0 },
   { 3754, 3758, 75 },
   { 3759, 3761, 76 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3762, 3763, 77 },
   { 3764, 3767, 78 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 121, 32, 0 },
   { 3762, 3763, 77 },
   { 3764, 3767, 78 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 123, 16, 0 },
   { 125, 124, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 221, 111, 0 },
   { 222, 113, 5 },
   { 223, 115, 6 },
   { 242, 32, 0 },
   { 245, 32, 0 },
   { 248, 98, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 226, 227, 6 },
   { 230, 227, 0 },
   { 231, 232, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 224, 115, 0 },
   { 226, 227, 6 },
   { 230, 227, 0 },
   { 231, 232, 0 },
   { 244, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 737, 739, 29 },
   { 234, 741, 30 },
   { 742, 744, 31 },
   { 745, 739, 32 },
   { 746, 741, 33 },
   { 747, 744, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 263, 264, 0 },
   { 265, 266, 5 },
   { 267, 227, 6 },
   { 737, 739, 29 },
   { 234, 741, 30 },
   { 742, 744, 31 },
   { 745, 739, 32 },
   { 746, 741, 33 },
   { 747, 744, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 257, 3, 0 },
   { 259, 258, 5 },
   { 260, 36, 6 },
   { 271, 272, 0 },
   { 276, 277, 0 },
   { 737, 739, 29 },
   { 234, 741, 30 },
   { 742, 744, 31 },
   { 745, 739, 32 },
   { 746, 741, 33 },
   { 747, 744, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 257, 3, 0 },
   { 259, 258, 5 },
   { 260, 36, 6 },
   { 263, 264, 0 },
   { 265, 266, 5 },
   { 267, 227, 6 },
   { 271, 272, 0 },
   { 276, 277, 0 },
   { 737, 739, 29 },
   { 234, 741, 30 },
   { 742, 744, 31 },
   { 745, 739, 32 },
   { 746, 741, 33 },
   { 747, 744, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 257, 3, 0 },
   { 259, 258, 5 },
   { 260, 36, 6 },
   { 271, 272, 0 },
   { 276, 277, 0 },
   { 284, 285, 0 },
   { 737, 739, 29 },
   { 234, 741, 30 },
   { 742, 744, 31 },
   { 745, 739, 32 },
   { 746, 741, 33 },
   { 747, 744, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 257, 3, 0 },
   { 259, 258, 5 },
   { 260, 36, 6 },
   { 263, 264, 0 },
   { 265, 266, 5 },
   { 267, 227, 6 },
   { 271, 272, 0 },
   { 276, 277, 0 },
   { 284, 285, 0 },
   { 737, 739, 29 },
   { 234, 741, 30 },
   { 742, 744, 31 },
   { 745, 739, 32 },
   { 746, 741, 33 },
   { 747, 744, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 233, 234, 6 },
   { 235, 234, 0 },
   { 236, 237, 0 },
   { 387, 288, 30 },
   { 748, 288, 33 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 233, 234, 6 },
   { 235, 234, 0 },
   { 236, 237, 0 },
   { 268, 269, 6 },
   { 387, 288, 30 },
   { 748, 288, 33 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 233, 234, 6 },
   { 235, 234, 0 },
   { 236, 237, 0 },
   { 261, 262, 0 },
   { 273, 274, 6 },
   { 279, 281, 6 },
   { 387, 288, 30 },
   { 748, 288, 33 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 233, 234, 6 },
   { 235, 234, 0 },
   { 236, 237, 0 },
   { 261, 262, 0 },
   { 268, 269, 6 },
   { 273, 274, 6 },
   { 279, 281, 6 },
   { 387, 288, 30 },
   { 748, 288, 33 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 233, 234, 6 },
   { 235, 234, 0 },
   { 236, 237, 0 },
   { 261, 262, 0 },
   { 273, 274, 6 },
   { 279, 281, 6 },
   { 287, 288, 0 },
   { 387, 288, 30 },
   { 748, 288, 33 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 233, 234, 6 },
   { 235, 234, 0 },
   { 236, 237, 0 },
   { 261, 262, 0 },
   { 268, 269, 6 },
   { 273, 274, 6 },
   { 279, 281, 6 },
   { 287, 288, 0 },
   { 387, 288, 30 },
   { 748, 288, 33 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2716, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2699, 2700, 0 },
   { 2702, 2703, 0 },
   { 2716, 32, 0 },
   { 2717, 61, 0 },
   { 2718, 32, 0 },
   { 2741, 2745, 0 },
   { 2747, 2751, 0 },
   { 2753, 2754, 0 },
   { 2756, 2757, 0 },
   { 3261, 3262, 58 },
   { 3292, 3293, 59 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2721, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2721, 32, 0 },
   { 2722, 32, 0 },
   { 2723, 63, 0 },
   { 2758, 2760, 0 },
   { 2761, 2763, 0 },
   { 2764, 2765, 0 },
   { 2766, 2767, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2707, 1235, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2707, 1235, 0 },
   { 3056, 760, 0 },
   { 3059, 1131, 0 },
   { 3208, 1077, 0 },
   { 3808, 3809, 81 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2708, 1077, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2708, 1077, 0 },
   { 3057, 1131, 0 },
   { 3058, 760, 0 },
   { 3207, 1235, 0 },
   { 3805, 3807, 81 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 217, 1517, 40 },
   { 3172, 111, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 239, 122, 0 },
   { 240, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 250, 4021, 104 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 291, 0, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 289, 0, 0 },
   { 290, 3, 0 },
   { 291, 0, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 291, 0, 0 },
   { 685, 687, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 289, 0, 0 },
   { 290, 3, 0 },
   { 291, 0, 0 },
   { 685, 687, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 291, 0, 0 },
   { 292, 264, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 289, 0, 0 },
   { 290, 3, 0 },
   { 291, 0, 0 },
   { 292, 264, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 291, 0, 0 },
   { 292, 264, 0 },
   { 685, 687, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 289, 0, 0 },
   { 290, 3, 0 },
   { 291, 0, 0 },
   { 292, 264, 0 },
   { 685, 687, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 331, 411, 10 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 331, 411, 10 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 297, 36, 0 },
   { 331, 411, 10 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 297, 36, 0 },
   { 331, 411, 10 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 297, 36, 0 },
   { 348, 350, 0 },
   { 331, 411, 10 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 297, 36, 0 },
   { 348, 350, 0 },
   { 331, 411, 10 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 334, 427, 11 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 334, 427, 11 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 298, 36, 0 },
   { 334, 427, 11 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 298, 36, 0 },
   { 334, 427, 11 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 298, 36, 0 },
   { 351, 353, 0 },
   { 334, 427, 11 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 298, 36, 0 },
   { 351, 353, 0 },
   { 334, 427, 11 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 456, 457, 10 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 299, 36, 0 },
   { 456, 457, 10 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 299, 36, 0 },
   { 363, 364, 7 },
   { 456, 457, 10 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 454, 455, 11 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 453, 334, 0 },
   { 454, 455, 11 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 300, 36, 0 },
   { 454, 455, 11 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 300, 36, 0 },
   { 453, 334, 0 },
   { 454, 455, 11 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 300, 36, 0 },
   { 365, 366, 8 },
   { 454, 455, 11 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 300, 36, 0 },
   { 365, 366, 8 },
   { 453, 334, 0 },
   { 454, 455, 11 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 343, 443, 13 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 343, 443, 13 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 301, 36, 0 },
   { 343, 443, 13 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 301, 36, 0 },
   { 343, 443, 13 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 301, 36, 0 },
   { 357, 359, 0 },
   { 343, 443, 13 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 301, 36, 0 },
   { 357, 359, 0 },
   { 343, 443, 13 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 346, 451, 13 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 346, 451, 13 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 302, 36, 0 },
   { 346, 451, 13 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 302, 36, 0 },
   { 346, 451, 13 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 302, 36, 0 },
   { 360, 362, 0 },
   { 346, 451, 13 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 302, 36, 0 },
   { 360, 362, 0 },
   { 346, 451, 13 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 462, 463, 13 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 303, 36, 0 },
   { 462, 463, 13 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 303, 36, 0 },
   { 369, 370, 7 },
   { 462, 463, 13 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 460, 461, 13 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 304, 36, 0 },
   { 460, 461, 13 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 304, 36, 0 },
   { 371, 372, 8 },
   { 460, 461, 13 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 337, 435, 12 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 337, 435, 12 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 305, 36, 0 },
   { 337, 435, 12 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 305, 36, 0 },
   { 337, 435, 12 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 306, 36, 0 },
   { 337, 435, 12 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 306, 36, 0 },
   { 337, 435, 12 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 305, 36, 0 },
   { 306, 36, 0 },
   { 354, 356, 0 },
   { 337, 435, 12 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 305, 36, 0 },
   { 306, 36, 0 },
   { 354, 356, 0 },
   { 337, 435, 12 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 458, 459, 12 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 307, 36, 0 },
   { 458, 459, 12 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 308, 36, 0 },
   { 458, 459, 12 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 307, 36, 0 },
   { 308, 36, 0 },
   { 367, 368, 7 },
   { 458, 459, 12 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1331, 1138, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1331, 1138, 0 },
   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3060, 760, 0 },
   { 3061, 1131, 0 },
   { 3064, 3065, 0 },
   { 3066, 3067, 0 },
   { 3070, 3071, 0 },
   { 3072, 3073, 0 },
   { 3074, 3075, 0 },
   { 3076, 3077, 0 },
   { 3079, 3080, 0 },
   { 3081, 3082, 0 },
   { 3083, 3084, 57 },
   { 3085, 3086, 57 },
   { 3089, 3090, 57 },
   { 3091, 3092, 57 },
   { 3093, 3, 0 },
   { 3095, 2264, 0 },
   { 3096, 3098, 0 },
   { 3100, 1228, 0 },
   { 3101, 3097, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3062, 1117, 0 },
   { 3063, 684, 0 },
   { 3093, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3062, 1117, 0 },
   { 3063, 684, 0 },
   { 3093, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1331, 1138, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3062, 1117, 0 },
   { 3063, 684, 0 },
   { 3093, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1331, 1138, 0 },
   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3060, 760, 0 },
   { 3061, 1131, 0 },
   { 3062, 1117, 0 },
   { 3063, 684, 0 },
   { 3064, 3065, 0 },
   { 3066, 3067, 0 },
   { 3070, 3071, 0 },
   { 3072, 3073, 0 },
   { 3074, 3075, 0 },
   { 3076, 3077, 0 },
   { 3079, 3080, 0 },
   { 3081, 3082, 0 },
   { 3083, 3084, 57 },
   { 3085, 3086, 57 },
   { 3089, 3090, 57 },
   { 3091, 3092, 57 },
   { 3093, 3, 0 },
   { 3095, 2264, 0 },
   { 3096, 3098, 0 },
   { 3100, 1228, 0 },
   { 3101, 3097, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2714, 1235, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2714, 1235, 0 },
   { 3189, 1077, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 688, 693, 20 },
   { 694, 699, 20 },
   { 700, 706, 21 },
   { 3165, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 707, 709, 22 },
   { 710, 712, 22 },
   { 713, 715, 23 },
   { 3163, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 708, 731, 26 },
   { 711, 732, 26 },
   { 714, 733, 27 },
   { 3167, 111, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 734, 736, 28 },
   { 3164, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 768, 773, 35 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 804, 805, 37 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 802, 803, 37 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 800, 801, 37 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 796, 799, 0 },
   { 800, 801, 37 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 806, 799, 37 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2787, 32, 0 },
   { 3250, 3251, 58 },
   { 1017, 422, 58 },
   { 3253, 3255, 58 },
   { 1008, 447, 59 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2786, 1229, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2786, 1229, 0 },
   { 2787, 32, 0 },
   { 3250, 3251, 58 },
   { 1017, 422, 58 },
   { 3253, 3255, 58 },
   { 1008, 447, 59 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2785, 32, 0 },
   { 3256, 3257, 58 },
   { 3258, 406, 58 },
   { 3259, 3260, 58 },
   { 3290, 439, 59 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2782, 1229, 0 },
   { 2784, 2783, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2782, 1229, 0 },
   { 2784, 2783, 0 },
   { 2785, 32, 0 },
   { 3256, 3257, 58 },
   { 3258, 406, 58 },
   { 3259, 3260, 58 },
   { 3290, 439, 59 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2711, 1077, 0 },
   { 3200, 1077, 0 },
   { 3203, 1235, 0 },
   { 3206, 1235, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2711, 1077, 0 },
   { 3200, 1077, 0 },
   { 3203, 1235, 0 },
   { 3206, 1235, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2711, 1077, 0 },
   { 3200, 1077, 0 },
   { 3203, 1235, 0 },
   { 3206, 1235, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2711, 1077, 0 },
   { 3200, 1077, 0 },
   { 3203, 1235, 0 },
   { 3206, 1235, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2713, 1235, 0 },
   { 3192, 1235, 0 },
   { 3195, 1077, 0 },
   { 3198, 1077, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2713, 1235, 0 },
   { 3192, 1235, 0 },
   { 3195, 1077, 0 },
   { 3198, 1077, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2713, 1235, 0 },
   { 3192, 1235, 0 },
   { 3195, 1077, 0 },
   { 3198, 1077, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2713, 1235, 0 },
   { 3192, 1235, 0 },
   { 3195, 1077, 0 },
   { 3198, 1077, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2715, 1077, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2715, 1077, 0 },
   { 3188, 1235, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2705, 1077, 0 },
   { 3212, 1077, 0 },
   { 3213, 1235, 0 },
   { 3214, 1235, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2705, 1077, 0 },
   { 3212, 1077, 0 },
   { 3213, 1235, 0 },
   { 3214, 1235, 0 },
   { 1489, 3803, 81 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2709, 1077, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2709, 1077, 0 },
   { 3217, 1077, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2709, 1077, 0 },
   { 3216, 1235, 0 },
   { 3810, 3807, 81 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2709, 1077, 0 },
   { 3216, 1235, 0 },
   { 3217, 1077, 0 },
   { 3810, 3807, 81 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2706, 1235, 0 },
   { 3209, 1235, 0 },
   { 3210, 1077, 0 },
   { 3211, 1077, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2706, 1235, 0 },
   { 3209, 1235, 0 },
   { 3210, 1077, 0 },
   { 3211, 1077, 0 },
   { 1486, 3804, 81 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2710, 1235, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2710, 1235, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1335, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1335, 32, 0 },
   { 3173, 217, 38 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1336, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1336, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1337, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1337, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1338, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1338, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1339, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1339, 32, 0 },
   { 1340, 61, 0 },
   { 1341, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1342, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1342, 32, 0 },
   { 1343, 32, 0 },
   { 1344, 63, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3932, 3935, 91 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3932, 3935, 91 },
   { 5094, 11, 0 },
   { 5147, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4257, 11, 0 },
   { 4258, 16, 0 },
   { 4259, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4247, 760, 0 },
   { 4248, 6, 0 },
   { 4249, 11, 0 },
   { 4250, 16, 0 },
   { 4251, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4252, 760, 0 },
   { 4253, 6, 0 },
   { 4254, 11, 0 },
   { 4255, 16, 0 },
   { 4256, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3927, 3931, 91 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3927, 3931, 91 },
   { 5122, 11, 0 },
   { 5175, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3936, 3940, 92 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3936, 3940, 92 },
   { 5227, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3941, 3944, 92 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3941, 3944, 92 },
   { 5200, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2725, 61, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2725, 61, 0 },
   { 2726, 32, 0 },
   { 2729, 2719, 0 },
   { 2768, 2770, 0 },
   { 2771, 2773, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2412, 2420, 47 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2414, 2421, 47 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2416, 2422, 47 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2418, 2423, 47 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2442, 2449, 48 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2450, 2452, 48 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2453, 2455, 48 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2456, 2458, 48 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2459, 2461, 48 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2462, 2465, 48 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2466, 2470, 48 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2471, 2473, 48 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2474, 2476, 48 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2477, 2479, 48 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2480, 2485, 48 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2486, 2492, 48 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2493, 2499, 48 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2500, 2516, 48 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2517, 2549, 48 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2550, 2553, 48 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2554, 2559, 48 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2560, 2564, 48 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2565, 2573, 48 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2574, 2590, 48 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2591, 2594, 48 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2595, 2600, 48 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2601, 2605, 48 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2606, 2614, 48 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2615, 2631, 48 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2632, 2635, 48 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2636, 2641, 48 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2642, 2646, 48 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2647, 2655, 48 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2656, 2672, 48 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3477, 3478, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3477, 3478, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2813, 2816, 50 },
   { 2792, 2795, 50 },
   { 2799, 2802, 50 },
   { 2817, 2820, 50 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2821, 2823, 50 },
   { 2805, 2807, 50 },
   { 2810, 2812, 50 },
   { 2824, 2826, 50 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2831, 2834, 51 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2831, 2834, 51 },
   { 2856, 32, 0 },
   { 2857, 251, 0 },
   { 2858, 2855, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2831, 2834, 51 },
   { 2859, 2829, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2831, 2834, 51 },
   { 2856, 32, 0 },
   { 2857, 251, 0 },
   { 2858, 2855, 0 },
   { 2859, 2829, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2848, 2901, 54 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2896, 2898, 53 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2895, 2877, 0 },
   { 2896, 2898, 53 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2903, 2985, 56 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2986, 3055, 56 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3094, 36, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3166, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3218, 3318, 61 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2742, 3325, 63 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3242, 3326, 64 },
   { 3242, 3326, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3244, 3327, 64 },
   { 3244, 3327, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3871, 122, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3278, 412, 58 },
   { 3279, 415, 58 },
   { 3280, 419, 58 },
   { 3281, 422, 58 },
   { 3294, 444, 59 },
   { 3295, 447, 59 },
   { 3871, 122, 0 },
   { 3873, 3875, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3872, 122, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3282, 393, 58 },
   { 3283, 397, 58 },
   { 3284, 402, 58 },
   { 3285, 406, 58 },
   { 3296, 436, 59 },
   { 3297, 439, 59 },
   { 3872, 122, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3319, 3322, 62 },
   { 3319, 4013, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3329, 4011, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3336, 4012, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3364, 4010, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3364, 4010, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3364, 4010, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3364, 4010, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3473, 16, 0 },
   { 3474, 122, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3475, 3476, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3479, 3481, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3482, 3483, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3923, 3926, 90 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3906, 3910, 87 },
   { 3906, 3914, 88 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3916, 3920, 88 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3698, 3701, 68 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3702, 3705, 68 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3706, 3709, 69 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3710, 3711, 70 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3716, 3720, 71 },
   { 3716, 3819, 82 },
   { 3716, 3821, 83 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3721, 3724, 72 },
   { 3734, 3738, 73 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3725, 3727, 72 },
   { 3739, 3741, 73 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3728, 3730, 72 },
   { 3742, 3746, 73 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3731, 3733, 72 },
   { 3747, 3749, 73 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3750, 3751, 74 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3752, 3753, 74 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3825, 3828, 84 },
   { 3825, 3899, 86 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3829, 3831, 84 },
   { 3829, 3905, 86 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3832, 2735, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3921, 3922, 89 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3946, 3952, 93 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3953, 3958, 94 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3959, 3966, 95 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3967, 3972, 96 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3973, 3978, 97 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3979, 3986, 98 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3987, 3994, 99 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3995, 4004, 100 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4014, 4016, 102 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4022, 951, 105 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4023, 4027, 106 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4028, 4032, 107 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4033, 4034, 108 },
   { 4033, 49, 105 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4035, 4028, 109 },
   { 4035, 4037, 107 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4038, 4023, 110 },
   { 4038, 49, 106 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4039, 4034, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4040, 555, 0 },
   { 4041, 4042, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4039, 4034, 0 },
   { 4040, 555, 0 },
   { 4041, 4042, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4040, 555, 0 },
   { 4041, 4042, 0 },
   { 4043, 4045, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4039, 4034, 0 },
   { 4040, 555, 0 },
   { 4041, 4042, 0 },
   { 4043, 4045, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4046, 4047, 1 },
   { 4049, 4053, 1 },
   { 4054, 122, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4260, 760, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4261, 6, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4262, 11, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4263, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5253, 5273, 117 },
   { 5275, 5293, 117 },
   { 5295, 5316, 117 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5627, 111, 119 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5628, 111, 119 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5629, 111, 119 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5630, 111, 119 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5631, 111, 119 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5632, 111, 119 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5634, 122, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5637, 135, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5635, 135, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5635, 135, 0 },
   { 5637, 135, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5916, 5921, 120 },
   { 5922, 5926, 120 },
   { 5927, 5932, 120 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3492, 3493, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5111, 5109, 0 },
   { 5164, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5136, 5109, 0 },
   { 5189, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5241, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5216, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2, 5, 1 },
   { 8, 10, 1 },
   { 13, 15, 1 },
   { 18, 20, 1 },
   { 23, 25, 1 },
   { 27, 31, 1 },
   { 40, 46, 3 },
   { 238, 61, 0 },
   { 246, 32, 0 },
   { 249, 100, 0 },
   { 3509, 3510, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2, 5, 1 },
   { 8, 10, 1 },
   { 13, 15, 1 },
   { 18, 20, 1 },
   { 23, 25, 1 },
   { 27, 31, 1 },
   { 40, 46, 3 },
   { 238, 61, 0 },
   { 246, 32, 0 },
   { 249, 100, 0 },
   { 3509, 3510, 0 },
   { 3553, 3510, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2, 5, 1 },
   { 8, 10, 1 },
   { 13, 15, 1 },
   { 18, 20, 1 },
   { 23, 25, 1 },
   { 27, 31, 1 },
   { 40, 46, 3 },
   { 238, 61, 0 },
   { 246, 32, 0 },
   { 249, 100, 0 },
   { 3492, 3493, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2, 5, 1 },
   { 8, 10, 1 },
   { 13, 15, 1 },
   { 18, 20, 1 },
   { 23, 25, 1 },
   { 27, 31, 1 },
   { 40, 46, 3 },
   { 238, 61, 0 },
   { 246, 32, 0 },
   { 249, 100, 0 },
   { 1024, 1027, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2, 5, 1 },
   { 8, 10, 1 },
   { 13, 15, 1 },
   { 18, 20, 1 },
   { 23, 25, 1 },
   { 27, 31, 1 },
   { 40, 46, 3 },
   { 238, 61, 0 },
   { 246, 32, 0 },
   { 249, 100, 0 },
   { 5623, 5626, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2, 5, 1 },
   { 8, 10, 1 },
   { 13, 15, 1 },
   { 18, 20, 1 },
   { 23, 25, 1 },
   { 27, 31, 1 },
   { 40, 46, 3 },
   { 238, 61, 0 },
   { 246, 32, 0 },
   { 249, 100, 0 },
   { 5111, 5109, 0 },
   { 5164, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2, 5, 1 },
   { 8, 10, 1 },
   { 13, 15, 1 },
   { 18, 20, 1 },
   { 23, 25, 1 },
   { 27, 31, 1 },
   { 40, 46, 3 },
   { 238, 61, 0 },
   { 246, 32, 0 },
   { 249, 100, 0 },
   { 5136, 5109, 0 },
   { 5189, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2, 5, 1 },
   { 8, 10, 1 },
   { 13, 15, 1 },
   { 18, 20, 1 },
   { 23, 25, 1 },
   { 27, 31, 1 },
   { 40, 46, 3 },
   { 238, 61, 0 },
   { 246, 32, 0 },
   { 249, 100, 0 },
   { 5241, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2, 5, 1 },
   { 8, 10, 1 },
   { 13, 15, 1 },
   { 18, 20, 1 },
   { 23, 25, 1 },
   { 27, 31, 1 },
   { 40, 46, 3 },
   { 238, 61, 0 },
   { 246, 32, 0 },
   { 249, 100, 0 },
   { 5216, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3492, 3493, 0 },
   { 5111, 5109, 0 },
   { 5164, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3492, 3493, 0 },
   { 5136, 5109, 0 },
   { 5189, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3492, 3493, 0 },
   { 5241, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3492, 3493, 0 },
   { 5216, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2691, 2692, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5111, 5109, 0 },
   { 5136, 5109, 0 },
   { 5164, 49, 0 },
   { 5189, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5111, 5109, 0 },
   { 5164, 49, 0 },
   { 5241, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5111, 5109, 0 },
   { 5164, 49, 0 },
   { 5216, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5136, 5109, 0 },
   { 5189, 49, 0 },
   { 5241, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5136, 5109, 0 },
   { 5189, 49, 0 },
   { 5216, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5216, 49, 0 },
   { 5241, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3599, 0, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 59, 32, 0 },
   { 69, 73, 1 },
   { 74, 77, 1 },
   { 3599, 0, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 206, 61, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 330, 331, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 333, 334, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 342, 343, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 345, 346, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 336, 337, 0 },
   { 340, 337, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5107, 4068, 0 },
   { 5161, 4081, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5133, 4068, 0 },
   { 5186, 4081, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5238, 4081, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5213, 4081, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 117, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 117, 32, 0 },
   { 3867, 3868, 85 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 117, 32, 0 },
   { 206, 61, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 117, 32, 0 },
   { 3539, 3540, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 117, 32, 0 },
   { 3539, 3540, 0 },
   { 3581, 3540, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 117, 32, 0 },
   { 312, 314, 0 },
   { 330, 331, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 117, 32, 0 },
   { 316, 317, 0 },
   { 333, 334, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 117, 32, 0 },
   { 323, 324, 0 },
   { 342, 343, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 117, 32, 0 },
   { 326, 327, 0 },
   { 345, 346, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 117, 32, 0 },
   { 319, 321, 0 },
   { 336, 337, 0 },
   { 340, 337, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 117, 32, 0 },
   { 5619, 5622, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 117, 32, 0 },
   { 5107, 4068, 0 },
   { 5161, 4081, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 117, 32, 0 },
   { 5133, 4068, 0 },
   { 5186, 4081, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 117, 32, 0 },
   { 5238, 4081, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 117, 32, 0 },
   { 5213, 4081, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 179, 181, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 186, 188, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 206, 61, 0 },
   { 209, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 206, 61, 0 },
   { 209, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 206, 61, 0 },
   { 330, 331, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 206, 61, 0 },
   { 333, 334, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 206, 61, 0 },
   { 342, 343, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 206, 61, 0 },
   { 345, 346, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 206, 61, 0 },
   { 336, 337, 0 },
   { 340, 337, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 206, 61, 0 },
   { 5107, 4068, 0 },
   { 5161, 4081, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 206, 61, 0 },
   { 5133, 4068, 0 },
   { 5186, 4081, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 206, 61, 0 },
   { 5238, 4081, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 206, 61, 0 },
   { 5213, 4081, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 330, 331, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 333, 334, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 342, 343, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 345, 346, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 336, 337, 0 },
   { 340, 337, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5107, 4068, 0 },
   { 5161, 4081, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5133, 4068, 0 },
   { 5186, 4081, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5238, 4081, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5213, 4081, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 330, 331, 0 },
   { 333, 334, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 330, 331, 0 },
   { 342, 343, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 330, 331, 0 },
   { 345, 346, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 330, 331, 0 },
   { 336, 337, 0 },
   { 340, 337, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 330, 331, 0 },
   { 5107, 4068, 0 },
   { 5161, 4081, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 330, 331, 0 },
   { 5133, 4068, 0 },
   { 5186, 4081, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 330, 331, 0 },
   { 5238, 4081, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 330, 331, 0 },
   { 5213, 4081, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 333, 334, 0 },
   { 342, 343, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 333, 334, 0 },
   { 345, 346, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 333, 334, 0 },
   { 336, 337, 0 },
   { 340, 337, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 333, 334, 0 },
   { 5107, 4068, 0 },
   { 5161, 4081, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 333, 334, 0 },
   { 5133, 4068, 0 },
   { 5186, 4081, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 333, 334, 0 },
   { 5238, 4081, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 333, 334, 0 },
   { 5213, 4081, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 342, 343, 0 },
   { 345, 346, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 336, 337, 0 },
   { 340, 337, 0 },
   { 342, 343, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 342, 343, 0 },
   { 5107, 4068, 0 },
   { 5161, 4081, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 342, 343, 0 },
   { 5133, 4068, 0 },
   { 5186, 4081, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 342, 343, 0 },
   { 5238, 4081, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 342, 343, 0 },
   { 5213, 4081, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 336, 337, 0 },
   { 340, 337, 0 },
   { 345, 346, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 345, 346, 0 },
   { 5107, 4068, 0 },
   { 5161, 4081, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 345, 346, 0 },
   { 5133, 4068, 0 },
   { 5186, 4081, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 345, 346, 0 },
   { 5238, 4081, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 345, 346, 0 },
   { 5213, 4081, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 336, 337, 0 },
   { 340, 337, 0 },
   { 5107, 4068, 0 },
   { 5161, 4081, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 336, 337, 0 },
   { 340, 337, 0 },
   { 5133, 4068, 0 },
   { 5186, 4081, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 336, 337, 0 },
   { 340, 337, 0 },
   { 5238, 4081, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 336, 337, 0 },
   { 340, 337, 0 },
   { 5213, 4081, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5107, 4068, 0 },
   { 5133, 4068, 0 },
   { 5161, 4081, 0 },
   { 5186, 4081, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5107, 4068, 0 },
   { 5161, 4081, 0 },
   { 5238, 4081, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5107, 4068, 0 },
   { 5161, 4081, 0 },
   { 5213, 4081, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5133, 4068, 0 },
   { 5186, 4081, 0 },
   { 5238, 4081, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5133, 4068, 0 },
   { 5186, 4081, 0 },
   { 5213, 4081, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5213, 4081, 0 },
   { 5238, 4081, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3363, 3364, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1313, 1311, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3695, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1331, 1138, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1313, 1311, 0 },
   { 1331, 1138, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3695, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1331, 1138, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5702, 5703, 0 },
   { 5706, 5703, 0 },
   { 5709, 5703, 0 },
   { 5712, 5703, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5891, 5892, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1313, 1311, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3695, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5895, 5896, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5689, 5690, 0 },
   { 5693, 5690, 0 },
   { 5696, 5690, 0 },
   { 5699, 5690, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5676, 5677, 0 },
   { 5680, 5677, 0 },
   { 5683, 5677, 0 },
   { 5686, 5677, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5661, 5663, 0 },
   { 5666, 5663, 0 },
   { 5669, 5663, 0 },
   { 5672, 5663, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5715, 5716, 0 },
   { 5719, 5716, 0 },
   { 5722, 5716, 0 },
   { 5725, 5716, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5728, 5729, 0 },
   { 5732, 5729, 0 },
   { 5735, 5729, 0 },
   { 5738, 5729, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5871, 5872, 0 },
   { 5871, 5872, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5640, 5641, 0 },
   { 5644, 5641, 0 },
   { 5646, 5648, 0 },
   { 5650, 5648, 0 },
   { 5653, 5655, 0 },
   { 5657, 5655, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1310, 1311, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3692, 3693, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1310, 1311, 0 },
   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3692, 3693, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1310, 1311, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3692, 3693, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1310, 1311, 0 },
   { 1313, 1311, 0 },
   { 1316, 1318, 0 },
   { 1321, 1318, 0 },
   { 1325, 1327, 0 },
   { 1330, 1327, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3692, 3693, 0 },
   { 3695, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5863, 5864, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 1779, 1781, 0 },
   { 1887, 1889, 0 },
   { 1972, 1974, 0 },
   { 3093, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5754, 5755, 0 },
   { 5758, 5755, 0 },
   { 5761, 5755, 0 },
   { 5764, 5755, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5767, 5768, 0 },
   { 5771, 5768, 0 },
   { 5774, 5768, 0 },
   { 5777, 5768, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5780, 5781, 0 },
   { 5784, 5781, 0 },
   { 5787, 5781, 0 },
   { 5790, 5781, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5793, 5794, 0 },
   { 5797, 5794, 0 },
   { 5800, 5794, 0 },
   { 5803, 5794, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5806, 5807, 0 },
   { 5810, 5807, 0 },
   { 5813, 5807, 0 },
   { 5816, 5807, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5819, 5820, 0 },
   { 5823, 5820, 0 },
   { 5826, 5820, 0 },
   { 5829, 5820, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5103, 5098, 0 },
   { 5156, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5103, 5098, 0 },
   { 5156, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5103, 5098, 0 },
   { 5156, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1313, 1311, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3695, 3697, 0 },
   { 5103, 5098, 0 },
   { 5156, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5128, 5098, 0 },
   { 5181, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5128, 5098, 0 },
   { 5181, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5128, 5098, 0 },
   { 5181, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1313, 1311, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3695, 3697, 0 },
   { 5128, 5098, 0 },
   { 5181, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5233, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5233, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5233, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1313, 1311, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3695, 3697, 0 },
   { 5233, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5208, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5208, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5208, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1313, 1311, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3695, 3697, 0 },
   { 5208, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5741, 5742, 0 },
   { 5745, 5742, 0 },
   { 5748, 5742, 0 },
   { 5751, 5742, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5867, 5868, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5832, 5833, 0 },
   { 5836, 5833, 0 },
   { 5840, 5842, 0 },
   { 5845, 5842, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5859, 5860, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5850, 5852, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5855, 5856, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5875, 5876, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5879, 5880, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5883, 5884, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5887, 5888, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3062, 1117, 0 },
   { 3063, 684, 0 },
   { 3093, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1313, 1311, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3062, 1117, 0 },
   { 3063, 684, 0 },
   { 3093, 3, 0 },
   { 3695, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1331, 1138, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3062, 1117, 0 },
   { 3063, 684, 0 },
   { 3093, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1313, 1311, 0 },
   { 1331, 1138, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3062, 1117, 0 },
   { 3063, 684, 0 },
   { 3093, 3, 0 },
   { 3695, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1331, 1138, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3062, 1117, 0 },
   { 3063, 684, 0 },
   { 3093, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3062, 1117, 0 },
   { 3063, 684, 0 },
   { 3093, 3, 0 },
   { 5702, 5703, 0 },
   { 5706, 5703, 0 },
   { 5709, 5703, 0 },
   { 5712, 5703, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3062, 1117, 0 },
   { 3063, 684, 0 },
   { 3093, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3062, 1117, 0 },
   { 3063, 684, 0 },
   { 3093, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3062, 1117, 0 },
   { 3063, 684, 0 },
   { 3093, 3, 0 },
   { 5891, 5892, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1313, 1311, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3062, 1117, 0 },
   { 3063, 684, 0 },
   { 3093, 3, 0 },
   { 3695, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3062, 1117, 0 },
   { 3063, 684, 0 },
   { 3093, 3, 0 },
   { 5895, 5896, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3062, 1117, 0 },
   { 3063, 684, 0 },
   { 3093, 3, 0 },
   { 5689, 5690, 0 },
   { 5693, 5690, 0 },
   { 5696, 5690, 0 },
   { 5699, 5690, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3062, 1117, 0 },
   { 3063, 684, 0 },
   { 3093, 3, 0 },
   { 5676, 5677, 0 },
   { 5680, 5677, 0 },
   { 5683, 5677, 0 },
   { 5686, 5677, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3062, 1117, 0 },
   { 3063, 684, 0 },
   { 3093, 3, 0 },
   { 5661, 5663, 0 },
   { 5666, 5663, 0 },
   { 5669, 5663, 0 },
   { 5672, 5663, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3062, 1117, 0 },
   { 3063, 684, 0 },
   { 3093, 3, 0 },
   { 5715, 5716, 0 },
   { 5719, 5716, 0 },
   { 5722, 5716, 0 },
   { 5725, 5716, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3062, 1117, 0 },
   { 3063, 684, 0 },
   { 3093, 3, 0 },
   { 5728, 5729, 0 },
   { 5732, 5729, 0 },
   { 5735, 5729, 0 },
   { 5738, 5729, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3062, 1117, 0 },
   { 3063, 684, 0 },
   { 3093, 3, 0 },
   { 5871, 5872, 0 },
   { 5871, 5872, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3062, 1117, 0 },
   { 3063, 684, 0 },
   { 3093, 3, 0 },
   { 5640, 5641, 0 },
   { 5644, 5641, 0 },
   { 5646, 5648, 0 },
   { 5650, 5648, 0 },
   { 5653, 5655, 0 },
   { 5657, 5655, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1310, 1311, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3062, 1117, 0 },
   { 3063, 684, 0 },
   { 3093, 3, 0 },
   { 3692, 3693, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1310, 1311, 0 },
   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3062, 1117, 0 },
   { 3063, 684, 0 },
   { 3093, 3, 0 },
   { 3692, 3693, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1310, 1311, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3062, 1117, 0 },
   { 3063, 684, 0 },
   { 3093, 3, 0 },
   { 3692, 3693, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1310, 1311, 0 },
   { 1313, 1311, 0 },
   { 1316, 1318, 0 },
   { 1321, 1318, 0 },
   { 1325, 1327, 0 },
   { 1330, 1327, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3062, 1117, 0 },
   { 3063, 684, 0 },
   { 3093, 3, 0 },
   { 3692, 3693, 0 },
   { 3695, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3062, 1117, 0 },
   { 3063, 684, 0 },
   { 3093, 3, 0 },
   { 5863, 5864, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3062, 1117, 0 },
   { 3063, 684, 0 },
   { 3093, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 1779, 1781, 0 },
   { 1887, 1889, 0 },
   { 1972, 1974, 0 },
   { 3062, 1117, 0 },
   { 3063, 684, 0 },
   { 3093, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3062, 1117, 0 },
   { 3063, 684, 0 },
   { 3093, 3, 0 },
   { 5754, 5755, 0 },
   { 5758, 5755, 0 },
   { 5761, 5755, 0 },
   { 5764, 5755, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3062, 1117, 0 },
   { 3063, 684, 0 },
   { 3093, 3, 0 },
   { 5767, 5768, 0 },
   { 5771, 5768, 0 },
   { 5774, 5768, 0 },
   { 5777, 5768, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3062, 1117, 0 },
   { 3063, 684, 0 },
   { 3093, 3, 0 },
   { 5780, 5781, 0 },
   { 5784, 5781, 0 },
   { 5787, 5781, 0 },
   { 5790, 5781, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3062, 1117, 0 },
   { 3063, 684, 0 },
   { 3093, 3, 0 },
   { 5793, 5794, 0 },
   { 5797, 5794, 0 },
   { 5800, 5794, 0 },
   { 5803, 5794, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3062, 1117, 0 },
   { 3063, 684, 0 },
   { 3093, 3, 0 },
   { 5806, 5807, 0 },
   { 5810, 5807, 0 },
   { 5813, 5807, 0 },
   { 5816, 5807, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3062, 1117, 0 },
   { 3063, 684, 0 },
   { 3093, 3, 0 },
   { 5819, 5820, 0 },
   { 5823, 5820, 0 },
   { 5826, 5820, 0 },
   { 5829, 5820, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3062, 1117, 0 },
   { 3063, 684, 0 },
   { 3093, 3, 0 },
   { 5103, 5098, 0 },
   { 5156, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3062, 1117, 0 },
   { 3063, 684, 0 },
   { 3093, 3, 0 },
   { 5103, 5098, 0 },
   { 5156, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3062, 1117, 0 },
   { 3063, 684, 0 },
   { 3093, 3, 0 },
   { 5103, 5098, 0 },
   { 5156, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1313, 1311, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3062, 1117, 0 },
   { 3063, 684, 0 },
   { 3093, 3, 0 },
   { 3695, 3697, 0 },
   { 5103, 5098, 0 },
   { 5156, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3062, 1117, 0 },
   { 3063, 684, 0 },
   { 3093, 3, 0 },
   { 5128, 5098, 0 },
   { 5181, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3062, 1117, 0 },
   { 3063, 684, 0 },
   { 3093, 3, 0 },
   { 5128, 5098, 0 },
   { 5181, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3062, 1117, 0 },
   { 3063, 684, 0 },
   { 3093, 3, 0 },
   { 5128, 5098, 0 },
   { 5181, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1313, 1311, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3062, 1117, 0 },
   { 3063, 684, 0 },
   { 3093, 3, 0 },
   { 3695, 3697, 0 },
   { 5128, 5098, 0 },
   { 5181, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3062, 1117, 0 },
   { 3063, 684, 0 },
   { 3093, 3, 0 },
   { 5233, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3062, 1117, 0 },
   { 3063, 684, 0 },
   { 3093, 3, 0 },
   { 5233, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3062, 1117, 0 },
   { 3063, 684, 0 },
   { 3093, 3, 0 },
   { 5233, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1313, 1311, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3062, 1117, 0 },
   { 3063, 684, 0 },
   { 3093, 3, 0 },
   { 3695, 3697, 0 },
   { 5233, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3062, 1117, 0 },
   { 3063, 684, 0 },
   { 3093, 3, 0 },
   { 5208, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3062, 1117, 0 },
   { 3063, 684, 0 },
   { 3093, 3, 0 },
   { 5208, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3062, 1117, 0 },
   { 3063, 684, 0 },
   { 3093, 3, 0 },
   { 5208, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1313, 1311, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3062, 1117, 0 },
   { 3063, 684, 0 },
   { 3093, 3, 0 },
   { 3695, 3697, 0 },
   { 5208, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3062, 1117, 0 },
   { 3063, 684, 0 },
   { 3093, 3, 0 },
   { 5741, 5742, 0 },
   { 5745, 5742, 0 },
   { 5748, 5742, 0 },
   { 5751, 5742, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3062, 1117, 0 },
   { 3063, 684, 0 },
   { 3093, 3, 0 },
   { 5867, 5868, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3062, 1117, 0 },
   { 3063, 684, 0 },
   { 3093, 3, 0 },
   { 5832, 5833, 0 },
   { 5836, 5833, 0 },
   { 5840, 5842, 0 },
   { 5845, 5842, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3062, 1117, 0 },
   { 3063, 684, 0 },
   { 3093, 3, 0 },
   { 5859, 5860, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3062, 1117, 0 },
   { 3063, 684, 0 },
   { 3093, 3, 0 },
   { 5850, 5852, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3062, 1117, 0 },
   { 3063, 684, 0 },
   { 3093, 3, 0 },
   { 5855, 5856, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3062, 1117, 0 },
   { 3063, 684, 0 },
   { 3093, 3, 0 },
   { 5875, 5876, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3062, 1117, 0 },
   { 3063, 684, 0 },
   { 3093, 3, 0 },
   { 5879, 5880, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3062, 1117, 0 },
   { 3063, 684, 0 },
   { 3093, 3, 0 },
   { 5883, 5884, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3062, 1117, 0 },
   { 3063, 684, 0 },
   { 3093, 3, 0 },
   { 5887, 5888, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3615, 3600, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3617, 3603, 0 },
   { 3622, 3603, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3618, 3606, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3619, 3609, 0 },
   { 3624, 3609, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3620, 3612, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1331, 1138, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1331, 1138, 0 },
   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3060, 760, 0 },
   { 3061, 1131, 0 },
   { 3064, 3065, 0 },
   { 3066, 3067, 0 },
   { 3070, 3071, 0 },
   { 3072, 3073, 0 },
   { 3074, 3075, 0 },
   { 3076, 3077, 0 },
   { 3079, 3080, 0 },
   { 3081, 3082, 0 },
   { 3083, 3084, 57 },
   { 3085, 3086, 57 },
   { 3089, 3090, 57 },
   { 3091, 3092, 57 },
   { 3093, 3, 0 },
   { 3095, 2264, 0 },
   { 3096, 3098, 0 },
   { 3100, 1228, 0 },
   { 3101, 3097, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1331, 1138, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1313, 1311, 0 },
   { 1331, 1138, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3695, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1331, 1138, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1307, 1308, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1307, 1308, 0 },
   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1307, 1308, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1307, 1308, 0 },
   { 1313, 1311, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3695, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1307, 1308, 0 },
   { 1331, 1138, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1307, 1308, 0 },
   { 1331, 1138, 0 },
   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3060, 760, 0 },
   { 3061, 1131, 0 },
   { 3064, 3065, 0 },
   { 3066, 3067, 0 },
   { 3070, 3071, 0 },
   { 3072, 3073, 0 },
   { 3074, 3075, 0 },
   { 3076, 3077, 0 },
   { 3079, 3080, 0 },
   { 3081, 3082, 0 },
   { 3083, 3084, 57 },
   { 3085, 3086, 57 },
   { 3089, 3090, 57 },
   { 3091, 3092, 57 },
   { 3093, 3, 0 },
   { 3095, 2264, 0 },
   { 3096, 3098, 0 },
   { 3100, 1228, 0 },
   { 3101, 3097, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1307, 1308, 0 },
   { 1331, 1138, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1307, 1308, 0 },
   { 1313, 1311, 0 },
   { 1331, 1138, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3695, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1307, 1308, 0 },
   { 1331, 1138, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1307, 1308, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5702, 5703, 0 },
   { 5706, 5703, 0 },
   { 5709, 5703, 0 },
   { 5712, 5703, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1307, 1308, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1307, 1308, 0 },
   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1307, 1308, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5891, 5892, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1307, 1308, 0 },
   { 1313, 1311, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3695, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1307, 1308, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5895, 5896, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1307, 1308, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5689, 5690, 0 },
   { 5693, 5690, 0 },
   { 5696, 5690, 0 },
   { 5699, 5690, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1307, 1308, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5676, 5677, 0 },
   { 5680, 5677, 0 },
   { 5683, 5677, 0 },
   { 5686, 5677, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1307, 1308, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5661, 5663, 0 },
   { 5666, 5663, 0 },
   { 5669, 5663, 0 },
   { 5672, 5663, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1307, 1308, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5715, 5716, 0 },
   { 5719, 5716, 0 },
   { 5722, 5716, 0 },
   { 5725, 5716, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1307, 1308, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5728, 5729, 0 },
   { 5732, 5729, 0 },
   { 5735, 5729, 0 },
   { 5738, 5729, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1307, 1308, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5871, 5872, 0 },
   { 5871, 5872, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1307, 1308, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5640, 5641, 0 },
   { 5644, 5641, 0 },
   { 5646, 5648, 0 },
   { 5650, 5648, 0 },
   { 5653, 5655, 0 },
   { 5657, 5655, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1307, 1308, 0 },
   { 1310, 1311, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3692, 3693, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1307, 1308, 0 },
   { 1310, 1311, 0 },
   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3692, 3693, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1307, 1308, 0 },
   { 1310, 1311, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3692, 3693, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1307, 1308, 0 },
   { 1310, 1311, 0 },
   { 1313, 1311, 0 },
   { 1316, 1318, 0 },
   { 1321, 1318, 0 },
   { 1325, 1327, 0 },
   { 1330, 1327, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3692, 3693, 0 },
   { 3695, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1307, 1308, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5863, 5864, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1307, 1308, 0 },
   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1307, 1308, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 1779, 1781, 0 },
   { 1887, 1889, 0 },
   { 1972, 1974, 0 },
   { 3093, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1307, 1308, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5754, 5755, 0 },
   { 5758, 5755, 0 },
   { 5761, 5755, 0 },
   { 5764, 5755, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1307, 1308, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5767, 5768, 0 },
   { 5771, 5768, 0 },
   { 5774, 5768, 0 },
   { 5777, 5768, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1307, 1308, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5780, 5781, 0 },
   { 5784, 5781, 0 },
   { 5787, 5781, 0 },
   { 5790, 5781, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1307, 1308, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5793, 5794, 0 },
   { 5797, 5794, 0 },
   { 5800, 5794, 0 },
   { 5803, 5794, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1307, 1308, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5806, 5807, 0 },
   { 5810, 5807, 0 },
   { 5813, 5807, 0 },
   { 5816, 5807, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1307, 1308, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5819, 5820, 0 },
   { 5823, 5820, 0 },
   { 5826, 5820, 0 },
   { 5829, 5820, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1307, 1308, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5103, 5098, 0 },
   { 5156, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1307, 1308, 0 },
   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5103, 5098, 0 },
   { 5156, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1307, 1308, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5103, 5098, 0 },
   { 5156, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1307, 1308, 0 },
   { 1313, 1311, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3695, 3697, 0 },
   { 5103, 5098, 0 },
   { 5156, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1307, 1308, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5128, 5098, 0 },
   { 5181, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1307, 1308, 0 },
   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5128, 5098, 0 },
   { 5181, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1307, 1308, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5128, 5098, 0 },
   { 5181, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1307, 1308, 0 },
   { 1313, 1311, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3695, 3697, 0 },
   { 5128, 5098, 0 },
   { 5181, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1307, 1308, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5233, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1307, 1308, 0 },
   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5233, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1307, 1308, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5233, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1307, 1308, 0 },
   { 1313, 1311, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3695, 3697, 0 },
   { 5233, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1307, 1308, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5208, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1307, 1308, 0 },
   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5208, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1307, 1308, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5208, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1307, 1308, 0 },
   { 1313, 1311, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3695, 3697, 0 },
   { 5208, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1307, 1308, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5741, 5742, 0 },
   { 5745, 5742, 0 },
   { 5748, 5742, 0 },
   { 5751, 5742, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1307, 1308, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5867, 5868, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1307, 1308, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5832, 5833, 0 },
   { 5836, 5833, 0 },
   { 5840, 5842, 0 },
   { 5845, 5842, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1307, 1308, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5859, 5860, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1307, 1308, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5850, 5852, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1307, 1308, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5855, 5856, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1307, 1308, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5875, 5876, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1307, 1308, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5879, 5880, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1307, 1308, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5883, 5884, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1307, 1308, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5887, 5888, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1278, 1279, 0 },
   { 1280, 1281, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1278, 1279, 0 },
   { 1280, 1281, 0 },
   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1278, 1279, 0 },
   { 1280, 1281, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1278, 1279, 0 },
   { 1280, 1281, 0 },
   { 1313, 1311, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3695, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1278, 1279, 0 },
   { 1280, 1281, 0 },
   { 1331, 1138, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1278, 1279, 0 },
   { 1280, 1281, 0 },
   { 1331, 1138, 0 },
   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3060, 760, 0 },
   { 3061, 1131, 0 },
   { 3064, 3065, 0 },
   { 3066, 3067, 0 },
   { 3070, 3071, 0 },
   { 3072, 3073, 0 },
   { 3074, 3075, 0 },
   { 3076, 3077, 0 },
   { 3079, 3080, 0 },
   { 3081, 3082, 0 },
   { 3083, 3084, 57 },
   { 3085, 3086, 57 },
   { 3089, 3090, 57 },
   { 3091, 3092, 57 },
   { 3093, 3, 0 },
   { 3095, 2264, 0 },
   { 3096, 3098, 0 },
   { 3100, 1228, 0 },
   { 3101, 3097, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1278, 1279, 0 },
   { 1280, 1281, 0 },
   { 1331, 1138, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1278, 1279, 0 },
   { 1280, 1281, 0 },
   { 1313, 1311, 0 },
   { 1331, 1138, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3695, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1278, 1279, 0 },
   { 1280, 1281, 0 },
   { 1331, 1138, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1278, 1279, 0 },
   { 1280, 1281, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5702, 5703, 0 },
   { 5706, 5703, 0 },
   { 5709, 5703, 0 },
   { 5712, 5703, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1278, 1279, 0 },
   { 1280, 1281, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1278, 1279, 0 },
   { 1280, 1281, 0 },
   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1278, 1279, 0 },
   { 1280, 1281, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5891, 5892, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1278, 1279, 0 },
   { 1280, 1281, 0 },
   { 1313, 1311, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3695, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1278, 1279, 0 },
   { 1280, 1281, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5895, 5896, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1278, 1279, 0 },
   { 1280, 1281, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5689, 5690, 0 },
   { 5693, 5690, 0 },
   { 5696, 5690, 0 },
   { 5699, 5690, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1278, 1279, 0 },
   { 1280, 1281, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5676, 5677, 0 },
   { 5680, 5677, 0 },
   { 5683, 5677, 0 },
   { 5686, 5677, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1278, 1279, 0 },
   { 1280, 1281, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5661, 5663, 0 },
   { 5666, 5663, 0 },
   { 5669, 5663, 0 },
   { 5672, 5663, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1278, 1279, 0 },
   { 1280, 1281, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5715, 5716, 0 },
   { 5719, 5716, 0 },
   { 5722, 5716, 0 },
   { 5725, 5716, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1278, 1279, 0 },
   { 1280, 1281, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5728, 5729, 0 },
   { 5732, 5729, 0 },
   { 5735, 5729, 0 },
   { 5738, 5729, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1278, 1279, 0 },
   { 1280, 1281, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5871, 5872, 0 },
   { 5871, 5872, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1278, 1279, 0 },
   { 1280, 1281, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5640, 5641, 0 },
   { 5644, 5641, 0 },
   { 5646, 5648, 0 },
   { 5650, 5648, 0 },
   { 5653, 5655, 0 },
   { 5657, 5655, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1278, 1279, 0 },
   { 1280, 1281, 0 },
   { 1310, 1311, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3692, 3693, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1278, 1279, 0 },
   { 1280, 1281, 0 },
   { 1310, 1311, 0 },
   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3692, 3693, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1278, 1279, 0 },
   { 1280, 1281, 0 },
   { 1310, 1311, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3692, 3693, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1278, 1279, 0 },
   { 1280, 1281, 0 },
   { 1310, 1311, 0 },
   { 1313, 1311, 0 },
   { 1316, 1318, 0 },
   { 1321, 1318, 0 },
   { 1325, 1327, 0 },
   { 1330, 1327, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3692, 3693, 0 },
   { 3695, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1278, 1279, 0 },
   { 1280, 1281, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5863, 5864, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1278, 1279, 0 },
   { 1280, 1281, 0 },
   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1278, 1279, 0 },
   { 1280, 1281, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 1779, 1781, 0 },
   { 1887, 1889, 0 },
   { 1972, 1974, 0 },
   { 3093, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1278, 1279, 0 },
   { 1280, 1281, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5754, 5755, 0 },
   { 5758, 5755, 0 },
   { 5761, 5755, 0 },
   { 5764, 5755, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1278, 1279, 0 },
   { 1280, 1281, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5767, 5768, 0 },
   { 5771, 5768, 0 },
   { 5774, 5768, 0 },
   { 5777, 5768, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1278, 1279, 0 },
   { 1280, 1281, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5780, 5781, 0 },
   { 5784, 5781, 0 },
   { 5787, 5781, 0 },
   { 5790, 5781, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1278, 1279, 0 },
   { 1280, 1281, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5793, 5794, 0 },
   { 5797, 5794, 0 },
   { 5800, 5794, 0 },
   { 5803, 5794, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1278, 1279, 0 },
   { 1280, 1281, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5806, 5807, 0 },
   { 5810, 5807, 0 },
   { 5813, 5807, 0 },
   { 5816, 5807, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1278, 1279, 0 },
   { 1280, 1281, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5819, 5820, 0 },
   { 5823, 5820, 0 },
   { 5826, 5820, 0 },
   { 5829, 5820, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1278, 1279, 0 },
   { 1280, 1281, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5103, 5098, 0 },
   { 5156, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1278, 1279, 0 },
   { 1280, 1281, 0 },
   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5103, 5098, 0 },
   { 5156, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1278, 1279, 0 },
   { 1280, 1281, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5103, 5098, 0 },
   { 5156, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1278, 1279, 0 },
   { 1280, 1281, 0 },
   { 1313, 1311, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3695, 3697, 0 },
   { 5103, 5098, 0 },
   { 5156, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1278, 1279, 0 },
   { 1280, 1281, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5128, 5098, 0 },
   { 5181, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1278, 1279, 0 },
   { 1280, 1281, 0 },
   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5128, 5098, 0 },
   { 5181, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1278, 1279, 0 },
   { 1280, 1281, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5128, 5098, 0 },
   { 5181, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1278, 1279, 0 },
   { 1280, 1281, 0 },
   { 1313, 1311, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3695, 3697, 0 },
   { 5128, 5098, 0 },
   { 5181, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1278, 1279, 0 },
   { 1280, 1281, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5233, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1278, 1279, 0 },
   { 1280, 1281, 0 },
   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5233, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1278, 1279, 0 },
   { 1280, 1281, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5233, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1278, 1279, 0 },
   { 1280, 1281, 0 },
   { 1313, 1311, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3695, 3697, 0 },
   { 5233, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1278, 1279, 0 },
   { 1280, 1281, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5208, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1278, 1279, 0 },
   { 1280, 1281, 0 },
   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5208, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1278, 1279, 0 },
   { 1280, 1281, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5208, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1278, 1279, 0 },
   { 1280, 1281, 0 },
   { 1313, 1311, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3695, 3697, 0 },
   { 5208, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1278, 1279, 0 },
   { 1280, 1281, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5741, 5742, 0 },
   { 5745, 5742, 0 },
   { 5748, 5742, 0 },
   { 5751, 5742, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1278, 1279, 0 },
   { 1280, 1281, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5867, 5868, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1278, 1279, 0 },
   { 1280, 1281, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5832, 5833, 0 },
   { 5836, 5833, 0 },
   { 5840, 5842, 0 },
   { 5845, 5842, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1278, 1279, 0 },
   { 1280, 1281, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5859, 5860, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1278, 1279, 0 },
   { 1280, 1281, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5850, 5852, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1278, 1279, 0 },
   { 1280, 1281, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5855, 5856, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1278, 1279, 0 },
   { 1280, 1281, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5875, 5876, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1278, 1279, 0 },
   { 1280, 1281, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5879, 5880, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1278, 1279, 0 },
   { 1280, 1281, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5883, 5884, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1278, 1279, 0 },
   { 1280, 1281, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5887, 5888, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1278, 1279, 0 },
   { 1280, 1281, 0 },
   { 1331, 1138, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 2889, 2891, 0 },
   { 3093, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1278, 1279, 0 },
   { 1280, 1281, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3691, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1278, 1279, 0 },
   { 1280, 1281, 0 },
   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3691, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1278, 1279, 0 },
   { 1280, 1281, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3691, 103, 0 },
   { 5891, 5892, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1278, 1279, 0 },
   { 1280, 1281, 0 },
   { 1313, 1311, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3691, 103, 0 },
   { 3695, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1285, 1286, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1285, 1286, 0 },
   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1285, 1286, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1285, 1286, 0 },
   { 1313, 1311, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3695, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1285, 1286, 0 },
   { 1331, 1138, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1285, 1286, 0 },
   { 1331, 1138, 0 },
   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3060, 760, 0 },
   { 3061, 1131, 0 },
   { 3064, 3065, 0 },
   { 3066, 3067, 0 },
   { 3070, 3071, 0 },
   { 3072, 3073, 0 },
   { 3074, 3075, 0 },
   { 3076, 3077, 0 },
   { 3079, 3080, 0 },
   { 3081, 3082, 0 },
   { 3083, 3084, 57 },
   { 3085, 3086, 57 },
   { 3089, 3090, 57 },
   { 3091, 3092, 57 },
   { 3093, 3, 0 },
   { 3095, 2264, 0 },
   { 3096, 3098, 0 },
   { 3100, 1228, 0 },
   { 3101, 3097, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1285, 1286, 0 },
   { 1331, 1138, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1285, 1286, 0 },
   { 1313, 1311, 0 },
   { 1331, 1138, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3695, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1285, 1286, 0 },
   { 1331, 1138, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1285, 1286, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5702, 5703, 0 },
   { 5706, 5703, 0 },
   { 5709, 5703, 0 },
   { 5712, 5703, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1285, 1286, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1285, 1286, 0 },
   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1285, 1286, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5891, 5892, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1285, 1286, 0 },
   { 1313, 1311, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3695, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1285, 1286, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5895, 5896, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1285, 1286, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5689, 5690, 0 },
   { 5693, 5690, 0 },
   { 5696, 5690, 0 },
   { 5699, 5690, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1285, 1286, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5676, 5677, 0 },
   { 5680, 5677, 0 },
   { 5683, 5677, 0 },
   { 5686, 5677, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1285, 1286, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5661, 5663, 0 },
   { 5666, 5663, 0 },
   { 5669, 5663, 0 },
   { 5672, 5663, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1285, 1286, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5715, 5716, 0 },
   { 5719, 5716, 0 },
   { 5722, 5716, 0 },
   { 5725, 5716, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1285, 1286, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5728, 5729, 0 },
   { 5732, 5729, 0 },
   { 5735, 5729, 0 },
   { 5738, 5729, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1285, 1286, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5871, 5872, 0 },
   { 5871, 5872, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1285, 1286, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5640, 5641, 0 },
   { 5644, 5641, 0 },
   { 5646, 5648, 0 },
   { 5650, 5648, 0 },
   { 5653, 5655, 0 },
   { 5657, 5655, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1285, 1286, 0 },
   { 1310, 1311, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3692, 3693, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1285, 1286, 0 },
   { 1310, 1311, 0 },
   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3692, 3693, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1285, 1286, 0 },
   { 1310, 1311, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3692, 3693, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1285, 1286, 0 },
   { 1310, 1311, 0 },
   { 1313, 1311, 0 },
   { 1316, 1318, 0 },
   { 1321, 1318, 0 },
   { 1325, 1327, 0 },
   { 1330, 1327, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3692, 3693, 0 },
   { 3695, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1285, 1286, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5863, 5864, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1285, 1286, 0 },
   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1285, 1286, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 1779, 1781, 0 },
   { 1887, 1889, 0 },
   { 1972, 1974, 0 },
   { 3093, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1285, 1286, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5754, 5755, 0 },
   { 5758, 5755, 0 },
   { 5761, 5755, 0 },
   { 5764, 5755, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1285, 1286, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5767, 5768, 0 },
   { 5771, 5768, 0 },
   { 5774, 5768, 0 },
   { 5777, 5768, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1285, 1286, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5780, 5781, 0 },
   { 5784, 5781, 0 },
   { 5787, 5781, 0 },
   { 5790, 5781, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1285, 1286, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5793, 5794, 0 },
   { 5797, 5794, 0 },
   { 5800, 5794, 0 },
   { 5803, 5794, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1285, 1286, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5806, 5807, 0 },
   { 5810, 5807, 0 },
   { 5813, 5807, 0 },
   { 5816, 5807, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1285, 1286, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5819, 5820, 0 },
   { 5823, 5820, 0 },
   { 5826, 5820, 0 },
   { 5829, 5820, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1285, 1286, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5103, 5098, 0 },
   { 5156, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1285, 1286, 0 },
   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5103, 5098, 0 },
   { 5156, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1285, 1286, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5103, 5098, 0 },
   { 5156, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1285, 1286, 0 },
   { 1313, 1311, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3695, 3697, 0 },
   { 5103, 5098, 0 },
   { 5156, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1285, 1286, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5128, 5098, 0 },
   { 5181, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1285, 1286, 0 },
   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5128, 5098, 0 },
   { 5181, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1285, 1286, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5128, 5098, 0 },
   { 5181, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1285, 1286, 0 },
   { 1313, 1311, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3695, 3697, 0 },
   { 5128, 5098, 0 },
   { 5181, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1285, 1286, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5233, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1285, 1286, 0 },
   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5233, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1285, 1286, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5233, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1285, 1286, 0 },
   { 1313, 1311, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3695, 3697, 0 },
   { 5233, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1285, 1286, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5208, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1285, 1286, 0 },
   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5208, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1285, 1286, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5208, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1285, 1286, 0 },
   { 1313, 1311, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3695, 3697, 0 },
   { 5208, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1285, 1286, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5741, 5742, 0 },
   { 5745, 5742, 0 },
   { 5748, 5742, 0 },
   { 5751, 5742, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1285, 1286, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5867, 5868, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1285, 1286, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5832, 5833, 0 },
   { 5836, 5833, 0 },
   { 5840, 5842, 0 },
   { 5845, 5842, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1285, 1286, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5859, 5860, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1285, 1286, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5850, 5852, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1285, 1286, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5855, 5856, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1285, 1286, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5875, 5876, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1285, 1286, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5879, 5880, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1285, 1286, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5883, 5884, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1285, 1286, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5887, 5888, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1298, 1299, 0 },
   { 1300, 1301, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1298, 1299, 0 },
   { 1300, 1301, 0 },
   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1298, 1299, 0 },
   { 1300, 1301, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1298, 1299, 0 },
   { 1300, 1301, 0 },
   { 1313, 1311, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3695, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1298, 1299, 0 },
   { 1300, 1301, 0 },
   { 1331, 1138, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1298, 1299, 0 },
   { 1300, 1301, 0 },
   { 1331, 1138, 0 },
   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3060, 760, 0 },
   { 3061, 1131, 0 },
   { 3064, 3065, 0 },
   { 3066, 3067, 0 },
   { 3070, 3071, 0 },
   { 3072, 3073, 0 },
   { 3074, 3075, 0 },
   { 3076, 3077, 0 },
   { 3079, 3080, 0 },
   { 3081, 3082, 0 },
   { 3083, 3084, 57 },
   { 3085, 3086, 57 },
   { 3089, 3090, 57 },
   { 3091, 3092, 57 },
   { 3093, 3, 0 },
   { 3095, 2264, 0 },
   { 3096, 3098, 0 },
   { 3100, 1228, 0 },
   { 3101, 3097, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1298, 1299, 0 },
   { 1300, 1301, 0 },
   { 1331, 1138, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1298, 1299, 0 },
   { 1300, 1301, 0 },
   { 1313, 1311, 0 },
   { 1331, 1138, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3695, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1298, 1299, 0 },
   { 1300, 1301, 0 },
   { 1331, 1138, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1298, 1299, 0 },
   { 1300, 1301, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5702, 5703, 0 },
   { 5706, 5703, 0 },
   { 5709, 5703, 0 },
   { 5712, 5703, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1298, 1299, 0 },
   { 1300, 1301, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1298, 1299, 0 },
   { 1300, 1301, 0 },
   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1298, 1299, 0 },
   { 1300, 1301, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5891, 5892, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1298, 1299, 0 },
   { 1300, 1301, 0 },
   { 1313, 1311, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3695, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1298, 1299, 0 },
   { 1300, 1301, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5895, 5896, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1298, 1299, 0 },
   { 1300, 1301, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5689, 5690, 0 },
   { 5693, 5690, 0 },
   { 5696, 5690, 0 },
   { 5699, 5690, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1298, 1299, 0 },
   { 1300, 1301, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5676, 5677, 0 },
   { 5680, 5677, 0 },
   { 5683, 5677, 0 },
   { 5686, 5677, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1298, 1299, 0 },
   { 1300, 1301, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5661, 5663, 0 },
   { 5666, 5663, 0 },
   { 5669, 5663, 0 },
   { 5672, 5663, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1298, 1299, 0 },
   { 1300, 1301, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5715, 5716, 0 },
   { 5719, 5716, 0 },
   { 5722, 5716, 0 },
   { 5725, 5716, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1298, 1299, 0 },
   { 1300, 1301, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5728, 5729, 0 },
   { 5732, 5729, 0 },
   { 5735, 5729, 0 },
   { 5738, 5729, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1298, 1299, 0 },
   { 1300, 1301, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5871, 5872, 0 },
   { 5871, 5872, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1298, 1299, 0 },
   { 1300, 1301, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5640, 5641, 0 },
   { 5644, 5641, 0 },
   { 5646, 5648, 0 },
   { 5650, 5648, 0 },
   { 5653, 5655, 0 },
   { 5657, 5655, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1298, 1299, 0 },
   { 1300, 1301, 0 },
   { 1310, 1311, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3692, 3693, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1298, 1299, 0 },
   { 1300, 1301, 0 },
   { 1310, 1311, 0 },
   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3692, 3693, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1298, 1299, 0 },
   { 1300, 1301, 0 },
   { 1310, 1311, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3692, 3693, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1298, 1299, 0 },
   { 1300, 1301, 0 },
   { 1310, 1311, 0 },
   { 1313, 1311, 0 },
   { 1316, 1318, 0 },
   { 1321, 1318, 0 },
   { 1325, 1327, 0 },
   { 1330, 1327, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3692, 3693, 0 },
   { 3695, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1298, 1299, 0 },
   { 1300, 1301, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5863, 5864, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1298, 1299, 0 },
   { 1300, 1301, 0 },
   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1298, 1299, 0 },
   { 1300, 1301, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 1779, 1781, 0 },
   { 1887, 1889, 0 },
   { 1972, 1974, 0 },
   { 3093, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1298, 1299, 0 },
   { 1300, 1301, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5754, 5755, 0 },
   { 5758, 5755, 0 },
   { 5761, 5755, 0 },
   { 5764, 5755, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1298, 1299, 0 },
   { 1300, 1301, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5767, 5768, 0 },
   { 5771, 5768, 0 },
   { 5774, 5768, 0 },
   { 5777, 5768, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1298, 1299, 0 },
   { 1300, 1301, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5780, 5781, 0 },
   { 5784, 5781, 0 },
   { 5787, 5781, 0 },
   { 5790, 5781, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1298, 1299, 0 },
   { 1300, 1301, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5793, 5794, 0 },
   { 5797, 5794, 0 },
   { 5800, 5794, 0 },
   { 5803, 5794, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1298, 1299, 0 },
   { 1300, 1301, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5806, 5807, 0 },
   { 5810, 5807, 0 },
   { 5813, 5807, 0 },
   { 5816, 5807, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1298, 1299, 0 },
   { 1300, 1301, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5819, 5820, 0 },
   { 5823, 5820, 0 },
   { 5826, 5820, 0 },
   { 5829, 5820, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1298, 1299, 0 },
   { 1300, 1301, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5103, 5098, 0 },
   { 5156, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1298, 1299, 0 },
   { 1300, 1301, 0 },
   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5103, 5098, 0 },
   { 5156, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1298, 1299, 0 },
   { 1300, 1301, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5103, 5098, 0 },
   { 5156, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1298, 1299, 0 },
   { 1300, 1301, 0 },
   { 1313, 1311, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3695, 3697, 0 },
   { 5103, 5098, 0 },
   { 5156, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1298, 1299, 0 },
   { 1300, 1301, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5128, 5098, 0 },
   { 5181, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1298, 1299, 0 },
   { 1300, 1301, 0 },
   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5128, 5098, 0 },
   { 5181, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1298, 1299, 0 },
   { 1300, 1301, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5128, 5098, 0 },
   { 5181, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1298, 1299, 0 },
   { 1300, 1301, 0 },
   { 1313, 1311, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3695, 3697, 0 },
   { 5128, 5098, 0 },
   { 5181, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1298, 1299, 0 },
   { 1300, 1301, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5233, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1298, 1299, 0 },
   { 1300, 1301, 0 },
   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5233, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1298, 1299, 0 },
   { 1300, 1301, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5233, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1298, 1299, 0 },
   { 1300, 1301, 0 },
   { 1313, 1311, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3695, 3697, 0 },
   { 5233, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1298, 1299, 0 },
   { 1300, 1301, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5208, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1298, 1299, 0 },
   { 1300, 1301, 0 },
   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5208, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1298, 1299, 0 },
   { 1300, 1301, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5208, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1298, 1299, 0 },
   { 1300, 1301, 0 },
   { 1313, 1311, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3695, 3697, 0 },
   { 5208, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1298, 1299, 0 },
   { 1300, 1301, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5741, 5742, 0 },
   { 5745, 5742, 0 },
   { 5748, 5742, 0 },
   { 5751, 5742, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1298, 1299, 0 },
   { 1300, 1301, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5867, 5868, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1298, 1299, 0 },
   { 1300, 1301, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5832, 5833, 0 },
   { 5836, 5833, 0 },
   { 5840, 5842, 0 },
   { 5845, 5842, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1298, 1299, 0 },
   { 1300, 1301, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5859, 5860, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1298, 1299, 0 },
   { 1300, 1301, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5850, 5852, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1298, 1299, 0 },
   { 1300, 1301, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5855, 5856, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1298, 1299, 0 },
   { 1300, 1301, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5875, 5876, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1298, 1299, 0 },
   { 1300, 1301, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5879, 5880, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1298, 1299, 0 },
   { 1300, 1301, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5883, 5884, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1298, 1299, 0 },
   { 1300, 1301, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5887, 5888, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1288, 1289, 0 },
   { 1290, 1291, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1288, 1289, 0 },
   { 1290, 1291, 0 },
   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1288, 1289, 0 },
   { 1290, 1291, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1288, 1289, 0 },
   { 1290, 1291, 0 },
   { 1313, 1311, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3695, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1288, 1289, 0 },
   { 1290, 1291, 0 },
   { 1331, 1138, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1288, 1289, 0 },
   { 1290, 1291, 0 },
   { 1331, 1138, 0 },
   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3060, 760, 0 },
   { 3061, 1131, 0 },
   { 3064, 3065, 0 },
   { 3066, 3067, 0 },
   { 3070, 3071, 0 },
   { 3072, 3073, 0 },
   { 3074, 3075, 0 },
   { 3076, 3077, 0 },
   { 3079, 3080, 0 },
   { 3081, 3082, 0 },
   { 3083, 3084, 57 },
   { 3085, 3086, 57 },
   { 3089, 3090, 57 },
   { 3091, 3092, 57 },
   { 3093, 3, 0 },
   { 3095, 2264, 0 },
   { 3096, 3098, 0 },
   { 3100, 1228, 0 },
   { 3101, 3097, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1288, 1289, 0 },
   { 1290, 1291, 0 },
   { 1331, 1138, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1288, 1289, 0 },
   { 1290, 1291, 0 },
   { 1313, 1311, 0 },
   { 1331, 1138, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3695, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1288, 1289, 0 },
   { 1290, 1291, 0 },
   { 1331, 1138, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1288, 1289, 0 },
   { 1290, 1291, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5702, 5703, 0 },
   { 5706, 5703, 0 },
   { 5709, 5703, 0 },
   { 5712, 5703, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1288, 1289, 0 },
   { 1290, 1291, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1288, 1289, 0 },
   { 1290, 1291, 0 },
   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1288, 1289, 0 },
   { 1290, 1291, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5891, 5892, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1288, 1289, 0 },
   { 1290, 1291, 0 },
   { 1313, 1311, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3695, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1288, 1289, 0 },
   { 1290, 1291, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5895, 5896, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1288, 1289, 0 },
   { 1290, 1291, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5689, 5690, 0 },
   { 5693, 5690, 0 },
   { 5696, 5690, 0 },
   { 5699, 5690, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1288, 1289, 0 },
   { 1290, 1291, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5676, 5677, 0 },
   { 5680, 5677, 0 },
   { 5683, 5677, 0 },
   { 5686, 5677, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1288, 1289, 0 },
   { 1290, 1291, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5661, 5663, 0 },
   { 5666, 5663, 0 },
   { 5669, 5663, 0 },
   { 5672, 5663, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1288, 1289, 0 },
   { 1290, 1291, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5715, 5716, 0 },
   { 5719, 5716, 0 },
   { 5722, 5716, 0 },
   { 5725, 5716, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1288, 1289, 0 },
   { 1290, 1291, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5728, 5729, 0 },
   { 5732, 5729, 0 },
   { 5735, 5729, 0 },
   { 5738, 5729, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1288, 1289, 0 },
   { 1290, 1291, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5871, 5872, 0 },
   { 5871, 5872, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1288, 1289, 0 },
   { 1290, 1291, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5640, 5641, 0 },
   { 5644, 5641, 0 },
   { 5646, 5648, 0 },
   { 5650, 5648, 0 },
   { 5653, 5655, 0 },
   { 5657, 5655, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1288, 1289, 0 },
   { 1290, 1291, 0 },
   { 1310, 1311, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3692, 3693, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1288, 1289, 0 },
   { 1290, 1291, 0 },
   { 1310, 1311, 0 },
   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3692, 3693, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1288, 1289, 0 },
   { 1290, 1291, 0 },
   { 1310, 1311, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3692, 3693, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1288, 1289, 0 },
   { 1290, 1291, 0 },
   { 1310, 1311, 0 },
   { 1313, 1311, 0 },
   { 1316, 1318, 0 },
   { 1321, 1318, 0 },
   { 1325, 1327, 0 },
   { 1330, 1327, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3692, 3693, 0 },
   { 3695, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1288, 1289, 0 },
   { 1290, 1291, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5863, 5864, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1288, 1289, 0 },
   { 1290, 1291, 0 },
   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1288, 1289, 0 },
   { 1290, 1291, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 1779, 1781, 0 },
   { 1887, 1889, 0 },
   { 1972, 1974, 0 },
   { 3093, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1288, 1289, 0 },
   { 1290, 1291, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5754, 5755, 0 },
   { 5758, 5755, 0 },
   { 5761, 5755, 0 },
   { 5764, 5755, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1288, 1289, 0 },
   { 1290, 1291, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5767, 5768, 0 },
   { 5771, 5768, 0 },
   { 5774, 5768, 0 },
   { 5777, 5768, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1288, 1289, 0 },
   { 1290, 1291, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5780, 5781, 0 },
   { 5784, 5781, 0 },
   { 5787, 5781, 0 },
   { 5790, 5781, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1288, 1289, 0 },
   { 1290, 1291, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5793, 5794, 0 },
   { 5797, 5794, 0 },
   { 5800, 5794, 0 },
   { 5803, 5794, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1288, 1289, 0 },
   { 1290, 1291, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5806, 5807, 0 },
   { 5810, 5807, 0 },
   { 5813, 5807, 0 },
   { 5816, 5807, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1288, 1289, 0 },
   { 1290, 1291, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5819, 5820, 0 },
   { 5823, 5820, 0 },
   { 5826, 5820, 0 },
   { 5829, 5820, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1288, 1289, 0 },
   { 1290, 1291, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5103, 5098, 0 },
   { 5156, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1288, 1289, 0 },
   { 1290, 1291, 0 },
   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5103, 5098, 0 },
   { 5156, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1288, 1289, 0 },
   { 1290, 1291, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5103, 5098, 0 },
   { 5156, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1288, 1289, 0 },
   { 1290, 1291, 0 },
   { 1313, 1311, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3695, 3697, 0 },
   { 5103, 5098, 0 },
   { 5156, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1288, 1289, 0 },
   { 1290, 1291, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5128, 5098, 0 },
   { 5181, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1288, 1289, 0 },
   { 1290, 1291, 0 },
   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5128, 5098, 0 },
   { 5181, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1288, 1289, 0 },
   { 1290, 1291, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5128, 5098, 0 },
   { 5181, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1288, 1289, 0 },
   { 1290, 1291, 0 },
   { 1313, 1311, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3695, 3697, 0 },
   { 5128, 5098, 0 },
   { 5181, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1288, 1289, 0 },
   { 1290, 1291, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5233, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1288, 1289, 0 },
   { 1290, 1291, 0 },
   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5233, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1288, 1289, 0 },
   { 1290, 1291, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5233, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1288, 1289, 0 },
   { 1290, 1291, 0 },
   { 1313, 1311, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3695, 3697, 0 },
   { 5233, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1288, 1289, 0 },
   { 1290, 1291, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5208, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1288, 1289, 0 },
   { 1290, 1291, 0 },
   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5208, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1288, 1289, 0 },
   { 1290, 1291, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5208, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1288, 1289, 0 },
   { 1290, 1291, 0 },
   { 1313, 1311, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3695, 3697, 0 },
   { 5208, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1288, 1289, 0 },
   { 1290, 1291, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5741, 5742, 0 },
   { 5745, 5742, 0 },
   { 5748, 5742, 0 },
   { 5751, 5742, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1288, 1289, 0 },
   { 1290, 1291, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5867, 5868, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1288, 1289, 0 },
   { 1290, 1291, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5832, 5833, 0 },
   { 5836, 5833, 0 },
   { 5840, 5842, 0 },
   { 5845, 5842, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1288, 1289, 0 },
   { 1290, 1291, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5859, 5860, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1288, 1289, 0 },
   { 1290, 1291, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5850, 5852, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1288, 1289, 0 },
   { 1290, 1291, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5855, 5856, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1288, 1289, 0 },
   { 1290, 1291, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5875, 5876, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1288, 1289, 0 },
   { 1290, 1291, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5879, 5880, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1288, 1289, 0 },
   { 1290, 1291, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5883, 5884, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1288, 1289, 0 },
   { 1290, 1291, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5887, 5888, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1302, 1303, 0 },
   { 1305, 1306, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1302, 1303, 0 },
   { 1305, 1306, 0 },
   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1302, 1303, 0 },
   { 1305, 1306, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1302, 1303, 0 },
   { 1305, 1306, 0 },
   { 1313, 1311, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3695, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1302, 1303, 0 },
   { 1305, 1306, 0 },
   { 1331, 1138, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1302, 1303, 0 },
   { 1305, 1306, 0 },
   { 1331, 1138, 0 },
   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3060, 760, 0 },
   { 3061, 1131, 0 },
   { 3064, 3065, 0 },
   { 3066, 3067, 0 },
   { 3070, 3071, 0 },
   { 3072, 3073, 0 },
   { 3074, 3075, 0 },
   { 3076, 3077, 0 },
   { 3079, 3080, 0 },
   { 3081, 3082, 0 },
   { 3083, 3084, 57 },
   { 3085, 3086, 57 },
   { 3089, 3090, 57 },
   { 3091, 3092, 57 },
   { 3093, 3, 0 },
   { 3095, 2264, 0 },
   { 3096, 3098, 0 },
   { 3100, 1228, 0 },
   { 3101, 3097, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1302, 1303, 0 },
   { 1305, 1306, 0 },
   { 1331, 1138, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1302, 1303, 0 },
   { 1305, 1306, 0 },
   { 1313, 1311, 0 },
   { 1331, 1138, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3695, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1302, 1303, 0 },
   { 1305, 1306, 0 },
   { 1331, 1138, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1302, 1303, 0 },
   { 1305, 1306, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5702, 5703, 0 },
   { 5706, 5703, 0 },
   { 5709, 5703, 0 },
   { 5712, 5703, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1302, 1303, 0 },
   { 1305, 1306, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1302, 1303, 0 },
   { 1305, 1306, 0 },
   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1302, 1303, 0 },
   { 1305, 1306, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5891, 5892, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1302, 1303, 0 },
   { 1305, 1306, 0 },
   { 1313, 1311, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3695, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1302, 1303, 0 },
   { 1305, 1306, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5895, 5896, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1302, 1303, 0 },
   { 1305, 1306, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5689, 5690, 0 },
   { 5693, 5690, 0 },
   { 5696, 5690, 0 },
   { 5699, 5690, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1302, 1303, 0 },
   { 1305, 1306, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5676, 5677, 0 },
   { 5680, 5677, 0 },
   { 5683, 5677, 0 },
   { 5686, 5677, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1302, 1303, 0 },
   { 1305, 1306, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5661, 5663, 0 },
   { 5666, 5663, 0 },
   { 5669, 5663, 0 },
   { 5672, 5663, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1302, 1303, 0 },
   { 1305, 1306, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5715, 5716, 0 },
   { 5719, 5716, 0 },
   { 5722, 5716, 0 },
   { 5725, 5716, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1302, 1303, 0 },
   { 1305, 1306, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5728, 5729, 0 },
   { 5732, 5729, 0 },
   { 5735, 5729, 0 },
   { 5738, 5729, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1302, 1303, 0 },
   { 1305, 1306, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5871, 5872, 0 },
   { 5871, 5872, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1302, 1303, 0 },
   { 1305, 1306, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5640, 5641, 0 },
   { 5644, 5641, 0 },
   { 5646, 5648, 0 },
   { 5650, 5648, 0 },
   { 5653, 5655, 0 },
   { 5657, 5655, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1302, 1303, 0 },
   { 1305, 1306, 0 },
   { 1310, 1311, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3692, 3693, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1302, 1303, 0 },
   { 1305, 1306, 0 },
   { 1310, 1311, 0 },
   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3692, 3693, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1302, 1303, 0 },
   { 1305, 1306, 0 },
   { 1310, 1311, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3692, 3693, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1302, 1303, 0 },
   { 1305, 1306, 0 },
   { 1310, 1311, 0 },
   { 1313, 1311, 0 },
   { 1316, 1318, 0 },
   { 1321, 1318, 0 },
   { 1325, 1327, 0 },
   { 1330, 1327, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3692, 3693, 0 },
   { 3695, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1302, 1303, 0 },
   { 1305, 1306, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5863, 5864, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1302, 1303, 0 },
   { 1305, 1306, 0 },
   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1302, 1303, 0 },
   { 1305, 1306, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 1779, 1781, 0 },
   { 1887, 1889, 0 },
   { 1972, 1974, 0 },
   { 3093, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1302, 1303, 0 },
   { 1305, 1306, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5754, 5755, 0 },
   { 5758, 5755, 0 },
   { 5761, 5755, 0 },
   { 5764, 5755, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1302, 1303, 0 },
   { 1305, 1306, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5767, 5768, 0 },
   { 5771, 5768, 0 },
   { 5774, 5768, 0 },
   { 5777, 5768, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1302, 1303, 0 },
   { 1305, 1306, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5780, 5781, 0 },
   { 5784, 5781, 0 },
   { 5787, 5781, 0 },
   { 5790, 5781, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1302, 1303, 0 },
   { 1305, 1306, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5793, 5794, 0 },
   { 5797, 5794, 0 },
   { 5800, 5794, 0 },
   { 5803, 5794, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1302, 1303, 0 },
   { 1305, 1306, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5806, 5807, 0 },
   { 5810, 5807, 0 },
   { 5813, 5807, 0 },
   { 5816, 5807, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1302, 1303, 0 },
   { 1305, 1306, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5819, 5820, 0 },
   { 5823, 5820, 0 },
   { 5826, 5820, 0 },
   { 5829, 5820, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1302, 1303, 0 },
   { 1305, 1306, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5103, 5098, 0 },
   { 5156, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1302, 1303, 0 },
   { 1305, 1306, 0 },
   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5103, 5098, 0 },
   { 5156, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1302, 1303, 0 },
   { 1305, 1306, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5103, 5098, 0 },
   { 5156, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1302, 1303, 0 },
   { 1305, 1306, 0 },
   { 1313, 1311, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3695, 3697, 0 },
   { 5103, 5098, 0 },
   { 5156, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1302, 1303, 0 },
   { 1305, 1306, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5128, 5098, 0 },
   { 5181, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1302, 1303, 0 },
   { 1305, 1306, 0 },
   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5128, 5098, 0 },
   { 5181, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1302, 1303, 0 },
   { 1305, 1306, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5128, 5098, 0 },
   { 5181, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1302, 1303, 0 },
   { 1305, 1306, 0 },
   { 1313, 1311, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3695, 3697, 0 },
   { 5128, 5098, 0 },
   { 5181, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1302, 1303, 0 },
   { 1305, 1306, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5233, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1302, 1303, 0 },
   { 1305, 1306, 0 },
   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5233, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1302, 1303, 0 },
   { 1305, 1306, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5233, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1302, 1303, 0 },
   { 1305, 1306, 0 },
   { 1313, 1311, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3695, 3697, 0 },
   { 5233, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1302, 1303, 0 },
   { 1305, 1306, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5208, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1302, 1303, 0 },
   { 1305, 1306, 0 },
   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5208, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1302, 1303, 0 },
   { 1305, 1306, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5208, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1302, 1303, 0 },
   { 1305, 1306, 0 },
   { 1313, 1311, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3695, 3697, 0 },
   { 5208, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1302, 1303, 0 },
   { 1305, 1306, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5741, 5742, 0 },
   { 5745, 5742, 0 },
   { 5748, 5742, 0 },
   { 5751, 5742, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1302, 1303, 0 },
   { 1305, 1306, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5867, 5868, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1302, 1303, 0 },
   { 1305, 1306, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5832, 5833, 0 },
   { 5836, 5833, 0 },
   { 5840, 5842, 0 },
   { 5845, 5842, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1302, 1303, 0 },
   { 1305, 1306, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5859, 5860, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1302, 1303, 0 },
   { 1305, 1306, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5850, 5852, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1302, 1303, 0 },
   { 1305, 1306, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5855, 5856, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1302, 1303, 0 },
   { 1305, 1306, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5875, 5876, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1302, 1303, 0 },
   { 1305, 1306, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5879, 5880, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1302, 1303, 0 },
   { 1305, 1306, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5883, 5884, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1302, 1303, 0 },
   { 1305, 1306, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5887, 5888, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1292, 1293, 0 },
   { 1295, 1296, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1292, 1293, 0 },
   { 1295, 1296, 0 },
   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1292, 1293, 0 },
   { 1295, 1296, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1292, 1293, 0 },
   { 1295, 1296, 0 },
   { 1313, 1311, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3695, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1292, 1293, 0 },
   { 1295, 1296, 0 },
   { 1331, 1138, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1292, 1293, 0 },
   { 1295, 1296, 0 },
   { 1331, 1138, 0 },
   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3060, 760, 0 },
   { 3061, 1131, 0 },
   { 3064, 3065, 0 },
   { 3066, 3067, 0 },
   { 3070, 3071, 0 },
   { 3072, 3073, 0 },
   { 3074, 3075, 0 },
   { 3076, 3077, 0 },
   { 3079, 3080, 0 },
   { 3081, 3082, 0 },
   { 3083, 3084, 57 },
   { 3085, 3086, 57 },
   { 3089, 3090, 57 },
   { 3091, 3092, 57 },
   { 3093, 3, 0 },
   { 3095, 2264, 0 },
   { 3096, 3098, 0 },
   { 3100, 1228, 0 },
   { 3101, 3097, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1292, 1293, 0 },
   { 1295, 1296, 0 },
   { 1331, 1138, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1292, 1293, 0 },
   { 1295, 1296, 0 },
   { 1313, 1311, 0 },
   { 1331, 1138, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3695, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1292, 1293, 0 },
   { 1295, 1296, 0 },
   { 1331, 1138, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1292, 1293, 0 },
   { 1295, 1296, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5702, 5703, 0 },
   { 5706, 5703, 0 },
   { 5709, 5703, 0 },
   { 5712, 5703, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1292, 1293, 0 },
   { 1295, 1296, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1292, 1293, 0 },
   { 1295, 1296, 0 },
   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1292, 1293, 0 },
   { 1295, 1296, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5891, 5892, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1292, 1293, 0 },
   { 1295, 1296, 0 },
   { 1313, 1311, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3695, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1292, 1293, 0 },
   { 1295, 1296, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5895, 5896, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1292, 1293, 0 },
   { 1295, 1296, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5689, 5690, 0 },
   { 5693, 5690, 0 },
   { 5696, 5690, 0 },
   { 5699, 5690, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1292, 1293, 0 },
   { 1295, 1296, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5676, 5677, 0 },
   { 5680, 5677, 0 },
   { 5683, 5677, 0 },
   { 5686, 5677, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1292, 1293, 0 },
   { 1295, 1296, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5661, 5663, 0 },
   { 5666, 5663, 0 },
   { 5669, 5663, 0 },
   { 5672, 5663, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1292, 1293, 0 },
   { 1295, 1296, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5715, 5716, 0 },
   { 5719, 5716, 0 },
   { 5722, 5716, 0 },
   { 5725, 5716, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1292, 1293, 0 },
   { 1295, 1296, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5728, 5729, 0 },
   { 5732, 5729, 0 },
   { 5735, 5729, 0 },
   { 5738, 5729, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1292, 1293, 0 },
   { 1295, 1296, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5871, 5872, 0 },
   { 5871, 5872, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1292, 1293, 0 },
   { 1295, 1296, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5640, 5641, 0 },
   { 5644, 5641, 0 },
   { 5646, 5648, 0 },
   { 5650, 5648, 0 },
   { 5653, 5655, 0 },
   { 5657, 5655, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1292, 1293, 0 },
   { 1295, 1296, 0 },
   { 1310, 1311, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3692, 3693, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1292, 1293, 0 },
   { 1295, 1296, 0 },
   { 1310, 1311, 0 },
   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3692, 3693, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1292, 1293, 0 },
   { 1295, 1296, 0 },
   { 1310, 1311, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3692, 3693, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1292, 1293, 0 },
   { 1295, 1296, 0 },
   { 1310, 1311, 0 },
   { 1313, 1311, 0 },
   { 1316, 1318, 0 },
   { 1321, 1318, 0 },
   { 1325, 1327, 0 },
   { 1330, 1327, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3692, 3693, 0 },
   { 3695, 3697, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1292, 1293, 0 },
   { 1295, 1296, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5863, 5864, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1292, 1293, 0 },
   { 1295, 1296, 0 },
   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1292, 1293, 0 },
   { 1295, 1296, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 1779, 1781, 0 },
   { 1887, 1889, 0 },
   { 1972, 1974, 0 },
   { 3093, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1292, 1293, 0 },
   { 1295, 1296, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5754, 5755, 0 },
   { 5758, 5755, 0 },
   { 5761, 5755, 0 },
   { 5764, 5755, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1292, 1293, 0 },
   { 1295, 1296, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5767, 5768, 0 },
   { 5771, 5768, 0 },
   { 5774, 5768, 0 },
   { 5777, 5768, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1292, 1293, 0 },
   { 1295, 1296, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5780, 5781, 0 },
   { 5784, 5781, 0 },
   { 5787, 5781, 0 },
   { 5790, 5781, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1292, 1293, 0 },
   { 1295, 1296, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5793, 5794, 0 },
   { 5797, 5794, 0 },
   { 5800, 5794, 0 },
   { 5803, 5794, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1292, 1293, 0 },
   { 1295, 1296, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5806, 5807, 0 },
   { 5810, 5807, 0 },
   { 5813, 5807, 0 },
   { 5816, 5807, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1292, 1293, 0 },
   { 1295, 1296, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5819, 5820, 0 },
   { 5823, 5820, 0 },
   { 5826, 5820, 0 },
   { 5829, 5820, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1292, 1293, 0 },
   { 1295, 1296, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5103, 5098, 0 },
   { 5156, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1292, 1293, 0 },
   { 1295, 1296, 0 },
   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5103, 5098, 0 },
   { 5156, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1292, 1293, 0 },
   { 1295, 1296, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5103, 5098, 0 },
   { 5156, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1292, 1293, 0 },
   { 1295, 1296, 0 },
   { 1313, 1311, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3695, 3697, 0 },
   { 5103, 5098, 0 },
   { 5156, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1292, 1293, 0 },
   { 1295, 1296, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5128, 5098, 0 },
   { 5181, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1292, 1293, 0 },
   { 1295, 1296, 0 },
   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5128, 5098, 0 },
   { 5181, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1292, 1293, 0 },
   { 1295, 1296, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5128, 5098, 0 },
   { 5181, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1292, 1293, 0 },
   { 1295, 1296, 0 },
   { 1313, 1311, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3695, 3697, 0 },
   { 5128, 5098, 0 },
   { 5181, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1292, 1293, 0 },
   { 1295, 1296, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5233, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1292, 1293, 0 },
   { 1295, 1296, 0 },
   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5233, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1292, 1293, 0 },
   { 1295, 1296, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5233, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1292, 1293, 0 },
   { 1295, 1296, 0 },
   { 1313, 1311, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3695, 3697, 0 },
   { 5233, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1292, 1293, 0 },
   { 1295, 1296, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5208, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1292, 1293, 0 },
   { 1295, 1296, 0 },
   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5208, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1292, 1293, 0 },
   { 1295, 1296, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5208, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1292, 1293, 0 },
   { 1295, 1296, 0 },
   { 1313, 1311, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3695, 3697, 0 },
   { 5208, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1292, 1293, 0 },
   { 1295, 1296, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5741, 5742, 0 },
   { 5745, 5742, 0 },
   { 5748, 5742, 0 },
   { 5751, 5742, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1292, 1293, 0 },
   { 1295, 1296, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5867, 5868, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1292, 1293, 0 },
   { 1295, 1296, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5832, 5833, 0 },
   { 5836, 5833, 0 },
   { 5840, 5842, 0 },
   { 5845, 5842, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1292, 1293, 0 },
   { 1295, 1296, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5859, 5860, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1292, 1293, 0 },
   { 1295, 1296, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5850, 5852, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1292, 1293, 0 },
   { 1295, 1296, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5855, 5856, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1292, 1293, 0 },
   { 1295, 1296, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5875, 5876, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1292, 1293, 0 },
   { 1295, 1296, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5879, 5880, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1292, 1293, 0 },
   { 1295, 1296, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5883, 5884, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1292, 1293, 0 },
   { 1295, 1296, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5887, 5888, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2148, 2149, 0 },
   { 2179, 2180, 0 },
   { 2209, 946, 0 },
   { 2239, 2240, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2148, 2149, 0 },
   { 2179, 2180, 0 },
   { 2209, 946, 0 },
   { 2239, 2240, 0 },
   { 2780, 1229, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2780, 1229, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 823, 825, 0 },
   { 2781, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 827, 836, 0 },
   { 849, 857, 0 },
   { 870, 877, 0 },
   { 890, 898, 0 },
   { 2781, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 1020, 1022, 0 },
   { 2781, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 990, 991, 0 },
   { 997, 998, 0 },
   { 1004, 1005, 0 },
   { 1013, 1014, 0 },
   { 2781, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 910, 913, 0 },
   { 918, 921, 0 },
   { 926, 929, 0 },
   { 934, 937, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 910, 913, 0 },
   { 918, 921, 0 },
   { 926, 929, 0 },
   { 934, 937, 0 },
   { 2781, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 910, 913, 0 },
   { 918, 921, 0 },
   { 926, 929, 0 },
   { 934, 937, 0 },
   { 2148, 2149, 0 },
   { 2179, 2180, 0 },
   { 2209, 946, 0 },
   { 2239, 2240, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 910, 913, 0 },
   { 918, 921, 0 },
   { 926, 929, 0 },
   { 934, 937, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 914, 913, 0 },
   { 922, 921, 0 },
   { 930, 929, 0 },
   { 938, 937, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 914, 913, 0 },
   { 922, 921, 0 },
   { 930, 929, 0 },
   { 938, 937, 0 },
   { 2781, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 914, 913, 0 },
   { 922, 921, 0 },
   { 930, 929, 0 },
   { 938, 937, 0 },
   { 2148, 2149, 0 },
   { 2179, 2180, 0 },
   { 2209, 946, 0 },
   { 2239, 2240, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 914, 913, 0 },
   { 922, 921, 0 },
   { 930, 929, 0 },
   { 938, 937, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 2781, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 2781, 32, 0 },
   { 3358, 3359, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3869, 3870, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 2781, 32, 0 },
   { 3869, 3870, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2148, 2149, 0 },
   { 2179, 2180, 0 },
   { 2209, 946, 0 },
   { 2239, 2240, 0 },
   { 3869, 3870, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3869, 3870, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2716, 32, 0 },
   { 2734, 2735, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2716, 32, 0 },
   { 2733, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2716, 32, 0 },
   { 2720, 61, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2716, 32, 0 },
   { 5114, 2039, 0 },
   { 5167, 2047, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2716, 32, 0 },
   { 5139, 2039, 0 },
   { 5192, 2047, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2716, 32, 0 },
   { 5244, 2047, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2716, 32, 0 },
   { 5219, 2047, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 950, 951, 0 },
   { 2699, 2700, 0 },
   { 2702, 2703, 0 },
   { 2716, 32, 0 },
   { 2717, 61, 0 },
   { 2718, 32, 0 },
   { 2741, 2745, 0 },
   { 2747, 2751, 0 },
   { 2753, 2754, 0 },
   { 2756, 2757, 0 },
   { 3261, 3262, 58 },
   { 3292, 3293, 59 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 945, 946, 0 },
   { 992, 991, 0 },
   { 999, 998, 0 },
   { 1007, 1005, 0 },
   { 1016, 1014, 0 },
   { 2699, 2700, 0 },
   { 2702, 2703, 0 },
   { 2716, 32, 0 },
   { 2717, 61, 0 },
   { 2718, 32, 0 },
   { 2741, 2745, 0 },
   { 2747, 2751, 0 },
   { 2753, 2754, 0 },
   { 2756, 2757, 0 },
   { 3261, 3262, 58 },
   { 3292, 3293, 59 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 955, 957, 0 },
   { 961, 963, 0 },
   { 967, 969, 0 },
   { 973, 975, 0 },
   { 979, 981, 0 },
   { 985, 987, 0 },
   { 2699, 2700, 0 },
   { 2702, 2703, 0 },
   { 2716, 32, 0 },
   { 2717, 61, 0 },
   { 2718, 32, 0 },
   { 2741, 2745, 0 },
   { 2747, 2751, 0 },
   { 2753, 2754, 0 },
   { 2756, 2757, 0 },
   { 3261, 3262, 58 },
   { 3292, 3293, 59 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2699, 2700, 0 },
   { 2702, 2703, 0 },
   { 2716, 32, 0 },
   { 2717, 61, 0 },
   { 2718, 32, 0 },
   { 2734, 2735, 0 },
   { 2741, 2745, 0 },
   { 2747, 2751, 0 },
   { 2753, 2754, 0 },
   { 2756, 2757, 0 },
   { 3261, 3262, 58 },
   { 3292, 3293, 59 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2699, 2700, 0 },
   { 2702, 2703, 0 },
   { 2716, 32, 0 },
   { 2717, 61, 0 },
   { 2718, 32, 0 },
   { 2734, 2735, 0 },
   { 2741, 2745, 0 },
   { 2747, 2751, 0 },
   { 2753, 2754, 0 },
   { 2756, 2757, 0 },
   { 3261, 3262, 58 },
   { 3292, 3293, 59 },
   { 3583, 3585, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2699, 2700, 0 },
   { 2702, 2703, 0 },
   { 2716, 32, 0 },
   { 2717, 61, 0 },
   { 2718, 32, 0 },
   { 2733, 3, 0 },
   { 2741, 2745, 0 },
   { 2747, 2751, 0 },
   { 2753, 2754, 0 },
   { 2756, 2757, 0 },
   { 3261, 3262, 58 },
   { 3292, 3293, 59 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 994, 993, 0 },
   { 1001, 1000, 0 },
   { 1009, 1008, 0 },
   { 1018, 1017, 0 },
   { 2699, 2700, 0 },
   { 2702, 2703, 0 },
   { 2716, 32, 0 },
   { 2717, 61, 0 },
   { 2718, 32, 0 },
   { 2741, 2745, 0 },
   { 2747, 2751, 0 },
   { 2753, 2754, 0 },
   { 2756, 2757, 0 },
   { 3261, 3262, 58 },
   { 3292, 3293, 59 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2699, 2700, 0 },
   { 2702, 2703, 0 },
   { 2716, 32, 0 },
   { 2717, 61, 0 },
   { 2718, 32, 0 },
   { 2720, 61, 0 },
   { 2741, 2745, 0 },
   { 2747, 2751, 0 },
   { 2753, 2754, 0 },
   { 2756, 2757, 0 },
   { 3261, 3262, 58 },
   { 3292, 3293, 59 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2699, 2700, 0 },
   { 2702, 2703, 0 },
   { 2716, 32, 0 },
   { 2717, 61, 0 },
   { 2718, 32, 0 },
   { 2741, 2745, 0 },
   { 2747, 2751, 0 },
   { 2753, 2754, 0 },
   { 2756, 2757, 0 },
   { 3261, 3262, 58 },
   { 3292, 3293, 59 },
   { 5114, 2039, 0 },
   { 5167, 2047, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2699, 2700, 0 },
   { 2702, 2703, 0 },
   { 2716, 32, 0 },
   { 2717, 61, 0 },
   { 2718, 32, 0 },
   { 2741, 2745, 0 },
   { 2747, 2751, 0 },
   { 2753, 2754, 0 },
   { 2756, 2757, 0 },
   { 3261, 3262, 58 },
   { 3292, 3293, 59 },
   { 5139, 2039, 0 },
   { 5192, 2047, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2699, 2700, 0 },
   { 2702, 2703, 0 },
   { 2716, 32, 0 },
   { 2717, 61, 0 },
   { 2718, 32, 0 },
   { 2741, 2745, 0 },
   { 2747, 2751, 0 },
   { 2753, 2754, 0 },
   { 2756, 2757, 0 },
   { 3261, 3262, 58 },
   { 3292, 3293, 59 },
   { 5244, 2047, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2699, 2700, 0 },
   { 2702, 2703, 0 },
   { 2716, 32, 0 },
   { 2717, 61, 0 },
   { 2718, 32, 0 },
   { 2741, 2745, 0 },
   { 2747, 2751, 0 },
   { 2753, 2754, 0 },
   { 2756, 2757, 0 },
   { 3261, 3262, 58 },
   { 3292, 3293, 59 },
   { 5219, 2047, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2077, 2078, 0 },
   { 2716, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2716, 32, 0 },
   { 2734, 2735, 0 },
   { 2738, 2739, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2716, 32, 0 },
   { 2733, 3, 0 },
   { 2734, 2735, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2716, 32, 0 },
   { 2720, 61, 0 },
   { 2734, 2735, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2716, 32, 0 },
   { 2734, 2735, 0 },
   { 5114, 2039, 0 },
   { 5167, 2047, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2716, 32, 0 },
   { 2734, 2735, 0 },
   { 5139, 2039, 0 },
   { 5192, 2047, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2716, 32, 0 },
   { 2734, 2735, 0 },
   { 5244, 2047, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2716, 32, 0 },
   { 2734, 2735, 0 },
   { 5219, 2047, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2294, 2295, 0 },
   { 2716, 32, 0 },
   { 2734, 2735, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 191, 193, 0 },
   { 2716, 32, 0 },
   { 2733, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2716, 32, 0 },
   { 2720, 61, 0 },
   { 2733, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2716, 32, 0 },
   { 2733, 3, 0 },
   { 5114, 2039, 0 },
   { 5167, 2047, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2716, 32, 0 },
   { 2733, 3, 0 },
   { 5139, 2039, 0 },
   { 5192, 2047, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2716, 32, 0 },
   { 2733, 3, 0 },
   { 5244, 2047, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2716, 32, 0 },
   { 2733, 3, 0 },
   { 5219, 2047, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1082, 1077, 0 },
   { 2716, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2130, 2132, 43 },
   { 2130, 2138, 45 },
   { 2161, 2163, 43 },
   { 2161, 2169, 45 },
   { 2191, 2193, 43 },
   { 2191, 2199, 45 },
   { 2221, 2223, 43 },
   { 2221, 2229, 45 },
   { 2716, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2142, 2143, 46 },
   { 2173, 2174, 46 },
   { 2203, 2204, 46 },
   { 2233, 2234, 46 },
   { 2716, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2716, 32, 0 },
   { 5529, 5530, 0 },
   { 5532, 5533, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2716, 32, 0 },
   { 5518, 5519, 0 },
   { 5522, 5523, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2716, 32, 0 },
   { 5524, 5525, 0 },
   { 5527, 5528, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1076, 1077, 0 },
   { 2716, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2693, 2692, 0 },
   { 2716, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2068, 2070, 0 },
   { 2716, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2073, 2074, 0 },
   { 2716, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2716, 32, 0 },
   { 2720, 61, 0 },
   { 2776, 2777, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2716, 32, 0 },
   { 2720, 61, 0 },
   { 5114, 2039, 0 },
   { 5167, 2047, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2716, 32, 0 },
   { 2720, 61, 0 },
   { 5139, 2039, 0 },
   { 5192, 2047, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2716, 32, 0 },
   { 2720, 61, 0 },
   { 5244, 2047, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2716, 32, 0 },
   { 2720, 61, 0 },
   { 5219, 2047, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1079, 1077, 0 },
   { 1628, 1630, 0 },
   { 1631, 1633, 0 },
   { 2716, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1079, 1077, 0 },
   { 1628, 1630, 0 },
   { 1631, 1633, 0 },
   { 1644, 1630, 0 },
   { 2716, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1079, 1077, 0 },
   { 1628, 1630, 0 },
   { 1631, 1633, 0 },
   { 1757, 1758, 0 },
   { 1759, 1758, 0 },
   { 1865, 1866, 0 },
   { 1867, 1866, 0 },
   { 1950, 1951, 0 },
   { 1952, 1951, 0 },
   { 2716, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1079, 1077, 0 },
   { 1628, 1630, 0 },
   { 1631, 1633, 0 },
   { 1644, 1630, 0 },
   { 1757, 1758, 0 },
   { 1759, 1758, 0 },
   { 1865, 1866, 0 },
   { 1867, 1866, 0 },
   { 1950, 1951, 0 },
   { 1952, 1951, 0 },
   { 2716, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1079, 1077, 0 },
   { 1628, 1630, 0 },
   { 1631, 1633, 0 },
   { 1649, 1633, 0 },
   { 2716, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1079, 1077, 0 },
   { 1628, 1630, 0 },
   { 1631, 1633, 0 },
   { 1649, 1633, 0 },
   { 1757, 1758, 0 },
   { 1759, 1758, 0 },
   { 1865, 1866, 0 },
   { 1867, 1866, 0 },
   { 1950, 1951, 0 },
   { 1952, 1951, 0 },
   { 2716, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1079, 1077, 0 },
   { 1628, 1630, 0 },
   { 1631, 1633, 0 },
   { 1644, 1630, 0 },
   { 1649, 1633, 0 },
   { 1757, 1758, 0 },
   { 1759, 1758, 0 },
   { 1865, 1866, 0 },
   { 1867, 1866, 0 },
   { 1950, 1951, 0 },
   { 1952, 1951, 0 },
   { 2716, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1634, 1636, 0 },
   { 1637, 1639, 0 },
   { 2716, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1634, 1636, 0 },
   { 1637, 1639, 0 },
   { 1652, 1636, 0 },
   { 2716, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1259, 1260, 38 },
   { 1634, 1636, 0 },
   { 1637, 1639, 0 },
   { 1760, 1761, 0 },
   { 1762, 1761, 0 },
   { 1868, 1869, 0 },
   { 1870, 1869, 0 },
   { 1953, 1954, 0 },
   { 1955, 1954, 0 },
   { 2716, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1259, 1260, 38 },
   { 1634, 1636, 0 },
   { 1637, 1639, 0 },
   { 1652, 1636, 0 },
   { 1760, 1761, 0 },
   { 1762, 1761, 0 },
   { 1868, 1869, 0 },
   { 1870, 1869, 0 },
   { 1953, 1954, 0 },
   { 1955, 1954, 0 },
   { 2716, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1634, 1636, 0 },
   { 1637, 1639, 0 },
   { 1655, 1639, 0 },
   { 2716, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1259, 1260, 38 },
   { 1634, 1636, 0 },
   { 1637, 1639, 0 },
   { 1655, 1639, 0 },
   { 1760, 1761, 0 },
   { 1762, 1761, 0 },
   { 1868, 1869, 0 },
   { 1870, 1869, 0 },
   { 1953, 1954, 0 },
   { 1955, 1954, 0 },
   { 2716, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1259, 1260, 38 },
   { 1634, 1636, 0 },
   { 1637, 1639, 0 },
   { 1652, 1636, 0 },
   { 1655, 1639, 0 },
   { 1760, 1761, 0 },
   { 1762, 1761, 0 },
   { 1868, 1869, 0 },
   { 1870, 1869, 0 },
   { 1953, 1954, 0 },
   { 1955, 1954, 0 },
   { 2716, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2716, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1084, 1077, 0 },
   { 1696, 1697, 0 },
   { 1698, 1699, 0 },
   { 2716, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1086, 1077, 0 },
   { 1704, 1705, 0 },
   { 1706, 1707, 0 },
   { 2716, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1700, 1701, 0 },
   { 1702, 1703, 0 },
   { 2716, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1708, 1709, 0 },
   { 1710, 1711, 0 },
   { 2716, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2056, 2057, 0 },
   { 2716, 32, 0 },
   { 5114, 2039, 0 },
   { 5167, 2047, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2716, 32, 0 },
   { 5114, 2039, 0 },
   { 5139, 2039, 0 },
   { 5167, 2047, 0 },
   { 5192, 2047, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2716, 32, 0 },
   { 5114, 2039, 0 },
   { 5167, 2047, 0 },
   { 5244, 2047, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2716, 32, 0 },
   { 5114, 2039, 0 },
   { 5167, 2047, 0 },
   { 5219, 2047, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2051, 2053, 0 },
   { 2716, 32, 0 },
   { 5139, 2039, 0 },
   { 5192, 2047, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2716, 32, 0 },
   { 5139, 2039, 0 },
   { 5192, 2047, 0 },
   { 5244, 2047, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2716, 32, 0 },
   { 5139, 2039, 0 },
   { 5192, 2047, 0 },
   { 5219, 2047, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2060, 2061, 0 },
   { 2716, 32, 0 },
   { 5244, 2047, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2716, 32, 0 },
   { 5219, 2047, 0 },
   { 5244, 2047, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2064, 2065, 0 },
   { 2716, 32, 0 },
   { 5219, 2047, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2721, 32, 0 },
   { 2731, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2721, 32, 0 },
   { 2732, 2354, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2263, 1235, 0 },
   { 2721, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2721, 32, 0 },
   { 2724, 63, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2721, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2721, 32, 0 },
   { 5117, 2081, 0 },
   { 5170, 2085, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2721, 32, 0 },
   { 5142, 2081, 0 },
   { 5195, 2085, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2721, 32, 0 },
   { 5247, 2085, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2721, 32, 0 },
   { 5222, 2085, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2721, 32, 0 },
   { 2722, 32, 0 },
   { 2723, 63, 0 },
   { 2731, 3, 0 },
   { 2758, 2760, 0 },
   { 2761, 2763, 0 },
   { 2764, 2765, 0 },
   { 2766, 2767, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2721, 32, 0 },
   { 2722, 32, 0 },
   { 2723, 63, 0 },
   { 2732, 2354, 0 },
   { 2758, 2760, 0 },
   { 2761, 2763, 0 },
   { 2764, 2765, 0 },
   { 2766, 2767, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2721, 32, 0 },
   { 2722, 32, 0 },
   { 2723, 63, 0 },
   { 2732, 2354, 0 },
   { 2758, 2760, 0 },
   { 2761, 2763, 0 },
   { 2764, 2765, 0 },
   { 2766, 2767, 0 },
   { 3587, 3589, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2263, 1235, 0 },
   { 2721, 32, 0 },
   { 2722, 32, 0 },
   { 2723, 63, 0 },
   { 2758, 2760, 0 },
   { 2761, 2763, 0 },
   { 2764, 2765, 0 },
   { 2766, 2767, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2721, 32, 0 },
   { 2722, 32, 0 },
   { 2723, 63, 0 },
   { 2724, 63, 0 },
   { 2758, 2760, 0 },
   { 2761, 2763, 0 },
   { 2764, 2765, 0 },
   { 2766, 2767, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2721, 32, 0 },
   { 2722, 32, 0 },
   { 2723, 63, 0 },
   { 2758, 2760, 0 },
   { 2761, 2763, 0 },
   { 2764, 2765, 0 },
   { 2766, 2767, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2721, 32, 0 },
   { 2722, 32, 0 },
   { 2723, 63, 0 },
   { 2758, 2760, 0 },
   { 2761, 2763, 0 },
   { 2764, 2765, 0 },
   { 2766, 2767, 0 },
   { 5117, 2081, 0 },
   { 5170, 2085, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2721, 32, 0 },
   { 2722, 32, 0 },
   { 2723, 63, 0 },
   { 2758, 2760, 0 },
   { 2761, 2763, 0 },
   { 2764, 2765, 0 },
   { 2766, 2767, 0 },
   { 5142, 2081, 0 },
   { 5195, 2085, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2721, 32, 0 },
   { 2722, 32, 0 },
   { 2723, 63, 0 },
   { 2758, 2760, 0 },
   { 2761, 2763, 0 },
   { 2764, 2765, 0 },
   { 2766, 2767, 0 },
   { 5247, 2085, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2721, 32, 0 },
   { 2722, 32, 0 },
   { 2723, 63, 0 },
   { 2758, 2760, 0 },
   { 2761, 2763, 0 },
   { 2764, 2765, 0 },
   { 2766, 2767, 0 },
   { 5222, 2085, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2101, 2102, 0 },
   { 2721, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2721, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 196, 198, 0 },
   { 2721, 32, 0 },
   { 2731, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2721, 32, 0 },
   { 2731, 3, 0 },
   { 2732, 2354, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2263, 1235, 0 },
   { 2721, 32, 0 },
   { 2731, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2721, 32, 0 },
   { 2724, 63, 0 },
   { 2731, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2721, 32, 0 },
   { 2731, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2721, 32, 0 },
   { 2731, 3, 0 },
   { 5117, 2081, 0 },
   { 5170, 2085, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2721, 32, 0 },
   { 2731, 3, 0 },
   { 5142, 2081, 0 },
   { 5195, 2085, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2721, 32, 0 },
   { 2731, 3, 0 },
   { 5247, 2085, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2721, 32, 0 },
   { 2731, 3, 0 },
   { 5222, 2085, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2291, 2293, 0 },
   { 2721, 32, 0 },
   { 2731, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2263, 1235, 0 },
   { 2721, 32, 0 },
   { 2732, 2354, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2721, 32, 0 },
   { 2724, 63, 0 },
   { 2732, 2354, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2721, 32, 0 },
   { 2732, 2354, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2721, 32, 0 },
   { 2732, 2354, 0 },
   { 5117, 2081, 0 },
   { 5170, 2085, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2721, 32, 0 },
   { 2732, 2354, 0 },
   { 5142, 2081, 0 },
   { 5195, 2085, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2721, 32, 0 },
   { 2732, 2354, 0 },
   { 5247, 2085, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2721, 32, 0 },
   { 2732, 2354, 0 },
   { 5222, 2085, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2139, 2141, 46 },
   { 2170, 2172, 46 },
   { 2200, 2202, 46 },
   { 2230, 2232, 46 },
   { 2252, 2253, 0 },
   { 2263, 1235, 0 },
   { 2721, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2263, 1235, 0 },
   { 2721, 32, 0 },
   { 2724, 63, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2263, 1235, 0 },
   { 2721, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2256, 2257, 0 },
   { 2260, 2261, 0 },
   { 2263, 1235, 0 },
   { 2721, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2263, 1235, 0 },
   { 2721, 32, 0 },
   { 5117, 2081, 0 },
   { 5170, 2085, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2263, 1235, 0 },
   { 2721, 32, 0 },
   { 5142, 2081, 0 },
   { 5195, 2085, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2263, 1235, 0 },
   { 2721, 32, 0 },
   { 5247, 2085, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2263, 1235, 0 },
   { 2721, 32, 0 },
   { 5222, 2085, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2135, 2136, 44 },
   { 2135, 2144, 45 },
   { 2166, 2167, 44 },
   { 2166, 2175, 45 },
   { 2196, 2197, 44 },
   { 2196, 2205, 45 },
   { 2226, 2227, 44 },
   { 2226, 2235, 45 },
   { 2721, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2721, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2721, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2694, 2695, 0 },
   { 2721, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2096, 2098, 0 },
   { 2721, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2099, 2100, 0 },
   { 2721, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2721, 32, 0 },
   { 2724, 63, 0 },
   { 2778, 2779, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2721, 32, 0 },
   { 2724, 63, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2721, 32, 0 },
   { 2724, 63, 0 },
   { 5117, 2081, 0 },
   { 5170, 2085, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2721, 32, 0 },
   { 2724, 63, 0 },
   { 5142, 2081, 0 },
   { 5195, 2085, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2721, 32, 0 },
   { 2724, 63, 0 },
   { 5247, 2085, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2721, 32, 0 },
   { 2724, 63, 0 },
   { 5222, 2085, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1595, 1597, 0 },
   { 1601, 1603, 0 },
   { 1737, 1052, 0 },
   { 2721, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2721, 32, 0 },
   { 5117, 2081, 0 },
   { 5170, 2085, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2721, 32, 0 },
   { 5142, 2081, 0 },
   { 5195, 2085, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2721, 32, 0 },
   { 5247, 2085, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2721, 32, 0 },
   { 5222, 2085, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1595, 1597, 0 },
   { 1601, 1603, 0 },
   { 1616, 1597, 0 },
   { 1737, 1052, 0 },
   { 2721, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1595, 1597, 0 },
   { 1601, 1603, 0 },
   { 1737, 1052, 0 },
   { 1743, 1745, 0 },
   { 1748, 1745, 0 },
   { 1851, 1853, 0 },
   { 1856, 1853, 0 },
   { 1936, 1938, 0 },
   { 1941, 1938, 0 },
   { 2721, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1595, 1597, 0 },
   { 1601, 1603, 0 },
   { 1616, 1597, 0 },
   { 1737, 1052, 0 },
   { 1743, 1745, 0 },
   { 1748, 1745, 0 },
   { 1851, 1853, 0 },
   { 1856, 1853, 0 },
   { 1936, 1938, 0 },
   { 1941, 1938, 0 },
   { 2721, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1595, 1597, 0 },
   { 1601, 1603, 0 },
   { 1621, 1603, 0 },
   { 1737, 1052, 0 },
   { 2721, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1595, 1597, 0 },
   { 1601, 1603, 0 },
   { 1621, 1603, 0 },
   { 1737, 1052, 0 },
   { 1743, 1745, 0 },
   { 1748, 1745, 0 },
   { 1851, 1853, 0 },
   { 1856, 1853, 0 },
   { 1936, 1938, 0 },
   { 1941, 1938, 0 },
   { 2721, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1595, 1597, 0 },
   { 1601, 1603, 0 },
   { 1616, 1597, 0 },
   { 1621, 1603, 0 },
   { 1737, 1052, 0 },
   { 1743, 1745, 0 },
   { 1748, 1745, 0 },
   { 1851, 1853, 0 },
   { 1856, 1853, 0 },
   { 1936, 1938, 0 },
   { 1941, 1938, 0 },
   { 2721, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1606, 1608, 0 },
   { 1611, 1613, 0 },
   { 2721, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1606, 1608, 0 },
   { 1611, 1613, 0 },
   { 1624, 1608, 0 },
   { 2721, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1606, 1608, 0 },
   { 1611, 1613, 0 },
   { 1751, 1753, 0 },
   { 1756, 1753, 0 },
   { 1859, 1861, 0 },
   { 1864, 1861, 0 },
   { 1944, 1946, 0 },
   { 1949, 1946, 0 },
   { 2721, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1606, 1608, 0 },
   { 1611, 1613, 0 },
   { 1624, 1608, 0 },
   { 1751, 1753, 0 },
   { 1756, 1753, 0 },
   { 1859, 1861, 0 },
   { 1864, 1861, 0 },
   { 1944, 1946, 0 },
   { 1949, 1946, 0 },
   { 2721, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1606, 1608, 0 },
   { 1611, 1613, 0 },
   { 1627, 1613, 0 },
   { 2721, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1606, 1608, 0 },
   { 1611, 1613, 0 },
   { 1627, 1613, 0 },
   { 1751, 1753, 0 },
   { 1756, 1753, 0 },
   { 1859, 1861, 0 },
   { 1864, 1861, 0 },
   { 1944, 1946, 0 },
   { 1949, 1946, 0 },
   { 2721, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1606, 1608, 0 },
   { 1611, 1613, 0 },
   { 1624, 1608, 0 },
   { 1627, 1613, 0 },
   { 1751, 1753, 0 },
   { 1756, 1753, 0 },
   { 1859, 1861, 0 },
   { 1864, 1861, 0 },
   { 1944, 1946, 0 },
   { 1949, 1946, 0 },
   { 2721, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2721, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1658, 1660, 0 },
   { 1663, 1665, 0 },
   { 2721, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1678, 1680, 0 },
   { 1683, 1685, 0 },
   { 2721, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1668, 1670, 0 },
   { 1673, 1675, 0 },
   { 2721, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1688, 1690, 0 },
   { 1693, 1695, 0 },
   { 2721, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2090, 2091, 0 },
   { 2721, 32, 0 },
   { 5117, 2081, 0 },
   { 5170, 2085, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2721, 32, 0 },
   { 5117, 2081, 0 },
   { 5142, 2081, 0 },
   { 5170, 2085, 0 },
   { 5195, 2085, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2721, 32, 0 },
   { 5117, 2081, 0 },
   { 5170, 2085, 0 },
   { 5247, 2085, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2721, 32, 0 },
   { 5117, 2081, 0 },
   { 5170, 2085, 0 },
   { 5222, 2085, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2087, 2089, 0 },
   { 2721, 32, 0 },
   { 5142, 2081, 0 },
   { 5195, 2085, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2721, 32, 0 },
   { 5142, 2081, 0 },
   { 5195, 2085, 0 },
   { 5247, 2085, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2721, 32, 0 },
   { 5142, 2081, 0 },
   { 5195, 2085, 0 },
   { 5222, 2085, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2092, 2093, 0 },
   { 2721, 32, 0 },
   { 5247, 2085, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2721, 32, 0 },
   { 5222, 2085, 0 },
   { 5247, 2085, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2094, 2095, 0 },
   { 2721, 32, 0 },
   { 5222, 2085, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2721, 32, 0 },
   { 3365, 3364, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2725, 61, 0 },
   { 5120, 2105, 0 },
   { 5173, 2109, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2725, 61, 0 },
   { 5145, 2105, 0 },
   { 5198, 2109, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2725, 61, 0 },
   { 5250, 2109, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2725, 61, 0 },
   { 5225, 2109, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2725, 61, 0 },
   { 2728, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2725, 61, 0 },
   { 2726, 32, 0 },
   { 2729, 2719, 0 },
   { 2768, 2770, 0 },
   { 2771, 2773, 0 },
   { 5120, 2105, 0 },
   { 5173, 2109, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2725, 61, 0 },
   { 2726, 32, 0 },
   { 2729, 2719, 0 },
   { 2768, 2770, 0 },
   { 2771, 2773, 0 },
   { 5145, 2105, 0 },
   { 5198, 2109, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2725, 61, 0 },
   { 2726, 32, 0 },
   { 2729, 2719, 0 },
   { 2768, 2770, 0 },
   { 2771, 2773, 0 },
   { 5250, 2109, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2725, 61, 0 },
   { 2726, 32, 0 },
   { 2729, 2719, 0 },
   { 2768, 2770, 0 },
   { 2771, 2773, 0 },
   { 5225, 2109, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2725, 61, 0 },
   { 2726, 32, 0 },
   { 2728, 3, 0 },
   { 2729, 2719, 0 },
   { 2768, 2770, 0 },
   { 2771, 2773, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2725, 61, 0 },
   { 2726, 32, 0 },
   { 2728, 3, 0 },
   { 2729, 2719, 0 },
   { 2768, 2770, 0 },
   { 2771, 2773, 0 },
   { 3591, 3593, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2125, 2126, 0 },
   { 2725, 61, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2120, 2122, 0 },
   { 2725, 61, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2123, 2124, 0 },
   { 2725, 61, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2114, 2115, 0 },
   { 2725, 61, 0 },
   { 5120, 2105, 0 },
   { 5173, 2109, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2725, 61, 0 },
   { 5120, 2105, 0 },
   { 5145, 2105, 0 },
   { 5173, 2109, 0 },
   { 5198, 2109, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2725, 61, 0 },
   { 5120, 2105, 0 },
   { 5173, 2109, 0 },
   { 5250, 2109, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2725, 61, 0 },
   { 5120, 2105, 0 },
   { 5173, 2109, 0 },
   { 5225, 2109, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2725, 61, 0 },
   { 2728, 3, 0 },
   { 5120, 2105, 0 },
   { 5173, 2109, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2111, 2113, 0 },
   { 2725, 61, 0 },
   { 5145, 2105, 0 },
   { 5198, 2109, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2725, 61, 0 },
   { 5145, 2105, 0 },
   { 5198, 2109, 0 },
   { 5250, 2109, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2725, 61, 0 },
   { 5145, 2105, 0 },
   { 5198, 2109, 0 },
   { 5225, 2109, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2725, 61, 0 },
   { 2728, 3, 0 },
   { 5145, 2105, 0 },
   { 5198, 2109, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2116, 2117, 0 },
   { 2725, 61, 0 },
   { 5250, 2109, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2725, 61, 0 },
   { 5225, 2109, 0 },
   { 5250, 2109, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2725, 61, 0 },
   { 2728, 3, 0 },
   { 5250, 2109, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2118, 2119, 0 },
   { 2725, 61, 0 },
   { 5225, 2109, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2725, 61, 0 },
   { 2728, 3, 0 },
   { 5225, 2109, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2152, 2153, 0 },
   { 2183, 2184, 0 },
   { 2212, 2213, 0 },
   { 2243, 2244, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2152, 2153, 0 },
   { 2183, 2184, 0 },
   { 2212, 2213, 0 },
   { 2243, 2244, 0 },
   { 2786, 1229, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2786, 1229, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 915, 917, 0 },
   { 923, 925, 0 },
   { 931, 933, 0 },
   { 939, 941, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 915, 917, 0 },
   { 923, 925, 0 },
   { 931, 933, 0 },
   { 939, 941, 0 },
   { 2787, 32, 0 },
   { 3250, 3251, 58 },
   { 1017, 422, 58 },
   { 3253, 3255, 58 },
   { 3288, 444, 59 },
   { 1008, 447, 59 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 915, 917, 0 },
   { 923, 925, 0 },
   { 931, 933, 0 },
   { 939, 941, 0 },
   { 2152, 2153, 0 },
   { 2183, 2184, 0 },
   { 2212, 2213, 0 },
   { 2243, 2244, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 915, 917, 0 },
   { 923, 925, 0 },
   { 931, 933, 0 },
   { 939, 941, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 838, 840, 0 },
   { 859, 861, 0 },
   { 879, 881, 0 },
   { 900, 902, 0 },
   { 2787, 32, 0 },
   { 3250, 3251, 58 },
   { 1017, 422, 58 },
   { 3253, 3255, 58 },
   { 1008, 447, 59 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2787, 32, 0 },
   { 3250, 3251, 58 },
   { 1017, 422, 58 },
   { 3253, 3255, 58 },
   { 1008, 447, 59 },
   { 3360, 3357, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2150, 2151, 0 },
   { 2181, 2182, 0 },
   { 2210, 2211, 0 },
   { 2241, 2242, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2150, 2151, 0 },
   { 2181, 2182, 0 },
   { 2210, 2211, 0 },
   { 2241, 2242, 0 },
   { 2782, 1229, 0 },
   { 2784, 2783, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2785, 32, 0 },
   { 3256, 3257, 58 },
   { 3258, 406, 58 },
   { 3259, 3260, 58 },
   { 3289, 436, 59 },
   { 3290, 439, 59 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2785, 32, 0 },
   { 3256, 3257, 58 },
   { 3258, 406, 58 },
   { 3259, 3260, 58 },
   { 3290, 439, 59 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2150, 2151, 0 },
   { 2181, 2182, 0 },
   { 2210, 2211, 0 },
   { 2241, 2242, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 842, 847, 0 },
   { 863, 868, 0 },
   { 883, 888, 0 },
   { 904, 909, 0 },
   { 2785, 32, 0 },
   { 3256, 3257, 58 },
   { 3258, 406, 58 },
   { 3259, 3260, 58 },
   { 3290, 439, 59 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3433, 3434, 0 },
   { 3436, 419, 0 },
   { 3437, 415, 0 },
   { 3438, 412, 0 },
   { 3440, 3411, 0 },
   { 3442, 3406, 0 },
   { 3444, 3401, 0 },
   { 3446, 3398, 0 },
   { 3448, 3394, 0 },
   { 3450, 3390, 0 },
   { 3452, 3453, 0 },
   { 3932, 3935, 91 },
   { 5094, 11, 0 },
   { 5147, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3383, 3251, 0 },
   { 3385, 415, 0 },
   { 3386, 419, 0 },
   { 3387, 422, 0 },
   { 3389, 3390, 0 },
   { 3392, 3394, 0 },
   { 3396, 3398, 0 },
   { 3399, 3401, 0 },
   { 3404, 3406, 0 },
   { 3409, 3411, 0 },
   { 3412, 3255, 0 },
   { 3932, 3935, 91 },
   { 5094, 11, 0 },
   { 5147, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3413, 3251, 0 },
   { 3415, 415, 0 },
   { 3416, 419, 0 },
   { 3417, 422, 0 },
   { 3419, 3390, 0 },
   { 3421, 3394, 0 },
   { 3423, 3398, 0 },
   { 3425, 3401, 0 },
   { 3427, 3406, 0 },
   { 3429, 3411, 0 },
   { 3430, 3255, 0 },
   { 3932, 3935, 91 },
   { 5094, 11, 0 },
   { 5147, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3287, 3271, 0 },
   { 3932, 3935, 91 },
   { 5094, 11, 0 },
   { 5147, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3286, 3271, 0 },
   { 3932, 3935, 91 },
   { 5094, 11, 0 },
   { 5147, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3431, 3265, 0 },
   { 3932, 3935, 91 },
   { 5094, 11, 0 },
   { 5147, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3375, 3376, 0 },
   { 3377, 3378, 0 },
   { 3379, 3380, 0 },
   { 3381, 3382, 0 },
   { 3932, 3935, 91 },
   { 5094, 11, 0 },
   { 5147, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3454, 3455, 0 },
   { 3456, 402, 0 },
   { 3457, 397, 0 },
   { 3458, 393, 0 },
   { 3459, 3460, 0 },
   { 3461, 3462, 0 },
   { 3463, 3464, 0 },
   { 3465, 3466, 0 },
   { 3467, 3468, 0 },
   { 3469, 3470, 0 },
   { 3471, 3472, 0 },
   { 3927, 3931, 91 },
   { 5122, 11, 0 },
   { 5175, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3367, 3368, 0 },
   { 3369, 3370, 0 },
   { 3371, 3372, 0 },
   { 3373, 3374, 0 },
   { 3927, 3931, 91 },
   { 5122, 11, 0 },
   { 5175, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3235, 21, 0 },
   { 3218, 3318, 61 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 48, 49, 0 },
   { 2748, 3323, 63 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 51, 49, 0 },
   { 2748, 3323, 63 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2748, 3323, 63 },
   { 3333, 2748, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3227, 16, 0 },
   { 2748, 3323, 63 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3224, 16, 0 },
   { 2748, 3323, 63 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3219, 16, 0 },
   { 2748, 3323, 63 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3222, 2443, 0 },
   { 2748, 3323, 63 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 99, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 102, 103, 0 },
   { 3169, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 105, 104, 0 },
   { 3169, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3169, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2413, 2412, 0 },
   { 3169, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2415, 2414, 0 },
   { 3169, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2417, 2416, 0 },
   { 3169, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2419, 2418, 0 },
   { 3169, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3169, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 109, 110, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4233, 760, 0 },
   { 4235, 6, 0 },
   { 4237, 11, 0 },
   { 4239, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 205, 111, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3597, 3526, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 112, 32, 0 },
   { 114, 11, 5 },
   { 116, 16, 6 },
   { 205, 111, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 112, 32, 0 },
   { 114, 11, 5 },
   { 116, 16, 6 },
   { 3524, 3526, 0 },
   { 3528, 3526, 0 },
   { 3597, 3526, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 112, 32, 0 },
   { 114, 11, 5 },
   { 116, 16, 6 },
   { 3524, 3526, 0 },
   { 3528, 3526, 0 },
   { 3555, 3526, 0 },
   { 3597, 3526, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 112, 32, 0 },
   { 114, 11, 5 },
   { 116, 16, 6 },
   { 3531, 3533, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 112, 32, 0 },
   { 114, 11, 5 },
   { 116, 16, 6 },
   { 3531, 3533, 0 },
   { 3562, 3564, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 112, 32, 0 },
   { 114, 11, 5 },
   { 116, 16, 6 },
   { 3535, 3537, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 112, 32, 0 },
   { 114, 11, 5 },
   { 116, 16, 6 },
   { 3535, 3537, 0 },
   { 3572, 3574, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 112, 32, 0 },
   { 114, 11, 5 },
   { 116, 16, 6 },
   { 5606, 5609, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 205, 111, 0 },
   { 214, 3, 0 },
   { 3597, 3526, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 131, 133, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 155, 157, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 137, 139, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 171, 166, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3484, 3485, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3674, 3675, 0 },
   { 3677, 3678, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 221, 111, 0 },
   { 222, 113, 5 },
   { 223, 115, 6 },
   { 242, 32, 0 },
   { 245, 32, 0 },
   { 248, 98, 0 },
   { 3484, 3485, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 221, 111, 0 },
   { 222, 113, 5 },
   { 223, 115, 6 },
   { 242, 32, 0 },
   { 245, 32, 0 },
   { 248, 98, 0 },
   { 3497, 3499, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 221, 111, 0 },
   { 222, 113, 5 },
   { 223, 115, 6 },
   { 242, 32, 0 },
   { 245, 32, 0 },
   { 248, 98, 0 },
   { 3497, 3499, 0 },
   { 3542, 3499, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 221, 111, 0 },
   { 222, 113, 5 },
   { 223, 115, 6 },
   { 242, 32, 0 },
   { 245, 32, 0 },
   { 248, 98, 0 },
   { 3505, 3507, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 221, 111, 0 },
   { 222, 113, 5 },
   { 223, 115, 6 },
   { 242, 32, 0 },
   { 245, 32, 0 },
   { 248, 98, 0 },
   { 3505, 3507, 0 },
   { 3546, 3507, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 221, 111, 0 },
   { 222, 113, 5 },
   { 223, 115, 6 },
   { 242, 32, 0 },
   { 245, 32, 0 },
   { 248, 98, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 221, 111, 0 },
   { 222, 113, 5 },
   { 223, 115, 6 },
   { 242, 32, 0 },
   { 245, 32, 0 },
   { 248, 98, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 221, 111, 0 },
   { 222, 113, 5 },
   { 223, 115, 6 },
   { 242, 32, 0 },
   { 245, 32, 0 },
   { 248, 98, 0 },
   { 5610, 5613, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 221, 111, 0 },
   { 222, 113, 5 },
   { 223, 115, 6 },
   { 242, 32, 0 },
   { 245, 32, 0 },
   { 248, 98, 0 },
   { 3674, 3675, 0 },
   { 3677, 3678, 0 },
   { 5610, 5613, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 221, 111, 0 },
   { 222, 113, 5 },
   { 223, 115, 6 },
   { 242, 32, 0 },
   { 245, 32, 0 },
   { 248, 98, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 221, 111, 0 },
   { 222, 113, 5 },
   { 223, 115, 6 },
   { 242, 32, 0 },
   { 245, 32, 0 },
   { 248, 98, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3484, 3485, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3484, 3485, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3484, 3485, 0 },
   { 3674, 3675, 0 },
   { 3677, 3678, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3484, 3485, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3484, 3485, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 252, 253, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3674, 3675, 0 },
   { 3677, 3678, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3674, 3675, 0 },
   { 3677, 3678, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3674, 3675, 0 },
   { 3677, 3678, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3674, 3675, 0 },
   { 3677, 3678, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2887, 2888, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2696, 1266, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2892, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 226, 227, 6 },
   { 230, 227, 0 },
   { 231, 232, 0 },
   { 3486, 3487, 6 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 226, 227, 6 },
   { 230, 227, 0 },
   { 231, 232, 0 },
   { 3680, 3681, 0 },
   { 3683, 3684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 224, 115, 0 },
   { 226, 227, 6 },
   { 230, 227, 0 },
   { 231, 232, 0 },
   { 244, 16, 0 },
   { 3486, 3487, 6 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 224, 115, 0 },
   { 226, 227, 6 },
   { 230, 227, 0 },
   { 231, 232, 0 },
   { 244, 16, 0 },
   { 3501, 3503, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 224, 115, 0 },
   { 226, 227, 6 },
   { 230, 227, 0 },
   { 231, 232, 0 },
   { 244, 16, 0 },
   { 3501, 3503, 0 },
   { 3544, 3503, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 224, 115, 0 },
   { 226, 227, 6 },
   { 230, 227, 0 },
   { 231, 232, 0 },
   { 244, 16, 0 },
   { 5615, 5618, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 224, 115, 0 },
   { 226, 227, 6 },
   { 230, 227, 0 },
   { 231, 232, 0 },
   { 244, 16, 0 },
   { 3680, 3681, 0 },
   { 3683, 3684, 0 },
   { 5615, 5618, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 226, 227, 6 },
   { 230, 227, 0 },
   { 231, 232, 0 },
   { 3486, 3487, 6 },
   { 3680, 3681, 0 },
   { 3683, 3684, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 226, 227, 6 },
   { 230, 227, 0 },
   { 231, 232, 0 },
   { 2894, 696, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 147, 148, 0 },
   { 737, 739, 29 },
   { 234, 741, 30 },
   { 742, 744, 31 },
   { 745, 739, 32 },
   { 746, 741, 33 },
   { 747, 744, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 143, 145, 0 },
   { 737, 739, 29 },
   { 234, 741, 30 },
   { 742, 744, 31 },
   { 745, 739, 32 },
   { 746, 741, 33 },
   { 747, 744, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 147, 148, 0 },
   { 257, 3, 0 },
   { 259, 258, 5 },
   { 260, 36, 6 },
   { 271, 272, 0 },
   { 276, 277, 0 },
   { 737, 739, 29 },
   { 234, 741, 30 },
   { 742, 744, 31 },
   { 745, 739, 32 },
   { 746, 741, 33 },
   { 747, 744, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 143, 145, 0 },
   { 257, 3, 0 },
   { 259, 258, 5 },
   { 260, 36, 6 },
   { 271, 272, 0 },
   { 276, 277, 0 },
   { 737, 739, 29 },
   { 234, 741, 30 },
   { 742, 744, 31 },
   { 745, 739, 32 },
   { 746, 741, 33 },
   { 747, 744, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 737, 739, 29 },
   { 234, 741, 30 },
   { 742, 744, 31 },
   { 745, 739, 32 },
   { 746, 741, 33 },
   { 747, 744, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 263, 264, 0 },
   { 265, 266, 5 },
   { 267, 227, 6 },
   { 737, 739, 29 },
   { 234, 741, 30 },
   { 742, 744, 31 },
   { 745, 739, 32 },
   { 746, 741, 33 },
   { 747, 744, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 147, 148, 0 },
   { 737, 739, 29 },
   { 234, 741, 30 },
   { 742, 744, 31 },
   { 745, 739, 32 },
   { 746, 741, 33 },
   { 747, 744, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 143, 145, 0 },
   { 737, 739, 29 },
   { 234, 741, 30 },
   { 742, 744, 31 },
   { 745, 739, 32 },
   { 746, 741, 33 },
   { 747, 744, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 147, 148, 0 },
   { 160, 162, 0 },
   { 737, 739, 29 },
   { 234, 741, 30 },
   { 742, 744, 31 },
   { 745, 739, 32 },
   { 746, 741, 33 },
   { 747, 744, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 147, 148, 0 },
   { 257, 3, 0 },
   { 259, 258, 5 },
   { 260, 36, 6 },
   { 271, 272, 0 },
   { 276, 277, 0 },
   { 284, 285, 0 },
   { 737, 739, 29 },
   { 234, 741, 30 },
   { 742, 744, 31 },
   { 745, 739, 32 },
   { 746, 741, 33 },
   { 747, 744, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 143, 145, 0 },
   { 257, 3, 0 },
   { 259, 258, 5 },
   { 260, 36, 6 },
   { 271, 272, 0 },
   { 276, 277, 0 },
   { 284, 285, 0 },
   { 737, 739, 29 },
   { 234, 741, 30 },
   { 742, 744, 31 },
   { 745, 739, 32 },
   { 746, 741, 33 },
   { 747, 744, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 257, 3, 0 },
   { 259, 258, 5 },
   { 260, 36, 6 },
   { 271, 272, 0 },
   { 276, 277, 0 },
   { 737, 739, 29 },
   { 234, 741, 30 },
   { 742, 744, 31 },
   { 745, 739, 32 },
   { 746, 741, 33 },
   { 747, 744, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 257, 3, 0 },
   { 259, 258, 5 },
   { 260, 36, 6 },
   { 263, 264, 0 },
   { 265, 266, 5 },
   { 267, 227, 6 },
   { 271, 272, 0 },
   { 276, 277, 0 },
   { 737, 739, 29 },
   { 234, 741, 30 },
   { 742, 744, 31 },
   { 745, 739, 32 },
   { 746, 741, 33 },
   { 747, 744, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 147, 148, 0 },
   { 257, 3, 0 },
   { 259, 258, 5 },
   { 260, 36, 6 },
   { 271, 272, 0 },
   { 276, 277, 0 },
   { 737, 739, 29 },
   { 234, 741, 30 },
   { 742, 744, 31 },
   { 745, 739, 32 },
   { 746, 741, 33 },
   { 747, 744, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 143, 145, 0 },
   { 257, 3, 0 },
   { 259, 258, 5 },
   { 260, 36, 6 },
   { 271, 272, 0 },
   { 276, 277, 0 },
   { 737, 739, 29 },
   { 234, 741, 30 },
   { 742, 744, 31 },
   { 745, 739, 32 },
   { 746, 741, 33 },
   { 747, 744, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 257, 3, 0 },
   { 259, 258, 5 },
   { 260, 36, 6 },
   { 271, 272, 0 },
   { 276, 277, 0 },
   { 737, 739, 29 },
   { 234, 741, 30 },
   { 742, 744, 31 },
   { 745, 739, 32 },
   { 746, 741, 33 },
   { 747, 744, 34 },
   { 3515, 3517, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 257, 3, 0 },
   { 259, 258, 5 },
   { 260, 36, 6 },
   { 263, 264, 0 },
   { 265, 266, 5 },
   { 267, 227, 6 },
   { 271, 272, 0 },
   { 276, 277, 0 },
   { 737, 739, 29 },
   { 234, 741, 30 },
   { 742, 744, 31 },
   { 745, 739, 32 },
   { 746, 741, 33 },
   { 747, 744, 34 },
   { 3515, 3517, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 147, 148, 0 },
   { 160, 162, 0 },
   { 257, 3, 0 },
   { 259, 258, 5 },
   { 260, 36, 6 },
   { 271, 272, 0 },
   { 276, 277, 0 },
   { 737, 739, 29 },
   { 234, 741, 30 },
   { 742, 744, 31 },
   { 745, 739, 32 },
   { 746, 741, 33 },
   { 747, 744, 34 },
   { 3515, 3517, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 143, 145, 0 },
   { 257, 3, 0 },
   { 259, 258, 5 },
   { 260, 36, 6 },
   { 271, 272, 0 },
   { 276, 277, 0 },
   { 737, 739, 29 },
   { 234, 741, 30 },
   { 742, 744, 31 },
   { 745, 739, 32 },
   { 746, 741, 33 },
   { 747, 744, 34 },
   { 3515, 3517, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 257, 3, 0 },
   { 259, 258, 5 },
   { 260, 36, 6 },
   { 271, 272, 0 },
   { 276, 277, 0 },
   { 737, 739, 29 },
   { 234, 741, 30 },
   { 742, 744, 31 },
   { 745, 739, 32 },
   { 746, 741, 33 },
   { 747, 744, 34 },
   { 3515, 3517, 0 },
   { 3549, 3517, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 257, 3, 0 },
   { 259, 258, 5 },
   { 260, 36, 6 },
   { 263, 264, 0 },
   { 265, 266, 5 },
   { 267, 227, 6 },
   { 271, 272, 0 },
   { 276, 277, 0 },
   { 737, 739, 29 },
   { 234, 741, 30 },
   { 742, 744, 31 },
   { 745, 739, 32 },
   { 746, 741, 33 },
   { 747, 744, 34 },
   { 3515, 3517, 0 },
   { 3549, 3517, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 147, 148, 0 },
   { 160, 162, 0 },
   { 257, 3, 0 },
   { 259, 258, 5 },
   { 260, 36, 6 },
   { 271, 272, 0 },
   { 276, 277, 0 },
   { 737, 739, 29 },
   { 234, 741, 30 },
   { 742, 744, 31 },
   { 745, 739, 32 },
   { 746, 741, 33 },
   { 747, 744, 34 },
   { 3515, 3517, 0 },
   { 3549, 3517, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 143, 145, 0 },
   { 257, 3, 0 },
   { 259, 258, 5 },
   { 260, 36, 6 },
   { 271, 272, 0 },
   { 276, 277, 0 },
   { 737, 739, 29 },
   { 234, 741, 30 },
   { 742, 744, 31 },
   { 745, 739, 32 },
   { 746, 741, 33 },
   { 747, 744, 34 },
   { 3515, 3517, 0 },
   { 3549, 3517, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 257, 3, 0 },
   { 259, 258, 5 },
   { 260, 36, 6 },
   { 271, 272, 0 },
   { 276, 277, 0 },
   { 737, 739, 29 },
   { 234, 741, 30 },
   { 742, 744, 31 },
   { 745, 739, 32 },
   { 746, 741, 33 },
   { 747, 744, 34 },
   { 3520, 3521, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 257, 3, 0 },
   { 259, 258, 5 },
   { 260, 36, 6 },
   { 263, 264, 0 },
   { 265, 266, 5 },
   { 267, 227, 6 },
   { 271, 272, 0 },
   { 276, 277, 0 },
   { 737, 739, 29 },
   { 234, 741, 30 },
   { 742, 744, 31 },
   { 745, 739, 32 },
   { 746, 741, 33 },
   { 747, 744, 34 },
   { 3520, 3521, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 147, 148, 0 },
   { 257, 3, 0 },
   { 259, 258, 5 },
   { 260, 36, 6 },
   { 271, 272, 0 },
   { 276, 277, 0 },
   { 737, 739, 29 },
   { 234, 741, 30 },
   { 742, 744, 31 },
   { 745, 739, 32 },
   { 746, 741, 33 },
   { 747, 744, 34 },
   { 3520, 3521, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 143, 145, 0 },
   { 257, 3, 0 },
   { 259, 258, 5 },
   { 260, 36, 6 },
   { 271, 272, 0 },
   { 276, 277, 0 },
   { 737, 739, 29 },
   { 234, 741, 30 },
   { 742, 744, 31 },
   { 745, 739, 32 },
   { 746, 741, 33 },
   { 747, 744, 34 },
   { 3520, 3521, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 737, 739, 29 },
   { 234, 741, 30 },
   { 742, 744, 31 },
   { 745, 739, 32 },
   { 746, 741, 33 },
   { 747, 744, 34 },
   { 3489, 3490, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 263, 264, 0 },
   { 265, 266, 5 },
   { 267, 227, 6 },
   { 737, 739, 29 },
   { 234, 741, 30 },
   { 742, 744, 31 },
   { 745, 739, 32 },
   { 746, 741, 33 },
   { 747, 744, 34 },
   { 3489, 3490, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 147, 148, 0 },
   { 737, 739, 29 },
   { 234, 741, 30 },
   { 742, 744, 31 },
   { 745, 739, 32 },
   { 746, 741, 33 },
   { 747, 744, 34 },
   { 3489, 3490, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 143, 145, 0 },
   { 737, 739, 29 },
   { 234, 741, 30 },
   { 742, 744, 31 },
   { 745, 739, 32 },
   { 746, 741, 33 },
   { 747, 744, 34 },
   { 3489, 3490, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 147, 148, 0 },
   { 160, 162, 0 },
   { 737, 739, 29 },
   { 234, 741, 30 },
   { 742, 744, 31 },
   { 745, 739, 32 },
   { 746, 741, 33 },
   { 747, 744, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 737, 739, 29 },
   { 234, 741, 30 },
   { 742, 744, 31 },
   { 745, 739, 32 },
   { 746, 741, 33 },
   { 747, 744, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 263, 264, 0 },
   { 265, 266, 5 },
   { 267, 227, 6 },
   { 737, 739, 29 },
   { 234, 741, 30 },
   { 742, 744, 31 },
   { 745, 739, 32 },
   { 746, 741, 33 },
   { 747, 744, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 147, 148, 0 },
   { 737, 739, 29 },
   { 234, 741, 30 },
   { 742, 744, 31 },
   { 745, 739, 32 },
   { 746, 741, 33 },
   { 747, 744, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 143, 145, 0 },
   { 737, 739, 29 },
   { 234, 741, 30 },
   { 742, 744, 31 },
   { 745, 739, 32 },
   { 746, 741, 33 },
   { 747, 744, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 168, 139, 0 },
   { 233, 234, 6 },
   { 235, 234, 0 },
   { 236, 237, 0 },
   { 387, 288, 30 },
   { 748, 288, 33 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 165, 166, 0 },
   { 233, 234, 6 },
   { 235, 234, 0 },
   { 236, 237, 0 },
   { 387, 288, 30 },
   { 748, 288, 33 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 168, 139, 0 },
   { 233, 234, 6 },
   { 235, 234, 0 },
   { 236, 237, 0 },
   { 261, 262, 0 },
   { 273, 274, 6 },
   { 279, 281, 6 },
   { 387, 288, 30 },
   { 748, 288, 33 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 165, 166, 0 },
   { 233, 234, 6 },
   { 235, 234, 0 },
   { 236, 237, 0 },
   { 261, 262, 0 },
   { 273, 274, 6 },
   { 279, 281, 6 },
   { 387, 288, 30 },
   { 748, 288, 33 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 168, 139, 0 },
   { 174, 176, 0 },
   { 233, 234, 6 },
   { 235, 234, 0 },
   { 236, 237, 0 },
   { 387, 288, 30 },
   { 748, 288, 33 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 168, 139, 0 },
   { 233, 234, 6 },
   { 235, 234, 0 },
   { 236, 237, 0 },
   { 261, 262, 0 },
   { 273, 274, 6 },
   { 279, 281, 6 },
   { 287, 288, 0 },
   { 387, 288, 30 },
   { 748, 288, 33 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 165, 166, 0 },
   { 233, 234, 6 },
   { 235, 234, 0 },
   { 236, 237, 0 },
   { 261, 262, 0 },
   { 273, 274, 6 },
   { 279, 281, 6 },
   { 287, 288, 0 },
   { 387, 288, 30 },
   { 748, 288, 33 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 233, 234, 6 },
   { 235, 234, 0 },
   { 236, 237, 0 },
   { 261, 262, 0 },
   { 273, 274, 6 },
   { 279, 281, 6 },
   { 387, 288, 30 },
   { 748, 288, 33 },
   { 3518, 3519, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 233, 234, 6 },
   { 235, 234, 0 },
   { 236, 237, 0 },
   { 261, 262, 0 },
   { 268, 269, 6 },
   { 273, 274, 6 },
   { 279, 281, 6 },
   { 387, 288, 30 },
   { 748, 288, 33 },
   { 3518, 3519, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 168, 139, 0 },
   { 174, 176, 0 },
   { 233, 234, 6 },
   { 235, 234, 0 },
   { 236, 237, 0 },
   { 261, 262, 0 },
   { 273, 274, 6 },
   { 279, 281, 6 },
   { 387, 288, 30 },
   { 748, 288, 33 },
   { 3518, 3519, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 165, 166, 0 },
   { 233, 234, 6 },
   { 235, 234, 0 },
   { 236, 237, 0 },
   { 261, 262, 0 },
   { 273, 274, 6 },
   { 279, 281, 6 },
   { 387, 288, 30 },
   { 748, 288, 33 },
   { 3518, 3519, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 233, 234, 6 },
   { 235, 234, 0 },
   { 236, 237, 0 },
   { 261, 262, 0 },
   { 273, 274, 6 },
   { 279, 281, 6 },
   { 387, 288, 30 },
   { 748, 288, 33 },
   { 3518, 3519, 0 },
   { 3550, 3519, 0 },
   { 3551, 3521, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 233, 234, 6 },
   { 235, 234, 0 },
   { 236, 237, 0 },
   { 261, 262, 0 },
   { 268, 269, 6 },
   { 273, 274, 6 },
   { 279, 281, 6 },
   { 387, 288, 30 },
   { 748, 288, 33 },
   { 3518, 3519, 0 },
   { 3550, 3519, 0 },
   { 3551, 3521, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 168, 139, 0 },
   { 174, 176, 0 },
   { 233, 234, 6 },
   { 235, 234, 0 },
   { 236, 237, 0 },
   { 261, 262, 0 },
   { 273, 274, 6 },
   { 279, 281, 6 },
   { 387, 288, 30 },
   { 748, 288, 33 },
   { 3518, 3519, 0 },
   { 3550, 3519, 0 },
   { 3551, 3521, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 165, 166, 0 },
   { 233, 234, 6 },
   { 235, 234, 0 },
   { 236, 237, 0 },
   { 261, 262, 0 },
   { 273, 274, 6 },
   { 279, 281, 6 },
   { 387, 288, 30 },
   { 748, 288, 33 },
   { 3518, 3519, 0 },
   { 3550, 3519, 0 },
   { 3551, 3521, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 233, 234, 6 },
   { 235, 234, 0 },
   { 236, 237, 0 },
   { 387, 288, 30 },
   { 748, 288, 33 },
   { 3491, 387, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 233, 234, 6 },
   { 235, 234, 0 },
   { 236, 237, 0 },
   { 268, 269, 6 },
   { 387, 288, 30 },
   { 748, 288, 33 },
   { 3491, 387, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 168, 139, 0 },
   { 233, 234, 6 },
   { 235, 234, 0 },
   { 236, 237, 0 },
   { 387, 288, 30 },
   { 748, 288, 33 },
   { 3491, 387, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 165, 166, 0 },
   { 233, 234, 6 },
   { 235, 234, 0 },
   { 236, 237, 0 },
   { 387, 288, 30 },
   { 748, 288, 33 },
   { 3491, 387, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 217, 1517, 40 },
   { 3172, 111, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 217, 1517, 40 },
   { 1530, 217, 0 },
   { 3172, 111, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1525, 1527, 0 },
   { 217, 1517, 40 },
   { 3172, 111, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1529, 1528, 0 },
   { 217, 1517, 40 },
   { 3172, 111, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2690, 1257, 0 },
   { 2714, 1235, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1191, 1192, 0 },
   { 2714, 1235, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1105, 1106, 0 },
   { 2690, 1257, 0 },
   { 2714, 1235, 0 },
   { 3189, 1077, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1233, 1108, 0 },
   { 2714, 1235, 0 },
   { 3189, 1077, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1191, 1192, 0 },
   { 2714, 1235, 0 },
   { 3189, 1077, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1191, 1192, 0 },
   { 1210, 1212, 0 },
   { 2714, 1235, 0 },
   { 3189, 1077, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1122, 1055, 0 },
   { 2714, 1235, 0 },
   { 3189, 1077, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2714, 1235, 0 },
   { 3189, 1077, 0 },
   { 5535, 5538, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1226, 1131, 0 },
   { 2714, 1235, 0 },
   { 3189, 1077, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1243, 1108, 0 },
   { 2714, 1235, 0 },
   { 3189, 1077, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2675, 1049, 0 },
   { 2683, 1046, 0 },
   { 2714, 1235, 0 },
   { 3189, 1077, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2676, 1046, 0 },
   { 2684, 1049, 0 },
   { 2714, 1235, 0 },
   { 3189, 1077, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2673, 1055, 0 },
   { 2681, 1052, 0 },
   { 2714, 1235, 0 },
   { 3189, 1077, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2674, 1052, 0 },
   { 2682, 1055, 0 },
   { 2714, 1235, 0 },
   { 3189, 1077, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1091, 1092, 0 },
   { 2690, 1257, 0 },
   { 2714, 1235, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1191, 1192, 0 },
   { 2690, 1257, 0 },
   { 2714, 1235, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1163, 1162, 0 },
   { 1406, 1162, 0 },
   { 1410, 1162, 0 },
   { 1414, 1162, 0 },
   { 2714, 1235, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2714, 1235, 0 },
   { 5030, 5032, 116 },
   { 5047, 5032, 116 },
   { 5055, 5056, 0 },
   { 5069, 5071, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1171, 1172, 0 },
   { 2711, 1077, 0 },
   { 3200, 1077, 0 },
   { 3203, 1235, 0 },
   { 3206, 1235, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2321, 1077, 0 },
   { 2711, 1077, 0 },
   { 3200, 1077, 0 },
   { 3203, 1235, 0 },
   { 3206, 1235, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2315, 2316, 0 },
   { 2711, 1077, 0 },
   { 3200, 1077, 0 },
   { 3203, 1235, 0 },
   { 3206, 1235, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1097, 1098, 0 },
   { 1171, 1172, 0 },
   { 2711, 1077, 0 },
   { 3200, 1077, 0 },
   { 3203, 1235, 0 },
   { 3206, 1235, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1252, 1253, 0 },
   { 2711, 1077, 0 },
   { 3200, 1077, 0 },
   { 3203, 1235, 0 },
   { 3206, 1235, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1239, 1240, 0 },
   { 2711, 1077, 0 },
   { 3200, 1077, 0 },
   { 3203, 1235, 0 },
   { 3206, 1235, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1116, 1118, 0 },
   { 1126, 1127, 0 },
   { 2711, 1077, 0 },
   { 3200, 1077, 0 },
   { 3203, 1235, 0 },
   { 3206, 1235, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2711, 1077, 0 },
   { 3200, 1077, 0 },
   { 3203, 1235, 0 },
   { 3206, 1235, 0 },
   { 5559, 5564, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2321, 1077, 0 },
   { 2711, 1077, 0 },
   { 3200, 1077, 0 },
   { 3203, 1235, 0 },
   { 3206, 1235, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1250, 1251, 0 },
   { 2711, 1077, 0 },
   { 3200, 1077, 0 },
   { 3203, 1235, 0 },
   { 3206, 1235, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2315, 2316, 0 },
   { 2711, 1077, 0 },
   { 3200, 1077, 0 },
   { 3203, 1235, 0 },
   { 3206, 1235, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1095, 1096, 0 },
   { 2711, 1077, 0 },
   { 3200, 1077, 0 },
   { 3203, 1235, 0 },
   { 3206, 1235, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1088, 1078, 0 },
   { 1171, 1172, 0 },
   { 2711, 1077, 0 },
   { 3200, 1077, 0 },
   { 3203, 1235, 0 },
   { 3206, 1235, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1238, 1077, 0 },
   { 2711, 1077, 0 },
   { 3200, 1077, 0 },
   { 3203, 1235, 0 },
   { 3206, 1235, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1187, 1188, 0 },
   { 2711, 1077, 0 },
   { 3200, 1077, 0 },
   { 3203, 1235, 0 },
   { 3206, 1235, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1187, 1188, 0 },
   { 2711, 1077, 0 },
   { 3200, 1077, 0 },
   { 3203, 1235, 0 },
   { 3206, 1235, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1171, 1172, 0 },
   { 1187, 1188, 0 },
   { 2711, 1077, 0 },
   { 3200, 1077, 0 },
   { 3203, 1235, 0 },
   { 3206, 1235, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1187, 1188, 0 },
   { 2321, 1077, 0 },
   { 2711, 1077, 0 },
   { 3200, 1077, 0 },
   { 3203, 1235, 0 },
   { 3206, 1235, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1187, 1188, 0 },
   { 2315, 2316, 0 },
   { 2711, 1077, 0 },
   { 3200, 1077, 0 },
   { 3203, 1235, 0 },
   { 3206, 1235, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1187, 1188, 0 },
   { 1196, 1199, 0 },
   { 2711, 1077, 0 },
   { 3200, 1077, 0 },
   { 3203, 1235, 0 },
   { 3206, 1235, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2711, 1077, 0 },
   { 3200, 1077, 0 },
   { 3203, 1235, 0 },
   { 3206, 1235, 0 },
   { 5551, 5554, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2317, 1078, 0 },
   { 2711, 1077, 0 },
   { 3200, 1077, 0 },
   { 3203, 1235, 0 },
   { 3206, 1235, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2317, 1078, 0 },
   { 2711, 1077, 0 },
   { 3200, 1077, 0 },
   { 3203, 1235, 0 },
   { 3206, 1235, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1171, 1172, 0 },
   { 2317, 1078, 0 },
   { 2711, 1077, 0 },
   { 3200, 1077, 0 },
   { 3203, 1235, 0 },
   { 3206, 1235, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2317, 1078, 0 },
   { 2321, 1077, 0 },
   { 2711, 1077, 0 },
   { 3200, 1077, 0 },
   { 3203, 1235, 0 },
   { 3206, 1235, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2315, 2316, 0 },
   { 2317, 1078, 0 },
   { 2711, 1077, 0 },
   { 3200, 1077, 0 },
   { 3203, 1235, 0 },
   { 3206, 1235, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1248, 1249, 0 },
   { 2711, 1077, 0 },
   { 3200, 1077, 0 },
   { 3203, 1235, 0 },
   { 3206, 1235, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2322, 1077, 0 },
   { 2711, 1077, 0 },
   { 3200, 1077, 0 },
   { 3203, 1235, 0 },
   { 3206, 1235, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2322, 1077, 0 },
   { 2711, 1077, 0 },
   { 3200, 1077, 0 },
   { 3203, 1235, 0 },
   { 3206, 1235, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1171, 1172, 0 },
   { 2322, 1077, 0 },
   { 2711, 1077, 0 },
   { 3200, 1077, 0 },
   { 3203, 1235, 0 },
   { 3206, 1235, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2321, 1077, 0 },
   { 2322, 1077, 0 },
   { 2711, 1077, 0 },
   { 3200, 1077, 0 },
   { 3203, 1235, 0 },
   { 3206, 1235, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2315, 2316, 0 },
   { 2322, 1077, 0 },
   { 2711, 1077, 0 },
   { 3200, 1077, 0 },
   { 3203, 1235, 0 },
   { 3206, 1235, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2711, 1077, 0 },
   { 3200, 1077, 0 },
   { 3203, 1235, 0 },
   { 3206, 1235, 0 },
   { 5037, 5038, 116 },
   { 5044, 5045, 116 },
   { 5050, 5038, 116 },
   { 5054, 5045, 116 },
   { 5061, 5062, 0 },
   { 5066, 5067, 0 },
   { 5076, 5077, 0 },
   { 5082, 5083, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1173, 1174, 0 },
   { 2713, 1235, 0 },
   { 3192, 1235, 0 },
   { 3195, 1077, 0 },
   { 3198, 1077, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2319, 1235, 0 },
   { 2713, 1235, 0 },
   { 3192, 1235, 0 },
   { 3195, 1077, 0 },
   { 3198, 1077, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2323, 2324, 0 },
   { 2713, 1235, 0 },
   { 3192, 1235, 0 },
   { 3195, 1077, 0 },
   { 3198, 1077, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1101, 1102, 0 },
   { 1173, 1174, 0 },
   { 2713, 1235, 0 },
   { 3192, 1235, 0 },
   { 3195, 1077, 0 },
   { 3198, 1077, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1256, 1257, 0 },
   { 2713, 1235, 0 },
   { 3192, 1235, 0 },
   { 3195, 1077, 0 },
   { 3198, 1077, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1236, 1237, 0 },
   { 2713, 1235, 0 },
   { 3192, 1235, 0 },
   { 3195, 1077, 0 },
   { 3198, 1077, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2713, 1235, 0 },
   { 3192, 1235, 0 },
   { 3195, 1077, 0 },
   { 3198, 1077, 0 },
   { 5569, 5572, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1130, 1131, 0 },
   { 2713, 1235, 0 },
   { 3192, 1235, 0 },
   { 3195, 1077, 0 },
   { 3198, 1077, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2319, 1235, 0 },
   { 2713, 1235, 0 },
   { 3192, 1235, 0 },
   { 3195, 1077, 0 },
   { 3198, 1077, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1246, 1247, 0 },
   { 2713, 1235, 0 },
   { 3192, 1235, 0 },
   { 3195, 1077, 0 },
   { 3198, 1077, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2323, 2324, 0 },
   { 2713, 1235, 0 },
   { 3192, 1235, 0 },
   { 3195, 1077, 0 },
   { 3198, 1077, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1099, 1100, 0 },
   { 2713, 1235, 0 },
   { 3192, 1235, 0 },
   { 3195, 1077, 0 },
   { 3198, 1077, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1089, 1090, 0 },
   { 1173, 1174, 0 },
   { 2713, 1235, 0 },
   { 3192, 1235, 0 },
   { 3195, 1077, 0 },
   { 3198, 1077, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1234, 1235, 0 },
   { 2713, 1235, 0 },
   { 3192, 1235, 0 },
   { 3195, 1077, 0 },
   { 3198, 1077, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1189, 1190, 0 },
   { 2713, 1235, 0 },
   { 3192, 1235, 0 },
   { 3195, 1077, 0 },
   { 3198, 1077, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1189, 1190, 0 },
   { 2713, 1235, 0 },
   { 3192, 1235, 0 },
   { 3195, 1077, 0 },
   { 3198, 1077, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1173, 1174, 0 },
   { 1189, 1190, 0 },
   { 2713, 1235, 0 },
   { 3192, 1235, 0 },
   { 3195, 1077, 0 },
   { 3198, 1077, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1189, 1190, 0 },
   { 2319, 1235, 0 },
   { 2713, 1235, 0 },
   { 3192, 1235, 0 },
   { 3195, 1077, 0 },
   { 3198, 1077, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1189, 1190, 0 },
   { 2323, 2324, 0 },
   { 2713, 1235, 0 },
   { 3192, 1235, 0 },
   { 3195, 1077, 0 },
   { 3198, 1077, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1189, 1190, 0 },
   { 1205, 1206, 0 },
   { 2713, 1235, 0 },
   { 3192, 1235, 0 },
   { 3195, 1077, 0 },
   { 3198, 1077, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1121, 1046, 0 },
   { 1125, 1102, 0 },
   { 2713, 1235, 0 },
   { 3192, 1235, 0 },
   { 3195, 1077, 0 },
   { 3198, 1077, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2713, 1235, 0 },
   { 3192, 1235, 0 },
   { 3195, 1077, 0 },
   { 3198, 1077, 0 },
   { 5565, 5568, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2325, 1090, 0 },
   { 2713, 1235, 0 },
   { 3192, 1235, 0 },
   { 3195, 1077, 0 },
   { 3198, 1077, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2325, 1090, 0 },
   { 2713, 1235, 0 },
   { 3192, 1235, 0 },
   { 3195, 1077, 0 },
   { 3198, 1077, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1173, 1174, 0 },
   { 2325, 1090, 0 },
   { 2713, 1235, 0 },
   { 3192, 1235, 0 },
   { 3195, 1077, 0 },
   { 3198, 1077, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2319, 1235, 0 },
   { 2325, 1090, 0 },
   { 2713, 1235, 0 },
   { 3192, 1235, 0 },
   { 3195, 1077, 0 },
   { 3198, 1077, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2323, 2324, 0 },
   { 2325, 1090, 0 },
   { 2713, 1235, 0 },
   { 3192, 1235, 0 },
   { 3195, 1077, 0 },
   { 3198, 1077, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1244, 1245, 0 },
   { 2713, 1235, 0 },
   { 3192, 1235, 0 },
   { 3195, 1077, 0 },
   { 3198, 1077, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2320, 1235, 0 },
   { 2713, 1235, 0 },
   { 3192, 1235, 0 },
   { 3195, 1077, 0 },
   { 3198, 1077, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2320, 1235, 0 },
   { 2713, 1235, 0 },
   { 3192, 1235, 0 },
   { 3195, 1077, 0 },
   { 3198, 1077, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1173, 1174, 0 },
   { 2320, 1235, 0 },
   { 2713, 1235, 0 },
   { 3192, 1235, 0 },
   { 3195, 1077, 0 },
   { 3198, 1077, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2319, 1235, 0 },
   { 2320, 1235, 0 },
   { 2713, 1235, 0 },
   { 3192, 1235, 0 },
   { 3195, 1077, 0 },
   { 3198, 1077, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2320, 1235, 0 },
   { 2323, 2324, 0 },
   { 2713, 1235, 0 },
   { 3192, 1235, 0 },
   { 3195, 1077, 0 },
   { 3198, 1077, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2713, 1235, 0 },
   { 3192, 1235, 0 },
   { 3195, 1077, 0 },
   { 3198, 1077, 0 },
   { 5035, 5036, 116 },
   { 5041, 5043, 116 },
   { 5049, 5036, 116 },
   { 5053, 5043, 116 },
   { 5059, 5060, 0 },
   { 5064, 5065, 0 },
   { 5074, 5075, 0 },
   { 5079, 5081, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2689, 1253, 0 },
   { 2715, 1077, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1193, 1194, 0 },
   { 2715, 1077, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1103, 1104, 0 },
   { 2689, 1253, 0 },
   { 2715, 1077, 0 },
   { 3188, 1235, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1232, 1110, 0 },
   { 2715, 1077, 0 },
   { 3188, 1235, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1193, 1194, 0 },
   { 2715, 1077, 0 },
   { 3188, 1235, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1193, 1194, 0 },
   { 1218, 1219, 0 },
   { 2715, 1077, 0 },
   { 3188, 1235, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1123, 1052, 0 },
   { 2715, 1077, 0 },
   { 3188, 1235, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2715, 1077, 0 },
   { 3188, 1235, 0 },
   { 5539, 5542, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1227, 760, 0 },
   { 2715, 1077, 0 },
   { 3188, 1235, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1242, 1110, 0 },
   { 2715, 1077, 0 },
   { 3188, 1235, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2679, 1049, 0 },
   { 2687, 1046, 0 },
   { 2715, 1077, 0 },
   { 3188, 1235, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2680, 1046, 0 },
   { 2688, 1049, 0 },
   { 2715, 1077, 0 },
   { 3188, 1235, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2677, 1055, 0 },
   { 2685, 1052, 0 },
   { 2715, 1077, 0 },
   { 3188, 1235, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2678, 1052, 0 },
   { 2686, 1055, 0 },
   { 2715, 1077, 0 },
   { 3188, 1235, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1093, 1094, 0 },
   { 2689, 1253, 0 },
   { 2715, 1077, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1193, 1194, 0 },
   { 2689, 1253, 0 },
   { 2715, 1077, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1152, 1151, 0 },
   { 1407, 1391, 0 },
   { 1411, 1391, 0 },
   { 1415, 1391, 0 },
   { 2715, 1077, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2715, 1077, 0 },
   { 5033, 5034, 116 },
   { 5048, 5034, 116 },
   { 5057, 5058, 0 },
   { 5072, 5073, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1335, 32, 0 },
   { 1502, 1254, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1335, 32, 0 },
   { 1507, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1335, 32, 0 },
   { 1352, 1283, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1335, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1335, 32, 0 },
   { 1502, 1254, 0 },
   { 3173, 217, 38 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1335, 32, 0 },
   { 1507, 32, 0 },
   { 3173, 217, 38 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1335, 32, 0 },
   { 1571, 1572, 0 },
   { 3173, 217, 38 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1272, 1275, 0 },
   { 1335, 32, 0 },
   { 3173, 217, 38 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1335, 32, 0 },
   { 1352, 1283, 0 },
   { 3173, 217, 38 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1335, 32, 0 },
   { 3173, 217, 38 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1335, 32, 0 },
   { 1517, 217, 38 },
   { 1521, 1522, 38 },
   { 3173, 217, 38 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1335, 32, 0 },
   { 1502, 1254, 0 },
   { 1507, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1335, 32, 0 },
   { 1352, 1283, 0 },
   { 1502, 1254, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1335, 32, 0 },
   { 1502, 1254, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1335, 32, 0 },
   { 1352, 1283, 0 },
   { 1507, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1335, 32, 0 },
   { 1507, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1268, 1266, 0 },
   { 1335, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1335, 32, 0 },
   { 1352, 1283, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1336, 32, 0 },
   { 1513, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1336, 32, 0 },
   { 1511, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1336, 32, 0 },
   { 1346, 1281, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1336, 32, 0 },
   { 1513, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1336, 32, 0 },
   { 1511, 103, 0 },
   { 1515, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1336, 32, 0 },
   { 1569, 1570, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1336, 32, 0 },
   { 1519, 217, 38 },
   { 1524, 1522, 38 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1336, 32, 0 },
   { 1346, 1281, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1336, 32, 0 },
   { 1511, 103, 0 },
   { 1513, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1336, 32, 0 },
   { 1346, 1281, 0 },
   { 1513, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1336, 32, 0 },
   { 1346, 1281, 0 },
   { 1511, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1262, 1263, 0 },
   { 1336, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 101, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5900, 5903, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2146, 6, 0 },
   { 2177, 11, 0 },
   { 2207, 16, 0 },
   { 2237, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 108, 106, 0 },
   { 3170, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 107, 106, 0 },
   { 3170, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3170, 32, 0 },
   { 5904, 5907, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1222, 1223, 0 },
   { 2707, 1235, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 200, 202, 0 },
   { 2707, 1235, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1107, 1108, 0 },
   { 2707, 1235, 0 },
   { 3056, 760, 0 },
   { 3059, 1131, 0 },
   { 3208, 1077, 0 },
   { 3808, 3809, 81 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1111, 1108, 0 },
   { 2707, 1235, 0 },
   { 3056, 760, 0 },
   { 3059, 1131, 0 },
   { 3208, 1077, 0 },
   { 3808, 3809, 81 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1222, 1223, 0 },
   { 2707, 1235, 0 },
   { 3056, 760, 0 },
   { 3059, 1131, 0 },
   { 3208, 1077, 0 },
   { 3808, 3809, 81 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 200, 202, 0 },
   { 1421, 1422, 0 },
   { 1426, 1425, 0 },
   { 1443, 1444, 0 },
   { 1448, 1447, 0 },
   { 1465, 1466, 0 },
   { 1470, 1469, 0 },
   { 1485, 1486, 0 },
   { 1490, 1489, 0 },
   { 2707, 1235, 0 },
   { 3056, 760, 0 },
   { 3059, 1131, 0 },
   { 3208, 1077, 0 },
   { 3808, 3809, 81 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2707, 1235, 0 },
   { 3056, 760, 0 },
   { 3059, 1131, 0 },
   { 3208, 1077, 0 },
   { 3808, 3809, 81 },
   { 5543, 5546, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1230, 1131, 0 },
   { 2707, 1235, 0 },
   { 3056, 760, 0 },
   { 3059, 1131, 0 },
   { 3208, 1077, 0 },
   { 3808, 3809, 81 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1429, 1422, 0 },
   { 1431, 1425, 0 },
   { 1451, 1444, 0 },
   { 1453, 1447, 0 },
   { 1473, 1466, 0 },
   { 1474, 1469, 0 },
   { 1493, 1486, 0 },
   { 1495, 1489, 0 },
   { 2707, 1235, 0 },
   { 3056, 760, 0 },
   { 3059, 1131, 0 },
   { 3208, 1077, 0 },
   { 3808, 3809, 81 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1434, 1422, 0 },
   { 1436, 1425, 0 },
   { 1456, 1444, 0 },
   { 1458, 1447, 0 },
   { 1477, 1466, 0 },
   { 1478, 1469, 0 },
   { 1498, 1486, 0 },
   { 1500, 1489, 0 },
   { 2707, 1235, 0 },
   { 3056, 760, 0 },
   { 3059, 1131, 0 },
   { 3208, 1077, 0 },
   { 3808, 3809, 81 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2707, 1235, 0 },
   { 3056, 760, 0 },
   { 3059, 1131, 0 },
   { 3208, 1077, 0 },
   { 3808, 3809, 81 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2707, 1235, 0 },
   { 3056, 760, 0 },
   { 3059, 1131, 0 },
   { 3208, 1077, 0 },
   { 3808, 3809, 81 },
   { 4393, 4398, 115 },
   { 4440, 4445, 115 },
   { 4486, 4491, 115 },
   { 4553, 4558, 116 },
   { 4604, 4609, 116 },
   { 4682, 4687, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2707, 1235, 0 },
   { 3056, 760, 0 },
   { 3059, 1131, 0 },
   { 3208, 1077, 0 },
   { 3808, 3809, 81 },
   { 4736, 4739, 115 },
   { 4776, 4780, 115 },
   { 4818, 4823, 115 },
   { 4882, 4887, 116 },
   { 4927, 4932, 116 },
   { 4999, 5004, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2707, 1235, 0 },
   { 3056, 760, 0 },
   { 3059, 1131, 0 },
   { 3208, 1077, 0 },
   { 3808, 3809, 81 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2707, 1235, 0 },
   { 3056, 760, 0 },
   { 3059, 1131, 0 },
   { 3208, 1077, 0 },
   { 3808, 3809, 81 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2707, 1235, 0 },
   { 3056, 760, 0 },
   { 3059, 1131, 0 },
   { 3208, 1077, 0 },
   { 3808, 3809, 81 },
   { 3893, 3890, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2707, 1235, 0 },
   { 3056, 760, 0 },
   { 3059, 1131, 0 },
   { 3208, 1077, 0 },
   { 3808, 3809, 81 },
   { 3889, 3890, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2707, 1235, 0 },
   { 3056, 760, 0 },
   { 3059, 1131, 0 },
   { 3208, 1077, 0 },
   { 3808, 3809, 81 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2707, 1235, 0 },
   { 3056, 760, 0 },
   { 3059, 1131, 0 },
   { 3208, 1077, 0 },
   { 3808, 3809, 81 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2707, 1235, 0 },
   { 3056, 760, 0 },
   { 3059, 1131, 0 },
   { 3208, 1077, 0 },
   { 3808, 3809, 81 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2707, 1235, 0 },
   { 3056, 760, 0 },
   { 3059, 1131, 0 },
   { 3208, 1077, 0 },
   { 3808, 3809, 81 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2707, 1235, 0 },
   { 3056, 760, 0 },
   { 3059, 1131, 0 },
   { 3208, 1077, 0 },
   { 3808, 3809, 81 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2707, 1235, 0 },
   { 3056, 760, 0 },
   { 3059, 1131, 0 },
   { 3208, 1077, 0 },
   { 3808, 3809, 81 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 200, 202, 0 },
   { 1222, 1223, 0 },
   { 2707, 1235, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1389, 1162, 0 },
   { 1394, 1162, 0 },
   { 1398, 1162, 0 },
   { 1402, 1162, 0 },
   { 2707, 1235, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2707, 1235, 0 },
   { 4375, 4377, 115 },
   { 4432, 4377, 115 },
   { 4477, 4377, 115 },
   { 4524, 4525, 116 },
   { 4538, 4540, 116 },
   { 4589, 4525, 116 },
   { 4597, 4540, 116 },
   { 4641, 4642, 0 },
   { 4654, 4655, 0 },
   { 4667, 4669, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2707, 1235, 0 },
   { 4720, 4722, 115 },
   { 4768, 4722, 115 },
   { 4810, 4722, 115 },
   { 4854, 4855, 116 },
   { 4867, 4869, 116 },
   { 4912, 4855, 116 },
   { 4920, 4869, 116 },
   { 4959, 4960, 0 },
   { 4972, 4973, 0 },
   { 4984, 4986, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 2708, 1077, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 203, 204, 0 },
   { 2708, 1077, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1109, 1110, 0 },
   { 2708, 1077, 0 },
   { 3057, 1131, 0 },
   { 3058, 760, 0 },
   { 3207, 1235, 0 },
   { 3805, 3807, 81 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1112, 1110, 0 },
   { 2708, 1077, 0 },
   { 3057, 1131, 0 },
   { 3058, 760, 0 },
   { 3207, 1235, 0 },
   { 3805, 3807, 81 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1224, 1225, 0 },
   { 2708, 1077, 0 },
   { 3057, 1131, 0 },
   { 3058, 760, 0 },
   { 3207, 1235, 0 },
   { 3805, 3807, 81 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 203, 204, 0 },
   { 1423, 1422, 0 },
   { 1424, 1425, 0 },
   { 1445, 1444, 0 },
   { 1446, 1447, 0 },
   { 1467, 1466, 0 },
   { 1468, 1469, 0 },
   { 1487, 1486, 0 },
   { 1488, 1489, 0 },
   { 2708, 1077, 0 },
   { 3057, 1131, 0 },
   { 3058, 760, 0 },
   { 3207, 1235, 0 },
   { 3805, 3807, 81 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2708, 1077, 0 },
   { 3057, 1131, 0 },
   { 3058, 760, 0 },
   { 3207, 1235, 0 },
   { 3805, 3807, 81 },
   { 5547, 5550, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1231, 760, 0 },
   { 2708, 1077, 0 },
   { 3057, 1131, 0 },
   { 3058, 760, 0 },
   { 3207, 1235, 0 },
   { 3805, 3807, 81 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1428, 1425, 0 },
   { 1432, 1422, 0 },
   { 1450, 1447, 0 },
   { 1454, 1444, 0 },
   { 1472, 1469, 0 },
   { 1475, 1466, 0 },
   { 1492, 1489, 0 },
   { 1496, 1486, 0 },
   { 2708, 1077, 0 },
   { 3057, 1131, 0 },
   { 3058, 760, 0 },
   { 3207, 1235, 0 },
   { 3805, 3807, 81 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1433, 1425, 0 },
   { 1437, 1422, 0 },
   { 1455, 1447, 0 },
   { 1459, 1444, 0 },
   { 1476, 1469, 0 },
   { 1479, 1466, 0 },
   { 1497, 1489, 0 },
   { 1501, 1486, 0 },
   { 2708, 1077, 0 },
   { 3057, 1131, 0 },
   { 3058, 760, 0 },
   { 3207, 1235, 0 },
   { 3805, 3807, 81 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2708, 1077, 0 },
   { 3057, 1131, 0 },
   { 3058, 760, 0 },
   { 3207, 1235, 0 },
   { 3805, 3807, 81 },
   { 4399, 4402, 115 },
   { 4446, 4449, 115 },
   { 4492, 4495, 115 },
   { 4559, 4562, 116 },
   { 4610, 4613, 116 },
   { 4688, 4691, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2708, 1077, 0 },
   { 3057, 1131, 0 },
   { 3058, 760, 0 },
   { 3207, 1235, 0 },
   { 3805, 3807, 81 },
   { 4740, 4743, 115 },
   { 4781, 4784, 115 },
   { 4824, 4827, 115 },
   { 4888, 4891, 116 },
   { 4933, 4936, 116 },
   { 5005, 5008, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2708, 1077, 0 },
   { 3057, 1131, 0 },
   { 3058, 760, 0 },
   { 3207, 1235, 0 },
   { 3805, 3807, 81 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2708, 1077, 0 },
   { 3057, 1131, 0 },
   { 3058, 760, 0 },
   { 3207, 1235, 0 },
   { 3805, 3807, 81 },
   { 3892, 3888, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2708, 1077, 0 },
   { 3057, 1131, 0 },
   { 3058, 760, 0 },
   { 3207, 1235, 0 },
   { 3805, 3807, 81 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2708, 1077, 0 },
   { 3057, 1131, 0 },
   { 3058, 760, 0 },
   { 3207, 1235, 0 },
   { 3805, 3807, 81 },
   { 3883, 3888, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2708, 1077, 0 },
   { 3057, 1131, 0 },
   { 3058, 760, 0 },
   { 3207, 1235, 0 },
   { 3805, 3807, 81 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2708, 1077, 0 },
   { 3057, 1131, 0 },
   { 3058, 760, 0 },
   { 3207, 1235, 0 },
   { 3805, 3807, 81 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2708, 1077, 0 },
   { 3057, 1131, 0 },
   { 3058, 760, 0 },
   { 3207, 1235, 0 },
   { 3805, 3807, 81 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2708, 1077, 0 },
   { 3057, 1131, 0 },
   { 3058, 760, 0 },
   { 3207, 1235, 0 },
   { 3805, 3807, 81 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2708, 1077, 0 },
   { 3057, 1131, 0 },
   { 3058, 760, 0 },
   { 3207, 1235, 0 },
   { 3805, 3807, 81 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2708, 1077, 0 },
   { 3057, 1131, 0 },
   { 3058, 760, 0 },
   { 3207, 1235, 0 },
   { 3805, 3807, 81 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 203, 204, 0 },
   { 1224, 1225, 0 },
   { 2708, 1077, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1390, 1391, 0 },
   { 1395, 1391, 0 },
   { 1399, 1391, 0 },
   { 1403, 1391, 0 },
   { 2708, 1077, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2708, 1077, 0 },
   { 4378, 4379, 115 },
   { 4433, 4379, 115 },
   { 4478, 4379, 115 },
   { 4526, 4527, 116 },
   { 4541, 4542, 116 },
   { 4590, 4527, 116 },
   { 4598, 4542, 116 },
   { 4643, 4644, 0 },
   { 4656, 4657, 0 },
   { 4670, 4671, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2708, 1077, 0 },
   { 4723, 4724, 115 },
   { 4769, 4724, 115 },
   { 4811, 4724, 115 },
   { 4856, 4857, 116 },
   { 4870, 4871, 116 },
   { 4913, 4857, 116 },
   { 4921, 4871, 116 },
   { 4961, 4962, 0 },
   { 4974, 4975, 0 },
   { 4987, 4988, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1337, 32, 0 },
   { 1503, 1504, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1337, 32, 0 },
   { 1508, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1337, 32, 0 },
   { 1356, 1303, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1337, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1337, 32, 0 },
   { 1503, 1504, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1337, 32, 0 },
   { 1508, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1337, 32, 0 },
   { 1356, 1303, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1337, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1337, 32, 0 },
   { 4016, 4014, 103 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1337, 32, 0 },
   { 1503, 1504, 0 },
   { 1508, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1337, 32, 0 },
   { 1356, 1303, 0 },
   { 1503, 1504, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1337, 32, 0 },
   { 1503, 1504, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1337, 32, 0 },
   { 1356, 1303, 0 },
   { 1508, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1337, 32, 0 },
   { 1508, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1337, 32, 0 },
   { 1356, 1303, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1338, 32, 0 },
   { 1514, 106, 39 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1338, 32, 0 },
   { 1512, 106, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1338, 32, 0 },
   { 1350, 1301, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1338, 32, 0 },
   { 1514, 106, 39 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1338, 32, 0 },
   { 1512, 106, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1338, 32, 0 },
   { 4018, 4014, 103 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1338, 32, 0 },
   { 1350, 1301, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1338, 32, 0 },
   { 1512, 106, 0 },
   { 1514, 106, 39 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1338, 32, 0 },
   { 1350, 1301, 0 },
   { 1514, 106, 39 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1338, 32, 0 },
   { 1350, 1301, 0 },
   { 1512, 106, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1787, 11, 0 },
   { 1895, 16, 0 },
   { 1980, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4242, 3111, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3131, 3132, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1785, 11, 0 },
   { 1893, 16, 0 },
   { 1978, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1811, 1812, 0 },
   { 1821, 1822, 0 },
   { 1839, 1840, 0 },
   { 1916, 1917, 0 },
   { 1926, 1927, 0 },
   { 2001, 2002, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2012, 2013, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1789, 11, 0 },
   { 1897, 16, 0 },
   { 1982, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4241, 3111, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3133, 3134, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1788, 11, 0 },
   { 1896, 16, 0 },
   { 1981, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1809, 1810, 0 },
   { 1819, 1820, 0 },
   { 1837, 1838, 0 },
   { 1914, 1915, 0 },
   { 1924, 1925, 0 },
   { 1999, 2000, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2010, 2011, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1805, 1806, 0 },
   { 1824, 1806, 0 },
   { 1842, 1806, 0 },
   { 1912, 1823, 0 },
   { 1928, 1823, 0 },
   { 1997, 1841, 0 },
   { 4257, 11, 0 },
   { 4258, 16, 0 },
   { 4259, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4240, 1528, 0 },
   { 4257, 11, 0 },
   { 4258, 16, 0 },
   { 4259, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4257, 11, 0 },
   { 4258, 16, 0 },
   { 4259, 21, 0 },
   { 5962, 5964, 121 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4257, 11, 0 },
   { 4258, 16, 0 },
   { 4259, 21, 0 },
   { 5946, 5948, 121 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4257, 11, 0 },
   { 4258, 16, 0 },
   { 4259, 21, 0 },
   { 5933, 5934, 121 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1807, 1808, 0 },
   { 1826, 1808, 0 },
   { 1844, 1808, 0 },
   { 1913, 1825, 0 },
   { 1929, 1825, 0 },
   { 1998, 1843, 0 },
   { 4257, 11, 0 },
   { 4258, 16, 0 },
   { 4259, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1803, 1804, 0 },
   { 1814, 11, 0 },
   { 1832, 11, 0 },
   { 1910, 1911, 0 },
   { 1919, 16, 0 },
   { 1995, 1996, 0 },
   { 3161, 16, 0 },
   { 4257, 11, 0 },
   { 4258, 16, 0 },
   { 4259, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3154, 16, 0 },
   { 4257, 11, 0 },
   { 4258, 16, 0 },
   { 4259, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3159, 2006, 0 },
   { 4257, 11, 0 },
   { 4258, 16, 0 },
   { 4259, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3160, 2003, 0 },
   { 4257, 11, 0 },
   { 4258, 16, 0 },
   { 4259, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2004, 2005, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3148, 1404, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5965, 5967, 121 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5949, 5951, 121 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5935, 5937, 121 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2007, 2008, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3137, 11, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3136, 1257, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1069, 1070, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1072, 1073, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5908, 5911, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1051, 1052, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2730, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1045, 1046, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1048, 1049, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1054, 1055, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1057, 1058, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1060, 1061, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1063, 1064, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1066, 1067, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 291, 0, 0 },
   { 466, 467, 14 },
   { 541, 542, 16 },
   { 607, 608, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 291, 0, 0 },
   { 466, 467, 14 },
   { 541, 542, 16 },
   { 607, 608, 18 },
   { 685, 687, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 291, 0, 0 },
   { 294, 296, 0 },
   { 470, 472, 14 },
   { 543, 545, 16 },
   { 611, 613, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 289, 0, 0 },
   { 290, 3, 0 },
   { 291, 0, 0 },
   { 294, 296, 0 },
   { 470, 472, 14 },
   { 543, 545, 16 },
   { 611, 613, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 291, 0, 0 },
   { 294, 296, 0 },
   { 466, 467, 14 },
   { 470, 472, 14 },
   { 541, 542, 16 },
   { 543, 545, 16 },
   { 607, 608, 18 },
   { 611, 613, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 291, 0, 0 },
   { 480, 483, 14 },
   { 552, 554, 16 },
   { 621, 624, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 289, 0, 0 },
   { 290, 3, 0 },
   { 291, 0, 0 },
   { 480, 483, 14 },
   { 552, 554, 16 },
   { 621, 624, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 291, 0, 0 },
   { 466, 467, 14 },
   { 480, 483, 14 },
   { 541, 542, 16 },
   { 552, 554, 16 },
   { 607, 608, 18 },
   { 621, 624, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 291, 0, 0 },
   { 292, 264, 0 },
   { 466, 467, 14 },
   { 541, 542, 16 },
   { 607, 608, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 291, 0, 0 },
   { 292, 264, 0 },
   { 466, 467, 14 },
   { 541, 542, 16 },
   { 607, 608, 18 },
   { 685, 687, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 291, 0, 0 },
   { 292, 264, 0 },
   { 294, 296, 0 },
   { 470, 472, 14 },
   { 543, 545, 16 },
   { 611, 613, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 289, 0, 0 },
   { 290, 3, 0 },
   { 291, 0, 0 },
   { 292, 264, 0 },
   { 294, 296, 0 },
   { 470, 472, 14 },
   { 543, 545, 16 },
   { 611, 613, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 291, 0, 0 },
   { 292, 264, 0 },
   { 294, 296, 0 },
   { 466, 467, 14 },
   { 470, 472, 14 },
   { 541, 542, 16 },
   { 543, 545, 16 },
   { 607, 608, 18 },
   { 611, 613, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 291, 0, 0 },
   { 292, 264, 0 },
   { 480, 483, 14 },
   { 552, 554, 16 },
   { 621, 624, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 289, 0, 0 },
   { 290, 3, 0 },
   { 291, 0, 0 },
   { 292, 264, 0 },
   { 480, 483, 14 },
   { 552, 554, 16 },
   { 621, 624, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 291, 0, 0 },
   { 292, 264, 0 },
   { 466, 467, 14 },
   { 480, 483, 14 },
   { 541, 542, 16 },
   { 552, 554, 16 },
   { 607, 608, 18 },
   { 621, 624, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 291, 0, 0 },
   { 294, 296, 0 },
   { 470, 472, 14 },
   { 476, 478, 14 },
   { 543, 545, 16 },
   { 548, 550, 16 },
   { 611, 613, 18 },
   { 617, 619, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 289, 0, 0 },
   { 290, 3, 0 },
   { 291, 0, 0 },
   { 294, 296, 0 },
   { 470, 472, 14 },
   { 476, 478, 14 },
   { 543, 545, 16 },
   { 548, 550, 16 },
   { 611, 613, 18 },
   { 617, 619, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 291, 0, 0 },
   { 294, 296, 0 },
   { 466, 467, 14 },
   { 470, 472, 14 },
   { 476, 478, 14 },
   { 541, 542, 16 },
   { 543, 545, 16 },
   { 548, 550, 16 },
   { 607, 608, 18 },
   { 611, 613, 18 },
   { 617, 619, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 291, 0, 0 },
   { 480, 483, 14 },
   { 552, 554, 16 },
   { 621, 624, 18 },
   { 681, 683, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 289, 0, 0 },
   { 290, 3, 0 },
   { 291, 0, 0 },
   { 480, 483, 14 },
   { 552, 554, 16 },
   { 621, 624, 18 },
   { 681, 683, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 291, 0, 0 },
   { 466, 467, 14 },
   { 480, 483, 14 },
   { 541, 542, 16 },
   { 552, 554, 16 },
   { 607, 608, 18 },
   { 621, 624, 18 },
   { 681, 683, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2353, 1077, 0 },
   { 2709, 1077, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2346, 1077, 0 },
   { 2709, 1077, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2334, 2335, 0 },
   { 2709, 1077, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2353, 1077, 0 },
   { 2709, 1077, 0 },
   { 3216, 1235, 0 },
   { 3810, 3807, 81 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2709, 1077, 0 },
   { 3216, 1235, 0 },
   { 3810, 3807, 81 },
   { 5593, 5596, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2346, 1077, 0 },
   { 2709, 1077, 0 },
   { 3216, 1235, 0 },
   { 3810, 3807, 81 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2346, 1077, 0 },
   { 2398, 2399, 0 },
   { 2709, 1077, 0 },
   { 3216, 1235, 0 },
   { 3810, 3807, 81 },
   { 3852, 1077, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2334, 2335, 0 },
   { 2709, 1077, 0 },
   { 3216, 1235, 0 },
   { 3810, 3807, 81 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2334, 2335, 0 },
   { 2375, 2377, 0 },
   { 2709, 1077, 0 },
   { 3216, 1235, 0 },
   { 3810, 3807, 81 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2709, 1077, 0 },
   { 3216, 1235, 0 },
   { 3810, 3807, 81 },
   { 4750, 4755, 115 },
   { 4791, 4796, 115 },
   { 4835, 4841, 115 },
   { 4897, 4901, 116 },
   { 4943, 4948, 116 },
   { 5014, 5018, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2709, 1077, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2709, 1077, 0 },
   { 3217, 1077, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2353, 1077, 0 },
   { 2709, 1077, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2346, 1077, 0 },
   { 2709, 1077, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2334, 2335, 0 },
   { 2709, 1077, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2355, 1077, 0 },
   { 2709, 1077, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2355, 1077, 0 },
   { 2709, 1077, 0 },
   { 3217, 1077, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2353, 1077, 0 },
   { 2355, 1077, 0 },
   { 2709, 1077, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2346, 1077, 0 },
   { 2355, 1077, 0 },
   { 2709, 1077, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2334, 2335, 0 },
   { 2355, 1077, 0 },
   { 2709, 1077, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2709, 1077, 0 },
   { 3217, 1077, 0 },
   { 5589, 5592, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2336, 1085, 0 },
   { 2709, 1077, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2336, 1085, 0 },
   { 2709, 1077, 0 },
   { 3217, 1077, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2336, 1085, 0 },
   { 2353, 1077, 0 },
   { 2709, 1077, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2336, 1085, 0 },
   { 2346, 1077, 0 },
   { 2709, 1077, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2334, 2335, 0 },
   { 2336, 1085, 0 },
   { 2709, 1077, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2336, 1085, 0 },
   { 2379, 2381, 0 },
   { 2709, 1077, 0 },
   { 3217, 1077, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2347, 1077, 0 },
   { 2709, 1077, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2347, 1077, 0 },
   { 2709, 1077, 0 },
   { 3217, 1077, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2347, 1077, 0 },
   { 2353, 1077, 0 },
   { 2709, 1077, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2346, 1077, 0 },
   { 2347, 1077, 0 },
   { 2709, 1077, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2334, 2335, 0 },
   { 2347, 1077, 0 },
   { 2709, 1077, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2347, 1077, 0 },
   { 2400, 2401, 0 },
   { 2709, 1077, 0 },
   { 3217, 1077, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2709, 1077, 0 },
   { 3217, 1077, 0 },
   { 4744, 4749, 115 },
   { 4785, 4790, 115 },
   { 4828, 4834, 115 },
   { 4892, 4896, 116 },
   { 4937, 4942, 116 },
   { 5009, 5013, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2709, 1077, 0 },
   { 4727, 4728, 115 },
   { 4734, 4735, 115 },
   { 4771, 4728, 115 },
   { 4775, 4735, 115 },
   { 4813, 4728, 115 },
   { 4817, 4735, 115 },
   { 4860, 4861, 116 },
   { 4865, 4866, 116 },
   { 4874, 4875, 116 },
   { 4880, 4881, 116 },
   { 4915, 4861, 116 },
   { 4918, 4866, 116 },
   { 4923, 4875, 116 },
   { 4926, 4881, 116 },
   { 4965, 4966, 0 },
   { 4970, 4971, 0 },
   { 4978, 4979, 0 },
   { 4982, 4983, 0 },
   { 4991, 4992, 0 },
   { 4997, 4998, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2356, 1235, 0 },
   { 2710, 1235, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2338, 1235, 0 },
   { 2710, 1235, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2348, 2349, 0 },
   { 2710, 1235, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2356, 1235, 0 },
   { 2710, 1235, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2710, 1235, 0 },
   { 5601, 5604, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2338, 1235, 0 },
   { 2710, 1235, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2338, 1235, 0 },
   { 2383, 2385, 0 },
   { 2710, 1235, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2348, 2349, 0 },
   { 2710, 1235, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2348, 2349, 0 },
   { 2402, 2403, 0 },
   { 2710, 1235, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2710, 1235, 0 },
   { 4762, 4767, 115 },
   { 4803, 4808, 115 },
   { 4848, 4853, 115 },
   { 4907, 4911, 116 },
   { 4954, 4958, 116 },
   { 5024, 5028, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2710, 1235, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2356, 1235, 0 },
   { 2710, 1235, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2338, 1235, 0 },
   { 2710, 1235, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2348, 2349, 0 },
   { 2710, 1235, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2357, 1235, 0 },
   { 2710, 1235, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2356, 1235, 0 },
   { 2357, 1235, 0 },
   { 2710, 1235, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2338, 1235, 0 },
   { 2357, 1235, 0 },
   { 2710, 1235, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2348, 2349, 0 },
   { 2357, 1235, 0 },
   { 2710, 1235, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2710, 1235, 0 },
   { 5597, 5600, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2350, 2351, 0 },
   { 2710, 1235, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2350, 2351, 0 },
   { 2356, 1235, 0 },
   { 2710, 1235, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2338, 1235, 0 },
   { 2350, 2351, 0 },
   { 2710, 1235, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2348, 2349, 0 },
   { 2350, 2351, 0 },
   { 2710, 1235, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2350, 2351, 0 },
   { 2404, 2405, 0 },
   { 2710, 1235, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2339, 1235, 0 },
   { 2710, 1235, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2339, 1235, 0 },
   { 2356, 1235, 0 },
   { 2710, 1235, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2338, 1235, 0 },
   { 2339, 1235, 0 },
   { 2710, 1235, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2339, 1235, 0 },
   { 2348, 2349, 0 },
   { 2710, 1235, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2339, 1235, 0 },
   { 2387, 2389, 0 },
   { 2710, 1235, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2710, 1235, 0 },
   { 4756, 4761, 115 },
   { 4797, 4802, 115 },
   { 4842, 4847, 115 },
   { 4902, 4906, 116 },
   { 4949, 4953, 116 },
   { 5019, 5023, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2710, 1235, 0 },
   { 4725, 4726, 115 },
   { 4731, 4733, 115 },
   { 4770, 4726, 115 },
   { 4774, 4733, 115 },
   { 4812, 4726, 115 },
   { 4816, 4733, 115 },
   { 4858, 4859, 116 },
   { 4863, 4864, 116 },
   { 4872, 4873, 116 },
   { 4877, 4879, 116 },
   { 4914, 4859, 116 },
   { 4917, 4864, 116 },
   { 4922, 4873, 116 },
   { 4925, 4879, 116 },
   { 4963, 4964, 0 },
   { 4968, 4969, 0 },
   { 4976, 4977, 0 },
   { 4980, 4981, 0 },
   { 4989, 4990, 0 },
   { 4994, 4996, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2828, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1339, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1339, 32, 0 },
   { 1354, 1293, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1339, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1339, 32, 0 },
   { 1340, 61, 0 },
   { 1341, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1339, 32, 0 },
   { 1340, 61, 0 },
   { 1341, 32, 0 },
   { 1354, 1293, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1339, 32, 0 },
   { 1340, 61, 0 },
   { 1341, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1339, 32, 0 },
   { 1739, 1740, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1339, 32, 0 },
   { 1354, 1293, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1339, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1339, 32, 0 },
   { 3120, 2692, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1339, 32, 0 },
   { 1354, 1293, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3834, 3835, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3832, 2735, 0 },
   { 3834, 3835, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4247, 760, 0 },
   { 4248, 6, 0 },
   { 4249, 11, 0 },
   { 4250, 16, 0 },
   { 4251, 21, 0 },
   { 5084, 3323, 0 },
   { 5085, 3326, 0 },
   { 5087, 4945, 0 },
   { 5089, 2025, 0 },
   { 5090, 2041, 0 },
   { 5092, 4838, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4246, 3111, 0 },
   { 4247, 760, 0 },
   { 4248, 6, 0 },
   { 4249, 11, 0 },
   { 4250, 16, 0 },
   { 4251, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4247, 760, 0 },
   { 4248, 6, 0 },
   { 4249, 11, 0 },
   { 4250, 16, 0 },
   { 4251, 21, 0 },
   { 5971, 5973, 121 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4247, 760, 0 },
   { 4248, 6, 0 },
   { 4249, 11, 0 },
   { 4250, 16, 0 },
   { 4251, 21, 0 },
   { 5955, 5957, 121 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4247, 760, 0 },
   { 4248, 6, 0 },
   { 4249, 11, 0 },
   { 4250, 16, 0 },
   { 4251, 21, 0 },
   { 5940, 5941, 121 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1816, 11, 0 },
   { 1834, 11, 0 },
   { 1921, 16, 0 },
   { 4247, 760, 0 },
   { 4248, 6, 0 },
   { 4249, 11, 0 },
   { 4250, 16, 0 },
   { 4251, 21, 0 },
   { 4265, 4266, 0 },
   { 4273, 4266, 0 },
   { 4279, 4266, 0 },
   { 4285, 4266, 0 },
   { 4289, 4290, 0 },
   { 4293, 4264, 0 },
   { 4297, 4264, 0 },
   { 4301, 4264, 0 },
   { 4305, 4306, 0 },
   { 4309, 4306, 0 },
   { 4311, 4312, 0 },
   { 4315, 4272, 0 },
   { 4319, 4272, 0 },
   { 4323, 4324, 0 },
   { 4327, 4324, 0 },
   { 4329, 4330, 0 },
   { 4332, 4324, 0 },
   { 4334, 4330, 0 },
   { 4336, 1815, 0 },
   { 4338, 4278, 0 },
   { 4342, 4343, 0 },
   { 4346, 4343, 0 },
   { 4348, 4349, 0 },
   { 4352, 4343, 0 },
   { 4354, 4349, 0 },
   { 4356, 1833, 0 },
   { 4358, 4343, 0 },
   { 4360, 4349, 0 },
   { 4362, 1833, 0 },
   { 4364, 1920, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4247, 760, 0 },
   { 4248, 6, 0 },
   { 4249, 11, 0 },
   { 4250, 16, 0 },
   { 4251, 21, 0 },
   { 4268, 4269, 0 },
   { 4275, 4269, 0 },
   { 4281, 4269, 0 },
   { 4286, 4269, 0 },
   { 4294, 4267, 0 },
   { 4298, 4267, 0 },
   { 4302, 4267, 0 },
   { 4316, 4274, 0 },
   { 4320, 4274, 0 },
   { 4339, 4280, 0 },
   { 5121, 11, 0 },
   { 5174, 16, 0 },
   { 5226, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3155, 16, 0 },
   { 4247, 760, 0 },
   { 4248, 6, 0 },
   { 4249, 11, 0 },
   { 4250, 16, 0 },
   { 4251, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3157, 2017, 0 },
   { 4247, 760, 0 },
   { 4248, 6, 0 },
   { 4249, 11, 0 },
   { 4250, 16, 0 },
   { 4251, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4247, 760, 0 },
   { 4248, 6, 0 },
   { 4249, 11, 0 },
   { 4250, 16, 0 },
   { 4251, 21, 0 },
   { 4366, 4367, 0 },
   { 4366, 4367, 0 },
   { 4368, 4369, 0 },
   { 4368, 4369, 0 },
   { 4370, 4250, 0 },
   { 4370, 4250, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4252, 760, 0 },
   { 4253, 6, 0 },
   { 4254, 11, 0 },
   { 4255, 16, 0 },
   { 4256, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4244, 3111, 0 },
   { 4252, 760, 0 },
   { 4253, 6, 0 },
   { 4254, 11, 0 },
   { 4255, 16, 0 },
   { 4256, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4252, 760, 0 },
   { 4253, 6, 0 },
   { 4254, 11, 0 },
   { 4255, 16, 0 },
   { 4256, 21, 0 },
   { 5968, 5970, 121 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4252, 760, 0 },
   { 4253, 6, 0 },
   { 4254, 11, 0 },
   { 4255, 16, 0 },
   { 4256, 21, 0 },
   { 5952, 5954, 121 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4252, 760, 0 },
   { 4253, 6, 0 },
   { 4254, 11, 0 },
   { 4255, 16, 0 },
   { 4256, 21, 0 },
   { 5938, 5939, 121 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3268, 3270, 58 },
   { 4252, 760, 0 },
   { 4253, 6, 0 },
   { 4254, 11, 0 },
   { 4255, 16, 0 },
   { 4256, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4252, 760, 0 },
   { 4253, 6, 0 },
   { 4254, 11, 0 },
   { 4255, 16, 0 },
   { 4256, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4252, 760, 0 },
   { 4253, 6, 0 },
   { 4254, 11, 0 },
   { 4255, 16, 0 },
   { 4256, 21, 0 },
   { 4270, 4266, 0 },
   { 4276, 4266, 0 },
   { 4282, 4266, 0 },
   { 4287, 4266, 0 },
   { 4295, 4264, 0 },
   { 4299, 4264, 0 },
   { 4303, 4264, 0 },
   { 4317, 4272, 0 },
   { 4321, 4272, 0 },
   { 4340, 4278, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1818, 11, 0 },
   { 1836, 11, 0 },
   { 1923, 16, 0 },
   { 4252, 760, 0 },
   { 4253, 6, 0 },
   { 4254, 11, 0 },
   { 4255, 16, 0 },
   { 4256, 21, 0 },
   { 4271, 4269, 0 },
   { 4277, 4269, 0 },
   { 4283, 4269, 0 },
   { 4288, 4269, 0 },
   { 4291, 4292, 0 },
   { 4296, 4267, 0 },
   { 4300, 4267, 0 },
   { 4304, 4267, 0 },
   { 4307, 4308, 0 },
   { 4310, 4308, 0 },
   { 4313, 4314, 0 },
   { 4318, 4274, 0 },
   { 4322, 4274, 0 },
   { 4325, 4326, 0 },
   { 4328, 4326, 0 },
   { 4331, 3298, 0 },
   { 4333, 4326, 0 },
   { 4335, 3298, 0 },
   { 4337, 1817, 0 },
   { 4341, 4280, 0 },
   { 4344, 4345, 0 },
   { 4347, 4345, 0 },
   { 4350, 4351, 0 },
   { 4353, 4345, 0 },
   { 4355, 4351, 0 },
   { 4357, 1835, 0 },
   { 4359, 4345, 0 },
   { 4361, 4351, 0 },
   { 4363, 1835, 0 },
   { 4365, 1922, 0 },
   { 5093, 11, 0 },
   { 5146, 16, 0 },
   { 5199, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3156, 16, 0 },
   { 4252, 760, 0 },
   { 4253, 6, 0 },
   { 4254, 11, 0 },
   { 4255, 16, 0 },
   { 4256, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3264, 3266, 58 },
   { 4252, 760, 0 },
   { 4253, 6, 0 },
   { 4254, 11, 0 },
   { 4255, 16, 0 },
   { 4256, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3158, 2014, 0 },
   { 4252, 760, 0 },
   { 4253, 6, 0 },
   { 4254, 11, 0 },
   { 4255, 16, 0 },
   { 4256, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4252, 760, 0 },
   { 4253, 6, 0 },
   { 4254, 11, 0 },
   { 4255, 16, 0 },
   { 4256, 21, 0 },
   { 4371, 2041, 0 },
   { 4371, 2041, 0 },
   { 4372, 3326, 0 },
   { 4372, 3326, 0 },
   { 4373, 4255, 0 },
   { 4373, 4255, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2742, 3325, 63 },
   { 3340, 2742, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3229, 1460, 0 },
   { 2742, 3325, 63 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3226, 122, 0 },
   { 2742, 3325, 63 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3220, 36, 0 },
   { 2742, 3325, 63 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3223, 2446, 0 },
   { 2742, 3325, 63 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3242, 3326, 64 },
   { 3330, 3242, 0 },
   { 3242, 3326, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3242, 3326, 64 },
   { 3344, 3242, 0 },
   { 3345, 3244, 0 },
   { 3242, 3326, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3244, 3327, 64 },
   { 3337, 3244, 0 },
   { 3244, 3327, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3837, 3830, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3839, 3830, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3839, 3830, 0 },
   { 3871, 122, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3837, 3830, 0 },
   { 3839, 3830, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3840, 3827, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3841, 3827, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3841, 3827, 0 },
   { 3872, 122, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3840, 3827, 0 },
   { 3841, 3827, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3328, 3329, 0 },
   { 3329, 4011, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3343, 3336, 0 },
   { 3329, 4011, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3341, 3329, 0 },
   { 3342, 3336, 0 },
   { 3329, 4011, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3335, 3336, 0 },
   { 3336, 4012, 101 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3843, 3844, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3846, 3844, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3846, 3844, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3843, 3844, 0 },
   { 3846, 3844, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2480, 2485, 48 },
   { 5495, 2480, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2480, 2485, 48 },
   { 5496, 2550, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2486, 2492, 48 },
   { 5501, 2486, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2486, 2492, 48 },
   { 5502, 2554, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2493, 2499, 48 },
   { 5505, 2493, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2493, 2499, 48 },
   { 5506, 2560, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2500, 2516, 48 },
   { 5509, 2500, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2500, 2516, 48 },
   { 5510, 2565, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2517, 2549, 48 },
   { 5513, 2517, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2517, 2549, 48 },
   { 5514, 2574, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2268, 2269, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2591, 2594, 48 },
   { 5499, 2591, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2591, 2594, 48 },
   { 5500, 2632, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2595, 2600, 48 },
   { 5503, 2595, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2595, 2600, 48 },
   { 5504, 2636, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2601, 2605, 48 },
   { 5507, 2601, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2601, 2605, 48 },
   { 5508, 2642, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2606, 2614, 48 },
   { 5511, 2606, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2606, 2614, 48 },
   { 5512, 2647, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2615, 2631, 48 },
   { 5515, 2615, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2615, 2631, 48 },
   { 5516, 2656, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2340, 1077, 0 },
   { 2705, 1077, 0 },
   { 3212, 1077, 0 },
   { 3213, 1235, 0 },
   { 3214, 1235, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2327, 2328, 0 },
   { 2705, 1077, 0 },
   { 3212, 1077, 0 },
   { 3213, 1235, 0 },
   { 3214, 1235, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2705, 1077, 0 },
   { 3212, 1077, 0 },
   { 3213, 1235, 0 },
   { 3214, 1235, 0 },
   { 5577, 5580, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2340, 1077, 0 },
   { 2390, 2391, 0 },
   { 2705, 1077, 0 },
   { 3212, 1077, 0 },
   { 3213, 1235, 0 },
   { 3214, 1235, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2327, 2328, 0 },
   { 2359, 2361, 0 },
   { 2705, 1077, 0 },
   { 3212, 1077, 0 },
   { 3213, 1235, 0 },
   { 3214, 1235, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2705, 1077, 0 },
   { 3212, 1077, 0 },
   { 3213, 1235, 0 },
   { 3214, 1235, 0 },
   { 4412, 4418, 115 },
   { 4458, 4463, 115 },
   { 4505, 4511, 115 },
   { 4571, 4576, 116 },
   { 4622, 4628, 116 },
   { 4700, 4706, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2705, 1077, 0 },
   { 3212, 1077, 0 },
   { 3213, 1235, 0 },
   { 3214, 1235, 0 },
   { 1489, 3803, 81 },
   { 5573, 5576, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2329, 1083, 0 },
   { 2705, 1077, 0 },
   { 3212, 1077, 0 },
   { 3213, 1235, 0 },
   { 3214, 1235, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2329, 1083, 0 },
   { 2705, 1077, 0 },
   { 3212, 1077, 0 },
   { 3213, 1235, 0 },
   { 3214, 1235, 0 },
   { 3796, 3798, 80 },
   { 1489, 3803, 81 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2329, 1083, 0 },
   { 2340, 1077, 0 },
   { 2705, 1077, 0 },
   { 3212, 1077, 0 },
   { 3213, 1235, 0 },
   { 3214, 1235, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2327, 2328, 0 },
   { 2329, 1083, 0 },
   { 2705, 1077, 0 },
   { 3212, 1077, 0 },
   { 3213, 1235, 0 },
   { 3214, 1235, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2329, 1083, 0 },
   { 2363, 2365, 0 },
   { 2705, 1077, 0 },
   { 3212, 1077, 0 },
   { 3213, 1235, 0 },
   { 3214, 1235, 0 },
   { 3796, 3798, 80 },
   { 1489, 3803, 81 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2341, 1077, 0 },
   { 2705, 1077, 0 },
   { 3212, 1077, 0 },
   { 3213, 1235, 0 },
   { 3214, 1235, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2341, 1077, 0 },
   { 2705, 1077, 0 },
   { 3212, 1077, 0 },
   { 3213, 1235, 0 },
   { 3214, 1235, 0 },
   { 3792, 3794, 80 },
   { 1489, 3803, 81 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2340, 1077, 0 },
   { 2341, 1077, 0 },
   { 2705, 1077, 0 },
   { 3212, 1077, 0 },
   { 3213, 1235, 0 },
   { 3214, 1235, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2327, 2328, 0 },
   { 2341, 1077, 0 },
   { 2705, 1077, 0 },
   { 3212, 1077, 0 },
   { 3213, 1235, 0 },
   { 3214, 1235, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2341, 1077, 0 },
   { 2392, 2393, 0 },
   { 2705, 1077, 0 },
   { 3212, 1077, 0 },
   { 3213, 1235, 0 },
   { 3214, 1235, 0 },
   { 3792, 3794, 80 },
   { 1489, 3803, 81 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2705, 1077, 0 },
   { 3212, 1077, 0 },
   { 3213, 1235, 0 },
   { 3214, 1235, 0 },
   { 1489, 3803, 81 },
   { 4403, 4410, 115 },
   { 4450, 4457, 115 },
   { 4496, 4503, 115 },
   { 4563, 4570, 116 },
   { 4614, 4621, 116 },
   { 4692, 4699, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2705, 1077, 0 },
   { 3212, 1077, 0 },
   { 3213, 1235, 0 },
   { 3214, 1235, 0 },
   { 4382, 4383, 115 },
   { 4391, 4392, 115 },
   { 4435, 4383, 115 },
   { 4439, 4392, 115 },
   { 4480, 4383, 115 },
   { 4484, 4392, 115 },
   { 4530, 4531, 116 },
   { 4535, 4536, 116 },
   { 4545, 4546, 116 },
   { 4551, 4552, 116 },
   { 4592, 4531, 116 },
   { 4595, 4536, 116 },
   { 4600, 4546, 116 },
   { 4603, 4552, 116 },
   { 4647, 4648, 0 },
   { 4652, 4653, 0 },
   { 4660, 4661, 0 },
   { 4664, 4665, 0 },
   { 4674, 4675, 0 },
   { 4680, 4681, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2331, 1235, 0 },
   { 2706, 1235, 0 },
   { 3209, 1235, 0 },
   { 3210, 1077, 0 },
   { 3211, 1077, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2342, 2343, 0 },
   { 2706, 1235, 0 },
   { 3209, 1235, 0 },
   { 3210, 1077, 0 },
   { 3211, 1077, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2706, 1235, 0 },
   { 3209, 1235, 0 },
   { 3210, 1077, 0 },
   { 3211, 1077, 0 },
   { 5585, 5588, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2331, 1235, 0 },
   { 2367, 2369, 0 },
   { 2706, 1235, 0 },
   { 3209, 1235, 0 },
   { 3210, 1077, 0 },
   { 3211, 1077, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2342, 2343, 0 },
   { 2394, 2395, 0 },
   { 2706, 1235, 0 },
   { 3209, 1235, 0 },
   { 3210, 1077, 0 },
   { 3211, 1077, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2706, 1235, 0 },
   { 3209, 1235, 0 },
   { 3210, 1077, 0 },
   { 3211, 1077, 0 },
   { 4425, 4430, 115 },
   { 4470, 4475, 115 },
   { 4518, 4523, 115 },
   { 4583, 4588, 116 },
   { 4635, 4640, 116 },
   { 4713, 4718, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2706, 1235, 0 },
   { 3209, 1235, 0 },
   { 3210, 1077, 0 },
   { 3211, 1077, 0 },
   { 1486, 3804, 81 },
   { 5581, 5584, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2344, 2345, 0 },
   { 2706, 1235, 0 },
   { 3209, 1235, 0 },
   { 3210, 1077, 0 },
   { 3211, 1077, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2344, 2345, 0 },
   { 2706, 1235, 0 },
   { 3209, 1235, 0 },
   { 3210, 1077, 0 },
   { 3211, 1077, 0 },
   { 3801, 3802, 80 },
   { 1486, 3804, 81 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2331, 1235, 0 },
   { 2344, 2345, 0 },
   { 2706, 1235, 0 },
   { 3209, 1235, 0 },
   { 3210, 1077, 0 },
   { 3211, 1077, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2342, 2343, 0 },
   { 2344, 2345, 0 },
   { 2706, 1235, 0 },
   { 3209, 1235, 0 },
   { 3210, 1077, 0 },
   { 3211, 1077, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2344, 2345, 0 },
   { 2396, 2397, 0 },
   { 2706, 1235, 0 },
   { 3209, 1235, 0 },
   { 3210, 1077, 0 },
   { 3211, 1077, 0 },
   { 3801, 3802, 80 },
   { 1486, 3804, 81 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2332, 1235, 0 },
   { 2706, 1235, 0 },
   { 3209, 1235, 0 },
   { 3210, 1077, 0 },
   { 3211, 1077, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2332, 1235, 0 },
   { 2706, 1235, 0 },
   { 3209, 1235, 0 },
   { 3210, 1077, 0 },
   { 3211, 1077, 0 },
   { 3799, 3800, 80 },
   { 1486, 3804, 81 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2331, 1235, 0 },
   { 2332, 1235, 0 },
   { 2706, 1235, 0 },
   { 3209, 1235, 0 },
   { 3210, 1077, 0 },
   { 3211, 1077, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2332, 1235, 0 },
   { 2342, 2343, 0 },
   { 2706, 1235, 0 },
   { 3209, 1235, 0 },
   { 3210, 1077, 0 },
   { 3211, 1077, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2332, 1235, 0 },
   { 2371, 2373, 0 },
   { 2706, 1235, 0 },
   { 3209, 1235, 0 },
   { 3210, 1077, 0 },
   { 3211, 1077, 0 },
   { 3799, 3800, 80 },
   { 1486, 3804, 81 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2706, 1235, 0 },
   { 3209, 1235, 0 },
   { 3210, 1077, 0 },
   { 3211, 1077, 0 },
   { 1486, 3804, 81 },
   { 4419, 4424, 115 },
   { 4464, 4469, 115 },
   { 4512, 4517, 115 },
   { 4577, 4582, 116 },
   { 4629, 4634, 116 },
   { 4707, 4712, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2706, 1235, 0 },
   { 3209, 1235, 0 },
   { 3210, 1077, 0 },
   { 3211, 1077, 0 },
   { 4380, 4381, 115 },
   { 4388, 4390, 115 },
   { 4434, 4381, 115 },
   { 4438, 4390, 115 },
   { 4479, 4381, 115 },
   { 4483, 4390, 115 },
   { 4528, 4529, 116 },
   { 4533, 4534, 116 },
   { 4543, 4544, 116 },
   { 4548, 4550, 116 },
   { 4591, 4529, 116 },
   { 4594, 4534, 116 },
   { 4599, 4544, 116 },
   { 4602, 4550, 116 },
   { 4645, 4646, 0 },
   { 4650, 4651, 0 },
   { 4658, 4659, 0 },
   { 4662, 4663, 0 },
   { 4672, 4673, 0 },
   { 4677, 4679, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2706, 1235, 0 },
   { 3209, 1235, 0 },
   { 3210, 1077, 0 },
   { 3211, 1077, 0 },
   { 1486, 3804, 81 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2706, 1235, 0 },
   { 3209, 1235, 0 },
   { 3210, 1077, 0 },
   { 3211, 1077, 0 },
   { 1486, 3804, 81 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2706, 1235, 0 },
   { 3209, 1235, 0 },
   { 3210, 1077, 0 },
   { 3211, 1077, 0 },
   { 1486, 3804, 81 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2706, 1235, 0 },
   { 3209, 1235, 0 },
   { 3210, 1077, 0 },
   { 3211, 1077, 0 },
   { 1486, 3804, 81 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2706, 1235, 0 },
   { 3209, 1235, 0 },
   { 3210, 1077, 0 },
   { 3211, 1077, 0 },
   { 1486, 3804, 81 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4014, 4016, 102 },
   { 5912, 5915, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2830, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2883, 2884, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2875, 2876, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2878, 2879, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2881, 2882, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2866, 2868, 0 },
   { 2848, 2901, 54 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2869, 2870, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2900, 2880, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2899, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2902, 2848, 55 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2871, 2874, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3150, 1392, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3140, 3141, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3151, 1392, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3142, 3143, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4243, 1528, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1827, 1828, 0 },
   { 1845, 1846, 0 },
   { 1930, 1931, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2021, 2022, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4245, 1528, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1783, 688, 0 },
   { 1891, 694, 0 },
   { 1976, 700, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1829, 1830, 0 },
   { 1847, 1848, 0 },
   { 1932, 1933, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2023, 2024, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1342, 32, 0 },
   { 1348, 1291, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1342, 32, 0 },
   { 1343, 32, 0 },
   { 1344, 63, 0 },
   { 1348, 1291, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1342, 32, 0 },
   { 3119, 2695, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3149, 1392, 0 },
   { 3149, 1392, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5974, 5976, 121 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5958, 5960, 121 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5942, 5944, 121 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2018, 2019, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2015, 2016, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3138, 11, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3139, 11, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3152, 1404, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3144, 3145, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3153, 1404, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3146, 3147, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 776, 778, 36 },
   { 788, 789, 0 },
   { 804, 805, 37 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 776, 778, 36 },
   { 783, 785, 0 },
   { 788, 789, 0 },
   { 804, 805, 37 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 776, 778, 36 },
   { 780, 264, 0 },
   { 783, 785, 0 },
   { 788, 789, 0 },
   { 804, 805, 37 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 793, 785, 0 },
   { 802, 803, 37 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 791, 264, 0 },
   { 793, 785, 0 },
   { 802, 803, 37 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 795, 264, 0 },
   { 800, 801, 37 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 795, 264, 0 },
   { 796, 799, 0 },
   { 800, 801, 37 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3313, 3314, 0 },
   { 3941, 3944, 92 },
   { 5200, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3315, 3314, 0 },
   { 3941, 3944, 92 },
   { 5200, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3361, 3357, 0 },
   { 3941, 3944, 92 },
   { 5200, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2416, 2422, 47 },
   { 2428, 2412, 0 },
   { 2436, 2414, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2416, 2422, 47 },
   { 2429, 2414, 0 },
   { 2437, 2412, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2416, 2422, 47 },
   { 2425, 2416, 0 },
   { 2434, 2418, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2416, 2422, 47 },
   { 2427, 2418, 0 },
   { 2435, 2416, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2418, 2423, 47 },
   { 2432, 2412, 0 },
   { 2440, 2414, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2418, 2423, 47 },
   { 2433, 2414, 0 },
   { 2441, 2412, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2418, 2423, 47 },
   { 2430, 2416, 0 },
   { 2438, 2418, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2418, 2423, 47 },
   { 2431, 2418, 0 },
   { 2439, 2416, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2831, 2834, 51 },
   { 2856, 32, 0 },
   { 2857, 251, 0 },
   { 2858, 2855, 0 },
   { 2863, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3230, 3231, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3232, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3239, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3241, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3234, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3670, 3635, 65 },
   { 3923, 3926, 90 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3671, 3672, 67 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 211, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 211, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5132, 4068, 0 },
   { 5185, 4081, 0 },
   { 5237, 4081, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5130, 4068, 0 },
   { 5183, 4081, 0 },
   { 5235, 4081, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5106, 4068, 0 },
   { 5160, 4081, 0 },
   { 5212, 4081, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5104, 4068, 0 },
   { 5158, 4081, 0 },
   { 5210, 4081, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 117, 32, 0 },
   { 211, 3, 0 },
   { 3539, 3540, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 117, 32, 0 },
   { 211, 3, 0 },
   { 3539, 3540, 0 },
   { 3581, 3540, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 117, 32, 0 },
   { 206, 61, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 117, 32, 0 },
   { 206, 61, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 117, 32, 0 },
   { 206, 61, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 117, 32, 0 },
   { 206, 61, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 117, 32, 0 },
   { 206, 61, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 117, 32, 0 },
   { 5132, 4068, 0 },
   { 5185, 4081, 0 },
   { 5237, 4081, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 117, 32, 0 },
   { 5130, 4068, 0 },
   { 5183, 4081, 0 },
   { 5235, 4081, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 117, 32, 0 },
   { 5106, 4068, 0 },
   { 5160, 4081, 0 },
   { 5212, 4081, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 117, 32, 0 },
   { 5104, 4068, 0 },
   { 5158, 4081, 0 },
   { 5210, 4081, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 206, 61, 0 },
   { 209, 3, 0 },
   { 211, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 206, 61, 0 },
   { 209, 3, 0 },
   { 211, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 206, 61, 0 },
   { 5132, 4068, 0 },
   { 5185, 4081, 0 },
   { 5237, 4081, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 206, 61, 0 },
   { 5130, 4068, 0 },
   { 5183, 4081, 0 },
   { 5235, 4081, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 206, 61, 0 },
   { 5106, 4068, 0 },
   { 5160, 4081, 0 },
   { 5212, 4081, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 206, 61, 0 },
   { 5104, 4068, 0 },
   { 5158, 4081, 0 },
   { 5210, 4081, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5132, 4068, 0 },
   { 5185, 4081, 0 },
   { 5237, 4081, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5130, 4068, 0 },
   { 5183, 4081, 0 },
   { 5235, 4081, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5106, 4068, 0 },
   { 5160, 4081, 0 },
   { 5212, 4081, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5104, 4068, 0 },
   { 5158, 4081, 0 },
   { 5210, 4081, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 211, 3, 0 },
   { 330, 331, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 211, 3, 0 },
   { 330, 331, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 330, 331, 0 },
   { 5132, 4068, 0 },
   { 5185, 4081, 0 },
   { 5237, 4081, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 330, 331, 0 },
   { 5130, 4068, 0 },
   { 5183, 4081, 0 },
   { 5235, 4081, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 330, 331, 0 },
   { 5106, 4068, 0 },
   { 5160, 4081, 0 },
   { 5212, 4081, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 330, 331, 0 },
   { 5104, 4068, 0 },
   { 5158, 4081, 0 },
   { 5210, 4081, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 211, 3, 0 },
   { 333, 334, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 211, 3, 0 },
   { 333, 334, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 333, 334, 0 },
   { 5132, 4068, 0 },
   { 5185, 4081, 0 },
   { 5237, 4081, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 333, 334, 0 },
   { 5130, 4068, 0 },
   { 5183, 4081, 0 },
   { 5235, 4081, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 333, 334, 0 },
   { 5106, 4068, 0 },
   { 5160, 4081, 0 },
   { 5212, 4081, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 333, 334, 0 },
   { 5104, 4068, 0 },
   { 5158, 4081, 0 },
   { 5210, 4081, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 211, 3, 0 },
   { 342, 343, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 211, 3, 0 },
   { 342, 343, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 342, 343, 0 },
   { 5132, 4068, 0 },
   { 5185, 4081, 0 },
   { 5237, 4081, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 342, 343, 0 },
   { 5130, 4068, 0 },
   { 5183, 4081, 0 },
   { 5235, 4081, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 342, 343, 0 },
   { 5106, 4068, 0 },
   { 5160, 4081, 0 },
   { 5212, 4081, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 342, 343, 0 },
   { 5104, 4068, 0 },
   { 5158, 4081, 0 },
   { 5210, 4081, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 211, 3, 0 },
   { 345, 346, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 211, 3, 0 },
   { 345, 346, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 345, 346, 0 },
   { 5132, 4068, 0 },
   { 5185, 4081, 0 },
   { 5237, 4081, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 345, 346, 0 },
   { 5130, 4068, 0 },
   { 5183, 4081, 0 },
   { 5235, 4081, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 345, 346, 0 },
   { 5106, 4068, 0 },
   { 5160, 4081, 0 },
   { 5212, 4081, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 345, 346, 0 },
   { 5104, 4068, 0 },
   { 5158, 4081, 0 },
   { 5210, 4081, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 211, 3, 0 },
   { 336, 337, 0 },
   { 340, 337, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 211, 3, 0 },
   { 336, 337, 0 },
   { 340, 337, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 336, 337, 0 },
   { 340, 337, 0 },
   { 5132, 4068, 0 },
   { 5185, 4081, 0 },
   { 5237, 4081, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 336, 337, 0 },
   { 340, 337, 0 },
   { 5130, 4068, 0 },
   { 5183, 4081, 0 },
   { 5235, 4081, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 336, 337, 0 },
   { 340, 337, 0 },
   { 5106, 4068, 0 },
   { 5160, 4081, 0 },
   { 5212, 4081, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 336, 337, 0 },
   { 340, 337, 0 },
   { 5104, 4068, 0 },
   { 5158, 4081, 0 },
   { 5210, 4081, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 211, 3, 0 },
   { 5107, 4068, 0 },
   { 5161, 4081, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 211, 3, 0 },
   { 5107, 4068, 0 },
   { 5161, 4081, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5107, 4068, 0 },
   { 5132, 4068, 0 },
   { 5161, 4081, 0 },
   { 5185, 4081, 0 },
   { 5237, 4081, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5107, 4068, 0 },
   { 5130, 4068, 0 },
   { 5161, 4081, 0 },
   { 5183, 4081, 0 },
   { 5235, 4081, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5106, 4068, 0 },
   { 5107, 4068, 0 },
   { 5160, 4081, 0 },
   { 5161, 4081, 0 },
   { 5212, 4081, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5104, 4068, 0 },
   { 5107, 4068, 0 },
   { 5158, 4081, 0 },
   { 5161, 4081, 0 },
   { 5210, 4081, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 211, 3, 0 },
   { 5133, 4068, 0 },
   { 5186, 4081, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 211, 3, 0 },
   { 5133, 4068, 0 },
   { 5186, 4081, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5132, 4068, 0 },
   { 5133, 4068, 0 },
   { 5185, 4081, 0 },
   { 5186, 4081, 0 },
   { 5237, 4081, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5130, 4068, 0 },
   { 5133, 4068, 0 },
   { 5183, 4081, 0 },
   { 5186, 4081, 0 },
   { 5235, 4081, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5106, 4068, 0 },
   { 5133, 4068, 0 },
   { 5160, 4081, 0 },
   { 5186, 4081, 0 },
   { 5212, 4081, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5104, 4068, 0 },
   { 5133, 4068, 0 },
   { 5158, 4081, 0 },
   { 5186, 4081, 0 },
   { 5210, 4081, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 211, 3, 0 },
   { 5238, 4081, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 211, 3, 0 },
   { 5238, 4081, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5132, 4068, 0 },
   { 5185, 4081, 0 },
   { 5237, 4081, 0 },
   { 5238, 4081, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5130, 4068, 0 },
   { 5183, 4081, 0 },
   { 5235, 4081, 0 },
   { 5238, 4081, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5106, 4068, 0 },
   { 5160, 4081, 0 },
   { 5212, 4081, 0 },
   { 5238, 4081, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5104, 4068, 0 },
   { 5158, 4081, 0 },
   { 5210, 4081, 0 },
   { 5238, 4081, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 211, 3, 0 },
   { 5213, 4081, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 211, 3, 0 },
   { 5213, 4081, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5132, 4068, 0 },
   { 5185, 4081, 0 },
   { 5213, 4081, 0 },
   { 5237, 4081, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5130, 4068, 0 },
   { 5183, 4081, 0 },
   { 5213, 4081, 0 },
   { 5235, 4081, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5106, 4068, 0 },
   { 5160, 4081, 0 },
   { 5212, 4081, 0 },
   { 5213, 4081, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5104, 4068, 0 },
   { 5158, 4081, 0 },
   { 5210, 4081, 0 },
   { 5213, 4081, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 211, 3, 0 },
   { 5132, 4068, 0 },
   { 5185, 4081, 0 },
   { 5237, 4081, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 211, 3, 0 },
   { 5130, 4068, 0 },
   { 5183, 4081, 0 },
   { 5235, 4081, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 211, 3, 0 },
   { 5106, 4068, 0 },
   { 5160, 4081, 0 },
   { 5212, 4081, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 211, 3, 0 },
   { 5104, 4068, 0 },
   { 5158, 4081, 0 },
   { 5210, 4081, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 211, 3, 0 },
   { 5132, 4068, 0 },
   { 5185, 4081, 0 },
   { 5237, 4081, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 211, 3, 0 },
   { 5130, 4068, 0 },
   { 5183, 4081, 0 },
   { 5235, 4081, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 211, 3, 0 },
   { 5106, 4068, 0 },
   { 5160, 4081, 0 },
   { 5212, 4081, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 211, 3, 0 },
   { 5104, 4068, 0 },
   { 5158, 4081, 0 },
   { 5210, 4081, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5130, 4068, 0 },
   { 5132, 4068, 0 },
   { 5183, 4081, 0 },
   { 5185, 4081, 0 },
   { 5235, 4081, 0 },
   { 5237, 4081, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5106, 4068, 0 },
   { 5132, 4068, 0 },
   { 5160, 4081, 0 },
   { 5185, 4081, 0 },
   { 5212, 4081, 0 },
   { 5237, 4081, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5104, 4068, 0 },
   { 5132, 4068, 0 },
   { 5158, 4081, 0 },
   { 5185, 4081, 0 },
   { 5210, 4081, 0 },
   { 5237, 4081, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5106, 4068, 0 },
   { 5130, 4068, 0 },
   { 5160, 4081, 0 },
   { 5183, 4081, 0 },
   { 5212, 4081, 0 },
   { 5235, 4081, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5104, 4068, 0 },
   { 5130, 4068, 0 },
   { 5158, 4081, 0 },
   { 5183, 4081, 0 },
   { 5210, 4081, 0 },
   { 5235, 4081, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5104, 4068, 0 },
   { 5106, 4068, 0 },
   { 5158, 4081, 0 },
   { 5160, 4081, 0 },
   { 5210, 4081, 0 },
   { 5212, 4081, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3354, 3355, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5126, 5098, 0 },
   { 5179, 5151, 0 },
   { 5231, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5126, 5098, 0 },
   { 5179, 5151, 0 },
   { 5231, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5126, 5098, 0 },
   { 5179, 5151, 0 },
   { 5231, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1313, 1311, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3695, 3697, 0 },
   { 5126, 5098, 0 },
   { 5179, 5151, 0 },
   { 5231, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5124, 5098, 0 },
   { 5177, 5151, 0 },
   { 5229, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5124, 5098, 0 },
   { 5177, 5151, 0 },
   { 5229, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5124, 5098, 0 },
   { 5177, 5151, 0 },
   { 5229, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1313, 1311, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3695, 3697, 0 },
   { 5124, 5098, 0 },
   { 5177, 5151, 0 },
   { 5229, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5101, 5098, 0 },
   { 5154, 5151, 0 },
   { 5206, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5101, 5098, 0 },
   { 5154, 5151, 0 },
   { 5206, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5101, 5098, 0 },
   { 5154, 5151, 0 },
   { 5206, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1313, 1311, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3695, 3697, 0 },
   { 5101, 5098, 0 },
   { 5154, 5151, 0 },
   { 5206, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5097, 5098, 0 },
   { 5150, 5151, 0 },
   { 5203, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5097, 5098, 0 },
   { 5150, 5151, 0 },
   { 5203, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5097, 5098, 0 },
   { 5150, 5151, 0 },
   { 5203, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1313, 1311, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3695, 3697, 0 },
   { 5097, 5098, 0 },
   { 5150, 5151, 0 },
   { 5203, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3062, 1117, 0 },
   { 3063, 684, 0 },
   { 3093, 3, 0 },
   { 5126, 5098, 0 },
   { 5179, 5151, 0 },
   { 5231, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3062, 1117, 0 },
   { 3063, 684, 0 },
   { 3093, 3, 0 },
   { 5126, 5098, 0 },
   { 5179, 5151, 0 },
   { 5231, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3062, 1117, 0 },
   { 3063, 684, 0 },
   { 3093, 3, 0 },
   { 5126, 5098, 0 },
   { 5179, 5151, 0 },
   { 5231, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1313, 1311, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3062, 1117, 0 },
   { 3063, 684, 0 },
   { 3093, 3, 0 },
   { 3695, 3697, 0 },
   { 5126, 5098, 0 },
   { 5179, 5151, 0 },
   { 5231, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3062, 1117, 0 },
   { 3063, 684, 0 },
   { 3093, 3, 0 },
   { 5124, 5098, 0 },
   { 5177, 5151, 0 },
   { 5229, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3062, 1117, 0 },
   { 3063, 684, 0 },
   { 3093, 3, 0 },
   { 5124, 5098, 0 },
   { 5177, 5151, 0 },
   { 5229, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3062, 1117, 0 },
   { 3063, 684, 0 },
   { 3093, 3, 0 },
   { 5124, 5098, 0 },
   { 5177, 5151, 0 },
   { 5229, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1313, 1311, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3062, 1117, 0 },
   { 3063, 684, 0 },
   { 3093, 3, 0 },
   { 3695, 3697, 0 },
   { 5124, 5098, 0 },
   { 5177, 5151, 0 },
   { 5229, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3062, 1117, 0 },
   { 3063, 684, 0 },
   { 3093, 3, 0 },
   { 5101, 5098, 0 },
   { 5154, 5151, 0 },
   { 5206, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3062, 1117, 0 },
   { 3063, 684, 0 },
   { 3093, 3, 0 },
   { 5101, 5098, 0 },
   { 5154, 5151, 0 },
   { 5206, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3062, 1117, 0 },
   { 3063, 684, 0 },
   { 3093, 3, 0 },
   { 5101, 5098, 0 },
   { 5154, 5151, 0 },
   { 5206, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1313, 1311, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3062, 1117, 0 },
   { 3063, 684, 0 },
   { 3093, 3, 0 },
   { 3695, 3697, 0 },
   { 5101, 5098, 0 },
   { 5154, 5151, 0 },
   { 5206, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3062, 1117, 0 },
   { 3063, 684, 0 },
   { 3093, 3, 0 },
   { 5097, 5098, 0 },
   { 5150, 5151, 0 },
   { 5203, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3062, 1117, 0 },
   { 3063, 684, 0 },
   { 3093, 3, 0 },
   { 5097, 5098, 0 },
   { 5150, 5151, 0 },
   { 5203, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3062, 1117, 0 },
   { 3063, 684, 0 },
   { 3093, 3, 0 },
   { 5097, 5098, 0 },
   { 5150, 5151, 0 },
   { 5203, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1313, 1311, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3062, 1117, 0 },
   { 3063, 684, 0 },
   { 3093, 3, 0 },
   { 3695, 3697, 0 },
   { 5097, 5098, 0 },
   { 5150, 5151, 0 },
   { 5203, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 391, 392, 9 },
   { 1331, 1138, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1307, 1308, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5126, 5098, 0 },
   { 5179, 5151, 0 },
   { 5231, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1307, 1308, 0 },
   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5126, 5098, 0 },
   { 5179, 5151, 0 },
   { 5231, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1307, 1308, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5126, 5098, 0 },
   { 5179, 5151, 0 },
   { 5231, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1307, 1308, 0 },
   { 1313, 1311, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3695, 3697, 0 },
   { 5126, 5098, 0 },
   { 5179, 5151, 0 },
   { 5231, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1307, 1308, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5124, 5098, 0 },
   { 5177, 5151, 0 },
   { 5229, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1307, 1308, 0 },
   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5124, 5098, 0 },
   { 5177, 5151, 0 },
   { 5229, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1307, 1308, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5124, 5098, 0 },
   { 5177, 5151, 0 },
   { 5229, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1307, 1308, 0 },
   { 1313, 1311, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3695, 3697, 0 },
   { 5124, 5098, 0 },
   { 5177, 5151, 0 },
   { 5229, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1307, 1308, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5101, 5098, 0 },
   { 5154, 5151, 0 },
   { 5206, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1307, 1308, 0 },
   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5101, 5098, 0 },
   { 5154, 5151, 0 },
   { 5206, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1307, 1308, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5101, 5098, 0 },
   { 5154, 5151, 0 },
   { 5206, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1307, 1308, 0 },
   { 1313, 1311, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3695, 3697, 0 },
   { 5101, 5098, 0 },
   { 5154, 5151, 0 },
   { 5206, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1307, 1308, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5097, 5098, 0 },
   { 5150, 5151, 0 },
   { 5203, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1307, 1308, 0 },
   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5097, 5098, 0 },
   { 5150, 5151, 0 },
   { 5203, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1307, 1308, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5097, 5098, 0 },
   { 5150, 5151, 0 },
   { 5203, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1307, 1308, 0 },
   { 1313, 1311, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3695, 3697, 0 },
   { 5097, 5098, 0 },
   { 5150, 5151, 0 },
   { 5203, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1278, 1279, 0 },
   { 1280, 1281, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5126, 5098, 0 },
   { 5179, 5151, 0 },
   { 5231, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1278, 1279, 0 },
   { 1280, 1281, 0 },
   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5126, 5098, 0 },
   { 5179, 5151, 0 },
   { 5231, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1278, 1279, 0 },
   { 1280, 1281, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5126, 5098, 0 },
   { 5179, 5151, 0 },
   { 5231, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1278, 1279, 0 },
   { 1280, 1281, 0 },
   { 1313, 1311, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3695, 3697, 0 },
   { 5126, 5098, 0 },
   { 5179, 5151, 0 },
   { 5231, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1278, 1279, 0 },
   { 1280, 1281, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5124, 5098, 0 },
   { 5177, 5151, 0 },
   { 5229, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1278, 1279, 0 },
   { 1280, 1281, 0 },
   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5124, 5098, 0 },
   { 5177, 5151, 0 },
   { 5229, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1278, 1279, 0 },
   { 1280, 1281, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5124, 5098, 0 },
   { 5177, 5151, 0 },
   { 5229, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1278, 1279, 0 },
   { 1280, 1281, 0 },
   { 1313, 1311, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3695, 3697, 0 },
   { 5124, 5098, 0 },
   { 5177, 5151, 0 },
   { 5229, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1278, 1279, 0 },
   { 1280, 1281, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5101, 5098, 0 },
   { 5154, 5151, 0 },
   { 5206, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1278, 1279, 0 },
   { 1280, 1281, 0 },
   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5101, 5098, 0 },
   { 5154, 5151, 0 },
   { 5206, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1278, 1279, 0 },
   { 1280, 1281, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5101, 5098, 0 },
   { 5154, 5151, 0 },
   { 5206, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1278, 1279, 0 },
   { 1280, 1281, 0 },
   { 1313, 1311, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3695, 3697, 0 },
   { 5101, 5098, 0 },
   { 5154, 5151, 0 },
   { 5206, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1278, 1279, 0 },
   { 1280, 1281, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5097, 5098, 0 },
   { 5150, 5151, 0 },
   { 5203, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1278, 1279, 0 },
   { 1280, 1281, 0 },
   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5097, 5098, 0 },
   { 5150, 5151, 0 },
   { 5203, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1278, 1279, 0 },
   { 1280, 1281, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5097, 5098, 0 },
   { 5150, 5151, 0 },
   { 5203, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1278, 1279, 0 },
   { 1280, 1281, 0 },
   { 1313, 1311, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3695, 3697, 0 },
   { 5097, 5098, 0 },
   { 5150, 5151, 0 },
   { 5203, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1285, 1286, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5126, 5098, 0 },
   { 5179, 5151, 0 },
   { 5231, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1285, 1286, 0 },
   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5126, 5098, 0 },
   { 5179, 5151, 0 },
   { 5231, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1285, 1286, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5126, 5098, 0 },
   { 5179, 5151, 0 },
   { 5231, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1285, 1286, 0 },
   { 1313, 1311, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3695, 3697, 0 },
   { 5126, 5098, 0 },
   { 5179, 5151, 0 },
   { 5231, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1285, 1286, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5124, 5098, 0 },
   { 5177, 5151, 0 },
   { 5229, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1285, 1286, 0 },
   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5124, 5098, 0 },
   { 5177, 5151, 0 },
   { 5229, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1285, 1286, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5124, 5098, 0 },
   { 5177, 5151, 0 },
   { 5229, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1285, 1286, 0 },
   { 1313, 1311, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3695, 3697, 0 },
   { 5124, 5098, 0 },
   { 5177, 5151, 0 },
   { 5229, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1285, 1286, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5101, 5098, 0 },
   { 5154, 5151, 0 },
   { 5206, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1285, 1286, 0 },
   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5101, 5098, 0 },
   { 5154, 5151, 0 },
   { 5206, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1285, 1286, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5101, 5098, 0 },
   { 5154, 5151, 0 },
   { 5206, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1285, 1286, 0 },
   { 1313, 1311, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3695, 3697, 0 },
   { 5101, 5098, 0 },
   { 5154, 5151, 0 },
   { 5206, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1285, 1286, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5097, 5098, 0 },
   { 5150, 5151, 0 },
   { 5203, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1285, 1286, 0 },
   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5097, 5098, 0 },
   { 5150, 5151, 0 },
   { 5203, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1285, 1286, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5097, 5098, 0 },
   { 5150, 5151, 0 },
   { 5203, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1282, 1283, 0 },
   { 1285, 1286, 0 },
   { 1313, 1311, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3695, 3697, 0 },
   { 5097, 5098, 0 },
   { 5150, 5151, 0 },
   { 5203, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1298, 1299, 0 },
   { 1300, 1301, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5126, 5098, 0 },
   { 5179, 5151, 0 },
   { 5231, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1298, 1299, 0 },
   { 1300, 1301, 0 },
   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5126, 5098, 0 },
   { 5179, 5151, 0 },
   { 5231, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1298, 1299, 0 },
   { 1300, 1301, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5126, 5098, 0 },
   { 5179, 5151, 0 },
   { 5231, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1298, 1299, 0 },
   { 1300, 1301, 0 },
   { 1313, 1311, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3695, 3697, 0 },
   { 5126, 5098, 0 },
   { 5179, 5151, 0 },
   { 5231, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1298, 1299, 0 },
   { 1300, 1301, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5124, 5098, 0 },
   { 5177, 5151, 0 },
   { 5229, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1298, 1299, 0 },
   { 1300, 1301, 0 },
   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5124, 5098, 0 },
   { 5177, 5151, 0 },
   { 5229, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1298, 1299, 0 },
   { 1300, 1301, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5124, 5098, 0 },
   { 5177, 5151, 0 },
   { 5229, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1298, 1299, 0 },
   { 1300, 1301, 0 },
   { 1313, 1311, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3695, 3697, 0 },
   { 5124, 5098, 0 },
   { 5177, 5151, 0 },
   { 5229, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1298, 1299, 0 },
   { 1300, 1301, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5101, 5098, 0 },
   { 5154, 5151, 0 },
   { 5206, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1298, 1299, 0 },
   { 1300, 1301, 0 },
   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5101, 5098, 0 },
   { 5154, 5151, 0 },
   { 5206, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1298, 1299, 0 },
   { 1300, 1301, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5101, 5098, 0 },
   { 5154, 5151, 0 },
   { 5206, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1298, 1299, 0 },
   { 1300, 1301, 0 },
   { 1313, 1311, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3695, 3697, 0 },
   { 5101, 5098, 0 },
   { 5154, 5151, 0 },
   { 5206, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1298, 1299, 0 },
   { 1300, 1301, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5097, 5098, 0 },
   { 5150, 5151, 0 },
   { 5203, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1298, 1299, 0 },
   { 1300, 1301, 0 },
   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5097, 5098, 0 },
   { 5150, 5151, 0 },
   { 5203, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1298, 1299, 0 },
   { 1300, 1301, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5097, 5098, 0 },
   { 5150, 5151, 0 },
   { 5203, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1298, 1299, 0 },
   { 1300, 1301, 0 },
   { 1313, 1311, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3695, 3697, 0 },
   { 5097, 5098, 0 },
   { 5150, 5151, 0 },
   { 5203, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1298, 1299, 0 },
   { 1300, 1301, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 2408, 2409, 0 },
   { 3093, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1288, 1289, 0 },
   { 1290, 1291, 0 },
   { 1331, 1138, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 4104, 4105, 112 },
   { 4117, 4118, 112 },
   { 4129, 4130, 112 },
   { 4141, 3764, 113 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1288, 1289, 0 },
   { 1290, 1291, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5126, 5098, 0 },
   { 5179, 5151, 0 },
   { 5231, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1288, 1289, 0 },
   { 1290, 1291, 0 },
   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5126, 5098, 0 },
   { 5179, 5151, 0 },
   { 5231, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1288, 1289, 0 },
   { 1290, 1291, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5126, 5098, 0 },
   { 5179, 5151, 0 },
   { 5231, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1288, 1289, 0 },
   { 1290, 1291, 0 },
   { 1313, 1311, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3695, 3697, 0 },
   { 5126, 5098, 0 },
   { 5179, 5151, 0 },
   { 5231, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1288, 1289, 0 },
   { 1290, 1291, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5124, 5098, 0 },
   { 5177, 5151, 0 },
   { 5229, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1288, 1289, 0 },
   { 1290, 1291, 0 },
   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5124, 5098, 0 },
   { 5177, 5151, 0 },
   { 5229, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1288, 1289, 0 },
   { 1290, 1291, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5124, 5098, 0 },
   { 5177, 5151, 0 },
   { 5229, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1288, 1289, 0 },
   { 1290, 1291, 0 },
   { 1313, 1311, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3695, 3697, 0 },
   { 5124, 5098, 0 },
   { 5177, 5151, 0 },
   { 5229, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1288, 1289, 0 },
   { 1290, 1291, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5101, 5098, 0 },
   { 5154, 5151, 0 },
   { 5206, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1288, 1289, 0 },
   { 1290, 1291, 0 },
   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5101, 5098, 0 },
   { 5154, 5151, 0 },
   { 5206, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1288, 1289, 0 },
   { 1290, 1291, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5101, 5098, 0 },
   { 5154, 5151, 0 },
   { 5206, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1288, 1289, 0 },
   { 1290, 1291, 0 },
   { 1313, 1311, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3695, 3697, 0 },
   { 5101, 5098, 0 },
   { 5154, 5151, 0 },
   { 5206, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1288, 1289, 0 },
   { 1290, 1291, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5097, 5098, 0 },
   { 5150, 5151, 0 },
   { 5203, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1288, 1289, 0 },
   { 1290, 1291, 0 },
   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5097, 5098, 0 },
   { 5150, 5151, 0 },
   { 5203, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1288, 1289, 0 },
   { 1290, 1291, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5097, 5098, 0 },
   { 5150, 5151, 0 },
   { 5203, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1288, 1289, 0 },
   { 1290, 1291, 0 },
   { 1313, 1311, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3695, 3697, 0 },
   { 5097, 5098, 0 },
   { 5150, 5151, 0 },
   { 5203, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1302, 1303, 0 },
   { 1305, 1306, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5126, 5098, 0 },
   { 5179, 5151, 0 },
   { 5231, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1302, 1303, 0 },
   { 1305, 1306, 0 },
   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5126, 5098, 0 },
   { 5179, 5151, 0 },
   { 5231, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1302, 1303, 0 },
   { 1305, 1306, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5126, 5098, 0 },
   { 5179, 5151, 0 },
   { 5231, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1302, 1303, 0 },
   { 1305, 1306, 0 },
   { 1313, 1311, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3695, 3697, 0 },
   { 5126, 5098, 0 },
   { 5179, 5151, 0 },
   { 5231, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1302, 1303, 0 },
   { 1305, 1306, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5124, 5098, 0 },
   { 5177, 5151, 0 },
   { 5229, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1302, 1303, 0 },
   { 1305, 1306, 0 },
   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5124, 5098, 0 },
   { 5177, 5151, 0 },
   { 5229, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1302, 1303, 0 },
   { 1305, 1306, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5124, 5098, 0 },
   { 5177, 5151, 0 },
   { 5229, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1302, 1303, 0 },
   { 1305, 1306, 0 },
   { 1313, 1311, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3695, 3697, 0 },
   { 5124, 5098, 0 },
   { 5177, 5151, 0 },
   { 5229, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1302, 1303, 0 },
   { 1305, 1306, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5101, 5098, 0 },
   { 5154, 5151, 0 },
   { 5206, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1302, 1303, 0 },
   { 1305, 1306, 0 },
   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5101, 5098, 0 },
   { 5154, 5151, 0 },
   { 5206, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1302, 1303, 0 },
   { 1305, 1306, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5101, 5098, 0 },
   { 5154, 5151, 0 },
   { 5206, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1302, 1303, 0 },
   { 1305, 1306, 0 },
   { 1313, 1311, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3695, 3697, 0 },
   { 5101, 5098, 0 },
   { 5154, 5151, 0 },
   { 5206, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1302, 1303, 0 },
   { 1305, 1306, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5097, 5098, 0 },
   { 5150, 5151, 0 },
   { 5203, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1302, 1303, 0 },
   { 1305, 1306, 0 },
   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5097, 5098, 0 },
   { 5150, 5151, 0 },
   { 5203, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1302, 1303, 0 },
   { 1305, 1306, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5097, 5098, 0 },
   { 5150, 5151, 0 },
   { 5203, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1302, 1303, 0 },
   { 1305, 1306, 0 },
   { 1313, 1311, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3695, 3697, 0 },
   { 5097, 5098, 0 },
   { 5150, 5151, 0 },
   { 5203, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1292, 1293, 0 },
   { 1295, 1296, 0 },
   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 4107, 4105, 112 },
   { 4120, 4118, 112 },
   { 4132, 4130, 112 },
   { 4143, 3764, 113 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1292, 1293, 0 },
   { 1295, 1296, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5126, 5098, 0 },
   { 5179, 5151, 0 },
   { 5231, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1292, 1293, 0 },
   { 1295, 1296, 0 },
   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5126, 5098, 0 },
   { 5179, 5151, 0 },
   { 5231, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1292, 1293, 0 },
   { 1295, 1296, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5126, 5098, 0 },
   { 5179, 5151, 0 },
   { 5231, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1292, 1293, 0 },
   { 1295, 1296, 0 },
   { 1313, 1311, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3695, 3697, 0 },
   { 5126, 5098, 0 },
   { 5179, 5151, 0 },
   { 5231, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1292, 1293, 0 },
   { 1295, 1296, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5124, 5098, 0 },
   { 5177, 5151, 0 },
   { 5229, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1292, 1293, 0 },
   { 1295, 1296, 0 },
   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5124, 5098, 0 },
   { 5177, 5151, 0 },
   { 5229, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1292, 1293, 0 },
   { 1295, 1296, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5124, 5098, 0 },
   { 5177, 5151, 0 },
   { 5229, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1292, 1293, 0 },
   { 1295, 1296, 0 },
   { 1313, 1311, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3695, 3697, 0 },
   { 5124, 5098, 0 },
   { 5177, 5151, 0 },
   { 5229, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1292, 1293, 0 },
   { 1295, 1296, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5101, 5098, 0 },
   { 5154, 5151, 0 },
   { 5206, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1292, 1293, 0 },
   { 1295, 1296, 0 },
   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5101, 5098, 0 },
   { 5154, 5151, 0 },
   { 5206, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1292, 1293, 0 },
   { 1295, 1296, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5101, 5098, 0 },
   { 5154, 5151, 0 },
   { 5206, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1292, 1293, 0 },
   { 1295, 1296, 0 },
   { 1313, 1311, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3695, 3697, 0 },
   { 5101, 5098, 0 },
   { 5154, 5151, 0 },
   { 5206, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1292, 1293, 0 },
   { 1295, 1296, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5097, 5098, 0 },
   { 5150, 5151, 0 },
   { 5203, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1292, 1293, 0 },
   { 1295, 1296, 0 },
   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5097, 5098, 0 },
   { 5150, 5151, 0 },
   { 5203, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1292, 1293, 0 },
   { 1295, 1296, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 5097, 5098, 0 },
   { 5150, 5151, 0 },
   { 5203, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1292, 1293, 0 },
   { 1295, 1296, 0 },
   { 1313, 1311, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3695, 3697, 0 },
   { 5097, 5098, 0 },
   { 5150, 5151, 0 },
   { 5203, 5151, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 4065, 4059, 8 },
   { 4078, 4072, 8 },
   { 4091, 4085, 8 },
   { 4098, 3754, 111 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 4111, 4105, 112 },
   { 4124, 4118, 112 },
   { 4136, 4130, 112 },
   { 4147, 3764, 113 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1331, 1138, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 4067, 4059, 8 },
   { 4080, 4072, 8 },
   { 4093, 4085, 8 },
   { 4100, 3754, 111 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1331, 1138, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 4113, 4105, 112 },
   { 4126, 4118, 112 },
   { 4138, 4130, 112 },
   { 4149, 3764, 113 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1288, 1289, 0 },
   { 1290, 1291, 0 },
   { 1331, 1138, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 4058, 4059, 8 },
   { 4071, 4072, 8 },
   { 4084, 4085, 8 },
   { 3758, 3754, 111 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1288, 1289, 0 },
   { 1290, 1291, 0 },
   { 1331, 1138, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 4058, 4059, 8 },
   { 4071, 4072, 8 },
   { 4084, 4085, 8 },
   { 3758, 3754, 111 },
   { 4104, 4105, 112 },
   { 4117, 4118, 112 },
   { 4129, 4130, 112 },
   { 4141, 3764, 113 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1292, 1293, 0 },
   { 1295, 1296, 0 },
   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 4061, 4059, 8 },
   { 4074, 4072, 8 },
   { 4087, 4085, 8 },
   { 4095, 3754, 111 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1292, 1293, 0 },
   { 1295, 1296, 0 },
   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 4061, 4059, 8 },
   { 4074, 4072, 8 },
   { 4087, 4085, 8 },
   { 4095, 3754, 111 },
   { 4107, 4105, 112 },
   { 4120, 4118, 112 },
   { 4132, 4130, 112 },
   { 4143, 3764, 113 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1302, 1303, 0 },
   { 1305, 1306, 0 },
   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3602, 3600, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1302, 1303, 0 },
   { 1305, 1306, 0 },
   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3605, 3603, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1302, 1303, 0 },
   { 1305, 1306, 0 },
   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3608, 3606, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1302, 1303, 0 },
   { 1305, 1306, 0 },
   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3611, 3609, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1302, 1303, 0 },
   { 1305, 1306, 0 },
   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3614, 3612, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5135, 5109, 0 },
   { 5188, 49, 0 },
   { 5240, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5134, 5109, 0 },
   { 5187, 49, 0 },
   { 5239, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5110, 5109, 0 },
   { 5163, 49, 0 },
   { 5215, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5108, 5109, 0 },
   { 5162, 49, 0 },
   { 5214, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2, 5, 1 },
   { 8, 10, 1 },
   { 13, 15, 1 },
   { 18, 20, 1 },
   { 23, 25, 1 },
   { 27, 31, 1 },
   { 40, 46, 3 },
   { 238, 61, 0 },
   { 246, 32, 0 },
   { 249, 100, 0 },
   { 1032, 1036, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2, 5, 1 },
   { 8, 10, 1 },
   { 13, 15, 1 },
   { 18, 20, 1 },
   { 23, 25, 1 },
   { 27, 31, 1 },
   { 40, 46, 3 },
   { 238, 61, 0 },
   { 246, 32, 0 },
   { 249, 100, 0 },
   { 1024, 1027, 0 },
   { 1032, 1036, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2, 5, 1 },
   { 8, 10, 1 },
   { 13, 15, 1 },
   { 18, 20, 1 },
   { 23, 25, 1 },
   { 27, 31, 1 },
   { 40, 46, 3 },
   { 238, 61, 0 },
   { 246, 32, 0 },
   { 249, 100, 0 },
   { 5135, 5109, 0 },
   { 5188, 49, 0 },
   { 5240, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2, 5, 1 },
   { 8, 10, 1 },
   { 13, 15, 1 },
   { 18, 20, 1 },
   { 23, 25, 1 },
   { 27, 31, 1 },
   { 40, 46, 3 },
   { 238, 61, 0 },
   { 246, 32, 0 },
   { 249, 100, 0 },
   { 5134, 5109, 0 },
   { 5187, 49, 0 },
   { 5239, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2, 5, 1 },
   { 8, 10, 1 },
   { 13, 15, 1 },
   { 18, 20, 1 },
   { 23, 25, 1 },
   { 27, 31, 1 },
   { 40, 46, 3 },
   { 238, 61, 0 },
   { 246, 32, 0 },
   { 249, 100, 0 },
   { 5110, 5109, 0 },
   { 5163, 49, 0 },
   { 5215, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2, 5, 1 },
   { 8, 10, 1 },
   { 13, 15, 1 },
   { 18, 20, 1 },
   { 23, 25, 1 },
   { 27, 31, 1 },
   { 40, 46, 3 },
   { 238, 61, 0 },
   { 246, 32, 0 },
   { 249, 100, 0 },
   { 5108, 5109, 0 },
   { 5162, 49, 0 },
   { 5214, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3492, 3493, 0 },
   { 5135, 5109, 0 },
   { 5188, 49, 0 },
   { 5240, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3492, 3493, 0 },
   { 5134, 5109, 0 },
   { 5187, 49, 0 },
   { 5239, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3492, 3493, 0 },
   { 5110, 5109, 0 },
   { 5163, 49, 0 },
   { 5215, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3492, 3493, 0 },
   { 5108, 5109, 0 },
   { 5162, 49, 0 },
   { 5214, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5111, 5109, 0 },
   { 5135, 5109, 0 },
   { 5164, 49, 0 },
   { 5188, 49, 0 },
   { 5240, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5111, 5109, 0 },
   { 5134, 5109, 0 },
   { 5164, 49, 0 },
   { 5187, 49, 0 },
   { 5239, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5110, 5109, 0 },
   { 5111, 5109, 0 },
   { 5163, 49, 0 },
   { 5164, 49, 0 },
   { 5215, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5108, 5109, 0 },
   { 5111, 5109, 0 },
   { 5162, 49, 0 },
   { 5164, 49, 0 },
   { 5214, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5135, 5109, 0 },
   { 5136, 5109, 0 },
   { 5188, 49, 0 },
   { 5189, 49, 0 },
   { 5240, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5134, 5109, 0 },
   { 5136, 5109, 0 },
   { 5187, 49, 0 },
   { 5189, 49, 0 },
   { 5239, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5110, 5109, 0 },
   { 5136, 5109, 0 },
   { 5163, 49, 0 },
   { 5189, 49, 0 },
   { 5215, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5108, 5109, 0 },
   { 5136, 5109, 0 },
   { 5162, 49, 0 },
   { 5189, 49, 0 },
   { 5214, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5135, 5109, 0 },
   { 5188, 49, 0 },
   { 5240, 49, 0 },
   { 5241, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5134, 5109, 0 },
   { 5187, 49, 0 },
   { 5239, 49, 0 },
   { 5241, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5110, 5109, 0 },
   { 5163, 49, 0 },
   { 5215, 49, 0 },
   { 5241, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5108, 5109, 0 },
   { 5162, 49, 0 },
   { 5214, 49, 0 },
   { 5241, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5135, 5109, 0 },
   { 5188, 49, 0 },
   { 5216, 49, 0 },
   { 5240, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5134, 5109, 0 },
   { 5187, 49, 0 },
   { 5216, 49, 0 },
   { 5239, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5110, 5109, 0 },
   { 5163, 49, 0 },
   { 5215, 49, 0 },
   { 5216, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5108, 5109, 0 },
   { 5162, 49, 0 },
   { 5214, 49, 0 },
   { 5216, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5134, 5109, 0 },
   { 5135, 5109, 0 },
   { 5187, 49, 0 },
   { 5188, 49, 0 },
   { 5239, 49, 0 },
   { 5240, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5110, 5109, 0 },
   { 5135, 5109, 0 },
   { 5163, 49, 0 },
   { 5188, 49, 0 },
   { 5215, 49, 0 },
   { 5240, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5108, 5109, 0 },
   { 5135, 5109, 0 },
   { 5162, 49, 0 },
   { 5188, 49, 0 },
   { 5214, 49, 0 },
   { 5240, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5110, 5109, 0 },
   { 5134, 5109, 0 },
   { 5163, 49, 0 },
   { 5187, 49, 0 },
   { 5215, 49, 0 },
   { 5239, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5108, 5109, 0 },
   { 5134, 5109, 0 },
   { 5162, 49, 0 },
   { 5187, 49, 0 },
   { 5214, 49, 0 },
   { 5239, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 5108, 5109, 0 },
   { 5110, 5109, 0 },
   { 5162, 49, 0 },
   { 5163, 49, 0 },
   { 5214, 49, 0 },
   { 5215, 49, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2780, 1229, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 910, 913, 0 },
   { 918, 921, 0 },
   { 926, 929, 0 },
   { 934, 937, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 914, 913, 0 },
   { 922, 921, 0 },
   { 930, 929, 0 },
   { 938, 937, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3869, 3870, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 1038, 1041, 0 },
   { 2781, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 816, 820, 0 },
   { 1020, 1022, 0 },
   { 2781, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 1020, 1022, 0 },
   { 1038, 1041, 0 },
   { 2781, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 2781, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 2781, 32, 0 },
   { 3348, 3350, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2156, 2158, 0 },
   { 2186, 2188, 0 },
   { 2216, 2218, 0 },
   { 2247, 2249, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2786, 1229, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2156, 2158, 0 },
   { 2186, 2188, 0 },
   { 2216, 2218, 0 },
   { 2247, 2249, 0 },
   { 2786, 1229, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 915, 917, 0 },
   { 923, 925, 0 },
   { 931, 933, 0 },
   { 939, 941, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 915, 917, 0 },
   { 923, 925, 0 },
   { 931, 933, 0 },
   { 939, 941, 0 },
   { 2156, 2158, 0 },
   { 2186, 2188, 0 },
   { 2216, 2218, 0 },
   { 2247, 2249, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2787, 32, 0 },
   { 3250, 3251, 58 },
   { 1017, 422, 58 },
   { 3253, 3255, 58 },
   { 1008, 447, 59 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2787, 32, 0 },
   { 3250, 3251, 58 },
   { 1017, 422, 58 },
   { 3253, 3255, 58 },
   { 1008, 447, 59 },
   { 3351, 3347, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3169, 32, 0 },
   { 3690, 3688, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3169, 32, 0 },
   { 3687, 3688, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3169, 32, 0 },
   { 3687, 3688, 0 },
   { 3690, 3688, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1156, 1155, 0 },
   { 2714, 1235, 0 },
   { 3189, 1077, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1160, 1159, 0 },
   { 2714, 1235, 0 },
   { 3189, 1077, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1105, 1106, 0 },
   { 1214, 1217, 0 },
   { 2690, 1257, 0 },
   { 2714, 1235, 0 },
   { 3189, 1077, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1154, 1155, 0 },
   { 1191, 1192, 0 },
   { 2714, 1235, 0 },
   { 3189, 1077, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1158, 1159, 0 },
   { 2714, 1235, 0 },
   { 3189, 1077, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1157, 1155, 0 },
   { 2690, 1257, 0 },
   { 2714, 1235, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1091, 1092, 0 },
   { 1164, 1162, 0 },
   { 2690, 1257, 0 },
   { 2714, 1235, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1141, 1138, 0 },
   { 2715, 1077, 0 },
   { 3188, 1235, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1148, 1146, 0 },
   { 2715, 1077, 0 },
   { 3188, 1235, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1103, 1104, 0 },
   { 1220, 1221, 0 },
   { 2689, 1253, 0 },
   { 2715, 1077, 0 },
   { 3188, 1235, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1137, 1138, 0 },
   { 1193, 1194, 0 },
   { 2715, 1077, 0 },
   { 3188, 1235, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1145, 1146, 0 },
   { 2715, 1077, 0 },
   { 3188, 1235, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1143, 1138, 0 },
   { 2689, 1253, 0 },
   { 2715, 1077, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1093, 1094, 0 },
   { 1153, 1151, 0 },
   { 2689, 1253, 0 },
   { 2715, 1077, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 383, 269, 9 },
   { 3674, 3675, 0 },
   { 3677, 3678, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 255, 253, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 221, 111, 0 },
   { 222, 113, 5 },
   { 223, 115, 6 },
   { 242, 32, 0 },
   { 245, 32, 0 },
   { 248, 98, 0 },
   { 383, 269, 9 },
   { 3674, 3675, 0 },
   { 3677, 3678, 0 },
   { 5610, 5613, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 221, 111, 0 },
   { 222, 113, 5 },
   { 223, 115, 6 },
   { 242, 32, 0 },
   { 245, 32, 0 },
   { 248, 98, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 221, 111, 0 },
   { 222, 113, 5 },
   { 223, 115, 6 },
   { 242, 32, 0 },
   { 245, 32, 0 },
   { 248, 98, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 221, 111, 0 },
   { 222, 113, 5 },
   { 223, 115, 6 },
   { 242, 32, 0 },
   { 245, 32, 0 },
   { 248, 98, 0 },
   { 255, 253, 0 },
   { 3497, 3499, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 221, 111, 0 },
   { 222, 113, 5 },
   { 223, 115, 6 },
   { 242, 32, 0 },
   { 245, 32, 0 },
   { 248, 98, 0 },
   { 255, 253, 0 },
   { 3497, 3499, 0 },
   { 3542, 3499, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 383, 269, 9 },
   { 3484, 3485, 0 },
   { 3674, 3675, 0 },
   { 3677, 3678, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3484, 3485, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3484, 3485, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 255, 253, 0 },
   { 3484, 3485, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 383, 269, 9 },
   { 3674, 3675, 0 },
   { 3677, 3678, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3484, 3485, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 255, 253, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 383, 269, 9 },
   { 3674, 3675, 0 },
   { 3677, 3678, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 252, 253, 0 },
   { 255, 253, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3674, 3675, 0 },
   { 3677, 3678, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3674, 3675, 0 },
   { 3677, 3678, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 255, 253, 0 },
   { 3674, 3675, 0 },
   { 3677, 3678, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 383, 269, 9 },
   { 3674, 3675, 0 },
   { 3677, 3678, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 255, 253, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 383, 269, 9 },
   { 3674, 3675, 0 },
   { 3677, 3678, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 255, 253, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 378, 379, 9 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 378, 379, 9 },
   { 383, 269, 9 },
   { 3674, 3675, 0 },
   { 3677, 3678, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 383, 269, 9 },
   { 3674, 3675, 0 },
   { 3677, 3678, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 383, 269, 9 },
   { 3674, 3675, 0 },
   { 3677, 3678, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 255, 253, 0 },
   { 383, 269, 9 },
   { 3674, 3675, 0 },
   { 3677, 3678, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 255, 253, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 255, 253, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 143, 145, 0 },
   { 519, 520, 0 },
   { 587, 588, 0 },
   { 659, 660, 0 },
   { 737, 739, 29 },
   { 234, 741, 30 },
   { 742, 744, 31 },
   { 745, 739, 32 },
   { 746, 741, 33 },
   { 747, 744, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 386, 387, 9 },
   { 737, 739, 29 },
   { 234, 741, 30 },
   { 742, 744, 31 },
   { 745, 739, 32 },
   { 746, 741, 33 },
   { 747, 744, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 263, 264, 0 },
   { 265, 266, 5 },
   { 267, 227, 6 },
   { 386, 387, 9 },
   { 737, 739, 29 },
   { 234, 741, 30 },
   { 742, 744, 31 },
   { 745, 739, 32 },
   { 746, 741, 33 },
   { 747, 744, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 147, 148, 0 },
   { 386, 387, 9 },
   { 737, 739, 29 },
   { 234, 741, 30 },
   { 742, 744, 31 },
   { 745, 739, 32 },
   { 746, 741, 33 },
   { 747, 744, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 143, 145, 0 },
   { 386, 387, 9 },
   { 737, 739, 29 },
   { 234, 741, 30 },
   { 742, 744, 31 },
   { 745, 739, 32 },
   { 746, 741, 33 },
   { 747, 744, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 143, 145, 0 },
   { 257, 3, 0 },
   { 259, 258, 5 },
   { 260, 36, 6 },
   { 271, 272, 0 },
   { 276, 277, 0 },
   { 519, 520, 0 },
   { 587, 588, 0 },
   { 659, 660, 0 },
   { 737, 739, 29 },
   { 234, 741, 30 },
   { 742, 744, 31 },
   { 745, 739, 32 },
   { 746, 741, 33 },
   { 747, 744, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 257, 3, 0 },
   { 259, 258, 5 },
   { 260, 36, 6 },
   { 271, 272, 0 },
   { 276, 277, 0 },
   { 386, 387, 9 },
   { 737, 739, 29 },
   { 234, 741, 30 },
   { 742, 744, 31 },
   { 745, 739, 32 },
   { 746, 741, 33 },
   { 747, 744, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 257, 3, 0 },
   { 259, 258, 5 },
   { 260, 36, 6 },
   { 263, 264, 0 },
   { 265, 266, 5 },
   { 267, 227, 6 },
   { 271, 272, 0 },
   { 276, 277, 0 },
   { 386, 387, 9 },
   { 737, 739, 29 },
   { 234, 741, 30 },
   { 742, 744, 31 },
   { 745, 739, 32 },
   { 746, 741, 33 },
   { 747, 744, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 147, 148, 0 },
   { 257, 3, 0 },
   { 259, 258, 5 },
   { 260, 36, 6 },
   { 271, 272, 0 },
   { 276, 277, 0 },
   { 386, 387, 9 },
   { 737, 739, 29 },
   { 234, 741, 30 },
   { 742, 744, 31 },
   { 745, 739, 32 },
   { 746, 741, 33 },
   { 747, 744, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 143, 145, 0 },
   { 257, 3, 0 },
   { 259, 258, 5 },
   { 260, 36, 6 },
   { 271, 272, 0 },
   { 276, 277, 0 },
   { 386, 387, 9 },
   { 737, 739, 29 },
   { 234, 741, 30 },
   { 742, 744, 31 },
   { 745, 739, 32 },
   { 746, 741, 33 },
   { 747, 744, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 143, 145, 0 },
   { 519, 520, 0 },
   { 587, 588, 0 },
   { 659, 660, 0 },
   { 737, 739, 29 },
   { 234, 741, 30 },
   { 742, 744, 31 },
   { 745, 739, 32 },
   { 746, 741, 33 },
   { 747, 744, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 386, 387, 9 },
   { 737, 739, 29 },
   { 234, 741, 30 },
   { 742, 744, 31 },
   { 745, 739, 32 },
   { 746, 741, 33 },
   { 747, 744, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 263, 264, 0 },
   { 265, 266, 5 },
   { 267, 227, 6 },
   { 386, 387, 9 },
   { 737, 739, 29 },
   { 234, 741, 30 },
   { 742, 744, 31 },
   { 745, 739, 32 },
   { 746, 741, 33 },
   { 747, 744, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 147, 148, 0 },
   { 386, 387, 9 },
   { 737, 739, 29 },
   { 234, 741, 30 },
   { 742, 744, 31 },
   { 745, 739, 32 },
   { 746, 741, 33 },
   { 747, 744, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 143, 145, 0 },
   { 386, 387, 9 },
   { 737, 739, 29 },
   { 234, 741, 30 },
   { 742, 744, 31 },
   { 745, 739, 32 },
   { 746, 741, 33 },
   { 747, 744, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 147, 148, 0 },
   { 160, 162, 0 },
   { 386, 387, 9 },
   { 737, 739, 29 },
   { 234, 741, 30 },
   { 742, 744, 31 },
   { 745, 739, 32 },
   { 746, 741, 33 },
   { 747, 744, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 143, 145, 0 },
   { 386, 387, 9 },
   { 519, 520, 0 },
   { 587, 588, 0 },
   { 659, 660, 0 },
   { 737, 739, 29 },
   { 234, 741, 30 },
   { 742, 744, 31 },
   { 745, 739, 32 },
   { 746, 741, 33 },
   { 747, 744, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 524, 525, 0 },
   { 591, 592, 0 },
   { 663, 664, 0 },
   { 737, 739, 29 },
   { 234, 741, 30 },
   { 742, 744, 31 },
   { 745, 739, 32 },
   { 746, 741, 33 },
   { 747, 744, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 263, 264, 0 },
   { 265, 266, 5 },
   { 267, 227, 6 },
   { 524, 525, 0 },
   { 591, 592, 0 },
   { 663, 664, 0 },
   { 737, 739, 29 },
   { 234, 741, 30 },
   { 742, 744, 31 },
   { 745, 739, 32 },
   { 746, 741, 33 },
   { 747, 744, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 147, 148, 0 },
   { 524, 525, 0 },
   { 591, 592, 0 },
   { 663, 664, 0 },
   { 737, 739, 29 },
   { 234, 741, 30 },
   { 742, 744, 31 },
   { 745, 739, 32 },
   { 746, 741, 33 },
   { 747, 744, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 143, 145, 0 },
   { 524, 525, 0 },
   { 591, 592, 0 },
   { 663, 664, 0 },
   { 737, 739, 29 },
   { 234, 741, 30 },
   { 742, 744, 31 },
   { 745, 739, 32 },
   { 746, 741, 33 },
   { 747, 744, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 143, 145, 0 },
   { 519, 520, 0 },
   { 524, 525, 0 },
   { 587, 588, 0 },
   { 591, 592, 0 },
   { 659, 660, 0 },
   { 663, 664, 0 },
   { 737, 739, 29 },
   { 234, 741, 30 },
   { 742, 744, 31 },
   { 745, 739, 32 },
   { 746, 741, 33 },
   { 747, 744, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 147, 148, 0 },
   { 530, 532, 0 },
   { 596, 598, 0 },
   { 669, 671, 0 },
   { 737, 739, 29 },
   { 234, 741, 30 },
   { 742, 744, 31 },
   { 745, 739, 32 },
   { 746, 741, 33 },
   { 747, 744, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 384, 385, 9 },
   { 737, 739, 29 },
   { 234, 741, 30 },
   { 742, 744, 31 },
   { 745, 739, 32 },
   { 746, 741, 33 },
   { 747, 744, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 263, 264, 0 },
   { 265, 266, 5 },
   { 267, 227, 6 },
   { 384, 385, 9 },
   { 737, 739, 29 },
   { 234, 741, 30 },
   { 742, 744, 31 },
   { 745, 739, 32 },
   { 746, 741, 33 },
   { 747, 744, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 147, 148, 0 },
   { 384, 385, 9 },
   { 737, 739, 29 },
   { 234, 741, 30 },
   { 742, 744, 31 },
   { 745, 739, 32 },
   { 746, 741, 33 },
   { 747, 744, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 143, 145, 0 },
   { 384, 385, 9 },
   { 737, 739, 29 },
   { 234, 741, 30 },
   { 742, 744, 31 },
   { 745, 739, 32 },
   { 746, 741, 33 },
   { 747, 744, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 384, 385, 9 },
   { 386, 387, 9 },
   { 737, 739, 29 },
   { 234, 741, 30 },
   { 742, 744, 31 },
   { 745, 739, 32 },
   { 746, 741, 33 },
   { 747, 744, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 263, 264, 0 },
   { 265, 266, 5 },
   { 267, 227, 6 },
   { 384, 385, 9 },
   { 386, 387, 9 },
   { 737, 739, 29 },
   { 234, 741, 30 },
   { 742, 744, 31 },
   { 745, 739, 32 },
   { 746, 741, 33 },
   { 747, 744, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 147, 148, 0 },
   { 384, 385, 9 },
   { 386, 387, 9 },
   { 737, 739, 29 },
   { 234, 741, 30 },
   { 742, 744, 31 },
   { 745, 739, 32 },
   { 746, 741, 33 },
   { 747, 744, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 143, 145, 0 },
   { 384, 385, 9 },
   { 386, 387, 9 },
   { 737, 739, 29 },
   { 234, 741, 30 },
   { 742, 744, 31 },
   { 745, 739, 32 },
   { 746, 741, 33 },
   { 747, 744, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2721, 32, 0 },
   { 5141, 2081, 0 },
   { 5194, 2085, 0 },
   { 5246, 2085, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2721, 32, 0 },
   { 5140, 2081, 0 },
   { 5193, 2085, 0 },
   { 5245, 2085, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2721, 32, 0 },
   { 5116, 2081, 0 },
   { 5169, 2085, 0 },
   { 5221, 2085, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2721, 32, 0 },
   { 5115, 2081, 0 },
   { 5168, 2085, 0 },
   { 5220, 2085, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2721, 32, 0 },
   { 2722, 32, 0 },
   { 2723, 63, 0 },
   { 2758, 2760, 0 },
   { 2761, 2763, 0 },
   { 2764, 2765, 0 },
   { 2766, 2767, 0 },
   { 5141, 2081, 0 },
   { 5194, 2085, 0 },
   { 5246, 2085, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2721, 32, 0 },
   { 2722, 32, 0 },
   { 2723, 63, 0 },
   { 2758, 2760, 0 },
   { 2761, 2763, 0 },
   { 2764, 2765, 0 },
   { 2766, 2767, 0 },
   { 5140, 2081, 0 },
   { 5193, 2085, 0 },
   { 5245, 2085, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2721, 32, 0 },
   { 2722, 32, 0 },
   { 2723, 63, 0 },
   { 2758, 2760, 0 },
   { 2761, 2763, 0 },
   { 2764, 2765, 0 },
   { 2766, 2767, 0 },
   { 5116, 2081, 0 },
   { 5169, 2085, 0 },
   { 5221, 2085, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2721, 32, 0 },
   { 2722, 32, 0 },
   { 2723, 63, 0 },
   { 2758, 2760, 0 },
   { 2761, 2763, 0 },
   { 2764, 2765, 0 },
   { 2766, 2767, 0 },
   { 5115, 2081, 0 },
   { 5168, 2085, 0 },
   { 5220, 2085, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2721, 32, 0 },
   { 2795, 2792, 49 },
   { 2802, 2799, 49 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2721, 32, 0 },
   { 2731, 3, 0 },
   { 5141, 2081, 0 },
   { 5194, 2085, 0 },
   { 5246, 2085, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2721, 32, 0 },
   { 2731, 3, 0 },
   { 5140, 2081, 0 },
   { 5193, 2085, 0 },
   { 5245, 2085, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2721, 32, 0 },
   { 2731, 3, 0 },
   { 5116, 2081, 0 },
   { 5169, 2085, 0 },
   { 5221, 2085, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2721, 32, 0 },
   { 2731, 3, 0 },
   { 5115, 2081, 0 },
   { 5168, 2085, 0 },
   { 5220, 2085, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2721, 32, 0 },
   { 2732, 2354, 0 },
   { 5141, 2081, 0 },
   { 5194, 2085, 0 },
   { 5246, 2085, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2721, 32, 0 },
   { 2732, 2354, 0 },
   { 5140, 2081, 0 },
   { 5193, 2085, 0 },
   { 5245, 2085, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2721, 32, 0 },
   { 2732, 2354, 0 },
   { 5116, 2081, 0 },
   { 5169, 2085, 0 },
   { 5221, 2085, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2721, 32, 0 },
   { 2732, 2354, 0 },
   { 5115, 2081, 0 },
   { 5168, 2085, 0 },
   { 5220, 2085, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2263, 1235, 0 },
   { 2721, 32, 0 },
   { 5141, 2081, 0 },
   { 5194, 2085, 0 },
   { 5246, 2085, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2263, 1235, 0 },
   { 2721, 32, 0 },
   { 5140, 2081, 0 },
   { 5193, 2085, 0 },
   { 5245, 2085, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2263, 1235, 0 },
   { 2721, 32, 0 },
   { 5116, 2081, 0 },
   { 5169, 2085, 0 },
   { 5221, 2085, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2263, 1235, 0 },
   { 2721, 32, 0 },
   { 5115, 2081, 0 },
   { 5168, 2085, 0 },
   { 5220, 2085, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2721, 32, 0 },
   { 2807, 2805, 49 },
   { 2812, 2810, 49 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2721, 32, 0 },
   { 2724, 63, 0 },
   { 5141, 2081, 0 },
   { 5194, 2085, 0 },
   { 5246, 2085, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2721, 32, 0 },
   { 2724, 63, 0 },
   { 5140, 2081, 0 },
   { 5193, 2085, 0 },
   { 5245, 2085, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2721, 32, 0 },
   { 2724, 63, 0 },
   { 5116, 2081, 0 },
   { 5169, 2085, 0 },
   { 5221, 2085, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2721, 32, 0 },
   { 2724, 63, 0 },
   { 5115, 2081, 0 },
   { 5168, 2085, 0 },
   { 5220, 2085, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1716, 1719, 0 },
   { 1723, 1719, 0 },
   { 1728, 1731, 0 },
   { 1735, 1731, 0 },
   { 2721, 32, 0 },
   { 2732, 2354, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2721, 32, 0 },
   { 5141, 2081, 0 },
   { 5194, 2085, 0 },
   { 5246, 2085, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2721, 32, 0 },
   { 5140, 2081, 0 },
   { 5193, 2085, 0 },
   { 5245, 2085, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2721, 32, 0 },
   { 5116, 2081, 0 },
   { 5169, 2085, 0 },
   { 5221, 2085, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2721, 32, 0 },
   { 5115, 2081, 0 },
   { 5168, 2085, 0 },
   { 5220, 2085, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2721, 32, 0 },
   { 5117, 2081, 0 },
   { 5141, 2081, 0 },
   { 5170, 2085, 0 },
   { 5194, 2085, 0 },
   { 5246, 2085, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2721, 32, 0 },
   { 5117, 2081, 0 },
   { 5140, 2081, 0 },
   { 5170, 2085, 0 },
   { 5193, 2085, 0 },
   { 5245, 2085, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2721, 32, 0 },
   { 5116, 2081, 0 },
   { 5117, 2081, 0 },
   { 5169, 2085, 0 },
   { 5170, 2085, 0 },
   { 5221, 2085, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2721, 32, 0 },
   { 5115, 2081, 0 },
   { 5117, 2081, 0 },
   { 5168, 2085, 0 },
   { 5170, 2085, 0 },
   { 5220, 2085, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2721, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2721, 32, 0 },
   { 5141, 2081, 0 },
   { 5142, 2081, 0 },
   { 5194, 2085, 0 },
   { 5195, 2085, 0 },
   { 5246, 2085, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2721, 32, 0 },
   { 5140, 2081, 0 },
   { 5142, 2081, 0 },
   { 5193, 2085, 0 },
   { 5195, 2085, 0 },
   { 5245, 2085, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2721, 32, 0 },
   { 5116, 2081, 0 },
   { 5142, 2081, 0 },
   { 5169, 2085, 0 },
   { 5195, 2085, 0 },
   { 5221, 2085, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2721, 32, 0 },
   { 5115, 2081, 0 },
   { 5142, 2081, 0 },
   { 5168, 2085, 0 },
   { 5195, 2085, 0 },
   { 5220, 2085, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2721, 32, 0 },
   { 5141, 2081, 0 },
   { 5194, 2085, 0 },
   { 5246, 2085, 0 },
   { 5247, 2085, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2721, 32, 0 },
   { 5140, 2081, 0 },
   { 5193, 2085, 0 },
   { 5245, 2085, 0 },
   { 5247, 2085, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2721, 32, 0 },
   { 5116, 2081, 0 },
   { 5169, 2085, 0 },
   { 5221, 2085, 0 },
   { 5247, 2085, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2721, 32, 0 },
   { 5115, 2081, 0 },
   { 5168, 2085, 0 },
   { 5220, 2085, 0 },
   { 5247, 2085, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2721, 32, 0 },
   { 5141, 2081, 0 },
   { 5194, 2085, 0 },
   { 5222, 2085, 0 },
   { 5246, 2085, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2721, 32, 0 },
   { 5140, 2081, 0 },
   { 5193, 2085, 0 },
   { 5222, 2085, 0 },
   { 5245, 2085, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2721, 32, 0 },
   { 5116, 2081, 0 },
   { 5169, 2085, 0 },
   { 5221, 2085, 0 },
   { 5222, 2085, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2721, 32, 0 },
   { 5115, 2081, 0 },
   { 5168, 2085, 0 },
   { 5220, 2085, 0 },
   { 5222, 2085, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2721, 32, 0 },
   { 2795, 2792, 49 },
   { 2802, 2799, 49 },
   { 2807, 2805, 49 },
   { 2812, 2810, 49 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2721, 32, 0 },
   { 5116, 2081, 0 },
   { 5169, 2085, 0 },
   { 5221, 2085, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2721, 32, 0 },
   { 5115, 2081, 0 },
   { 5168, 2085, 0 },
   { 5220, 2085, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2721, 32, 0 },
   { 3104, 3105, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2721, 32, 0 },
   { 5140, 2081, 0 },
   { 5141, 2081, 0 },
   { 5193, 2085, 0 },
   { 5194, 2085, 0 },
   { 5245, 2085, 0 },
   { 5246, 2085, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2721, 32, 0 },
   { 5116, 2081, 0 },
   { 5141, 2081, 0 },
   { 5169, 2085, 0 },
   { 5194, 2085, 0 },
   { 5221, 2085, 0 },
   { 5246, 2085, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2721, 32, 0 },
   { 5115, 2081, 0 },
   { 5141, 2081, 0 },
   { 5168, 2085, 0 },
   { 5194, 2085, 0 },
   { 5220, 2085, 0 },
   { 5246, 2085, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2721, 32, 0 },
   { 5116, 2081, 0 },
   { 5140, 2081, 0 },
   { 5169, 2085, 0 },
   { 5193, 2085, 0 },
   { 5221, 2085, 0 },
   { 5245, 2085, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2721, 32, 0 },
   { 5115, 2081, 0 },
   { 5140, 2081, 0 },
   { 5168, 2085, 0 },
   { 5193, 2085, 0 },
   { 5220, 2085, 0 },
   { 5245, 2085, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2721, 32, 0 },
   { 5115, 2081, 0 },
   { 5116, 2081, 0 },
   { 5168, 2085, 0 },
   { 5169, 2085, 0 },
   { 5220, 2085, 0 },
   { 5221, 2085, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2721, 32, 0 },
   { 5115, 2081, 0 },
   { 5168, 2085, 0 },
   { 5220, 2085, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2721, 32, 0 },
   { 3356, 3355, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4219, 4220, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4225, 4226, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4231, 4232, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4214, 4217, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4222, 4223, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4228, 4229, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2716, 32, 0 },
   { 2733, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2716, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1418, 1419, 0 },
   { 1440, 1441, 0 },
   { 1462, 1463, 0 },
   { 1482, 1483, 0 },
   { 2716, 32, 0 },
   { 2720, 61, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2716, 32, 0 },
   { 5138, 2039, 0 },
   { 5191, 2047, 0 },
   { 5243, 2047, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2716, 32, 0 },
   { 5137, 2039, 0 },
   { 5190, 2047, 0 },
   { 5242, 2047, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2716, 32, 0 },
   { 5113, 2039, 0 },
   { 5166, 2047, 0 },
   { 5218, 2047, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2716, 32, 0 },
   { 5112, 2039, 0 },
   { 5165, 2047, 0 },
   { 5217, 2047, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2699, 2700, 0 },
   { 2702, 2703, 0 },
   { 2716, 32, 0 },
   { 2717, 61, 0 },
   { 2718, 32, 0 },
   { 2733, 3, 0 },
   { 2741, 2745, 0 },
   { 2747, 2751, 0 },
   { 2753, 2754, 0 },
   { 2756, 2757, 0 },
   { 3261, 3262, 58 },
   { 3292, 3293, 59 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2699, 2700, 0 },
   { 2702, 2703, 0 },
   { 2716, 32, 0 },
   { 2717, 61, 0 },
   { 2718, 32, 0 },
   { 2733, 3, 0 },
   { 2741, 2745, 0 },
   { 2747, 2751, 0 },
   { 2753, 2754, 0 },
   { 2756, 2757, 0 },
   { 3261, 3262, 58 },
   { 3292, 3293, 59 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2699, 2700, 0 },
   { 2702, 2703, 0 },
   { 2716, 32, 0 },
   { 2717, 61, 0 },
   { 2718, 32, 0 },
   { 2741, 2745, 0 },
   { 2747, 2751, 0 },
   { 2753, 2754, 0 },
   { 2756, 2757, 0 },
   { 3113, 1528, 0 },
   { 3114, 3111, 0 },
   { 3261, 3262, 58 },
   { 3292, 3293, 59 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2699, 2700, 0 },
   { 2702, 2703, 0 },
   { 2716, 32, 0 },
   { 2717, 61, 0 },
   { 2718, 32, 0 },
   { 2741, 2745, 0 },
   { 2747, 2751, 0 },
   { 2753, 2754, 0 },
   { 2756, 2757, 0 },
   { 3261, 3262, 58 },
   { 3292, 3293, 59 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1418, 1419, 0 },
   { 1440, 1441, 0 },
   { 1462, 1463, 0 },
   { 1482, 1483, 0 },
   { 2699, 2700, 0 },
   { 2702, 2703, 0 },
   { 2716, 32, 0 },
   { 2717, 61, 0 },
   { 2718, 32, 0 },
   { 2720, 61, 0 },
   { 2741, 2745, 0 },
   { 2747, 2751, 0 },
   { 2753, 2754, 0 },
   { 2756, 2757, 0 },
   { 3261, 3262, 58 },
   { 3292, 3293, 59 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2699, 2700, 0 },
   { 2702, 2703, 0 },
   { 2716, 32, 0 },
   { 2717, 61, 0 },
   { 2718, 32, 0 },
   { 2741, 2745, 0 },
   { 2747, 2751, 0 },
   { 2753, 2754, 0 },
   { 2756, 2757, 0 },
   { 3261, 3262, 58 },
   { 3292, 3293, 59 },
   { 5138, 2039, 0 },
   { 5191, 2047, 0 },
   { 5243, 2047, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2699, 2700, 0 },
   { 2702, 2703, 0 },
   { 2716, 32, 0 },
   { 2717, 61, 0 },
   { 2718, 32, 0 },
   { 2741, 2745, 0 },
   { 2747, 2751, 0 },
   { 2753, 2754, 0 },
   { 2756, 2757, 0 },
   { 3261, 3262, 58 },
   { 3292, 3293, 59 },
   { 5137, 2039, 0 },
   { 5190, 2047, 0 },
   { 5242, 2047, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2699, 2700, 0 },
   { 2702, 2703, 0 },
   { 2716, 32, 0 },
   { 2717, 61, 0 },
   { 2718, 32, 0 },
   { 2741, 2745, 0 },
   { 2747, 2751, 0 },
   { 2753, 2754, 0 },
   { 2756, 2757, 0 },
   { 3261, 3262, 58 },
   { 3292, 3293, 59 },
   { 5113, 2039, 0 },
   { 5166, 2047, 0 },
   { 5218, 2047, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2028, 2031, 0 },
   { 2699, 2700, 0 },
   { 2702, 2703, 0 },
   { 2716, 32, 0 },
   { 2717, 61, 0 },
   { 2718, 32, 0 },
   { 2741, 2745, 0 },
   { 2747, 2751, 0 },
   { 2753, 2754, 0 },
   { 2756, 2757, 0 },
   { 3261, 3262, 58 },
   { 3292, 3293, 59 },
   { 5112, 2039, 0 },
   { 5165, 2047, 0 },
   { 5217, 2047, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2716, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2716, 32, 0 },
   { 2733, 3, 0 },
   { 2734, 2735, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2716, 32, 0 },
   { 2734, 2735, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1418, 1419, 0 },
   { 1440, 1441, 0 },
   { 1462, 1463, 0 },
   { 1482, 1483, 0 },
   { 2716, 32, 0 },
   { 2720, 61, 0 },
   { 2734, 2735, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2716, 32, 0 },
   { 2734, 2735, 0 },
   { 5138, 2039, 0 },
   { 5191, 2047, 0 },
   { 5243, 2047, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2716, 32, 0 },
   { 2734, 2735, 0 },
   { 5137, 2039, 0 },
   { 5190, 2047, 0 },
   { 5242, 2047, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2716, 32, 0 },
   { 2734, 2735, 0 },
   { 5113, 2039, 0 },
   { 5166, 2047, 0 },
   { 5218, 2047, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2716, 32, 0 },
   { 2734, 2735, 0 },
   { 5112, 2039, 0 },
   { 5165, 2047, 0 },
   { 5217, 2047, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 191, 193, 0 },
   { 2716, 32, 0 },
   { 2733, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2716, 32, 0 },
   { 2733, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1418, 1419, 0 },
   { 1440, 1441, 0 },
   { 1462, 1463, 0 },
   { 1482, 1483, 0 },
   { 2716, 32, 0 },
   { 2720, 61, 0 },
   { 2733, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2716, 32, 0 },
   { 2733, 3, 0 },
   { 5138, 2039, 0 },
   { 5191, 2047, 0 },
   { 5243, 2047, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2716, 32, 0 },
   { 2733, 3, 0 },
   { 5137, 2039, 0 },
   { 5190, 2047, 0 },
   { 5242, 2047, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2716, 32, 0 },
   { 2733, 3, 0 },
   { 5113, 2039, 0 },
   { 5166, 2047, 0 },
   { 5218, 2047, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2716, 32, 0 },
   { 2733, 3, 0 },
   { 5112, 2039, 0 },
   { 5165, 2047, 0 },
   { 5217, 2047, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2130, 2132, 43 },
   { 2130, 2138, 45 },
   { 2161, 2163, 43 },
   { 2161, 2169, 45 },
   { 2191, 2193, 43 },
   { 2191, 2199, 45 },
   { 2221, 2223, 43 },
   { 2221, 2229, 45 },
   { 2716, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1082, 1077, 0 },
   { 2716, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2716, 32, 0 },
   { 2720, 61, 0 },
   { 2733, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2716, 32, 0 },
   { 2720, 61, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1418, 1419, 0 },
   { 1440, 1441, 0 },
   { 1462, 1463, 0 },
   { 1482, 1483, 0 },
   { 2716, 32, 0 },
   { 2720, 61, 0 },
   { 2776, 2777, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2716, 32, 0 },
   { 2720, 61, 0 },
   { 5138, 2039, 0 },
   { 5191, 2047, 0 },
   { 5243, 2047, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2716, 32, 0 },
   { 2720, 61, 0 },
   { 5137, 2039, 0 },
   { 5190, 2047, 0 },
   { 5242, 2047, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2716, 32, 0 },
   { 2720, 61, 0 },
   { 5113, 2039, 0 },
   { 5166, 2047, 0 },
   { 5218, 2047, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2716, 32, 0 },
   { 2720, 61, 0 },
   { 5112, 2039, 0 },
   { 5165, 2047, 0 },
   { 5217, 2047, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2716, 32, 0 },
   { 2733, 3, 0 },
   { 5114, 2039, 0 },
   { 5167, 2047, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2716, 32, 0 },
   { 5114, 2039, 0 },
   { 5167, 2047, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1418, 1419, 0 },
   { 1440, 1441, 0 },
   { 1462, 1463, 0 },
   { 1482, 1483, 0 },
   { 2716, 32, 0 },
   { 2720, 61, 0 },
   { 5114, 2039, 0 },
   { 5167, 2047, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2716, 32, 0 },
   { 5114, 2039, 0 },
   { 5138, 2039, 0 },
   { 5167, 2047, 0 },
   { 5191, 2047, 0 },
   { 5243, 2047, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2716, 32, 0 },
   { 5114, 2039, 0 },
   { 5137, 2039, 0 },
   { 5167, 2047, 0 },
   { 5190, 2047, 0 },
   { 5242, 2047, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2716, 32, 0 },
   { 5113, 2039, 0 },
   { 5114, 2039, 0 },
   { 5166, 2047, 0 },
   { 5167, 2047, 0 },
   { 5218, 2047, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2716, 32, 0 },
   { 5112, 2039, 0 },
   { 5114, 2039, 0 },
   { 5165, 2047, 0 },
   { 5167, 2047, 0 },
   { 5217, 2047, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2716, 32, 0 },
   { 2733, 3, 0 },
   { 5139, 2039, 0 },
   { 5192, 2047, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2716, 32, 0 },
   { 5139, 2039, 0 },
   { 5192, 2047, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1418, 1419, 0 },
   { 1440, 1441, 0 },
   { 1462, 1463, 0 },
   { 1482, 1483, 0 },
   { 2716, 32, 0 },
   { 2720, 61, 0 },
   { 5139, 2039, 0 },
   { 5192, 2047, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2716, 32, 0 },
   { 5138, 2039, 0 },
   { 5139, 2039, 0 },
   { 5191, 2047, 0 },
   { 5192, 2047, 0 },
   { 5243, 2047, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2716, 32, 0 },
   { 5137, 2039, 0 },
   { 5139, 2039, 0 },
   { 5190, 2047, 0 },
   { 5192, 2047, 0 },
   { 5242, 2047, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2716, 32, 0 },
   { 5113, 2039, 0 },
   { 5139, 2039, 0 },
   { 5166, 2047, 0 },
   { 5192, 2047, 0 },
   { 5218, 2047, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2716, 32, 0 },
   { 5112, 2039, 0 },
   { 5139, 2039, 0 },
   { 5165, 2047, 0 },
   { 5192, 2047, 0 },
   { 5217, 2047, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2716, 32, 0 },
   { 2733, 3, 0 },
   { 5244, 2047, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2716, 32, 0 },
   { 5244, 2047, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1418, 1419, 0 },
   { 1440, 1441, 0 },
   { 1462, 1463, 0 },
   { 1482, 1483, 0 },
   { 2716, 32, 0 },
   { 2720, 61, 0 },
   { 5244, 2047, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2716, 32, 0 },
   { 5138, 2039, 0 },
   { 5191, 2047, 0 },
   { 5243, 2047, 0 },
   { 5244, 2047, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2716, 32, 0 },
   { 5137, 2039, 0 },
   { 5190, 2047, 0 },
   { 5242, 2047, 0 },
   { 5244, 2047, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2716, 32, 0 },
   { 5113, 2039, 0 },
   { 5166, 2047, 0 },
   { 5218, 2047, 0 },
   { 5244, 2047, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2716, 32, 0 },
   { 5112, 2039, 0 },
   { 5165, 2047, 0 },
   { 5217, 2047, 0 },
   { 5244, 2047, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2716, 32, 0 },
   { 2733, 3, 0 },
   { 5219, 2047, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2716, 32, 0 },
   { 5219, 2047, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1418, 1419, 0 },
   { 1440, 1441, 0 },
   { 1462, 1463, 0 },
   { 1482, 1483, 0 },
   { 2716, 32, 0 },
   { 2720, 61, 0 },
   { 5219, 2047, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2716, 32, 0 },
   { 5138, 2039, 0 },
   { 5191, 2047, 0 },
   { 5219, 2047, 0 },
   { 5243, 2047, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2716, 32, 0 },
   { 5137, 2039, 0 },
   { 5190, 2047, 0 },
   { 5219, 2047, 0 },
   { 5242, 2047, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2716, 32, 0 },
   { 5113, 2039, 0 },
   { 5166, 2047, 0 },
   { 5218, 2047, 0 },
   { 5219, 2047, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2716, 32, 0 },
   { 5112, 2039, 0 },
   { 5165, 2047, 0 },
   { 5217, 2047, 0 },
   { 5219, 2047, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2716, 32, 0 },
   { 2733, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1418, 1419, 0 },
   { 1440, 1441, 0 },
   { 1462, 1463, 0 },
   { 1482, 1483, 0 },
   { 2716, 32, 0 },
   { 2720, 61, 0 },
   { 2733, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2716, 32, 0 },
   { 2733, 3, 0 },
   { 5138, 2039, 0 },
   { 5191, 2047, 0 },
   { 5243, 2047, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2716, 32, 0 },
   { 2733, 3, 0 },
   { 5137, 2039, 0 },
   { 5190, 2047, 0 },
   { 5242, 2047, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2716, 32, 0 },
   { 2733, 3, 0 },
   { 5113, 2039, 0 },
   { 5166, 2047, 0 },
   { 5218, 2047, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2716, 32, 0 },
   { 2733, 3, 0 },
   { 5112, 2039, 0 },
   { 5165, 2047, 0 },
   { 5217, 2047, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2716, 32, 0 },
   { 3102, 3103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1418, 1419, 0 },
   { 1440, 1441, 0 },
   { 1462, 1463, 0 },
   { 1482, 1483, 0 },
   { 2716, 32, 0 },
   { 2720, 61, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2716, 32, 0 },
   { 5138, 2039, 0 },
   { 5191, 2047, 0 },
   { 5243, 2047, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2716, 32, 0 },
   { 5137, 2039, 0 },
   { 5190, 2047, 0 },
   { 5242, 2047, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2716, 32, 0 },
   { 5113, 2039, 0 },
   { 5166, 2047, 0 },
   { 5218, 2047, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2716, 32, 0 },
   { 5112, 2039, 0 },
   { 5165, 2047, 0 },
   { 5217, 2047, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2130, 2132, 43 },
   { 2130, 2138, 45 },
   { 2161, 2163, 43 },
   { 2161, 2169, 45 },
   { 2191, 2193, 43 },
   { 2191, 2199, 45 },
   { 2221, 2223, 43 },
   { 2221, 2229, 45 },
   { 2716, 32, 0 },
   { 3247, 3249, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1418, 1419, 0 },
   { 1440, 1441, 0 },
   { 1462, 1463, 0 },
   { 1482, 1483, 0 },
   { 2716, 32, 0 },
   { 2720, 61, 0 },
   { 5138, 2039, 0 },
   { 5191, 2047, 0 },
   { 5243, 2047, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1418, 1419, 0 },
   { 1440, 1441, 0 },
   { 1462, 1463, 0 },
   { 1482, 1483, 0 },
   { 2716, 32, 0 },
   { 2720, 61, 0 },
   { 5137, 2039, 0 },
   { 5190, 2047, 0 },
   { 5242, 2047, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1418, 1419, 0 },
   { 1440, 1441, 0 },
   { 1462, 1463, 0 },
   { 1482, 1483, 0 },
   { 2716, 32, 0 },
   { 2720, 61, 0 },
   { 5113, 2039, 0 },
   { 5166, 2047, 0 },
   { 5218, 2047, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1418, 1419, 0 },
   { 1440, 1441, 0 },
   { 1462, 1463, 0 },
   { 1482, 1483, 0 },
   { 2716, 32, 0 },
   { 2720, 61, 0 },
   { 5112, 2039, 0 },
   { 5165, 2047, 0 },
   { 5217, 2047, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2716, 32, 0 },
   { 5137, 2039, 0 },
   { 5138, 2039, 0 },
   { 5190, 2047, 0 },
   { 5191, 2047, 0 },
   { 5242, 2047, 0 },
   { 5243, 2047, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2716, 32, 0 },
   { 5113, 2039, 0 },
   { 5138, 2039, 0 },
   { 5166, 2047, 0 },
   { 5191, 2047, 0 },
   { 5218, 2047, 0 },
   { 5243, 2047, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2716, 32, 0 },
   { 5112, 2039, 0 },
   { 5138, 2039, 0 },
   { 5165, 2047, 0 },
   { 5191, 2047, 0 },
   { 5217, 2047, 0 },
   { 5243, 2047, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2716, 32, 0 },
   { 5113, 2039, 0 },
   { 5137, 2039, 0 },
   { 5166, 2047, 0 },
   { 5190, 2047, 0 },
   { 5218, 2047, 0 },
   { 5242, 2047, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2716, 32, 0 },
   { 5112, 2039, 0 },
   { 5137, 2039, 0 },
   { 5165, 2047, 0 },
   { 5190, 2047, 0 },
   { 5217, 2047, 0 },
   { 5242, 2047, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2716, 32, 0 },
   { 5112, 2039, 0 },
   { 5113, 2039, 0 },
   { 5165, 2047, 0 },
   { 5166, 2047, 0 },
   { 5217, 2047, 0 },
   { 5218, 2047, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2716, 32, 0 },
   { 5112, 2039, 0 },
   { 5165, 2047, 0 },
   { 5217, 2047, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2411, 2410, 0 },
   { 3170, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3237, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1168, 1138, 0 },
   { 2711, 1077, 0 },
   { 3200, 1077, 0 },
   { 3203, 1235, 0 },
   { 3206, 1235, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1095, 1096, 0 },
   { 1255, 1253, 0 },
   { 2711, 1077, 0 },
   { 3200, 1077, 0 },
   { 3203, 1235, 0 },
   { 3206, 1235, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1095, 1096, 0 },
   { 1201, 1204, 0 },
   { 2711, 1077, 0 },
   { 3200, 1077, 0 },
   { 3203, 1235, 0 },
   { 3206, 1235, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1095, 1096, 0 },
   { 2704, 760, 0 },
   { 2711, 1077, 0 },
   { 3200, 1077, 0 },
   { 3203, 1235, 0 },
   { 3206, 1235, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1187, 1188, 0 },
   { 1277, 1049, 0 },
   { 2711, 1077, 0 },
   { 3200, 1077, 0 },
   { 3203, 1235, 0 },
   { 3206, 1235, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1187, 1188, 0 },
   { 1196, 1199, 0 },
   { 1277, 1049, 0 },
   { 2711, 1077, 0 },
   { 3200, 1077, 0 },
   { 3203, 1235, 0 },
   { 3206, 1235, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1170, 1155, 0 },
   { 2713, 1235, 0 },
   { 3192, 1235, 0 },
   { 3195, 1077, 0 },
   { 3198, 1077, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1099, 1100, 0 },
   { 1258, 1257, 0 },
   { 1258, 1257, 0 },
   { 2713, 1235, 0 },
   { 3192, 1235, 0 },
   { 3195, 1077, 0 },
   { 3198, 1077, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1099, 1100, 0 },
   { 1207, 1208, 0 },
   { 2713, 1235, 0 },
   { 3192, 1235, 0 },
   { 3195, 1077, 0 },
   { 3198, 1077, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1099, 1100, 0 },
   { 1133, 1131, 0 },
   { 2713, 1235, 0 },
   { 3192, 1235, 0 },
   { 3195, 1077, 0 },
   { 3198, 1077, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1335, 32, 0 },
   { 1502, 1254, 0 },
   { 1505, 1254, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1335, 32, 0 },
   { 1502, 1254, 0 },
   { 1581, 1583, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1335, 32, 0 },
   { 1352, 1283, 0 },
   { 1374, 1376, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1335, 32, 0 },
   { 1502, 1254, 0 },
   { 1505, 1254, 0 },
   { 3173, 217, 38 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1335, 32, 0 },
   { 1502, 1254, 0 },
   { 1581, 1583, 0 },
   { 3173, 217, 38 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1335, 32, 0 },
   { 1352, 1283, 0 },
   { 1374, 1376, 0 },
   { 3173, 217, 38 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1335, 32, 0 },
   { 1352, 1283, 0 },
   { 1374, 1376, 0 },
   { 1502, 1254, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1335, 32, 0 },
   { 1502, 1254, 0 },
   { 1505, 1254, 0 },
   { 1507, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1335, 32, 0 },
   { 1502, 1254, 0 },
   { 1507, 32, 0 },
   { 1581, 1583, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1335, 32, 0 },
   { 1352, 1283, 0 },
   { 1374, 1376, 0 },
   { 1507, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1335, 32, 0 },
   { 1352, 1283, 0 },
   { 1502, 1254, 0 },
   { 1505, 1254, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1335, 32, 0 },
   { 1352, 1283, 0 },
   { 1502, 1254, 0 },
   { 1581, 1583, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1335, 32, 0 },
   { 1502, 1254, 0 },
   { 1505, 1254, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1335, 32, 0 },
   { 1502, 1254, 0 },
   { 1581, 1583, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1335, 32, 0 },
   { 1352, 1283, 0 },
   { 1374, 1376, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1335, 32, 0 },
   { 1502, 1254, 0 },
   { 1505, 1254, 0 },
   { 1581, 1583, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1335, 32, 0 },
   { 1352, 1283, 0 },
   { 1374, 1376, 0 },
   { 1502, 1254, 0 },
   { 1505, 1254, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1269, 1270, 0 },
   { 1335, 32, 0 },
   { 1502, 1254, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1335, 32, 0 },
   { 1352, 1283, 0 },
   { 1374, 1376, 0 },
   { 1502, 1254, 0 },
   { 1581, 1583, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1336, 32, 0 },
   { 1509, 32, 0 },
   { 1513, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1336, 32, 0 },
   { 1513, 103, 0 },
   { 1575, 1578, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1336, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1336, 32, 0 },
   { 1346, 1281, 0 },
   { 1359, 1361, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1336, 32, 0 },
   { 1509, 32, 0 },
   { 1513, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1336, 32, 0 },
   { 1513, 103, 0 },
   { 1575, 1578, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1336, 32, 0 },
   { 1587, 1588, 38 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1336, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1336, 32, 0 },
   { 1519, 217, 38 },
   { 1524, 1522, 38 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1336, 32, 0 },
   { 1346, 1281, 0 },
   { 1359, 1361, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1336, 32, 0 },
   { 1513, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1336, 32, 0 },
   { 1346, 1281, 0 },
   { 1359, 1361, 0 },
   { 1513, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1336, 32, 0 },
   { 1509, 32, 0 },
   { 1511, 103, 0 },
   { 1513, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1336, 32, 0 },
   { 1511, 103, 0 },
   { 1513, 103, 0 },
   { 1575, 1578, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1336, 32, 0 },
   { 1511, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1336, 32, 0 },
   { 1346, 1281, 0 },
   { 1359, 1361, 0 },
   { 1511, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1336, 32, 0 },
   { 1346, 1281, 0 },
   { 1509, 32, 0 },
   { 1513, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1336, 32, 0 },
   { 1346, 1281, 0 },
   { 1513, 103, 0 },
   { 1575, 1578, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1336, 32, 0 },
   { 1346, 1281, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1336, 32, 0 },
   { 1509, 32, 0 },
   { 1513, 103, 0 },
   { 1575, 1578, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1336, 32, 0 },
   { 1509, 32, 0 },
   { 1513, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1336, 32, 0 },
   { 1346, 1281, 0 },
   { 1359, 1361, 0 },
   { 1509, 32, 0 },
   { 1513, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1265, 1267, 0 },
   { 1336, 32, 0 },
   { 1513, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1336, 32, 0 },
   { 1513, 103, 0 },
   { 1575, 1578, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1336, 32, 0 },
   { 1346, 1281, 0 },
   { 1359, 1361, 0 },
   { 1513, 103, 0 },
   { 1575, 1578, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1336, 32, 0 },
   { 1346, 1281, 0 },
   { 1359, 1361, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 217, 1517, 40 },
   { 1533, 1535, 38 },
   { 3172, 111, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 217, 1517, 40 },
   { 1538, 1540, 38 },
   { 3172, 111, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 217, 1517, 40 },
   { 1543, 1545, 41 },
   { 3172, 111, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 217, 1517, 40 },
   { 1547, 1551, 38 },
   { 3172, 111, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 217, 1517, 40 },
   { 3172, 111, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 217, 1517, 40 },
   { 2697, 1263, 0 },
   { 3172, 111, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 205, 111, 0 },
   { 728, 707, 24 },
   { 729, 710, 24 },
   { 730, 713, 25 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 216, 3, 0 },
   { 3597, 3526, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 112, 32, 0 },
   { 114, 11, 5 },
   { 116, 16, 6 },
   { 205, 111, 0 },
   { 3557, 3560, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 112, 32, 0 },
   { 114, 11, 5 },
   { 116, 16, 6 },
   { 205, 111, 0 },
   { 3566, 3570, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 112, 32, 0 },
   { 114, 11, 5 },
   { 116, 16, 6 },
   { 205, 111, 0 },
   { 3576, 3579, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 112, 32, 0 },
   { 114, 11, 5 },
   { 116, 16, 6 },
   { 205, 111, 0 },
   { 810, 812, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 112, 32, 0 },
   { 114, 11, 5 },
   { 116, 16, 6 },
   { 205, 111, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 112, 32, 0 },
   { 114, 11, 5 },
   { 116, 16, 6 },
   { 205, 111, 0 },
   { 728, 707, 24 },
   { 729, 710, 24 },
   { 730, 713, 25 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 112, 32, 0 },
   { 114, 11, 5 },
   { 116, 16, 6 },
   { 216, 3, 0 },
   { 3524, 3526, 0 },
   { 3528, 3526, 0 },
   { 3597, 3526, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 112, 32, 0 },
   { 114, 11, 5 },
   { 116, 16, 6 },
   { 216, 3, 0 },
   { 3524, 3526, 0 },
   { 3528, 3526, 0 },
   { 3555, 3526, 0 },
   { 3597, 3526, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 205, 111, 0 },
   { 214, 3, 0 },
   { 216, 3, 0 },
   { 3597, 3526, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 205, 111, 0 },
   { 214, 3, 0 },
   { 728, 707, 24 },
   { 729, 710, 24 },
   { 730, 713, 25 },
   { 3597, 3526, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 219, 220, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 205, 111, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 205, 111, 0 },
   { 214, 3, 0 },
   { 216, 3, 0 },
   { 728, 707, 24 },
   { 729, 710, 24 },
   { 730, 713, 25 },
   { 3597, 3526, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 131, 133, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2831, 2834, 51 },
   { 2856, 32, 0 },
   { 2857, 251, 0 },
   { 2858, 2855, 0 },
   { 2865, 103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2835, 2831, 52 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2835, 2831, 52 },
   { 2847, 2848, 0 },
   { 2851, 251, 0 },
   { 2854, 2855, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1337, 32, 0 },
   { 1503, 1504, 0 },
   { 1506, 1504, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1337, 32, 0 },
   { 1356, 1303, 0 },
   { 1384, 1386, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1337, 32, 0 },
   { 1503, 1504, 0 },
   { 1506, 1504, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1337, 32, 0 },
   { 1356, 1303, 0 },
   { 1384, 1386, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1337, 32, 0 },
   { 1356, 1303, 0 },
   { 1384, 1386, 0 },
   { 1503, 1504, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1337, 32, 0 },
   { 1503, 1504, 0 },
   { 1506, 1504, 0 },
   { 1508, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1337, 32, 0 },
   { 1356, 1303, 0 },
   { 1384, 1386, 0 },
   { 1508, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1337, 32, 0 },
   { 1356, 1303, 0 },
   { 1503, 1504, 0 },
   { 1506, 1504, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1337, 32, 0 },
   { 1503, 1504, 0 },
   { 1506, 1504, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1337, 32, 0 },
   { 1356, 1303, 0 },
   { 1384, 1386, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1337, 32, 0 },
   { 1356, 1303, 0 },
   { 1384, 1386, 0 },
   { 1503, 1504, 0 },
   { 1506, 1504, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1337, 32, 0 },
   { 1503, 1504, 0 },
   { 3116, 3105, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1338, 32, 0 },
   { 1510, 32, 0 },
   { 1514, 106, 39 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1338, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1338, 32, 0 },
   { 1350, 1301, 0 },
   { 1369, 1371, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1338, 32, 0 },
   { 1510, 32, 0 },
   { 1514, 106, 39 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1338, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1338, 32, 0 },
   { 4018, 4014, 103 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1338, 32, 0 },
   { 1350, 1301, 0 },
   { 1369, 1371, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1338, 32, 0 },
   { 1514, 106, 39 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1338, 32, 0 },
   { 1350, 1301, 0 },
   { 1369, 1371, 0 },
   { 1514, 106, 39 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1338, 32, 0 },
   { 1510, 32, 0 },
   { 1512, 106, 0 },
   { 1514, 106, 39 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1338, 32, 0 },
   { 1512, 106, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1338, 32, 0 },
   { 1350, 1301, 0 },
   { 1369, 1371, 0 },
   { 1512, 106, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1338, 32, 0 },
   { 1350, 1301, 0 },
   { 1510, 32, 0 },
   { 1514, 106, 39 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1338, 32, 0 },
   { 1350, 1301, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1338, 32, 0 },
   { 1510, 32, 0 },
   { 1514, 106, 39 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1338, 32, 0 },
   { 1350, 1301, 0 },
   { 1369, 1371, 0 },
   { 1510, 32, 0 },
   { 1514, 106, 39 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1338, 32, 0 },
   { 1514, 106, 39 },
   { 3115, 3103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1338, 32, 0 },
   { 1350, 1301, 0 },
   { 1369, 1371, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1107, 1108, 0 },
   { 2707, 1235, 0 },
   { 3056, 760, 0 },
   { 3059, 1131, 0 },
   { 3106, 760, 0 },
   { 3208, 1077, 0 },
   { 3808, 3809, 81 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1109, 1110, 0 },
   { 2708, 1077, 0 },
   { 3057, 1131, 0 },
   { 3058, 760, 0 },
   { 3107, 1131, 0 },
   { 3207, 1235, 0 },
   { 3805, 3807, 81 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2267, 1391, 0 },
   { 2708, 1077, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2705, 1077, 0 },
   { 3109, 760, 0 },
   { 3212, 1077, 0 },
   { 3213, 1235, 0 },
   { 3214, 1235, 0 },
   { 1489, 3803, 81 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2346, 1077, 0 },
   { 2709, 1077, 0 },
   { 3848, 1077, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2709, 1077, 0 },
   { 3110, 760, 0 },
   { 3216, 1235, 0 },
   { 3810, 3807, 81 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2346, 1077, 0 },
   { 2709, 1077, 0 },
   { 3216, 1235, 0 },
   { 3810, 3807, 81 },
   { 3848, 1077, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2346, 1077, 0 },
   { 2398, 2399, 0 },
   { 2709, 1077, 0 },
   { 3216, 1235, 0 },
   { 3810, 3807, 81 },
   { 3848, 1077, 0 },
   { 3852, 1077, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2346, 1077, 0 },
   { 2709, 1077, 0 },
   { 3848, 1077, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2346, 1077, 0 },
   { 2355, 1077, 0 },
   { 2709, 1077, 0 },
   { 3848, 1077, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2336, 1085, 0 },
   { 2346, 1077, 0 },
   { 2709, 1077, 0 },
   { 3848, 1077, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2346, 1077, 0 },
   { 2347, 1077, 0 },
   { 2709, 1077, 0 },
   { 3848, 1077, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2706, 1235, 0 },
   { 3108, 1131, 0 },
   { 3209, 1235, 0 },
   { 3210, 1077, 0 },
   { 3211, 1077, 0 },
   { 1486, 3804, 81 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1339, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1339, 32, 0 },
   { 1354, 1293, 0 },
   { 1379, 1381, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1339, 32, 0 },
   { 1340, 61, 0 },
   { 1341, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1339, 32, 0 },
   { 1340, 61, 0 },
   { 1341, 32, 0 },
   { 1354, 1293, 0 },
   { 1379, 1381, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1339, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1339, 32, 0 },
   { 1354, 1293, 0 },
   { 1379, 1381, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1339, 32, 0 },
   { 1354, 1293, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1339, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1339, 32, 0 },
   { 1354, 1293, 0 },
   { 1379, 1381, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1339, 32, 0 },
   { 3118, 3103, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1339, 32, 0 },
   { 1354, 1293, 0 },
   { 1379, 1381, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1342, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1342, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1342, 32, 0 },
   { 1348, 1291, 0 },
   { 1364, 1366, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1342, 32, 0 },
   { 1343, 32, 0 },
   { 1344, 63, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1342, 32, 0 },
   { 1343, 32, 0 },
   { 1344, 63, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1342, 32, 0 },
   { 1343, 32, 0 },
   { 1344, 63, 0 },
   { 1348, 1291, 0 },
   { 1364, 1366, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1342, 32, 0 },
   { 1348, 1291, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1342, 32, 0 },
   { 1348, 1291, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1342, 32, 0 },
   { 3117, 3105, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1342, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1342, 32, 0 },
   { 1348, 1291, 0 },
   { 1364, 1366, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1342, 32, 0 },
   { 1348, 1291, 0 },
   { 1364, 1366, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2268, 2269, 0 },
   { 2273, 2288, 1 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2268, 2269, 0 },
   { 3878, 3876, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2268, 2269, 0 },
   { 3881, 3876, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1592, 1591, 0 },
   { 3932, 3935, 91 },
   { 5094, 11, 0 },
   { 5147, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2725, 61, 0 },
   { 5144, 2105, 0 },
   { 5197, 2109, 0 },
   { 5249, 2109, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2725, 61, 0 },
   { 5143, 2105, 0 },
   { 5196, 2109, 0 },
   { 5248, 2109, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2725, 61, 0 },
   { 5119, 2105, 0 },
   { 5172, 2109, 0 },
   { 5224, 2109, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2725, 61, 0 },
   { 5118, 2105, 0 },
   { 5171, 2109, 0 },
   { 5223, 2109, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2725, 61, 0 },
   { 2726, 32, 0 },
   { 2729, 2719, 0 },
   { 2768, 2770, 0 },
   { 2771, 2773, 0 },
   { 5144, 2105, 0 },
   { 5197, 2109, 0 },
   { 5249, 2109, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2725, 61, 0 },
   { 2726, 32, 0 },
   { 2729, 2719, 0 },
   { 2768, 2770, 0 },
   { 2771, 2773, 0 },
   { 5143, 2105, 0 },
   { 5196, 2109, 0 },
   { 5248, 2109, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2725, 61, 0 },
   { 2726, 32, 0 },
   { 2729, 2719, 0 },
   { 2768, 2770, 0 },
   { 2771, 2773, 0 },
   { 5119, 2105, 0 },
   { 5172, 2109, 0 },
   { 5224, 2109, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2725, 61, 0 },
   { 2726, 32, 0 },
   { 2729, 2719, 0 },
   { 2768, 2770, 0 },
   { 2771, 2773, 0 },
   { 5118, 2105, 0 },
   { 5171, 2109, 0 },
   { 5223, 2109, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2725, 61, 0 },
   { 5120, 2105, 0 },
   { 5144, 2105, 0 },
   { 5173, 2109, 0 },
   { 5197, 2109, 0 },
   { 5249, 2109, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2725, 61, 0 },
   { 5120, 2105, 0 },
   { 5143, 2105, 0 },
   { 5173, 2109, 0 },
   { 5196, 2109, 0 },
   { 5248, 2109, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2725, 61, 0 },
   { 5119, 2105, 0 },
   { 5120, 2105, 0 },
   { 5172, 2109, 0 },
   { 5173, 2109, 0 },
   { 5224, 2109, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2725, 61, 0 },
   { 5118, 2105, 0 },
   { 5120, 2105, 0 },
   { 5171, 2109, 0 },
   { 5173, 2109, 0 },
   { 5223, 2109, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2725, 61, 0 },
   { 5144, 2105, 0 },
   { 5145, 2105, 0 },
   { 5197, 2109, 0 },
   { 5198, 2109, 0 },
   { 5249, 2109, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2725, 61, 0 },
   { 5143, 2105, 0 },
   { 5145, 2105, 0 },
   { 5196, 2109, 0 },
   { 5198, 2109, 0 },
   { 5248, 2109, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2725, 61, 0 },
   { 5119, 2105, 0 },
   { 5145, 2105, 0 },
   { 5172, 2109, 0 },
   { 5198, 2109, 0 },
   { 5224, 2109, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2725, 61, 0 },
   { 5118, 2105, 0 },
   { 5145, 2105, 0 },
   { 5171, 2109, 0 },
   { 5198, 2109, 0 },
   { 5223, 2109, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2725, 61, 0 },
   { 5144, 2105, 0 },
   { 5197, 2109, 0 },
   { 5249, 2109, 0 },
   { 5250, 2109, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2725, 61, 0 },
   { 5143, 2105, 0 },
   { 5196, 2109, 0 },
   { 5248, 2109, 0 },
   { 5250, 2109, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2725, 61, 0 },
   { 5119, 2105, 0 },
   { 5172, 2109, 0 },
   { 5224, 2109, 0 },
   { 5250, 2109, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2725, 61, 0 },
   { 5118, 2105, 0 },
   { 5171, 2109, 0 },
   { 5223, 2109, 0 },
   { 5250, 2109, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2725, 61, 0 },
   { 5144, 2105, 0 },
   { 5197, 2109, 0 },
   { 5225, 2109, 0 },
   { 5249, 2109, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2725, 61, 0 },
   { 5143, 2105, 0 },
   { 5196, 2109, 0 },
   { 5225, 2109, 0 },
   { 5248, 2109, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2725, 61, 0 },
   { 5119, 2105, 0 },
   { 5172, 2109, 0 },
   { 5224, 2109, 0 },
   { 5225, 2109, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2725, 61, 0 },
   { 5118, 2105, 0 },
   { 5171, 2109, 0 },
   { 5223, 2109, 0 },
   { 5225, 2109, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2725, 61, 0 },
   { 2728, 3, 0 },
   { 5144, 2105, 0 },
   { 5197, 2109, 0 },
   { 5249, 2109, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2725, 61, 0 },
   { 2728, 3, 0 },
   { 5143, 2105, 0 },
   { 5196, 2109, 0 },
   { 5248, 2109, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2725, 61, 0 },
   { 2728, 3, 0 },
   { 5119, 2105, 0 },
   { 5172, 2109, 0 },
   { 5224, 2109, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2725, 61, 0 },
   { 2728, 3, 0 },
   { 5118, 2105, 0 },
   { 5171, 2109, 0 },
   { 5223, 2109, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2725, 61, 0 },
   { 5143, 2105, 0 },
   { 5144, 2105, 0 },
   { 5196, 2109, 0 },
   { 5197, 2109, 0 },
   { 5248, 2109, 0 },
   { 5249, 2109, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2725, 61, 0 },
   { 5119, 2105, 0 },
   { 5144, 2105, 0 },
   { 5172, 2109, 0 },
   { 5197, 2109, 0 },
   { 5224, 2109, 0 },
   { 5249, 2109, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2725, 61, 0 },
   { 5118, 2105, 0 },
   { 5144, 2105, 0 },
   { 5171, 2109, 0 },
   { 5197, 2109, 0 },
   { 5223, 2109, 0 },
   { 5249, 2109, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2725, 61, 0 },
   { 5119, 2105, 0 },
   { 5143, 2105, 0 },
   { 5172, 2109, 0 },
   { 5196, 2109, 0 },
   { 5224, 2109, 0 },
   { 5248, 2109, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2725, 61, 0 },
   { 5118, 2105, 0 },
   { 5143, 2105, 0 },
   { 5171, 2109, 0 },
   { 5196, 2109, 0 },
   { 5223, 2109, 0 },
   { 5248, 2109, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2725, 61, 0 },
   { 5118, 2105, 0 },
   { 5119, 2105, 0 },
   { 5171, 2109, 0 },
   { 5172, 2109, 0 },
   { 5223, 2109, 0 },
   { 5224, 2109, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2725, 61, 0 },
   { 5118, 2105, 0 },
   { 5171, 2109, 0 },
   { 5223, 2109, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1818, 11, 0 },
   { 1836, 11, 0 },
   { 1923, 16, 0 },
   { 2034, 2031, 0 },
   { 4252, 760, 0 },
   { 4253, 6, 0 },
   { 4254, 11, 0 },
   { 4255, 16, 0 },
   { 4256, 21, 0 },
   { 4271, 4269, 0 },
   { 4277, 4269, 0 },
   { 4283, 4269, 0 },
   { 4288, 4269, 0 },
   { 4291, 4292, 0 },
   { 4296, 4267, 0 },
   { 4300, 4267, 0 },
   { 4304, 4267, 0 },
   { 4307, 4308, 0 },
   { 4310, 4308, 0 },
   { 4313, 4314, 0 },
   { 4318, 4274, 0 },
   { 4322, 4274, 0 },
   { 4325, 4326, 0 },
   { 4328, 4326, 0 },
   { 4331, 3298, 0 },
   { 4333, 4326, 0 },
   { 4335, 3298, 0 },
   { 4337, 1817, 0 },
   { 4341, 4280, 0 },
   { 4344, 4345, 0 },
   { 4347, 4345, 0 },
   { 4350, 4351, 0 },
   { 4353, 4345, 0 },
   { 4355, 4351, 0 },
   { 4357, 1835, 0 },
   { 4359, 4345, 0 },
   { 4361, 4351, 0 },
   { 4363, 1835, 0 },
   { 4365, 1922, 0 },
   { 5093, 11, 0 },
   { 5146, 16, 0 },
   { 5199, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1818, 11, 0 },
   { 1836, 11, 0 },
   { 1923, 16, 0 },
   { 3276, 3277, 0 },
   { 4252, 760, 0 },
   { 4253, 6, 0 },
   { 4254, 11, 0 },
   { 4255, 16, 0 },
   { 4256, 21, 0 },
   { 4271, 4269, 0 },
   { 4277, 4269, 0 },
   { 4283, 4269, 0 },
   { 4288, 4269, 0 },
   { 4291, 4292, 0 },
   { 4296, 4267, 0 },
   { 4300, 4267, 0 },
   { 4304, 4267, 0 },
   { 4307, 4308, 0 },
   { 4310, 4308, 0 },
   { 4313, 4314, 0 },
   { 4318, 4274, 0 },
   { 4322, 4274, 0 },
   { 4325, 4326, 0 },
   { 4328, 4326, 0 },
   { 4331, 3298, 0 },
   { 4333, 4326, 0 },
   { 4335, 3298, 0 },
   { 4337, 1817, 0 },
   { 4341, 4280, 0 },
   { 4344, 4345, 0 },
   { 4347, 4345, 0 },
   { 4350, 4351, 0 },
   { 4353, 4345, 0 },
   { 4355, 4351, 0 },
   { 4357, 1835, 0 },
   { 4359, 4345, 0 },
   { 4361, 4351, 0 },
   { 4363, 1835, 0 },
   { 4365, 1922, 0 },
   { 5093, 11, 0 },
   { 5146, 16, 0 },
   { 5199, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3273, 3275, 0 },
   { 4247, 760, 0 },
   { 4248, 6, 0 },
   { 4249, 11, 0 },
   { 4250, 16, 0 },
   { 4251, 21, 0 },
   { 4268, 4269, 0 },
   { 4275, 4269, 0 },
   { 4281, 4269, 0 },
   { 4286, 4269, 0 },
   { 4294, 4267, 0 },
   { 4298, 4267, 0 },
   { 4302, 4267, 0 },
   { 4316, 4274, 0 },
   { 4320, 4274, 0 },
   { 4339, 4280, 0 },
   { 5121, 11, 0 },
   { 5174, 16, 0 },
   { 5226, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2146, 6, 0 },
   { 2177, 11, 0 },
   { 2207, 16, 0 },
   { 2237, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1339, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1339, 32, 0 },
   { 1565, 1566, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1339, 32, 0 },
   { 1340, 61, 0 },
   { 1341, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1339, 32, 0 },
   { 1340, 61, 0 },
   { 1341, 32, 0 },
   { 1565, 1566, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1339, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1339, 32, 0 },
   { 1565, 1566, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1339, 32, 0 },
   { 1354, 1293, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1339, 32, 0 },
   { 1354, 1293, 0 },
   { 1565, 1566, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1339, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1339, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1339, 32, 0 },
   { 1565, 1566, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1339, 32, 0 },
   { 1354, 1293, 0 },
   { 1379, 1381, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1339, 32, 0 },
   { 1354, 1293, 0 },
   { 1379, 1381, 0 },
   { 1565, 1566, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1339, 32, 0 },
   { 1565, 1566, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1331, 1138, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3646, 3635, 65 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1331, 1138, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3666, 3630, 66 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3648, 3635, 65 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3668, 3630, 66 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3644, 3635, 65 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3647, 3635, 65 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3665, 3630, 66 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3667, 3630, 66 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1331, 1138, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3637, 3629, 65 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3642, 3629, 65 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1331, 1138, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3639, 3635, 65 },
   { 3646, 3635, 65 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3643, 3635, 65 },
   { 3648, 3635, 65 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1331, 1138, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3658, 3603, 66 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3663, 3603, 66 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1331, 1138, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3660, 3630, 66 },
   { 3666, 3630, 66 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3664, 3630, 66 },
   { 3668, 3630, 66 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3628, 3629, 65 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3640, 3629, 65 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3634, 3635, 65 },
   { 3644, 3635, 65 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3641, 3635, 65 },
   { 3647, 3635, 65 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3652, 3603, 66 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3661, 3603, 66 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1333, 1146, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3656, 3630, 66 },
   { 3665, 3630, 66 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 3093, 3, 0 },
   { 3662, 3630, 66 },
   { 3667, 3630, 66 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2721, 32, 0 },
   { 2791, 2792, 49 },
   { 2798, 2799, 49 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2721, 32, 0 },
   { 2804, 2805, 49 },
   { 2809, 2810, 49 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2721, 32, 0 },
   { 2791, 2792, 49 },
   { 2798, 2799, 49 },
   { 2807, 2805, 49 },
   { 2812, 2810, 49 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2721, 32, 0 },
   { 2732, 2354, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2721, 32, 0 },
   { 2795, 2792, 49 },
   { 2802, 2799, 49 },
   { 2804, 2805, 49 },
   { 2809, 2810, 49 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2721, 32, 0 },
   { 2791, 2792, 49 },
   { 2798, 2799, 49 },
   { 2804, 2805, 49 },
   { 2809, 2810, 49 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 945, 946, 0 },
   { 992, 991, 0 },
   { 999, 998, 0 },
   { 1007, 1005, 0 },
   { 1016, 1014, 0 },
   { 2699, 2700, 0 },
   { 2702, 2703, 0 },
   { 2716, 32, 0 },
   { 2717, 61, 0 },
   { 2718, 32, 0 },
   { 2741, 2745, 0 },
   { 2747, 2751, 0 },
   { 2753, 2754, 0 },
   { 2756, 2757, 0 },
   { 3261, 3262, 58 },
   { 3292, 3293, 59 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 994, 993, 0 },
   { 1001, 1000, 0 },
   { 1009, 1008, 0 },
   { 1018, 1017, 0 },
   { 2699, 2700, 0 },
   { 2702, 2703, 0 },
   { 2716, 32, 0 },
   { 2717, 61, 0 },
   { 2718, 32, 0 },
   { 2741, 2745, 0 },
   { 2747, 2751, 0 },
   { 2753, 2754, 0 },
   { 2756, 2757, 0 },
   { 3261, 3262, 58 },
   { 3292, 3293, 59 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 501, 491, 15 },
   { 571, 562, 17 },
   { 642, 632, 19 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 501, 491, 15 },
   { 511, 509, 14 },
   { 571, 562, 17 },
   { 580, 578, 16 },
   { 642, 632, 19 },
   { 651, 649, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 216, 3, 0 },
   { 718, 719, 24 },
   { 722, 723, 24 },
   { 726, 727, 25 },
   { 3597, 3526, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 112, 32, 0 },
   { 114, 11, 5 },
   { 116, 16, 6 },
   { 501, 491, 15 },
   { 571, 562, 17 },
   { 642, 632, 19 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 112, 32, 0 },
   { 114, 11, 5 },
   { 116, 16, 6 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 112, 32, 0 },
   { 114, 11, 5 },
   { 116, 16, 6 },
   { 501, 491, 15 },
   { 511, 509, 14 },
   { 571, 562, 17 },
   { 580, 578, 16 },
   { 642, 632, 19 },
   { 651, 649, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 112, 32, 0 },
   { 114, 11, 5 },
   { 116, 16, 6 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 112, 32, 0 },
   { 114, 11, 5 },
   { 116, 16, 6 },
   { 216, 3, 0 },
   { 718, 719, 24 },
   { 722, 723, 24 },
   { 726, 727, 25 },
   { 3524, 3526, 0 },
   { 3528, 3526, 0 },
   { 3597, 3526, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 112, 32, 0 },
   { 114, 11, 5 },
   { 116, 16, 6 },
   { 216, 3, 0 },
   { 718, 719, 24 },
   { 722, 723, 24 },
   { 726, 727, 25 },
   { 3524, 3526, 0 },
   { 3528, 3526, 0 },
   { 3555, 3526, 0 },
   { 3597, 3526, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 112, 32, 0 },
   { 114, 11, 5 },
   { 116, 16, 6 },
   { 205, 111, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 205, 111, 0 },
   { 501, 491, 15 },
   { 571, 562, 17 },
   { 642, 632, 19 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 205, 111, 0 },
   { 501, 491, 15 },
   { 511, 509, 14 },
   { 571, 562, 17 },
   { 580, 578, 16 },
   { 642, 632, 19 },
   { 651, 649, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 205, 111, 0 },
   { 214, 3, 0 },
   { 216, 3, 0 },
   { 718, 719, 24 },
   { 722, 723, 24 },
   { 726, 727, 25 },
   { 3597, 3526, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 501, 491, 15 },
   { 571, 562, 17 },
   { 642, 632, 19 },
   { 3597, 3526, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 501, 491, 15 },
   { 511, 509, 14 },
   { 571, 562, 17 },
   { 580, 578, 16 },
   { 642, 632, 19 },
   { 651, 649, 18 },
   { 3597, 3526, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 131, 133, 0 },
   { 501, 491, 15 },
   { 571, 562, 17 },
   { 642, 632, 19 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 131, 133, 0 },
   { 490, 491, 15 },
   { 501, 491, 15 },
   { 561, 562, 17 },
   { 571, 562, 17 },
   { 631, 632, 19 },
   { 642, 632, 19 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 131, 133, 0 },
   { 501, 491, 15 },
   { 511, 509, 14 },
   { 571, 562, 17 },
   { 580, 578, 16 },
   { 642, 632, 19 },
   { 651, 649, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 131, 133, 0 },
   { 490, 491, 15 },
   { 501, 491, 15 },
   { 511, 509, 14 },
   { 561, 562, 17 },
   { 571, 562, 17 },
   { 580, 578, 16 },
   { 631, 632, 19 },
   { 642, 632, 19 },
   { 651, 649, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 155, 157, 0 },
   { 501, 491, 15 },
   { 571, 562, 17 },
   { 642, 632, 19 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 155, 157, 0 },
   { 501, 491, 15 },
   { 511, 509, 14 },
   { 571, 562, 17 },
   { 580, 578, 16 },
   { 642, 632, 19 },
   { 651, 649, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 205, 111, 0 },
   { 501, 491, 15 },
   { 571, 562, 17 },
   { 642, 632, 19 },
   { 728, 707, 24 },
   { 729, 710, 24 },
   { 730, 713, 25 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 205, 111, 0 },
   { 501, 491, 15 },
   { 511, 509, 14 },
   { 571, 562, 17 },
   { 580, 578, 16 },
   { 642, 632, 19 },
   { 651, 649, 18 },
   { 728, 707, 24 },
   { 729, 710, 24 },
   { 730, 713, 25 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 205, 111, 0 },
   { 214, 3, 0 },
   { 216, 3, 0 },
   { 718, 719, 24 },
   { 722, 723, 24 },
   { 726, 727, 25 },
   { 728, 707, 24 },
   { 729, 710, 24 },
   { 730, 713, 25 },
   { 3597, 3526, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 216, 3, 0 },
   { 501, 491, 15 },
   { 571, 562, 17 },
   { 642, 632, 19 },
   { 3597, 3526, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 216, 3, 0 },
   { 501, 491, 15 },
   { 511, 509, 14 },
   { 571, 562, 17 },
   { 580, 578, 16 },
   { 642, 632, 19 },
   { 651, 649, 18 },
   { 3597, 3526, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 131, 133, 0 },
   { 501, 491, 15 },
   { 571, 562, 17 },
   { 642, 632, 19 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 131, 133, 0 },
   { 490, 491, 15 },
   { 501, 491, 15 },
   { 561, 562, 17 },
   { 571, 562, 17 },
   { 631, 632, 19 },
   { 642, 632, 19 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 205, 111, 0 },
   { 1793, 1794, 42 },
   { 1901, 1902, 42 },
   { 1986, 1987, 42 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 216, 3, 0 },
   { 501, 491, 15 },
   { 571, 562, 17 },
   { 642, 632, 19 },
   { 718, 719, 24 },
   { 722, 723, 24 },
   { 726, 727, 25 },
   { 3597, 3526, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 216, 3, 0 },
   { 501, 491, 15 },
   { 511, 509, 14 },
   { 571, 562, 17 },
   { 580, 578, 16 },
   { 642, 632, 19 },
   { 651, 649, 18 },
   { 718, 719, 24 },
   { 722, 723, 24 },
   { 726, 727, 25 },
   { 3597, 3526, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2080, 2082, 0 },
   { 2084, 2086, 0 },
   { 4252, 760, 0 },
   { 4253, 6, 0 },
   { 4254, 11, 0 },
   { 4255, 16, 0 },
   { 4256, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2038, 2040, 0 },
   { 2046, 2048, 0 },
   { 4252, 760, 0 },
   { 4253, 6, 0 },
   { 4254, 11, 0 },
   { 4255, 16, 0 },
   { 4256, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2104, 2106, 0 },
   { 2108, 2110, 0 },
   { 4252, 760, 0 },
   { 4253, 6, 0 },
   { 4254, 11, 0 },
   { 4255, 16, 0 },
   { 4256, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 990, 991, 0 },
   { 997, 998, 0 },
   { 1004, 1005, 0 },
   { 1013, 1014, 0 },
   { 2781, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 2274, 2287, 0 },
   { 2781, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2787, 32, 0 },
   { 3250, 3251, 58 },
   { 1017, 422, 58 },
   { 3253, 3255, 58 },
   { 1008, 447, 59 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1335, 32, 0 },
   { 1555, 1556, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1335, 32, 0 },
   { 1502, 1254, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1335, 32, 0 },
   { 1555, 1556, 0 },
   { 3173, 217, 38 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1335, 32, 0 },
   { 1517, 217, 38 },
   { 1521, 1522, 38 },
   { 1555, 1556, 0 },
   { 3173, 217, 38 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1335, 32, 0 },
   { 1502, 1254, 0 },
   { 3173, 217, 38 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1335, 32, 0 },
   { 1502, 1254, 0 },
   { 1555, 1556, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1335, 32, 0 },
   { 1507, 32, 0 },
   { 1555, 1556, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1335, 32, 0 },
   { 1502, 1254, 0 },
   { 1507, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1335, 32, 0 },
   { 1352, 1283, 0 },
   { 1555, 1556, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1335, 32, 0 },
   { 1352, 1283, 0 },
   { 1502, 1254, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1335, 32, 0 },
   { 1502, 1254, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1335, 32, 0 },
   { 1502, 1254, 0 },
   { 1505, 1254, 0 },
   { 1555, 1556, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1335, 32, 0 },
   { 1502, 1254, 0 },
   { 1505, 1254, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1335, 32, 0 },
   { 1502, 1254, 0 },
   { 1555, 1556, 0 },
   { 1581, 1583, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1335, 32, 0 },
   { 1502, 1254, 0 },
   { 1581, 1583, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1335, 32, 0 },
   { 1352, 1283, 0 },
   { 1374, 1376, 0 },
   { 1555, 1556, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1335, 32, 0 },
   { 1352, 1283, 0 },
   { 1374, 1376, 0 },
   { 1502, 1254, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1335, 32, 0 },
   { 1502, 1254, 0 },
   { 1555, 1556, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 221, 111, 0 },
   { 222, 113, 5 },
   { 223, 115, 6 },
   { 242, 32, 0 },
   { 245, 32, 0 },
   { 248, 98, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 221, 111, 0 },
   { 222, 113, 5 },
   { 223, 115, 6 },
   { 242, 32, 0 },
   { 245, 32, 0 },
   { 248, 98, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3484, 3485, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3484, 3485, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3674, 3675, 0 },
   { 3677, 3678, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3674, 3675, 0 },
   { 3677, 3678, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 383, 269, 9 },
   { 3674, 3675, 0 },
   { 3677, 3678, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 383, 269, 9 },
   { 3674, 3675, 0 },
   { 3677, 3678, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3484, 3485, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 255, 253, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 255, 253, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 147, 148, 0 },
   { 514, 509, 0 },
   { 583, 578, 0 },
   { 654, 649, 0 },
   { 737, 739, 29 },
   { 234, 741, 30 },
   { 742, 744, 31 },
   { 745, 739, 32 },
   { 746, 741, 33 },
   { 747, 744, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 147, 148, 0 },
   { 257, 3, 0 },
   { 259, 258, 5 },
   { 260, 36, 6 },
   { 271, 272, 0 },
   { 276, 277, 0 },
   { 514, 509, 0 },
   { 583, 578, 0 },
   { 654, 649, 0 },
   { 737, 739, 29 },
   { 234, 741, 30 },
   { 742, 744, 31 },
   { 745, 739, 32 },
   { 746, 741, 33 },
   { 747, 744, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 147, 148, 0 },
   { 514, 509, 0 },
   { 583, 578, 0 },
   { 654, 649, 0 },
   { 737, 739, 29 },
   { 234, 741, 30 },
   { 742, 744, 31 },
   { 745, 739, 32 },
   { 746, 741, 33 },
   { 747, 744, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 147, 148, 0 },
   { 160, 162, 0 },
   { 514, 509, 0 },
   { 583, 578, 0 },
   { 654, 649, 0 },
   { 737, 739, 29 },
   { 234, 741, 30 },
   { 742, 744, 31 },
   { 745, 739, 32 },
   { 746, 741, 33 },
   { 747, 744, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 147, 148, 0 },
   { 514, 509, 0 },
   { 524, 525, 0 },
   { 583, 578, 0 },
   { 591, 592, 0 },
   { 654, 649, 0 },
   { 663, 664, 0 },
   { 737, 739, 29 },
   { 234, 741, 30 },
   { 742, 744, 31 },
   { 745, 739, 32 },
   { 746, 741, 33 },
   { 747, 744, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 147, 148, 0 },
   { 386, 387, 9 },
   { 514, 509, 0 },
   { 583, 578, 0 },
   { 654, 649, 0 },
   { 737, 739, 29 },
   { 234, 741, 30 },
   { 742, 744, 31 },
   { 745, 739, 32 },
   { 746, 741, 33 },
   { 747, 744, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1161, 1162, 0 },
   { 1191, 1192, 0 },
   { 2714, 1235, 0 },
   { 3189, 1077, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1150, 1151, 0 },
   { 1193, 1194, 0 },
   { 2715, 1077, 0 },
   { 3188, 1235, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2841, 2844, 52 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1095, 1096, 0 },
   { 1167, 1138, 0 },
   { 2711, 1077, 0 },
   { 3200, 1077, 0 },
   { 3203, 1235, 0 },
   { 3206, 1235, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1099, 1100, 0 },
   { 1169, 1155, 0 },
   { 2713, 1235, 0 },
   { 3192, 1235, 0 },
   { 3195, 1077, 0 },
   { 3198, 1077, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1337, 32, 0 },
   { 1560, 1561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1337, 32, 0 },
   { 1560, 1561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1337, 32, 0 },
   { 1560, 1561, 0 },
   { 4016, 4014, 103 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1337, 32, 0 },
   { 1503, 1504, 0 },
   { 1560, 1561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1337, 32, 0 },
   { 1508, 32, 0 },
   { 1560, 1561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1337, 32, 0 },
   { 1356, 1303, 0 },
   { 1560, 1561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1337, 32, 0 },
   { 1503, 1504, 0 },
   { 1506, 1504, 0 },
   { 1560, 1561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1337, 32, 0 },
   { 1356, 1303, 0 },
   { 1384, 1386, 0 },
   { 1560, 1561, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2708, 1077, 0 },
   { 3057, 1131, 0 },
   { 3058, 760, 0 },
   { 3124, 3126, 0 },
   { 3207, 1235, 0 },
   { 3805, 3807, 81 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2708, 1077, 0 },
   { 3057, 1131, 0 },
   { 3058, 760, 0 },
   { 3128, 3129, 0 },
   { 3207, 1235, 0 },
   { 3805, 3807, 81 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 206, 61, 0 },
   { 1800, 1801, 42 },
   { 1908, 1909, 42 },
   { 1993, 1994, 42 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3858, 3859, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3839, 3830, 0 },
   { 3858, 3859, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3860, 3861, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3841, 3827, 0 },
   { 3860, 3861, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3864, 3865, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3864, 3865, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 3843, 3844, 0 },
   { 3864, 3865, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2721, 32, 0 },
   { 2732, 2354, 0 },
   { 3309, 3311, 60 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 196, 198, 0 },
   { 2721, 32, 0 },
   { 2731, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2721, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1187, 1188, 0 },
   { 1196, 1199, 0 },
   { 2711, 1077, 0 },
   { 3177, 1077, 0 },
   { 3200, 1077, 0 },
   { 3203, 1235, 0 },
   { 3206, 1235, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1187, 1188, 0 },
   { 1196, 1199, 0 },
   { 1277, 1049, 0 },
   { 2711, 1077, 0 },
   { 3181, 1077, 0 },
   { 3200, 1077, 0 },
   { 3203, 1235, 0 },
   { 3206, 1235, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1183, 1186, 0 },
   { 2317, 1078, 0 },
   { 2711, 1077, 0 },
   { 3200, 1077, 0 },
   { 3203, 1235, 0 },
   { 3206, 1235, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1336, 32, 0 },
   { 3184, 3176, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1336, 32, 0 },
   { 1587, 1588, 38 },
   { 3186, 3180, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 221, 111, 0 },
   { 222, 113, 5 },
   { 223, 115, 6 },
   { 242, 32, 0 },
   { 245, 32, 0 },
   { 248, 98, 0 },
   { 759, 767, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 112, 32, 0 },
   { 114, 11, 5 },
   { 116, 16, 6 },
   { 205, 111, 0 },
   { 538, 539, 15 },
   { 604, 605, 17 },
   { 677, 678, 19 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 131, 133, 0 },
   { 496, 497, 15 },
   { 567, 568, 17 },
   { 637, 638, 19 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 131, 133, 0 },
   { 496, 497, 15 },
   { 501, 491, 15 },
   { 567, 568, 17 },
   { 571, 562, 17 },
   { 637, 638, 19 },
   { 642, 632, 19 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 131, 133, 0 },
   { 490, 491, 15 },
   { 496, 497, 15 },
   { 501, 491, 15 },
   { 561, 562, 17 },
   { 567, 568, 17 },
   { 571, 562, 17 },
   { 631, 632, 19 },
   { 637, 638, 19 },
   { 642, 632, 19 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 131, 133, 0 },
   { 490, 491, 15 },
   { 501, 491, 15 },
   { 508, 509, 14 },
   { 561, 562, 17 },
   { 571, 562, 17 },
   { 577, 578, 16 },
   { 631, 632, 19 },
   { 642, 632, 19 },
   { 648, 649, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 131, 133, 0 },
   { 490, 491, 15 },
   { 501, 491, 15 },
   { 508, 509, 14 },
   { 511, 509, 14 },
   { 561, 562, 17 },
   { 571, 562, 17 },
   { 577, 578, 16 },
   { 580, 578, 16 },
   { 631, 632, 19 },
   { 642, 632, 19 },
   { 648, 649, 18 },
   { 651, 649, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 131, 133, 0 },
   { 490, 491, 15 },
   { 496, 497, 15 },
   { 501, 491, 15 },
   { 508, 509, 14 },
   { 561, 562, 17 },
   { 567, 568, 17 },
   { 571, 562, 17 },
   { 577, 578, 16 },
   { 631, 632, 19 },
   { 637, 638, 19 },
   { 642, 632, 19 },
   { 648, 649, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 131, 133, 0 },
   { 496, 497, 15 },
   { 567, 568, 17 },
   { 637, 638, 19 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 131, 133, 0 },
   { 490, 491, 15 },
   { 501, 491, 15 },
   { 508, 509, 14 },
   { 561, 562, 17 },
   { 571, 562, 17 },
   { 577, 578, 16 },
   { 631, 632, 19 },
   { 642, 632, 19 },
   { 648, 649, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2300, 2303, 0 },
   { 2716, 32, 0 },
   { 2720, 61, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2308, 2312, 0 },
   { 2716, 32, 0 },
   { 2720, 61, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2300, 2303, 0 },
   { 2308, 2312, 0 },
   { 2716, 32, 0 },
   { 2720, 61, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 2781, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2787, 32, 0 },
   { 3250, 3251, 58 },
   { 1017, 422, 58 },
   { 3253, 3255, 58 },
   { 1008, 447, 59 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2699, 2700, 0 },
   { 2702, 2703, 0 },
   { 2716, 32, 0 },
   { 2717, 61, 0 },
   { 2718, 32, 0 },
   { 2733, 3, 0 },
   { 2741, 2745, 0 },
   { 2747, 2751, 0 },
   { 2753, 2754, 0 },
   { 2756, 2757, 0 },
   { 3261, 3262, 58 },
   { 3292, 3293, 59 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 1331, 1138, 0 },
   { 1332, 1138, 0 },
   { 1334, 1146, 0 },
   { 1769, 1776, 0 },
   { 1877, 1884, 0 },
   { 1962, 1969, 0 },
   { 3093, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 945, 946, 0 },
   { 992, 991, 0 },
   { 999, 998, 0 },
   { 1007, 1005, 0 },
   { 1016, 1014, 0 },
   { 2699, 2700, 0 },
   { 2702, 2703, 0 },
   { 2716, 32, 0 },
   { 2717, 61, 0 },
   { 2718, 32, 0 },
   { 2741, 2745, 0 },
   { 2747, 2751, 0 },
   { 2753, 2754, 0 },
   { 2756, 2757, 0 },
   { 3261, 3262, 58 },
   { 3292, 3293, 59 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 994, 993, 0 },
   { 1001, 1000, 0 },
   { 1009, 1008, 0 },
   { 1018, 1017, 0 },
   { 2699, 2700, 0 },
   { 2702, 2703, 0 },
   { 2716, 32, 0 },
   { 2717, 61, 0 },
   { 2718, 32, 0 },
   { 2741, 2745, 0 },
   { 2747, 2751, 0 },
   { 2753, 2754, 0 },
   { 2756, 2757, 0 },
   { 3261, 3262, 58 },
   { 3292, 3293, 59 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 990, 991, 0 },
   { 997, 998, 0 },
   { 1004, 1005, 0 },
   { 1013, 1014, 0 },
   { 2781, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2787, 32, 0 },
   { 3250, 3251, 58 },
   { 1017, 422, 58 },
   { 3253, 3255, 58 },
   { 1008, 447, 59 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 196, 198, 0 },
   { 2721, 32, 0 },
   { 2731, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2721, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 2781, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2787, 32, 0 },
   { 3250, 3251, 58 },
   { 1017, 422, 58 },
   { 3253, 3255, 58 },
   { 1008, 447, 59 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2699, 2700, 0 },
   { 2702, 2703, 0 },
   { 2716, 32, 0 },
   { 2717, 61, 0 },
   { 2718, 32, 0 },
   { 2733, 3, 0 },
   { 2741, 2745, 0 },
   { 2747, 2751, 0 },
   { 2753, 2754, 0 },
   { 2756, 2757, 0 },
   { 3261, 3262, 58 },
   { 3292, 3293, 59 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 945, 946, 0 },
   { 992, 991, 0 },
   { 999, 998, 0 },
   { 1007, 1005, 0 },
   { 1016, 1014, 0 },
   { 2699, 2700, 0 },
   { 2702, 2703, 0 },
   { 2716, 32, 0 },
   { 2717, 61, 0 },
   { 2718, 32, 0 },
   { 2741, 2745, 0 },
   { 2747, 2751, 0 },
   { 2753, 2754, 0 },
   { 2756, 2757, 0 },
   { 3261, 3262, 58 },
   { 3292, 3293, 59 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 994, 993, 0 },
   { 1001, 1000, 0 },
   { 1009, 1008, 0 },
   { 1018, 1017, 0 },
   { 2699, 2700, 0 },
   { 2702, 2703, 0 },
   { 2716, 32, 0 },
   { 2717, 61, 0 },
   { 2718, 32, 0 },
   { 2741, 2745, 0 },
   { 2747, 2751, 0 },
   { 2753, 2754, 0 },
   { 2756, 2757, 0 },
   { 3261, 3262, 58 },
   { 3292, 3293, 59 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 990, 991, 0 },
   { 997, 998, 0 },
   { 1004, 1005, 0 },
   { 1013, 1014, 0 },
   { 2781, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2787, 32, 0 },
   { 3250, 3251, 58 },
   { 1017, 422, 58 },
   { 3253, 3255, 58 },
   { 1008, 447, 59 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 196, 198, 0 },
   { 2721, 32, 0 },
   { 2731, 3, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2721, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 2781, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2787, 32, 0 },
   { 3250, 3251, 58 },
   { 1017, 422, 58 },
   { 3253, 3255, 58 },
   { 1008, 447, 59 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2699, 2700, 0 },
   { 2702, 2703, 0 },
   { 2716, 32, 0 },
   { 2717, 61, 0 },
   { 2718, 32, 0 },
   { 2733, 3, 0 },
   { 2741, 2745, 0 },
   { 2747, 2751, 0 },
   { 2753, 2754, 0 },
   { 2756, 2757, 0 },
   { 3261, 3262, 58 },
   { 3292, 3293, 59 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 945, 946, 0 },
   { 992, 991, 0 },
   { 999, 998, 0 },
   { 1007, 1005, 0 },
   { 1016, 1014, 0 },
   { 2699, 2700, 0 },
   { 2702, 2703, 0 },
   { 2716, 32, 0 },
   { 2717, 61, 0 },
   { 2718, 32, 0 },
   { 2741, 2745, 0 },
   { 2747, 2751, 0 },
   { 2753, 2754, 0 },
   { 2756, 2757, 0 },
   { 3261, 3262, 58 },
   { 3292, 3293, 59 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 994, 993, 0 },
   { 1001, 1000, 0 },
   { 1009, 1008, 0 },
   { 1018, 1017, 0 },
   { 2699, 2700, 0 },
   { 2702, 2703, 0 },
   { 2716, 32, 0 },
   { 2717, 61, 0 },
   { 2718, 32, 0 },
   { 2741, 2745, 0 },
   { 2747, 2751, 0 },
   { 2753, 2754, 0 },
   { 2756, 2757, 0 },
   { 3261, 3262, 58 },
   { 3292, 3293, 59 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 38, 2 },
   { 990, 991, 0 },
   { 997, 998, 0 },
   { 1004, 1005, 0 },
   { 1013, 1014, 0 },
   { 2781, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2787, 32, 0 },
   { 3250, 3251, 58 },
   { 1017, 422, 58 },
   { 3253, 3255, 58 },
   { 1008, 447, 59 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 196, 198, 0 },
   { 2721, 32, 0 },
   { 2731, 3, 0 },
   { 5493, 5418, 118 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 2721, 32, 0 },
   { 5417, 5418, 118 },
   { ~0, ~0, ~0 }, /* Sentinel */

};

static const struct per_op_table nir_opt_algebraic_pass_op_table[nir_num_search_ops] = {
   [nir_op_imul] = {
      .filter = (const uint16_t []) {
         0,
         1,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         0,
         0,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         10,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         13,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         14,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         17,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         11,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         5,
         13,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         12,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         3,
         3,
         3,
         3,
         3,
         3,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         17,
         17,
         15,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         6,
         0,
         6,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 18,
      .table = (const uint16_t []) {
      
         2,
         3,
         2,
         2,
         355,
         2,
         2,
         2,
         356,
         357,
         358,
         359,
         2,
         2,
         2233,
         2234,
         2235,
         2236,
         3,
         3,
         360,
         361,
         362,
         363,
         364,
         3,
         365,
         366,
         367,
         368,
         2237,
         2238,
         2239,
         2240,
         2241,
         2242,
         2,
         360,
         2,
         2,
         355,
         2,
         2,
         2,
         356,
         357,
         358,
         359,
         2,
         2,
         2233,
         2234,
         2235,
         2236,
         2,
         361,
         2,
         2,
         355,
         2,
         2,
         2,
         356,
         357,
         358,
         359,
         2,
         2,
         2233,
         2234,
         2235,
         2236,
         355,
         362,
         355,
         355,
         355,
         355,
         355,
         355,
         369,
         370,
         371,
         372,
         355,
         355,
         2243,
         2244,
         2245,
         2246,
         2,
         363,
         2,
         2,
         355,
         2,
         2,
         2,
         356,
         357,
         358,
         359,
         2,
         2,
         2233,
         2234,
         2235,
         2236,
         2,
         364,
         2,
         2,
         355,
         2,
         2,
         2,
         356,
         357,
         358,
         359,
         2,
         2,
         2233,
         2234,
         2235,
         2236,
         2,
         3,
         2,
         2,
         355,
         2,
         2,
         373,
         356,
         357,
         358,
         359,
         2,
         2,
         2233,
         2234,
         2235,
         2236,
         356,
         365,
         356,
         356,
         369,
         356,
         356,
         356,
         356,
         374,
         375,
         376,
         356,
         356,
         2247,
         2248,
         2249,
         2250,
         357,
         366,
         357,
         357,
         370,
         357,
         357,
         357,
         374,
         357,
         377,
         378,
         357,
         357,
         2251,
         2252,
         2253,
         2254,
         358,
         367,
         358,
         358,
         371,
         358,
         358,
         358,
         375,
         377,
         358,
         379,
         358,
         358,
         2255,
         2256,
         2257,
         2258,
         359,
         368,
         359,
         359,
         372,
         359,
         359,
         359,
         376,
         378,
         379,
         359,
         359,
         359,
         2259,
         2260,
         2261,
         2262,
         2,
         2237,
         2,
         2,
         355,
         2,
         2,
         2,
         356,
         357,
         358,
         359,
         2,
         2,
         2233,
         2234,
         2235,
         2236,
         2,
         2238,
         2,
         2,
         355,
         2,
         2,
         2,
         356,
         357,
         358,
         359,
         2,
         2,
         2233,
         2234,
         2235,
         2236,
         2233,
         2239,
         2233,
         2233,
         2243,
         2233,
         2233,
         2233,
         2247,
         2251,
         2255,
         2259,
         2233,
         2233,
         2233,
         2263,
         2264,
         2265,
         2234,
         2240,
         2234,
         2234,
         2244,
         2234,
         2234,
         2234,
         2248,
         2252,
         2256,
         2260,
         2234,
         2234,
         2263,
         2234,
         2266,
         2267,
         2235,
         2241,
         2235,
         2235,
         2245,
         2235,
         2235,
         2235,
         2249,
         2253,
         2257,
         2261,
         2235,
         2235,
         2264,
         2266,
         2235,
         2268,
         2236,
         2242,
         2236,
         2236,
         2246,
         2236,
         2236,
         2236,
         2250,
         2254,
         2258,
         2262,
         2236,
         2236,
         2265,
         2267,
         2268,
         2236,
      },
   },
   [nir_op_ishl] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         2,
         0,
         3,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         6,
         0,
         7,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         0,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         4,
         14,
         4,
         15,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         0,
         3,
         0,
         0,
         0,
         3,
         0,
         0,
         3,
         3,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         6,
         6,
         0,
         0,
         7,
         0,
         7,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         17,
         0,
         17,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         4,
         15,
         14,
         14,
         14,
         14,
         14,
         4,
         4,
         4,
         4,
         0,
         12,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         18,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         19,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         8,
         0,
         0,
         0,
         3,
         3,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         0,
         0,
         20,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         6,
         21,
         0,
         5,
         5,
         3,
         6,
         22,
         16,
         3,
         6,
         23,
         5,
         5,
         3,
         6,
         24,
         16,
         3,
         6,
         25,
         5,
         5,
         3,
         6,
         0,
         16,
      },
      
      .num_filtered_states = 26,
      .table = (const uint16_t []) {
      
         4,
         5,
         4,
         4,
         4,
         1023,
         4,
         4,
         4,
         1024,
         4,
         4,
         4,
         4,
         2269,
         4,
         4,
         4,
         1023,
         4,
         4,
         1023,
         4,
         1023,
         4,
         1023,
         6,
         7,
         6,
         6,
         6,
         1025,
         6,
         6,
         6,
         1026,
         6,
         6,
         6,
         6,
         2270,
         6,
         6,
         6,
         1025,
         6,
         6,
         1025,
         6,
         1025,
         6,
         1025,
         4,
         1027,
         4,
         4,
         4,
         1023,
         4,
         4,
         4,
         1024,
         4,
         4,
         4,
         4,
         2269,
         4,
         4,
         4,
         1023,
         4,
         4,
         1023,
         4,
         1023,
         4,
         1023,
         4,
         1028,
         4,
         4,
         4,
         1023,
         4,
         4,
         4,
         1024,
         4,
         4,
         4,
         4,
         2269,
         4,
         4,
         4,
         1023,
         4,
         4,
         1023,
         4,
         1023,
         4,
         1023,
         4,
         1029,
         4,
         4,
         4,
         1023,
         4,
         4,
         4,
         1024,
         4,
         4,
         4,
         4,
         2269,
         4,
         4,
         4,
         1023,
         4,
         4,
         1023,
         4,
         1023,
         4,
         1023,
         4,
         1030,
         4,
         4,
         4,
         1023,
         4,
         4,
         4,
         1024,
         4,
         4,
         4,
         4,
         2269,
         4,
         4,
         4,
         1023,
         4,
         4,
         1023,
         4,
         1023,
         4,
         1023,
         1031,
         1032,
         1031,
         1031,
         1031,
         1033,
         1031,
         1031,
         1031,
         1034,
         1031,
         1031,
         1031,
         1031,
         2271,
         1031,
         1031,
         1031,
         1033,
         1031,
         1031,
         1033,
         1031,
         1033,
         1031,
         1033,
         1035,
         1036,
         1035,
         1035,
         1035,
         1037,
         1035,
         1035,
         1035,
         1038,
         1035,
         1035,
         1035,
         1035,
         2272,
         1035,
         1035,
         1035,
         1037,
         1035,
         1035,
         1037,
         1035,
         1037,
         1035,
         1037,
         4,
         1039,
         4,
         4,
         4,
         1023,
         4,
         4,
         4,
         1024,
         4,
         4,
         4,
         4,
         2269,
         4,
         4,
         4,
         1023,
         4,
         4,
         1023,
         4,
         1023,
         4,
         1023,
         4,
         5,
         4,
         4,
         4,
         1023,
         4,
         4,
         4,
         1024,
         4,
         4,
         4,
         4,
         2269,
         4,
         4,
         4,
         1023,
         4,
         4,
         1023,
         4,
         1023,
         4,
         1023,
         4,
         1040,
         4,
         4,
         4,
         1023,
         4,
         4,
         4,
         1024,
         4,
         4,
         4,
         4,
         2269,
         4,
         4,
         4,
         1023,
         4,
         4,
         1023,
         4,
         1023,
         4,
         1023,
         1041,
         1042,
         1041,
         1041,
         1041,
         1043,
         1041,
         1041,
         1041,
         1044,
         1041,
         1041,
         1041,
         1041,
         2273,
         1041,
         1041,
         1041,
         1043,
         1041,
         1041,
         1043,
         1041,
         1043,
         1041,
         1043,
         4,
         2274,
         4,
         4,
         4,
         1023,
         4,
         4,
         4,
         1024,
         4,
         4,
         4,
         4,
         2269,
         4,
         4,
         4,
         1023,
         4,
         4,
         1023,
         4,
         1023,
         4,
         1023,
         4,
         2275,
         4,
         4,
         4,
         1023,
         4,
         4,
         4,
         1024,
         4,
         4,
         4,
         4,
         2269,
         4,
         4,
         4,
         1023,
         4,
         4,
         1023,
         4,
         1023,
         4,
         1023,
         4,
         1029,
         4,
         4,
         4,
         1023,
         4,
         4,
         4,
         1024,
         4,
         4,
         4,
         4,
         2269,
         4,
         4,
         4,
         1023,
         4,
         4,
         1023,
         4,
         1023,
         4,
         1023,
         4,
         2276,
         4,
         4,
         4,
         1023,
         4,
         4,
         4,
         1024,
         4,
         4,
         4,
         4,
         2269,
         4,
         4,
         4,
         1023,
         4,
         4,
         1023,
         4,
         1023,
         4,
         1023,
         4,
         2277,
         4,
         4,
         4,
         1023,
         4,
         4,
         4,
         1024,
         4,
         4,
         4,
         4,
         2269,
         4,
         4,
         4,
         1023,
         4,
         4,
         1023,
         4,
         1023,
         4,
         1023,
         4,
         2278,
         4,
         4,
         4,
         1023,
         4,
         4,
         4,
         1024,
         4,
         4,
         4,
         4,
         2269,
         4,
         4,
         4,
         1023,
         4,
         4,
         1023,
         4,
         1023,
         4,
         1023,
         4,
         2812,
         4,
         4,
         4,
         1023,
         4,
         4,
         4,
         1024,
         4,
         4,
         4,
         4,
         2269,
         4,
         4,
         4,
         1023,
         4,
         4,
         1023,
         4,
         1023,
         4,
         1023,
         4,
         2813,
         4,
         4,
         4,
         1023,
         4,
         4,
         4,
         1024,
         4,
         4,
         4,
         4,
         2269,
         4,
         4,
         4,
         1023,
         4,
         4,
         1023,
         4,
         1023,
         4,
         1023,
         4,
         2909,
         4,
         4,
         4,
         1023,
         4,
         4,
         4,
         1024,
         4,
         4,
         4,
         4,
         2269,
         4,
         4,
         4,
         1023,
         4,
         4,
         1023,
         4,
         1023,
         4,
         1023,
         4,
         2915,
         4,
         4,
         4,
         1023,
         4,
         4,
         4,
         1024,
         4,
         4,
         4,
         4,
         2269,
         4,
         4,
         4,
         1023,
         4,
         4,
         1023,
         4,
         1023,
         4,
         1023,
         4,
         2919,
         4,
         4,
         4,
         1023,
         4,
         4,
         4,
         1024,
         4,
         4,
         4,
         4,
         2269,
         4,
         4,
         4,
         1023,
         4,
         4,
         1023,
         4,
         1023,
         4,
         1023,
         4,
         2924,
         4,
         4,
         4,
         1023,
         4,
         4,
         4,
         1024,
         4,
         4,
         4,
         4,
         2269,
         4,
         4,
         4,
         1023,
         4,
         4,
         1023,
         4,
         1023,
         4,
         1023,
         4,
         2928,
         4,
         4,
         4,
         1023,
         4,
         4,
         4,
         1024,
         4,
         4,
         4,
         4,
         2269,
         4,
         4,
         4,
         1023,
         4,
         4,
         1023,
         4,
         1023,
         4,
         1023,
         4,
         2933,
         4,
         4,
         4,
         1023,
         4,
         4,
         4,
         1024,
         4,
         4,
         4,
         4,
         2269,
         4,
         4,
         4,
         1023,
         4,
         4,
         1023,
         4,
         1023,
         4,
         1023,
      },
   },
   [nir_op_unpack_64_2x32_split_x] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 8,
      .table = (const uint16_t []) {
      
         8,
         1271,
         1272,
         1273,
         1274,
         1275,
         1276,
         1277,
      },
   },
   [nir_op_imul_2x32_64] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         9,
      },
   },
   [nir_op_umul_2x32_64] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         10,
      },
   },
   [nir_op_udiv] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         11,
         0,
         11,
      },
   },
   [nir_op_idiv] = {
      .filter = (const uint16_t []) {
         0,
         1,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         0,
         12,
         0,
         0,
         12,
         0,
         380,
         381,
         380,
      },
   },
   [nir_op_umod] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         13,
         0,
         13,
      },
   },
   [nir_op_imod] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         14,
         0,
         14,
      },
   },
   [nir_op_irem] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         15,
         0,
         15,
      },
   },
   [nir_op_fneg] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         2,
         0,
         0,
         0,
         3,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         6,
         6,
         0,
         7,
         0,
         7,
         0,
         7,
         0,
         8,
         0,
         8,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         0,
         13,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         3,
         3,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         3,
         3,
         3,
         3,
         3,
         14,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         15,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         8,
         0,
         0,
         9,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         10,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         17,
         5,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         9,
         9,
         9,
         9,
         9,
         9,
         3,
         3,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         5,
         5,
         5,
         5,
         5,
         5,
         15,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         17,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         13,
         5,
         4,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 18,
      .table = (const uint16_t []) {
      
         16,
         1278,
         1279,
         1280,
         1281,
         1282,
         1283,
         1284,
         1285,
         1286,
         1287,
         1288,
         1289,
         1290,
         2614,
         2615,
         2616,
         2805,
      },
   },
   [nir_op_ineg] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         8,
         9,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         11,
         5,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 12,
      .table = (const uint16_t []) {
      
         17,
         1555,
         1556,
         1557,
         1558,
         1559,
         1560,
         1561,
         1562,
         1563,
         1564,
         2727,
      },
   },
   [nir_op_fabs] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         5,
         6,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         9,
         0,
         0,
         0,
         10,
         10,
         11,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         9,
         0,
         0,
         0,
         10,
         10,
         11,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         10,
         10,
         11,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         10,
         10,
         11,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         11,
         10,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         10,
         10,
         11,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         10,
         10,
         11,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         10,
         10,
         11,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         10,
         10,
         11,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         10,
         10,
         11,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         7,
         7,
         7,
         7,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 12,
      .table = (const uint16_t []) {
      
         18,
         1291,
         1292,
         1293,
         1294,
         1295,
         1296,
         1297,
         1298,
         2287,
         2288,
         2289,
      },
   },
   [nir_search_op_u2f] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         19,
         1922,
         1923,
         1924,
      },
   },
   [nir_op_iabs] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 5,
      .table = (const uint16_t []) {
      
         20,
         1565,
         1566,
         1567,
         2534,
      },
   },
   [nir_search_op_f2b] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         21,
         1299,
         1300,
      },
   },
   [nir_op_fadd] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         3,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         6,
         6,
         7,
         8,
         7,
         8,
         7,
         8,
         9,
         10,
         9,
         10,
         9,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         0,
         0,
         12,
         12,
         0,
         0,
         0,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         14,
         2,
         2,
         15,
         16,
         17,
         18,
         19,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         20,
         3,
         21,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         20,
         3,
         3,
         3,
         3,
         3,
         5,
         22,
         5,
         5,
         23,
         24,
         5,
         5,
         5,
         5,
         5,
         22,
         5,
         5,
         5,
         23,
         24,
         22,
         5,
         5,
         23,
         24,
         5,
         22,
         22,
         22,
         25,
         26,
         5,
         23,
         24,
         23,
         24,
         5,
         23,
         27,
         5,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         7,
         7,
         7,
         7,
         7,
         8,
         7,
         7,
         7,
         7,
         7,
         7,
         8,
         7,
         7,
         7,
         8,
         7,
         7,
         7,
         8,
         7,
         7,
         7,
         8,
         7,
         7,
         7,
         8,
         7,
         7,
         7,
         7,
         8,
         7,
         7,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         10,
         9,
         9,
         9,
         10,
         9,
         9,
         9,
         10,
         9,
         9,
         28,
         11,
         11,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         29,
         29,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         30,
         31,
         5,
         5,
         30,
         31,
         5,
         5,
         5,
         30,
         31,
         5,
         22,
         32,
         33,
         34,
         22,
         5,
         30,
         31,
         5,
         30,
         31,
         5,
         23,
         35,
         36,
         23,
         24,
         37,
         38,
         24,
         5,
         5,
         30,
         31,
         5,
         30,
         31,
         31,
         7,
         7,
         8,
         7,
         7,
         7,
         7,
         8,
         7,
         7,
         7,
         7,
         8,
         7,
         7,
         7,
         7,
         7,
         8,
         7,
         7,
         7,
         7,
         7,
         8,
         7,
         7,
         7,
         8,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         39,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         28,
         28,
         28,
         11,
         11,
         11,
         40,
         3,
         21,
         21,
         21,
         21,
         21,
         41,
         4,
         4,
         20,
         40,
         3,
         20,
         40,
         3,
         0,
         2,
         42,
         43,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         12,
         0,
         12,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         4,
         4,
         4,
         4,
         4,
         4,
         21,
         20,
         20,
         20,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         40,
         40,
         40,
         3,
         3,
         3,
         3,
         20,
         3,
         3,
         44,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         45,
         46,
         45,
         46,
         45,
         46,
         45,
         47,
         45,
         46,
         45,
         46,
         48,
         49,
         50,
         51,
         45,
         46,
         52,
         53,
         54,
         46,
         45,
         46,
         55,
         7,
         7,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         21,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 56,
      .table = (const uint16_t []) {
      
         22,
         23,
         1301,
         1302,
         1302,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         1301,
         1301,
         1301,
         1301,
         1301,
         2597,
         2598,
         2598,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         2774,
         2774,
         22,
         2774,
         2774,
         2775,
         2775,
         2774,
         2774,
         22,
         2776,
         2776,
         1301,
         1301,
         1301,
         22,
         2774,
         2774,
         22,
         2775,
         22,
         2774,
         22,
         2774,
         2774,
         2774,
         23,
         23,
         1303,
         1304,
         1305,
         23,
         23,
         1306,
         1307,
         1308,
         1309,
         23,
         1310,
         23,
         2599,
         2600,
         2601,
         2602,
         2603,
         2604,
         2605,
         2606,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         2777,
         2777,
         2778,
         2777,
         2777,
         2779,
         2779,
         2777,
         2777,
         2780,
         2781,
         2782,
         2783,
         2603,
         2896,
         23,
         2777,
         2777,
         23,
         2779,
         23,
         2777,
         2778,
         2777,
         2777,
         2777,
         1301,
         1303,
         1301,
         1311,
         1311,
         1301,
         1301,
         1301,
         1301,
         1301,
         1301,
         1301,
         1301,
         1301,
         1301,
         1301,
         1301,
         1301,
         1301,
         2597,
         2607,
         2607,
         1301,
         1301,
         1301,
         1301,
         1301,
         1301,
         1301,
         1301,
         2784,
         2784,
         1301,
         2784,
         2784,
         2785,
         2785,
         2784,
         2784,
         1301,
         2786,
         2786,
         1301,
         1301,
         1301,
         1301,
         2784,
         2784,
         1301,
         2785,
         1301,
         2784,
         1301,
         2784,
         2784,
         2784,
         1302,
         1304,
         1311,
         1302,
         1302,
         1302,
         1302,
         1302,
         1302,
         1302,
         1302,
         1302,
         1302,
         1302,
         1311,
         1311,
         1311,
         1311,
         1311,
         2608,
         2598,
         2598,
         1302,
         1302,
         1302,
         1302,
         1302,
         1302,
         1302,
         1302,
         2787,
         2787,
         1302,
         2787,
         2787,
         2788,
         2788,
         2787,
         2787,
         1302,
         2776,
         2776,
         1311,
         1311,
         1311,
         1302,
         2787,
         2787,
         1302,
         2788,
         1302,
         2787,
         1302,
         2787,
         2787,
         2787,
         1302,
         1305,
         1311,
         1302,
         1302,
         1302,
         1302,
         1302,
         1302,
         1302,
         1302,
         1302,
         1302,
         1302,
         1311,
         1311,
         1311,
         1311,
         1311,
         2608,
         2598,
         2598,
         1302,
         1302,
         1302,
         1302,
         1302,
         1302,
         1302,
         1302,
         2787,
         2787,
         1302,
         2787,
         2787,
         2788,
         2788,
         2787,
         2787,
         1302,
         2776,
         2776,
         1311,
         1311,
         1311,
         1302,
         2787,
         2787,
         1302,
         2788,
         1302,
         2787,
         1302,
         2787,
         2787,
         2787,
         22,
         23,
         1301,
         1302,
         1302,
         1312,
         22,
         1313,
         1313,
         22,
         22,
         22,
         22,
         22,
         1301,
         1301,
         1301,
         1301,
         1301,
         2597,
         2598,
         2598,
         1312,
         1312,
         1312,
         1312,
         1312,
         1312,
         22,
         22,
         2789,
         2790,
         1312,
         2789,
         2790,
         2791,
         2792,
         2789,
         2790,
         22,
         2776,
         2776,
         1301,
         1301,
         1301,
         1312,
         2790,
         2790,
         1312,
         2792,
         1312,
         2790,
         1312,
         2789,
         2790,
         2790,
         22,
         23,
         1301,
         1302,
         1302,
         22,
         1314,
         22,
         22,
         1315,
         1315,
         22,
         22,
         22,
         1301,
         1301,
         1301,
         1301,
         1301,
         2597,
         2598,
         2598,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         2774,
         2774,
         22,
         2774,
         2774,
         2775,
         2775,
         2774,
         2774,
         22,
         2776,
         2776,
         1301,
         1301,
         1301,
         22,
         2774,
         2774,
         22,
         2775,
         22,
         2774,
         22,
         2774,
         2774,
         2774,
         22,
         1306,
         1301,
         1302,
         1302,
         1313,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         1301,
         1301,
         1301,
         1301,
         1301,
         2597,
         2598,
         2598,
         1313,
         1313,
         1313,
         1313,
         1313,
         1313,
         22,
         22,
         2793,
         2793,
         1313,
         2793,
         2793,
         2794,
         2794,
         2793,
         2793,
         22,
         2776,
         2776,
         1301,
         1301,
         1301,
         1313,
         2793,
         2793,
         1313,
         2794,
         1313,
         2793,
         1313,
         2793,
         2793,
         2793,
         22,
         1307,
         1301,
         1302,
         1302,
         1313,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         1301,
         1301,
         1301,
         1301,
         1301,
         2597,
         2598,
         2598,
         1313,
         1313,
         1313,
         1313,
         1313,
         1313,
         22,
         22,
         2793,
         2793,
         1313,
         2793,
         2793,
         2794,
         2794,
         2793,
         2793,
         22,
         2776,
         2776,
         1301,
         1301,
         1301,
         1313,
         2793,
         2793,
         1313,
         2794,
         1313,
         2793,
         1313,
         2793,
         2793,
         2793,
         22,
         1308,
         1301,
         1302,
         1302,
         22,
         1315,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         1301,
         1301,
         1301,
         1301,
         1301,
         2597,
         2598,
         2598,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         2774,
         2774,
         22,
         2774,
         2774,
         2775,
         2775,
         2774,
         2774,
         22,
         2776,
         2776,
         1301,
         1301,
         1301,
         22,
         2774,
         2774,
         22,
         2775,
         22,
         2774,
         22,
         2774,
         2774,
         2774,
         22,
         1309,
         1301,
         1302,
         1302,
         22,
         1315,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         1301,
         1301,
         1301,
         1301,
         1301,
         2597,
         2598,
         2598,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         2774,
         2774,
         22,
         2774,
         2774,
         2775,
         2775,
         2774,
         2774,
         22,
         2776,
         2776,
         1301,
         1301,
         1301,
         22,
         2774,
         2774,
         22,
         2775,
         22,
         2774,
         22,
         2774,
         2774,
         2774,
         22,
         23,
         1301,
         1302,
         1302,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         1301,
         1301,
         1301,
         1301,
         1301,
         2597,
         2598,
         2598,
         22,
         22,
         22,
         22,
         22,
         22,
         2609,
         22,
         2774,
         2774,
         22,
         2774,
         2774,
         2775,
         2775,
         2774,
         2774,
         22,
         2776,
         2776,
         1301,
         1301,
         1301,
         22,
         2774,
         2774,
         22,
         2775,
         22,
         2774,
         22,
         2774,
         2774,
         2774,
         22,
         1310,
         1301,
         1302,
         1302,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         1301,
         1301,
         1301,
         1301,
         1301,
         2597,
         2598,
         2598,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         2774,
         2774,
         22,
         2774,
         2774,
         2775,
         2775,
         2774,
         2774,
         22,
         2776,
         2776,
         1301,
         1301,
         1301,
         22,
         2774,
         2774,
         22,
         2775,
         22,
         2774,
         22,
         2774,
         2774,
         2774,
         22,
         23,
         1301,
         1302,
         1302,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         1316,
         1301,
         1301,
         1301,
         1301,
         2610,
         2597,
         2598,
         2598,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         1316,
         2774,
         2774,
         22,
         2774,
         2774,
         2775,
         2775,
         2774,
         2774,
         22,
         2776,
         2776,
         1301,
         2610,
         1301,
         22,
         2774,
         2774,
         22,
         2775,
         22,
         2774,
         22,
         2774,
         2774,
         2774,
         1301,
         2599,
         1301,
         1311,
         1311,
         1301,
         1301,
         1301,
         1301,
         1301,
         1301,
         1301,
         1301,
         1301,
         1301,
         1301,
         1301,
         1301,
         1301,
         2597,
         2607,
         2607,
         1301,
         1301,
         1301,
         1301,
         1301,
         1301,
         1301,
         1301,
         2784,
         2784,
         1301,
         2784,
         2784,
         2785,
         2785,
         2784,
         2784,
         1301,
         2786,
         2786,
         1301,
         1301,
         1301,
         1301,
         2784,
         2784,
         1301,
         2785,
         1301,
         2784,
         1301,
         2784,
         2784,
         2784,
         1301,
         2600,
         1301,
         1311,
         1311,
         1301,
         1301,
         1301,
         1301,
         1301,
         1301,
         1301,
         1301,
         1301,
         1301,
         1301,
         1301,
         1301,
         1301,
         2597,
         2607,
         2607,
         1301,
         1301,
         1301,
         1301,
         1301,
         1301,
         1301,
         1301,
         2784,
         2784,
         1301,
         2784,
         2784,
         2785,
         2785,
         2784,
         2784,
         1301,
         2786,
         2786,
         1301,
         1301,
         1301,
         1301,
         2784,
         2784,
         1301,
         2785,
         1301,
         2784,
         1301,
         2784,
         2784,
         2784,
         1301,
         2601,
         1301,
         1311,
         1311,
         1301,
         1301,
         1301,
         1301,
         1301,
         1301,
         1301,
         1301,
         1301,
         1301,
         1301,
         1301,
         1301,
         1301,
         2597,
         2607,
         2607,
         1301,
         1301,
         1301,
         1301,
         1301,
         1301,
         1301,
         1301,
         2784,
         2784,
         1301,
         2784,
         2784,
         2785,
         2785,
         2784,
         2784,
         1301,
         2786,
         2786,
         1301,
         1301,
         1301,
         1301,
         2784,
         2784,
         1301,
         2785,
         1301,
         2784,
         1301,
         2784,
         2784,
         2784,
         1301,
         2602,
         1301,
         1311,
         1311,
         1301,
         1301,
         1301,
         1301,
         1301,
         1301,
         1301,
         1301,
         1301,
         1301,
         1301,
         1301,
         1301,
         1301,
         2597,
         2607,
         2607,
         1301,
         1301,
         1301,
         1301,
         1301,
         1301,
         1301,
         1301,
         2784,
         2784,
         1301,
         2784,
         2784,
         2785,
         2785,
         2784,
         2784,
         1301,
         2786,
         2786,
         1301,
         1301,
         1301,
         1301,
         2784,
         2784,
         1301,
         2785,
         1301,
         2784,
         1301,
         2784,
         2784,
         2784,
         1301,
         2603,
         1301,
         1311,
         1311,
         1301,
         1301,
         1301,
         1301,
         1301,
         1301,
         1301,
         1301,
         2610,
         1301,
         1301,
         1301,
         1301,
         1301,
         2597,
         2607,
         2607,
         1301,
         1301,
         1301,
         1301,
         1301,
         1301,
         1301,
         2610,
         2784,
         2784,
         1301,
         2784,
         2784,
         2785,
         2785,
         2784,
         2784,
         1301,
         2786,
         2786,
         1301,
         1301,
         1301,
         1301,
         2784,
         2784,
         1301,
         2785,
         1301,
         2784,
         1301,
         2784,
         2784,
         2784,
         2597,
         2604,
         2597,
         2608,
         2608,
         2597,
         2597,
         2597,
         2597,
         2597,
         2597,
         2597,
         2597,
         2597,
         2597,
         2597,
         2597,
         2597,
         2597,
         2597,
         2611,
         2611,
         2597,
         2597,
         2597,
         2597,
         2597,
         2597,
         2597,
         2597,
         2795,
         2795,
         2597,
         2795,
         2795,
         2796,
         2796,
         2795,
         2795,
         2597,
         2797,
         2797,
         2597,
         2597,
         2597,
         2597,
         2795,
         2795,
         2597,
         2796,
         2597,
         2795,
         2597,
         2795,
         2795,
         2795,
         2598,
         2605,
         2607,
         2598,
         2598,
         2598,
         2598,
         2598,
         2598,
         2598,
         2598,
         2598,
         2598,
         2598,
         2607,
         2607,
         2607,
         2607,
         2607,
         2611,
         2598,
         2598,
         2598,
         2598,
         2598,
         2598,
         2598,
         2598,
         2598,
         2598,
         2798,
         2798,
         2598,
         2798,
         2798,
         2799,
         2799,
         2798,
         2798,
         2598,
         2776,
         2776,
         2607,
         2607,
         2607,
         2598,
         2798,
         2798,
         2598,
         2799,
         2598,
         2798,
         2598,
         2798,
         2798,
         2798,
         2598,
         2606,
         2607,
         2598,
         2598,
         2598,
         2598,
         2598,
         2598,
         2598,
         2598,
         2598,
         2598,
         2598,
         2607,
         2607,
         2607,
         2607,
         2607,
         2611,
         2598,
         2598,
         2598,
         2598,
         2598,
         2598,
         2598,
         2598,
         2598,
         2598,
         2798,
         2798,
         2598,
         2798,
         2798,
         2799,
         2799,
         2798,
         2798,
         2598,
         2776,
         2776,
         2607,
         2607,
         2607,
         2598,
         2798,
         2798,
         2598,
         2799,
         2598,
         2798,
         2598,
         2798,
         2798,
         2798,
         22,
         23,
         1301,
         1302,
         1302,
         1312,
         22,
         1313,
         1313,
         22,
         22,
         22,
         22,
         22,
         1301,
         1301,
         1301,
         1301,
         1301,
         2597,
         2598,
         2598,
         1312,
         1312,
         1312,
         1312,
         1312,
         1312,
         22,
         22,
         2789,
         2790,
         1312,
         2789,
         2790,
         2791,
         2792,
         2789,
         2790,
         22,
         2776,
         2776,
         1301,
         1301,
         1301,
         2897,
         2790,
         2790,
         2897,
         2792,
         2897,
         2790,
         2897,
         2898,
         2899,
         2899,
         22,
         23,
         1301,
         1302,
         1302,
         1312,
         22,
         1313,
         1313,
         22,
         22,
         22,
         22,
         22,
         1301,
         1301,
         1301,
         1301,
         1301,
         2597,
         2598,
         2598,
         1312,
         1312,
         1312,
         1312,
         1312,
         1312,
         22,
         22,
         2789,
         2790,
         1312,
         2789,
         2790,
         2791,
         2792,
         2789,
         2790,
         22,
         2776,
         2776,
         1301,
         1301,
         1301,
         1312,
         2900,
         2900,
         1312,
         2901,
         1312,
         2900,
         1312,
         2789,
         2790,
         2900,
         22,
         23,
         1301,
         1302,
         1302,
         1312,
         22,
         1313,
         1313,
         22,
         22,
         22,
         22,
         22,
         1301,
         1301,
         1301,
         1301,
         1301,
         2597,
         2598,
         2598,
         1312,
         1312,
         2612,
         1312,
         2612,
         2612,
         22,
         22,
         2789,
         2790,
         1312,
         2789,
         2790,
         2791,
         2792,
         2800,
         2801,
         22,
         2776,
         2776,
         1301,
         1301,
         1301,
         1312,
         2790,
         2790,
         1312,
         2792,
         2612,
         2801,
         1312,
         2789,
         2790,
         2790,
         22,
         23,
         1301,
         1302,
         1302,
         1312,
         22,
         1313,
         1313,
         22,
         22,
         22,
         22,
         22,
         1301,
         1301,
         1301,
         1301,
         1301,
         2597,
         2598,
         2598,
         1312,
         1312,
         1312,
         1312,
         1312,
         1312,
         22,
         22,
         2789,
         2790,
         1312,
         2789,
         2790,
         2791,
         2792,
         2789,
         2790,
         22,
         2776,
         2776,
         1301,
         1301,
         1301,
         2897,
         2900,
         2900,
         2897,
         2901,
         2897,
         2900,
         2897,
         2898,
         2899,
         2902,
         22,
         23,
         1301,
         1302,
         1302,
         1312,
         22,
         1313,
         1313,
         22,
         22,
         22,
         22,
         22,
         1301,
         1301,
         1301,
         1301,
         1301,
         2597,
         2598,
         2598,
         1312,
         1312,
         2612,
         1312,
         2612,
         2612,
         22,
         22,
         2789,
         2790,
         1312,
         2789,
         2790,
         2791,
         2792,
         2800,
         2801,
         22,
         2776,
         2776,
         1301,
         1301,
         1301,
         2897,
         2790,
         2790,
         2897,
         2792,
         2903,
         2801,
         2897,
         2898,
         2899,
         2899,
         22,
         23,
         1301,
         1302,
         1302,
         1312,
         22,
         1313,
         1313,
         22,
         22,
         22,
         22,
         22,
         1301,
         1301,
         1301,
         1301,
         1301,
         2597,
         2598,
         2598,
         1312,
         1312,
         2612,
         1312,
         2612,
         2612,
         22,
         22,
         2789,
         2790,
         1312,
         2789,
         2790,
         2791,
         2792,
         2800,
         2801,
         22,
         2776,
         2776,
         1301,
         1301,
         1301,
         1312,
         2900,
         2900,
         1312,
         2901,
         2612,
         2904,
         1312,
         2789,
         2790,
         2900,
         22,
         23,
         1301,
         1302,
         1302,
         22,
         22,
         22,
         22,
         22,
         22,
         2609,
         22,
         22,
         1301,
         1301,
         1301,
         1301,
         1301,
         2597,
         2598,
         2598,
         22,
         22,
         22,
         22,
         22,
         22,
         2609,
         22,
         2774,
         2774,
         22,
         2774,
         2774,
         2775,
         2775,
         2774,
         2774,
         22,
         2776,
         2776,
         1301,
         1301,
         1301,
         22,
         2774,
         2774,
         22,
         2775,
         22,
         2774,
         22,
         2774,
         2774,
         2774,
         22,
         23,
         1301,
         1302,
         1302,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         1316,
         1301,
         1301,
         1301,
         1301,
         2610,
         2597,
         2598,
         2598,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         1316,
         2774,
         2774,
         22,
         2774,
         2774,
         2775,
         2775,
         2774,
         2774,
         22,
         2776,
         2776,
         1301,
         2802,
         1301,
         22,
         2774,
         2774,
         22,
         2775,
         22,
         2774,
         22,
         2774,
         2774,
         2774,
         2774,
         2777,
         2784,
         2787,
         2787,
         2789,
         2774,
         2793,
         2793,
         2774,
         2774,
         2774,
         2774,
         2774,
         2784,
         2784,
         2784,
         2784,
         2784,
         2795,
         2798,
         2798,
         2789,
         2789,
         2789,
         2789,
         2789,
         2789,
         2774,
         2774,
         2789,
         2790,
         2789,
         2789,
         2790,
         2791,
         2792,
         2789,
         2790,
         2774,
         2803,
         2803,
         2784,
         2784,
         2784,
         2789,
         2790,
         2790,
         2789,
         2792,
         2789,
         2790,
         2789,
         2789,
         2790,
         2790,
         2774,
         2777,
         2784,
         2787,
         2787,
         2790,
         2774,
         2793,
         2793,
         2774,
         2774,
         2774,
         2774,
         2774,
         2784,
         2784,
         2784,
         2784,
         2784,
         2795,
         2798,
         2798,
         2790,
         2790,
         2790,
         2790,
         2790,
         2790,
         2774,
         2774,
         2790,
         2790,
         2790,
         2790,
         2790,
         2792,
         2792,
         2790,
         2790,
         2774,
         2803,
         2803,
         2784,
         2784,
         2784,
         2790,
         2790,
         2790,
         2790,
         2792,
         2790,
         2790,
         2790,
         2790,
         2790,
         2790,
         22,
         2778,
         1301,
         1302,
         1302,
         1312,
         22,
         1313,
         1313,
         22,
         22,
         22,
         22,
         22,
         1301,
         1301,
         1301,
         1301,
         1301,
         2597,
         2598,
         2598,
         1312,
         1312,
         1312,
         1312,
         1312,
         1312,
         22,
         22,
         2789,
         2790,
         1312,
         2789,
         2790,
         2791,
         2792,
         2789,
         2790,
         22,
         2776,
         2776,
         1301,
         1301,
         1301,
         2897,
         2790,
         2790,
         2897,
         2792,
         2897,
         2790,
         2897,
         2898,
         2899,
         2899,
         2774,
         2777,
         2784,
         2787,
         2787,
         2789,
         2774,
         2793,
         2793,
         2774,
         2774,
         2774,
         2774,
         2774,
         2784,
         2784,
         2784,
         2784,
         2784,
         2795,
         2798,
         2798,
         2789,
         2789,
         2789,
         2789,
         2789,
         2789,
         2774,
         2774,
         2789,
         2790,
         2789,
         2789,
         2790,
         2791,
         2792,
         2789,
         2790,
         2774,
         2803,
         2803,
         2784,
         2784,
         2784,
         2898,
         2790,
         2790,
         2898,
         2792,
         2898,
         2790,
         2898,
         2898,
         2899,
         2899,
         2774,
         2777,
         2784,
         2787,
         2787,
         2790,
         2774,
         2793,
         2793,
         2774,
         2774,
         2774,
         2774,
         2774,
         2784,
         2784,
         2784,
         2784,
         2784,
         2795,
         2798,
         2798,
         2790,
         2790,
         2790,
         2790,
         2790,
         2790,
         2774,
         2774,
         2790,
         2790,
         2790,
         2790,
         2790,
         2792,
         2792,
         2790,
         2790,
         2774,
         2803,
         2803,
         2784,
         2784,
         2784,
         2899,
         2790,
         2790,
         2899,
         2792,
         2899,
         2790,
         2899,
         2899,
         2899,
         2899,
         2775,
         2779,
         2785,
         2788,
         2788,
         2791,
         2775,
         2794,
         2794,
         2775,
         2775,
         2775,
         2775,
         2775,
         2785,
         2785,
         2785,
         2785,
         2785,
         2796,
         2799,
         2799,
         2791,
         2791,
         2791,
         2791,
         2791,
         2791,
         2775,
         2775,
         2791,
         2792,
         2791,
         2791,
         2792,
         2791,
         2792,
         2791,
         2792,
         2775,
         2804,
         2804,
         2785,
         2785,
         2785,
         2791,
         2901,
         2901,
         2791,
         2901,
         2791,
         2901,
         2791,
         2791,
         2792,
         2901,
         2775,
         2779,
         2785,
         2788,
         2788,
         2792,
         2775,
         2794,
         2794,
         2775,
         2775,
         2775,
         2775,
         2775,
         2785,
         2785,
         2785,
         2785,
         2785,
         2796,
         2799,
         2799,
         2792,
         2792,
         2792,
         2792,
         2792,
         2792,
         2775,
         2775,
         2792,
         2792,
         2792,
         2792,
         2792,
         2792,
         2792,
         2792,
         2792,
         2775,
         2804,
         2804,
         2785,
         2785,
         2785,
         2792,
         2901,
         2901,
         2792,
         2901,
         2792,
         2901,
         2792,
         2792,
         2792,
         2901,
         2774,
         2777,
         2784,
         2787,
         2787,
         2789,
         2774,
         2793,
         2793,
         2774,
         2774,
         2774,
         2774,
         2774,
         2784,
         2784,
         2784,
         2784,
         2784,
         2795,
         2798,
         2798,
         2789,
         2789,
         2800,
         2789,
         2800,
         2800,
         2774,
         2774,
         2789,
         2790,
         2789,
         2789,
         2790,
         2791,
         2792,
         2800,
         2801,
         2774,
         2803,
         2803,
         2784,
         2784,
         2784,
         2789,
         2790,
         2790,
         2789,
         2792,
         2800,
         2801,
         2789,
         2789,
         2790,
         2790,
         2774,
         2777,
         2784,
         2787,
         2787,
         2790,
         2774,
         2793,
         2793,
         2774,
         2774,
         2774,
         2774,
         2774,
         2784,
         2784,
         2784,
         2784,
         2784,
         2795,
         2798,
         2798,
         2790,
         2790,
         2801,
         2790,
         2801,
         2801,
         2774,
         2774,
         2790,
         2790,
         2790,
         2790,
         2790,
         2792,
         2792,
         2801,
         2801,
         2774,
         2803,
         2803,
         2784,
         2784,
         2784,
         2790,
         2790,
         2790,
         2790,
         2792,
         2801,
         2801,
         2790,
         2790,
         2790,
         2790,
         22,
         2780,
         1301,
         1302,
         1302,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         1301,
         1301,
         1301,
         1301,
         1301,
         2597,
         2598,
         2598,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         2774,
         2774,
         22,
         2774,
         2774,
         2775,
         2775,
         2774,
         2774,
         22,
         2776,
         2776,
         1301,
         1301,
         1301,
         22,
         2774,
         2774,
         22,
         2775,
         22,
         2774,
         22,
         2774,
         2774,
         2774,
         2776,
         2781,
         2786,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2786,
         2786,
         2786,
         2786,
         2786,
         2797,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2803,
         2803,
         2776,
         2803,
         2803,
         2804,
         2804,
         2803,
         2803,
         2776,
         2776,
         2776,
         2786,
         2786,
         2786,
         2776,
         2803,
         2803,
         2776,
         2804,
         2776,
         2803,
         2776,
         2803,
         2803,
         2803,
         2776,
         2782,
         2786,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2786,
         2786,
         2786,
         2786,
         2786,
         2797,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2776,
         2803,
         2803,
         2776,
         2803,
         2803,
         2804,
         2804,
         2803,
         2803,
         2776,
         2776,
         2776,
         2786,
         2786,
         2786,
         2776,
         2803,
         2803,
         2776,
         2804,
         2776,
         2803,
         2776,
         2803,
         2803,
         2803,
         1301,
         2783,
         1301,
         1311,
         1311,
         1301,
         1301,
         1301,
         1301,
         1301,
         1301,
         1301,
         1301,
         1301,
         1301,
         1301,
         1301,
         1301,
         1301,
         2597,
         2607,
         2607,
         1301,
         1301,
         1301,
         1301,
         1301,
         1301,
         1301,
         1301,
         2784,
         2784,
         1301,
         2784,
         2784,
         2785,
         2785,
         2784,
         2784,
         1301,
         2786,
         2786,
         1301,
         1301,
         1301,
         1301,
         2784,
         2784,
         1301,
         2785,
         1301,
         2784,
         1301,
         2784,
         2784,
         2784,
         1301,
         2603,
         1301,
         1311,
         1311,
         1301,
         1301,
         1301,
         1301,
         1301,
         1301,
         1301,
         1301,
         2610,
         1301,
         1301,
         1301,
         1301,
         1301,
         2597,
         2607,
         2607,
         1301,
         1301,
         1301,
         1301,
         1301,
         1301,
         1301,
         2802,
         2784,
         2784,
         1301,
         2784,
         2784,
         2785,
         2785,
         2784,
         2784,
         1301,
         2786,
         2786,
         1301,
         1301,
         1301,
         1301,
         2784,
         2784,
         1301,
         2785,
         1301,
         2784,
         1301,
         2784,
         2784,
         2784,
         1301,
         2896,
         1301,
         1311,
         1311,
         1301,
         1301,
         1301,
         1301,
         1301,
         1301,
         1301,
         1301,
         1301,
         1301,
         1301,
         1301,
         1301,
         1301,
         2597,
         2607,
         2607,
         1301,
         1301,
         1301,
         1301,
         1301,
         1301,
         1301,
         1301,
         2784,
         2784,
         1301,
         2784,
         2784,
         2785,
         2785,
         2784,
         2784,
         1301,
         2786,
         2786,
         1301,
         1301,
         1301,
         1301,
         2784,
         2784,
         1301,
         2785,
         1301,
         2784,
         1301,
         2784,
         2784,
         2784,
         22,
         23,
         1301,
         1302,
         1302,
         1312,
         22,
         1313,
         1313,
         22,
         22,
         22,
         22,
         22,
         1301,
         1301,
         1301,
         1301,
         1301,
         2597,
         2598,
         2598,
         2897,
         1312,
         1312,
         2897,
         2897,
         1312,
         22,
         22,
         2789,
         2790,
         2897,
         2898,
         2899,
         2791,
         2792,
         2789,
         2790,
         22,
         2776,
         2776,
         1301,
         1301,
         1301,
         2897,
         2790,
         2899,
         2897,
         2792,
         2897,
         2790,
         2897,
         2898,
         2899,
         2899,
         2774,
         2777,
         2784,
         2787,
         2787,
         2790,
         2774,
         2793,
         2793,
         2774,
         2774,
         2774,
         2774,
         2774,
         2784,
         2784,
         2784,
         2784,
         2784,
         2795,
         2798,
         2798,
         2790,
         2900,
         2790,
         2900,
         2790,
         2900,
         2774,
         2774,
         2790,
         2790,
         2790,
         2790,
         2790,
         2901,
         2901,
         2790,
         2790,
         2774,
         2803,
         2803,
         2784,
         2784,
         2784,
         2790,
         2790,
         2790,
         2900,
         2901,
         2790,
         2790,
         2790,
         2790,
         2790,
         2790,
         2774,
         2777,
         2784,
         2787,
         2787,
         2790,
         2774,
         2793,
         2793,
         2774,
         2774,
         2774,
         2774,
         2774,
         2784,
         2784,
         2784,
         2784,
         2784,
         2795,
         2798,
         2798,
         2790,
         2900,
         2790,
         2900,
         2790,
         2900,
         2774,
         2774,
         2790,
         2790,
         2790,
         2790,
         2790,
         2901,
         2901,
         2790,
         2790,
         2774,
         2803,
         2803,
         2784,
         2784,
         2784,
         2899,
         2790,
         2790,
         2902,
         2901,
         2899,
         2790,
         2899,
         2899,
         2899,
         2899,
         22,
         23,
         1301,
         1302,
         1302,
         1312,
         22,
         1313,
         1313,
         22,
         22,
         22,
         22,
         22,
         1301,
         1301,
         1301,
         1301,
         1301,
         2597,
         2598,
         2598,
         2897,
         1312,
         1312,
         2897,
         2897,
         1312,
         22,
         22,
         2789,
         2790,
         2897,
         2898,
         2899,
         2791,
         2792,
         2789,
         2790,
         22,
         2776,
         2776,
         1301,
         1301,
         1301,
         2897,
         2900,
         2902,
         2897,
         2901,
         2897,
         2900,
         2897,
         2898,
         2899,
         2902,
         2775,
         2779,
         2785,
         2788,
         2788,
         2792,
         2775,
         2794,
         2794,
         2775,
         2775,
         2775,
         2775,
         2775,
         2785,
         2785,
         2785,
         2785,
         2785,
         2796,
         2799,
         2799,
         2792,
         2901,
         2792,
         2901,
         2792,
         2901,
         2775,
         2775,
         2792,
         2792,
         2792,
         2792,
         2792,
         2901,
         2901,
         2792,
         2792,
         2775,
         2804,
         2804,
         2785,
         2785,
         2785,
         2792,
         2901,
         2901,
         2901,
         2901,
         2792,
         2901,
         2792,
         2792,
         2792,
         2901,
         22,
         23,
         1301,
         1302,
         1302,
         1312,
         22,
         1313,
         1313,
         22,
         22,
         22,
         22,
         22,
         1301,
         1301,
         1301,
         1301,
         1301,
         2597,
         2598,
         2598,
         2897,
         1312,
         2612,
         2897,
         2903,
         2612,
         22,
         22,
         2789,
         2790,
         2897,
         2898,
         2899,
         2791,
         2792,
         2800,
         2801,
         22,
         2776,
         2776,
         1301,
         1301,
         1301,
         2897,
         2790,
         2899,
         2897,
         2792,
         2903,
         2801,
         2897,
         2898,
         2899,
         2899,
         2774,
         2777,
         2784,
         2787,
         2787,
         2790,
         2774,
         2793,
         2793,
         2774,
         2774,
         2774,
         2774,
         2774,
         2784,
         2784,
         2784,
         2784,
         2784,
         2795,
         2798,
         2798,
         2790,
         2900,
         2801,
         2900,
         2801,
         2904,
         2774,
         2774,
         2790,
         2790,
         2790,
         2790,
         2790,
         2901,
         2901,
         2801,
         2801,
         2774,
         2803,
         2803,
         2784,
         2784,
         2784,
         2790,
         2790,
         2790,
         2900,
         2901,
         2801,
         2801,
         2790,
         2790,
         2790,
         2790,
         22,
         2778,
         1301,
         1302,
         1302,
         1312,
         22,
         1313,
         1313,
         22,
         22,
         22,
         22,
         22,
         1301,
         1301,
         1301,
         1301,
         1301,
         2597,
         2598,
         2598,
         2897,
         1312,
         1312,
         2897,
         2897,
         1312,
         22,
         22,
         2789,
         2790,
         2897,
         2898,
         2899,
         2791,
         2792,
         2789,
         2790,
         22,
         2776,
         2776,
         1301,
         1301,
         1301,
         2897,
         2790,
         2899,
         2897,
         2792,
         2897,
         2790,
         2897,
         2898,
         2899,
         2899,
         2774,
         2777,
         2784,
         2787,
         2787,
         2789,
         2774,
         2793,
         2793,
         2774,
         2774,
         2774,
         2774,
         2774,
         2784,
         2784,
         2784,
         2784,
         2784,
         2795,
         2798,
         2798,
         2898,
         2789,
         2789,
         2898,
         2898,
         2789,
         2774,
         2774,
         2789,
         2790,
         2898,
         2898,
         2899,
         2791,
         2792,
         2789,
         2790,
         2774,
         2803,
         2803,
         2784,
         2784,
         2784,
         2898,
         2790,
         2899,
         2898,
         2792,
         2898,
         2790,
         2898,
         2898,
         2899,
         2899,
         2774,
         2777,
         2784,
         2787,
         2787,
         2790,
         2774,
         2793,
         2793,
         2774,
         2774,
         2774,
         2774,
         2774,
         2784,
         2784,
         2784,
         2784,
         2784,
         2795,
         2798,
         2798,
         2899,
         2790,
         2790,
         2899,
         2899,
         2790,
         2774,
         2774,
         2790,
         2790,
         2899,
         2899,
         2899,
         2792,
         2792,
         2790,
         2790,
         2774,
         2803,
         2803,
         2784,
         2784,
         2784,
         2899,
         2790,
         2899,
         2899,
         2792,
         2899,
         2790,
         2899,
         2899,
         2899,
         2899,
         2774,
         2777,
         2784,
         2787,
         2787,
         2790,
         2774,
         2793,
         2793,
         2774,
         2774,
         2774,
         2774,
         2774,
         2784,
         2784,
         2784,
         2784,
         2784,
         2795,
         2798,
         2798,
         2899,
         2900,
         2790,
         2902,
         2899,
         2900,
         2774,
         2774,
         2790,
         2790,
         2899,
         2899,
         2899,
         2901,
         2901,
         2790,
         2790,
         2774,
         2803,
         2803,
         2784,
         2784,
         2784,
         2899,
         2790,
         2899,
         2902,
         2901,
         2899,
         2790,
         2899,
         2899,
         2899,
         2899,
      },
   },
   [nir_op_iadd] = {
      .filter = (const uint16_t []) {
         0,
         1,
         2,
         3,
         4,
         4,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         9,
         0,
         9,
         0,
         10,
         0,
         10,
         0,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         0,
         11,
         0,
         11,
         0,
         12,
         0,
         12,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         0,
         13,
         0,
         13,
         0,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         14,
         14,
         0,
         0,
         14,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         0,
         17,
         0,
         18,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         19,
         20,
         21,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         22,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         8,
         8,
         23,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         7,
         7,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         0,
         0,
         14,
         14,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         14,
         14,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         14,
         14,
         14,
         14,
         14,
         0,
         0,
         0,
         0,
         14,
         14,
         14,
         14,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         14,
         14,
         14,
         14,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         14,
         14,
         14,
         14,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         14,
         14,
         14,
         14,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         14,
         14,
         14,
         14,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         14,
         14,
         14,
         14,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         14,
         14,
         14,
         14,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         5,
         5,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         16,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         24,
         6,
         6,
         6,
         25,
         26,
         27,
         28,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         29,
         30,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         31,
         32,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         33,
         33,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         34,
         35,
         36,
         0,
         0,
         0,
         18,
         18,
         18,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         7,
         7,
         8,
         8,
         23,
         23,
         23,
         23,
         23,
         8,
         8,
         8,
         8,
         22,
         22,
         22,
         22,
         22,
         22,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         14,
         14,
         14,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         3,
         3,
         3,
         3,
         3,
         3,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         4,
         5,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         32,
         32,
         30,
         37,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         14,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         14,
         0,
         14,
         0,
         14,
         0,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         22,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         14,
         0,
         0,
         4,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 38,
      .table = (const uint16_t []) {
      
         24,
         25,
         24,
         24,
         24,
         24,
         382,
         24,
         383,
         384,
         385,
         386,
         387,
         388,
         24,
         389,
         390,
         391,
         392,
         24,
         24,
         24,
         1976,
         1977,
         382,
         382,
         382,
         382,
         382,
         1978,
         1979,
         1980,
         1981,
         24,
         24,
         24,
         24,
         382,
         25,
         25,
         25,
         393,
         25,
         394,
         395,
         396,
         397,
         398,
         399,
         400,
         401,
         402,
         403,
         404,
         405,
         406,
         407,
         25,
         25,
         25,
         1982,
         1983,
         1984,
         1985,
         1986,
         1987,
         1988,
         1989,
         1990,
         1991,
         1992,
         25,
         25,
         25,
         25,
         395,
         24,
         25,
         408,
         408,
         24,
         24,
         382,
         24,
         383,
         384,
         385,
         386,
         387,
         388,
         24,
         389,
         390,
         391,
         392,
         24,
         24,
         24,
         1976,
         1977,
         382,
         382,
         382,
         382,
         382,
         1978,
         1979,
         1980,
         1981,
         24,
         24,
         24,
         24,
         382,
         24,
         393,
         408,
         408,
         24,
         24,
         382,
         24,
         383,
         384,
         385,
         386,
         387,
         388,
         24,
         389,
         390,
         391,
         392,
         24,
         24,
         24,
         1976,
         1977,
         382,
         382,
         382,
         382,
         382,
         1978,
         1979,
         1980,
         1981,
         24,
         24,
         24,
         24,
         382,
         24,
         25,
         24,
         24,
         409,
         409,
         382,
         24,
         383,
         384,
         385,
         386,
         387,
         388,
         24,
         389,
         390,
         391,
         392,
         24,
         24,
         24,
         1976,
         1977,
         382,
         382,
         382,
         382,
         382,
         1978,
         1979,
         1980,
         1981,
         24,
         24,
         24,
         24,
         382,
         24,
         394,
         24,
         24,
         409,
         409,
         382,
         24,
         383,
         384,
         385,
         386,
         387,
         388,
         24,
         389,
         390,
         391,
         392,
         24,
         24,
         24,
         1976,
         1977,
         382,
         382,
         382,
         382,
         382,
         1978,
         1979,
         1980,
         1981,
         24,
         24,
         24,
         24,
         382,
         382,
         395,
         382,
         382,
         382,
         382,
         382,
         410,
         411,
         412,
         413,
         414,
         415,
         416,
         382,
         417,
         418,
         419,
         420,
         382,
         382,
         382,
         1993,
         1994,
         382,
         382,
         382,
         382,
         382,
         1995,
         1996,
         1997,
         1998,
         382,
         382,
         382,
         382,
         382,
         24,
         396,
         24,
         24,
         24,
         24,
         410,
         24,
         383,
         384,
         385,
         386,
         387,
         388,
         24,
         389,
         390,
         391,
         392,
         24,
         24,
         24,
         1976,
         1977,
         410,
         410,
         410,
         410,
         410,
         1978,
         1979,
         1980,
         1981,
         24,
         24,
         24,
         24,
         410,
         383,
         397,
         383,
         383,
         383,
         383,
         411,
         383,
         383,
         421,
         422,
         423,
         424,
         425,
         383,
         426,
         427,
         428,
         429,
         383,
         383,
         383,
         1977,
         1977,
         411,
         411,
         411,
         411,
         411,
         1999,
         2000,
         2001,
         2002,
         383,
         383,
         383,
         383,
         411,
         384,
         398,
         384,
         384,
         384,
         384,
         412,
         384,
         421,
         384,
         430,
         431,
         432,
         433,
         384,
         434,
         435,
         436,
         437,
         384,
         384,
         384,
         2003,
         2004,
         412,
         412,
         412,
         412,
         412,
         2005,
         2006,
         2007,
         2008,
         384,
         384,
         384,
         384,
         412,
         385,
         399,
         385,
         385,
         385,
         385,
         413,
         385,
         422,
         430,
         385,
         438,
         439,
         440,
         385,
         441,
         442,
         443,
         444,
         385,
         385,
         385,
         2009,
         2010,
         413,
         413,
         413,
         413,
         413,
         2011,
         2012,
         2013,
         2014,
         385,
         385,
         385,
         385,
         413,
         386,
         400,
         386,
         386,
         386,
         386,
         414,
         386,
         423,
         431,
         438,
         386,
         445,
         446,
         386,
         447,
         448,
         449,
         450,
         386,
         386,
         386,
         2015,
         2016,
         414,
         414,
         414,
         414,
         414,
         2017,
         2018,
         2019,
         2020,
         386,
         386,
         386,
         386,
         414,
         387,
         401,
         387,
         387,
         387,
         387,
         415,
         387,
         424,
         432,
         439,
         445,
         387,
         451,
         387,
         452,
         453,
         454,
         455,
         387,
         387,
         387,
         2021,
         2022,
         415,
         415,
         415,
         415,
         415,
         2023,
         2024,
         2025,
         2026,
         387,
         387,
         387,
         387,
         415,
         388,
         402,
         388,
         388,
         388,
         388,
         416,
         388,
         425,
         433,
         440,
         446,
         451,
         388,
         388,
         456,
         457,
         458,
         459,
         388,
         388,
         388,
         2027,
         2028,
         416,
         416,
         416,
         416,
         416,
         2029,
         2030,
         2031,
         2032,
         388,
         388,
         388,
         388,
         416,
         24,
         403,
         24,
         24,
         24,
         24,
         382,
         24,
         383,
         384,
         385,
         386,
         387,
         388,
         24,
         389,
         390,
         391,
         392,
         24,
         24,
         24,
         1976,
         1977,
         382,
         382,
         382,
         382,
         382,
         1978,
         1979,
         1980,
         1981,
         24,
         24,
         24,
         24,
         382,
         389,
         404,
         389,
         389,
         389,
         389,
         417,
         389,
         426,
         434,
         441,
         447,
         452,
         456,
         389,
         389,
         460,
         461,
         462,
         389,
         389,
         389,
         2033,
         2034,
         417,
         417,
         417,
         417,
         417,
         2035,
         2036,
         2037,
         2038,
         389,
         389,
         389,
         389,
         417,
         390,
         405,
         390,
         390,
         390,
         390,
         418,
         390,
         427,
         435,
         442,
         448,
         453,
         457,
         390,
         460,
         390,
         463,
         464,
         390,
         390,
         390,
         2039,
         2040,
         418,
         418,
         418,
         418,
         418,
         2041,
         2042,
         2043,
         2044,
         390,
         390,
         390,
         390,
         418,
         391,
         406,
         391,
         391,
         391,
         391,
         419,
         391,
         428,
         436,
         443,
         449,
         454,
         458,
         391,
         461,
         463,
         391,
         465,
         391,
         391,
         391,
         2045,
         2046,
         419,
         419,
         419,
         419,
         419,
         2047,
         2048,
         2049,
         2050,
         391,
         391,
         391,
         391,
         419,
         392,
         407,
         392,
         392,
         392,
         392,
         420,
         392,
         429,
         437,
         444,
         450,
         455,
         459,
         392,
         462,
         464,
         465,
         392,
         392,
         392,
         392,
         2051,
         2052,
         420,
         420,
         420,
         420,
         420,
         2053,
         2054,
         2055,
         2056,
         392,
         392,
         392,
         392,
         420,
         24,
         25,
         24,
         24,
         24,
         24,
         382,
         24,
         383,
         384,
         385,
         386,
         387,
         388,
         24,
         389,
         390,
         391,
         392,
         24,
         466,
         466,
         1976,
         1977,
         382,
         382,
         382,
         382,
         382,
         1978,
         1979,
         1980,
         1981,
         24,
         24,
         24,
         24,
         382,
         24,
         25,
         24,
         24,
         24,
         24,
         382,
         24,
         383,
         384,
         385,
         386,
         387,
         388,
         24,
         389,
         390,
         391,
         392,
         466,
         24,
         466,
         1976,
         1977,
         382,
         382,
         382,
         382,
         382,
         1978,
         1979,
         1980,
         1981,
         24,
         24,
         24,
         24,
         382,
         24,
         25,
         24,
         24,
         24,
         24,
         382,
         24,
         383,
         384,
         385,
         386,
         387,
         388,
         24,
         389,
         390,
         391,
         392,
         466,
         466,
         466,
         1976,
         1977,
         382,
         382,
         382,
         382,
         382,
         1978,
         1979,
         1980,
         1981,
         24,
         24,
         24,
         24,
         382,
         1976,
         1982,
         1976,
         1976,
         1976,
         1976,
         1993,
         1976,
         1977,
         2003,
         2009,
         2015,
         2021,
         2027,
         1976,
         2033,
         2039,
         2045,
         2051,
         1976,
         1976,
         1976,
         1976,
         1977,
         1993,
         1993,
         1993,
         1993,
         1993,
         2057,
         2058,
         2059,
         2060,
         1976,
         1976,
         1976,
         1976,
         1993,
         1977,
         1983,
         1977,
         1977,
         1977,
         1977,
         1994,
         1977,
         1977,
         2004,
         2010,
         2016,
         2022,
         2028,
         1977,
         2034,
         2040,
         2046,
         2052,
         1977,
         1977,
         1977,
         1977,
         1977,
         1994,
         1994,
         1994,
         1994,
         1994,
         2061,
         2062,
         2063,
         2064,
         1977,
         1977,
         1977,
         1977,
         1994,
         382,
         1984,
         382,
         382,
         382,
         382,
         382,
         410,
         411,
         412,
         413,
         414,
         415,
         416,
         382,
         417,
         418,
         419,
         420,
         382,
         382,
         382,
         1993,
         1994,
         382,
         382,
         382,
         382,
         382,
         1995,
         1996,
         1997,
         1998,
         382,
         382,
         382,
         382,
         382,
         382,
         1985,
         382,
         382,
         382,
         382,
         382,
         410,
         411,
         412,
         413,
         414,
         415,
         416,
         382,
         417,
         418,
         419,
         420,
         382,
         382,
         382,
         1993,
         1994,
         382,
         382,
         382,
         382,
         382,
         1995,
         1996,
         1997,
         1998,
         382,
         382,
         382,
         382,
         382,
         382,
         1986,
         382,
         382,
         382,
         382,
         382,
         410,
         411,
         412,
         413,
         414,
         415,
         416,
         382,
         417,
         418,
         419,
         420,
         382,
         382,
         382,
         1993,
         1994,
         382,
         382,
         382,
         382,
         382,
         1995,
         1996,
         1997,
         1998,
         382,
         382,
         382,
         382,
         382,
         382,
         1987,
         382,
         382,
         382,
         382,
         382,
         410,
         411,
         412,
         413,
         414,
         415,
         416,
         382,
         417,
         418,
         419,
         420,
         382,
         382,
         382,
         1993,
         1994,
         382,
         382,
         382,
         382,
         382,
         1995,
         1996,
         1997,
         1998,
         382,
         382,
         382,
         382,
         382,
         382,
         1988,
         382,
         382,
         382,
         382,
         382,
         410,
         411,
         412,
         413,
         414,
         415,
         416,
         382,
         417,
         418,
         419,
         420,
         382,
         382,
         382,
         1993,
         1994,
         382,
         382,
         382,
         382,
         382,
         1995,
         1996,
         1997,
         1998,
         382,
         382,
         382,
         382,
         382,
         1978,
         1989,
         1978,
         1978,
         1978,
         1978,
         1995,
         1978,
         1999,
         2005,
         2011,
         2017,
         2023,
         2029,
         1978,
         2035,
         2041,
         2047,
         2053,
         1978,
         1978,
         1978,
         2057,
         2061,
         1995,
         1995,
         1995,
         1995,
         1995,
         1978,
         2065,
         2066,
         2067,
         1978,
         1978,
         1978,
         1978,
         1995,
         1979,
         1990,
         1979,
         1979,
         1979,
         1979,
         1996,
         1979,
         2000,
         2006,
         2012,
         2018,
         2024,
         2030,
         1979,
         2036,
         2042,
         2048,
         2054,
         1979,
         1979,
         1979,
         2058,
         2062,
         1996,
         1996,
         1996,
         1996,
         1996,
         2065,
         1979,
         2068,
         2069,
         1979,
         1979,
         1979,
         1979,
         1996,
         1980,
         1991,
         1980,
         1980,
         1980,
         1980,
         1997,
         1980,
         2001,
         2007,
         2013,
         2019,
         2025,
         2031,
         1980,
         2037,
         2043,
         2049,
         2055,
         1980,
         1980,
         1980,
         2059,
         2063,
         1997,
         1997,
         1997,
         1997,
         1997,
         2066,
         2068,
         1980,
         2070,
         1980,
         1980,
         1980,
         1980,
         1997,
         1981,
         1992,
         1981,
         1981,
         1981,
         1981,
         1998,
         1981,
         2002,
         2008,
         2014,
         2020,
         2026,
         2032,
         1981,
         2038,
         2044,
         2050,
         2056,
         1981,
         1981,
         1981,
         2060,
         2064,
         1998,
         1998,
         1998,
         1998,
         1998,
         2067,
         2069,
         2070,
         1981,
         1981,
         1981,
         1981,
         1981,
         1998,
         24,
         25,
         24,
         24,
         24,
         24,
         382,
         24,
         383,
         384,
         385,
         386,
         387,
         388,
         24,
         389,
         390,
         391,
         392,
         24,
         24,
         24,
         1976,
         1977,
         382,
         382,
         382,
         382,
         382,
         1978,
         1979,
         1980,
         1981,
         24,
         24,
         24,
         24,
         2879,
         24,
         25,
         24,
         24,
         24,
         24,
         382,
         24,
         383,
         384,
         385,
         386,
         387,
         388,
         24,
         389,
         390,
         391,
         392,
         24,
         24,
         24,
         1976,
         1977,
         382,
         382,
         382,
         382,
         382,
         1978,
         1979,
         1980,
         1981,
         24,
         24,
         2071,
         2071,
         382,
         24,
         25,
         24,
         24,
         24,
         24,
         382,
         24,
         383,
         384,
         385,
         386,
         387,
         388,
         24,
         389,
         390,
         391,
         392,
         24,
         24,
         24,
         1976,
         1977,
         382,
         382,
         382,
         382,
         382,
         1978,
         1979,
         1980,
         1981,
         24,
         2071,
         24,
         2071,
         382,
         24,
         25,
         24,
         24,
         24,
         24,
         382,
         24,
         383,
         384,
         385,
         386,
         387,
         388,
         24,
         389,
         390,
         391,
         392,
         24,
         24,
         24,
         1976,
         1977,
         382,
         382,
         382,
         382,
         382,
         1978,
         1979,
         1980,
         1981,
         24,
         2071,
         2071,
         2071,
         382,
         382,
         395,
         382,
         382,
         382,
         382,
         382,
         410,
         411,
         412,
         413,
         414,
         415,
         416,
         382,
         417,
         418,
         419,
         420,
         382,
         382,
         382,
         1993,
         1994,
         382,
         382,
         382,
         382,
         382,
         1995,
         1996,
         1997,
         1998,
         2879,
         382,
         382,
         382,
         382,
      },
   },
   [nir_op_iadd_sat] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         26,
         27,
         27,
         27,
      },
   },
   [nir_op_isub_sat] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         28,
         29,
         28,
         29,
      },
   },
   [nir_op_uadd_sat] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         30,
         31,
         31,
         31,
      },
   },
   [nir_op_usub_sat] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         32,
         33,
         32,
         33,
      },
   },
   [nir_op_usadd_4x8_vc4] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         34,
         34,
         34,
      },
   },
   [nir_op_fmul] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         4,
         5,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         10,
         0,
         0,
         9,
         10,
         0,
         0,
         11,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         0,
         0,
         0,
         0,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         15,
         16,
         15,
         15,
         15,
         0,
         0,
         0,
         0,
         9,
         10,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         10,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         10,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         10,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         10,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         10,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         10,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         17,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         18,
         0,
         19,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         18,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         20,
         3,
         3,
         3,
         4,
         4,
         4,
         4,
         4,
         4,
         21,
         4,
         4,
         4,
         4,
         3,
         20,
         3,
         3,
         3,
         20,
         3,
         20,
         3,
         3,
         3,
         20,
         20,
         20,
         3,
         3,
         3,
         3,
         3,
         3,
         5,
         5,
         6,
         6,
         6,
         6,
         6,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         13,
         13,
         13,
         13,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         4,
         4,
         4,
         4,
         4,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         20,
         20,
         20,
         20,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         22,
         7,
         18,
         0,
         19,
         19,
         19,
         19,
         23,
         19,
         0,
         0,
         18,
         18,
         0,
         18,
         18,
         0,
         0,
         2,
         2,
         2,
         11,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         9,
         0,
         9,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         24,
         0,
         0,
         19,
         18,
         18,
         18,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         18,
         18,
         18,
         0,
         0,
         0,
         0,
         18,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         4,
         4,
         3,
         3,
         3,
         3,
         20,
         20,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         19,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 25,
      .table = (const uint16_t []) {
      
         35,
         36,
         1317,
         35,
         35,
         35,
         35,
         1318,
         1319,
         35,
         1320,
         35,
         1321,
         1322,
         35,
         35,
         2304,
         1317,
         2305,
         2306,
         2307,
         2307,
         2833,
         2834,
         35,
         36,
         36,
         1323,
         1324,
         1325,
         1326,
         1327,
         1328,
         1329,
         1330,
         1331,
         36,
         1332,
         1333,
         36,
         1330,
         2308,
         1323,
         2309,
         2310,
         2311,
         2312,
         2835,
         2836,
         2895,
         1317,
         1323,
         1317,
         1317,
         1317,
         1317,
         1317,
         1334,
         1335,
         1317,
         1336,
         1317,
         1337,
         1338,
         1317,
         1317,
         2313,
         1317,
         2314,
         2315,
         2316,
         2316,
         2837,
         2838,
         1317,
         35,
         1324,
         1317,
         35,
         35,
         35,
         35,
         1318,
         1339,
         35,
         1320,
         35,
         1321,
         1322,
         35,
         35,
         2304,
         1317,
         2305,
         2306,
         2307,
         2307,
         2833,
         2834,
         35,
         35,
         1325,
         1317,
         35,
         35,
         35,
         35,
         1318,
         1339,
         35,
         1320,
         35,
         1321,
         1322,
         35,
         35,
         2304,
         1317,
         2305,
         2306,
         2307,
         2307,
         2833,
         2834,
         35,
         35,
         1326,
         1317,
         35,
         35,
         35,
         35,
         1318,
         1319,
         35,
         1320,
         35,
         1321,
         1322,
         35,
         35,
         2304,
         1317,
         2305,
         2306,
         2307,
         2307,
         2833,
         2834,
         35,
         35,
         1327,
         1317,
         35,
         35,
         35,
         35,
         1318,
         1319,
         35,
         1320,
         35,
         1321,
         1322,
         35,
         35,
         2304,
         1317,
         2305,
         2306,
         2307,
         2307,
         2833,
         2834,
         35,
         1318,
         1328,
         1334,
         1318,
         1318,
         1318,
         1318,
         1340,
         1341,
         1318,
         1342,
         1318,
         1343,
         1344,
         1318,
         1318,
         2317,
         2318,
         2319,
         2320,
         2321,
         2321,
         2839,
         2840,
         1318,
         1319,
         1329,
         1335,
         1339,
         1339,
         1319,
         1319,
         1341,
         1319,
         1319,
         1345,
         1319,
         1346,
         1347,
         1319,
         1319,
         2322,
         1335,
         2323,
         2324,
         2325,
         2325,
         2841,
         2842,
         1319,
         35,
         1330,
         1317,
         35,
         35,
         35,
         35,
         1318,
         1319,
         35,
         1320,
         35,
         1321,
         1322,
         35,
         35,
         2304,
         1317,
         2305,
         2306,
         2307,
         2307,
         2833,
         2834,
         35,
         1320,
         1331,
         1336,
         1320,
         1320,
         1320,
         1320,
         1342,
         1345,
         1320,
         1320,
         1320,
         1348,
         1349,
         1320,
         1320,
         2304,
         1336,
         2326,
         2327,
         2328,
         2328,
         2843,
         2844,
         1320,
         35,
         36,
         1317,
         35,
         35,
         35,
         35,
         1318,
         1319,
         35,
         1320,
         1350,
         1321,
         1322,
         35,
         35,
         2304,
         1317,
         2305,
         2306,
         2307,
         2307,
         2833,
         2834,
         35,
         1321,
         1332,
         1337,
         1321,
         1321,
         1321,
         1321,
         1343,
         1346,
         1321,
         1348,
         1321,
         1351,
         1352,
         1321,
         1321,
         2329,
         1337,
         2330,
         2331,
         2332,
         2332,
         2845,
         2846,
         1321,
         1322,
         1333,
         1338,
         1322,
         1322,
         1322,
         1322,
         1344,
         1347,
         1322,
         1349,
         1322,
         1352,
         1322,
         1322,
         1322,
         2333,
         1338,
         2334,
         2335,
         2336,
         2336,
         2847,
         2848,
         1322,
         35,
         36,
         1317,
         35,
         35,
         35,
         35,
         1318,
         1319,
         35,
         1320,
         35,
         1321,
         1322,
         1353,
         35,
         2304,
         1317,
         2305,
         2306,
         2307,
         2307,
         2833,
         2834,
         35,
         35,
         1330,
         1317,
         35,
         35,
         35,
         35,
         1318,
         1319,
         35,
         1320,
         35,
         1321,
         1322,
         35,
         2337,
         2338,
         1317,
         2305,
         2306,
         2307,
         2307,
         2833,
         2834,
         35,
         2304,
         2308,
         2313,
         2304,
         2304,
         2304,
         2304,
         2317,
         2322,
         2304,
         2304,
         2304,
         2329,
         2333,
         2304,
         2338,
         2338,
         2313,
         2339,
         2340,
         2341,
         2341,
         2849,
         2850,
         2304,
         1317,
         1323,
         1317,
         1317,
         1317,
         1317,
         1317,
         2318,
         1335,
         1317,
         1336,
         1317,
         1337,
         1338,
         1317,
         1317,
         2313,
         1317,
         2314,
         2315,
         2316,
         2316,
         2851,
         2838,
         1317,
         2305,
         2309,
         2314,
         2305,
         2305,
         2305,
         2305,
         2319,
         2323,
         2305,
         2326,
         2305,
         2330,
         2334,
         2305,
         2305,
         2339,
         2314,
         2305,
         2306,
         2342,
         2342,
         2852,
         2834,
         2305,
         2306,
         2310,
         2315,
         2306,
         2306,
         2306,
         2306,
         2320,
         2324,
         2306,
         2327,
         2306,
         2331,
         2335,
         2306,
         2306,
         2340,
         2315,
         2306,
         2343,
         2344,
         2344,
         2853,
         2854,
         2306,
         2307,
         2311,
         2316,
         2307,
         2307,
         2307,
         2307,
         2321,
         2325,
         2307,
         2328,
         2307,
         2332,
         2336,
         2307,
         2307,
         2341,
         2316,
         2342,
         2344,
         2307,
         2307,
         2855,
         2856,
         2307,
         2307,
         2312,
         2316,
         2307,
         2307,
         2307,
         2307,
         2321,
         2325,
         2307,
         2328,
         2307,
         2332,
         2336,
         2307,
         2307,
         2341,
         2316,
         2342,
         2344,
         2307,
         2307,
         2855,
         2856,
         2307,
         2833,
         2835,
         2837,
         2833,
         2833,
         2833,
         2833,
         2839,
         2841,
         2833,
         2843,
         2833,
         2845,
         2847,
         2833,
         2833,
         2849,
         2851,
         2852,
         2853,
         2855,
         2855,
         2839,
         2857,
         2833,
         2834,
         2836,
         2838,
         2834,
         2834,
         2834,
         2834,
         2840,
         2842,
         2834,
         2844,
         2834,
         2846,
         2848,
         2834,
         2834,
         2850,
         2838,
         2834,
         2854,
         2856,
         2856,
         2857,
         2854,
         2834,
         35,
         2895,
         1317,
         35,
         35,
         35,
         35,
         1318,
         1319,
         35,
         1320,
         35,
         1321,
         1322,
         35,
         35,
         2304,
         1317,
         2305,
         2306,
         2307,
         2307,
         2833,
         2834,
         35,
      },
   },
   [nir_op_fmulz] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         0,
         0,
         5,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         5,
         6,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         4,
         4,
         4,
         4,
         4,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         5,
         0,
         5,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 8,
      .table = (const uint16_t []) {
      
         37,
         38,
         1354,
         37,
         37,
         37,
         1355,
         37,
         38,
         38,
         1356,
         1357,
         1358,
         1359,
         1360,
         38,
         1354,
         1356,
         1354,
         1354,
         1354,
         1354,
         1361,
         1354,
         37,
         1357,
         1354,
         37,
         37,
         37,
         1355,
         37,
         37,
         1358,
         1354,
         37,
         37,
         37,
         1355,
         37,
         37,
         1359,
         1354,
         37,
         37,
         37,
         1355,
         37,
         1355,
         1360,
         1361,
         1355,
         1355,
         1355,
         1355,
         1355,
         37,
         38,
         1354,
         37,
         37,
         37,
         1355,
         1362,
      },
   },
   [nir_op_ffma] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         4,
         5,
         5,
         6,
         6,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         9,
         8,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         0,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         11,
         3,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         12,
         4,
         3,
         3,
         3,
         11,
         3,
         3,
         3,
         3,
         3,
         11,
         3,
         3,
         11,
         3,
         11,
         3,
         3,
         11,
         11,
         3,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         6,
         6,
         6,
         6,
         13,
         13,
         13,
         13,
         6,
         6,
         6,
         13,
         13,
         13,
         13,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         13,
         13,
         13,
         13,
         13,
         14,
         14,
         14,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         4,
         4,
         4,
         4,
         4,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         11,
         11,
         11,
         11,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         14,
         13,
         13,
         13,
         13,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         0,
         10,
         10,
         10,
         10,
         15,
         10,
         0,
         0,
         10,
         10,
         0,
         10,
         10,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         10,
         0,
         0,
         0,
         0,
         10,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         4,
         4,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         11,
         11,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         6,
         6,
         13,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 16,
      .table = (const uint16_t []) {
      
         39,
         40,
         39,
         1363,
         1363,
         39,
         1364,
         39,
         39,
         39,
         39,
         1363,
         1363,
         1364,
         1364,
         39,
         41,
         42,
         41,
         1365,
         1365,
         41,
         1366,
         41,
         41,
         41,
         41,
         1365,
         1365,
         1366,
         1366,
         41,
         1367,
         1368,
         1367,
         1369,
         1369,
         1367,
         1370,
         1367,
         1367,
         1367,
         1367,
         1369,
         1369,
         1370,
         1370,
         1367,
         39,
         40,
         39,
         1371,
         1371,
         39,
         1364,
         39,
         39,
         39,
         39,
         1371,
         1371,
         1364,
         1364,
         39,
         39,
         40,
         39,
         1371,
         1371,
         39,
         1364,
         39,
         39,
         39,
         39,
         1371,
         1371,
         1364,
         1364,
         39,
         39,
         40,
         39,
         1363,
         1363,
         39,
         1364,
         39,
         39,
         39,
         39,
         1363,
         1363,
         1364,
         1364,
         39,
         39,
         40,
         39,
         1363,
         1363,
         39,
         1364,
         39,
         39,
         39,
         39,
         1363,
         1363,
         1364,
         1364,
         39,
         39,
         40,
         39,
         1363,
         1363,
         39,
         1364,
         39,
         39,
         39,
         39,
         1363,
         1363,
         1364,
         2345,
         39,
         39,
         40,
         39,
         1363,
         1363,
         39,
         1364,
         39,
         39,
         39,
         39,
         1363,
         1363,
         1364,
         1364,
         39,
         2346,
         2347,
         2346,
         2348,
         2348,
         2346,
         2349,
         2346,
         2346,
         2346,
         2346,
         2348,
         2348,
         2349,
         2349,
         2346,
         39,
         40,
         39,
         1363,
         1363,
         39,
         1364,
         39,
         39,
         39,
         39,
         1363,
         1363,
         1364,
         1364,
         39,
         39,
         40,
         39,
         1371,
         1371,
         39,
         1364,
         39,
         39,
         39,
         39,
         1371,
         1371,
         1364,
         1364,
         39,
         39,
         40,
         39,
         1371,
         1371,
         39,
         1364,
         39,
         39,
         39,
         39,
         1371,
         1371,
         1364,
         1364,
         39,
         39,
         40,
         39,
         1363,
         1363,
         39,
         1364,
         39,
         39,
         39,
         39,
         1363,
         1363,
         1364,
         1364,
         39,
         39,
         40,
         39,
         1363,
         1363,
         39,
         1364,
         39,
         39,
         39,
         39,
         1363,
         1363,
         1364,
         1364,
         39,
         39,
         40,
         39,
         1363,
         1363,
         39,
         1364,
         39,
         39,
         39,
         39,
         2858,
         2858,
         1364,
         1364,
         39,
         41,
         42,
         41,
         1365,
         1365,
         41,
         1366,
         41,
         41,
         41,
         41,
         1365,
         1365,
         1366,
         1366,
         41,
         43,
         44,
         43,
         1372,
         1372,
         43,
         1373,
         43,
         43,
         43,
         43,
         1372,
         1372,
         1373,
         1373,
         43,
         1374,
         1375,
         1374,
         1376,
         1376,
         1374,
         1377,
         1374,
         1374,
         1374,
         1374,
         1376,
         1376,
         1377,
         1377,
         1374,
         1378,
         1379,
         1378,
         1380,
         1380,
         1378,
         1381,
         1378,
         1378,
         1378,
         1378,
         1380,
         1380,
         1381,
         1381,
         1378,
         1382,
         1383,
         1382,
         1384,
         1384,
         1382,
         1385,
         1382,
         1382,
         1382,
         1382,
         1384,
         1384,
         1385,
         1385,
         1382,
         1386,
         1387,
         1386,
         1388,
         1388,
         1386,
         1389,
         1386,
         1386,
         1386,
         1386,
         1388,
         1388,
         1389,
         1389,
         1386,
         41,
         42,
         41,
         1365,
         1365,
         41,
         1366,
         41,
         41,
         41,
         41,
         1365,
         1365,
         1366,
         1366,
         41,
         41,
         42,
         41,
         1365,
         1365,
         41,
         1366,
         41,
         41,
         41,
         41,
         1365,
         1365,
         1366,
         2350,
         41,
         41,
         42,
         41,
         1365,
         1365,
         41,
         1366,
         41,
         41,
         41,
         41,
         1365,
         1365,
         1366,
         1366,
         41,
         2351,
         2352,
         2351,
         2353,
         2353,
         2351,
         2354,
         2351,
         2351,
         2351,
         2351,
         2353,
         2353,
         2354,
         2354,
         2351,
         41,
         42,
         41,
         1365,
         1365,
         41,
         1366,
         41,
         41,
         41,
         41,
         1365,
         1365,
         1366,
         1366,
         41,
         1378,
         1379,
         1378,
         1380,
         1380,
         1378,
         1381,
         1378,
         1378,
         1378,
         1378,
         1380,
         1380,
         1381,
         1381,
         1378,
         1382,
         1383,
         1382,
         1384,
         1384,
         1382,
         1385,
         1382,
         1382,
         1382,
         1382,
         1384,
         1384,
         1385,
         1385,
         1382,
         41,
         42,
         41,
         1365,
         1365,
         41,
         1366,
         41,
         41,
         41,
         41,
         1365,
         1365,
         1366,
         1366,
         41,
         41,
         42,
         41,
         1365,
         1365,
         41,
         1366,
         41,
         41,
         41,
         41,
         1365,
         1365,
         1366,
         1366,
         41,
         41,
         42,
         41,
         1365,
         1365,
         41,
         1366,
         41,
         41,
         41,
         41,
         2859,
         2859,
         1366,
         1366,
         41,
         1367,
         1368,
         1367,
         1369,
         1369,
         1367,
         1370,
         1367,
         1367,
         1367,
         1367,
         1369,
         1369,
         1370,
         1370,
         1367,
         1374,
         1375,
         1374,
         1376,
         1376,
         1374,
         1377,
         1374,
         1374,
         1374,
         1374,
         1376,
         1376,
         1377,
         1377,
         1374,
         1390,
         1391,
         1390,
         1392,
         1392,
         1390,
         1393,
         1390,
         1390,
         1390,
         1390,
         1392,
         1392,
         1393,
         1393,
         1390,
         1367,
         1368,
         1367,
         1394,
         1394,
         1367,
         1370,
         1367,
         1367,
         1367,
         1367,
         1394,
         1394,
         1370,
         1370,
         1367,
         1367,
         1368,
         1367,
         1394,
         1394,
         1367,
         1370,
         1367,
         1367,
         1367,
         1367,
         1394,
         1394,
         1370,
         1370,
         1367,
         1367,
         1368,
         1367,
         1369,
         1369,
         1367,
         1370,
         1367,
         1367,
         1367,
         1367,
         1369,
         1369,
         1370,
         1370,
         1367,
         1367,
         1368,
         1367,
         1369,
         1369,
         1367,
         1370,
         1367,
         1367,
         1367,
         1367,
         1369,
         1369,
         1370,
         1370,
         1367,
         1395,
         1396,
         1395,
         1397,
         1397,
         1395,
         1398,
         1395,
         1395,
         1395,
         1395,
         1397,
         1397,
         1398,
         2355,
         1395,
         1367,
         1368,
         1367,
         1369,
         1369,
         1367,
         1370,
         1367,
         1367,
         1367,
         1367,
         1369,
         1369,
         1370,
         1370,
         1367,
         2356,
         2357,
         2356,
         2358,
         2358,
         2356,
         2359,
         2356,
         2356,
         2356,
         2356,
         2358,
         2358,
         2359,
         2359,
         2356,
         1367,
         1368,
         1367,
         1369,
         1369,
         1367,
         1370,
         1367,
         1367,
         1367,
         1367,
         1369,
         1369,
         1370,
         1370,
         1367,
         1367,
         1368,
         1367,
         1394,
         1394,
         1367,
         1370,
         1367,
         1367,
         1367,
         1367,
         1394,
         1394,
         1370,
         1370,
         1367,
         1367,
         1368,
         1367,
         1394,
         1394,
         1367,
         1370,
         1367,
         1367,
         1367,
         1367,
         1394,
         1394,
         1370,
         1370,
         1367,
         1367,
         1368,
         1367,
         1369,
         1369,
         1367,
         1370,
         1367,
         1367,
         1367,
         1367,
         1369,
         1369,
         1370,
         1370,
         1367,
         1367,
         1368,
         1367,
         1369,
         1369,
         1367,
         1370,
         1367,
         1367,
         1367,
         1367,
         1369,
         1369,
         1370,
         1370,
         1367,
         1367,
         1368,
         1367,
         1369,
         1369,
         1367,
         1370,
         1367,
         1367,
         1367,
         1367,
         2860,
         2860,
         1370,
         1370,
         1367,
         39,
         40,
         39,
         1371,
         1371,
         39,
         1364,
         39,
         39,
         39,
         39,
         1371,
         1371,
         1364,
         1364,
         39,
         1378,
         1379,
         1378,
         1380,
         1380,
         1378,
         1381,
         1378,
         1378,
         1378,
         1378,
         1380,
         1380,
         1381,
         1381,
         1378,
         1367,
         1368,
         1367,
         1394,
         1394,
         1367,
         1370,
         1367,
         1367,
         1367,
         1367,
         1394,
         1394,
         1370,
         1370,
         1367,
         39,
         40,
         39,
         1371,
         1371,
         39,
         1364,
         39,
         39,
         39,
         39,
         1371,
         1371,
         1364,
         1364,
         39,
         39,
         40,
         39,
         1371,
         1371,
         39,
         1364,
         39,
         39,
         39,
         39,
         1371,
         1371,
         1364,
         1364,
         39,
         39,
         40,
         39,
         1371,
         1371,
         39,
         1364,
         39,
         39,
         39,
         39,
         1371,
         1371,
         1364,
         1364,
         39,
         39,
         40,
         39,
         1371,
         1371,
         39,
         1364,
         39,
         39,
         39,
         39,
         1371,
         1371,
         1364,
         1364,
         39,
         39,
         40,
         39,
         1371,
         1371,
         39,
         1364,
         39,
         39,
         39,
         39,
         1371,
         1371,
         1364,
         2345,
         39,
         39,
         40,
         39,
         1371,
         1371,
         39,
         1364,
         39,
         39,
         39,
         39,
         1371,
         1371,
         1364,
         1364,
         39,
         2346,
         2347,
         2346,
         2360,
         2360,
         2346,
         2349,
         2346,
         2346,
         2346,
         2346,
         2360,
         2360,
         2349,
         2349,
         2346,
         39,
         40,
         39,
         1371,
         1371,
         39,
         1364,
         39,
         39,
         39,
         39,
         1371,
         1371,
         1364,
         1364,
         39,
         39,
         40,
         39,
         1371,
         1371,
         39,
         1364,
         39,
         39,
         39,
         39,
         1371,
         1371,
         1364,
         1364,
         39,
         39,
         40,
         39,
         1371,
         1371,
         39,
         1364,
         39,
         39,
         39,
         39,
         1371,
         1371,
         1364,
         1364,
         39,
         39,
         40,
         39,
         1371,
         1371,
         39,
         1364,
         39,
         39,
         39,
         39,
         1371,
         1371,
         1364,
         1364,
         39,
         39,
         40,
         39,
         1371,
         1371,
         39,
         1364,
         39,
         39,
         39,
         39,
         1371,
         1371,
         1364,
         1364,
         39,
         39,
         40,
         39,
         1371,
         1371,
         39,
         1364,
         39,
         39,
         39,
         39,
         2861,
         2861,
         1364,
         1364,
         39,
         39,
         40,
         39,
         1371,
         1371,
         39,
         1364,
         39,
         39,
         39,
         39,
         1371,
         1371,
         1364,
         1364,
         39,
         1382,
         1383,
         1382,
         1384,
         1384,
         1382,
         1385,
         1382,
         1382,
         1382,
         1382,
         1384,
         1384,
         1385,
         1385,
         1382,
         1367,
         1368,
         1367,
         1394,
         1394,
         1367,
         1370,
         1367,
         1367,
         1367,
         1367,
         1394,
         1394,
         1370,
         1370,
         1367,
         39,
         40,
         39,
         1371,
         1371,
         39,
         1364,
         39,
         39,
         39,
         39,
         1371,
         1371,
         1364,
         1364,
         39,
         39,
         40,
         39,
         1371,
         1371,
         39,
         1364,
         39,
         39,
         39,
         39,
         1371,
         1371,
         1364,
         1364,
         39,
         39,
         40,
         39,
         1371,
         1371,
         39,
         1364,
         39,
         39,
         39,
         39,
         1371,
         1371,
         1364,
         1364,
         39,
         39,
         40,
         39,
         1371,
         1371,
         39,
         1364,
         39,
         39,
         39,
         39,
         1371,
         1371,
         1364,
         1364,
         39,
         39,
         40,
         39,
         1371,
         1371,
         39,
         1364,
         39,
         39,
         39,
         39,
         1371,
         1371,
         1364,
         2345,
         39,
         39,
         40,
         39,
         1371,
         1371,
         39,
         1364,
         39,
         39,
         39,
         39,
         1371,
         1371,
         1364,
         1364,
         39,
         2346,
         2347,
         2346,
         2360,
         2360,
         2346,
         2349,
         2346,
         2346,
         2346,
         2346,
         2360,
         2360,
         2349,
         2349,
         2346,
         39,
         40,
         39,
         1371,
         1371,
         39,
         1364,
         39,
         39,
         39,
         39,
         1371,
         1371,
         1364,
         1364,
         39,
         39,
         40,
         39,
         1371,
         1371,
         39,
         1364,
         39,
         39,
         39,
         39,
         1371,
         1371,
         1364,
         1364,
         39,
         39,
         40,
         39,
         1371,
         1371,
         39,
         1364,
         39,
         39,
         39,
         39,
         1371,
         1371,
         1364,
         1364,
         39,
         39,
         40,
         39,
         1371,
         1371,
         39,
         1364,
         39,
         39,
         39,
         39,
         1371,
         1371,
         1364,
         1364,
         39,
         39,
         40,
         39,
         1371,
         1371,
         39,
         1364,
         39,
         39,
         39,
         39,
         1371,
         1371,
         1364,
         1364,
         39,
         39,
         40,
         39,
         1371,
         1371,
         39,
         1364,
         39,
         39,
         39,
         39,
         2861,
         2861,
         1364,
         1364,
         39,
         39,
         40,
         39,
         1363,
         1363,
         39,
         1364,
         39,
         39,
         39,
         39,
         1363,
         1363,
         1364,
         1364,
         39,
         1386,
         1387,
         1386,
         1388,
         1388,
         1386,
         1389,
         1386,
         1386,
         1386,
         1386,
         1388,
         1388,
         1389,
         1389,
         1386,
         1367,
         1368,
         1367,
         1369,
         1369,
         1367,
         1370,
         1367,
         1367,
         1367,
         1367,
         1369,
         1369,
         1370,
         1370,
         1367,
         39,
         40,
         39,
         1371,
         1371,
         39,
         1364,
         39,
         39,
         39,
         39,
         1371,
         1371,
         1364,
         1364,
         39,
         39,
         40,
         39,
         1371,
         1371,
         39,
         1364,
         39,
         39,
         39,
         39,
         1371,
         1371,
         1364,
         1364,
         39,
         39,
         40,
         39,
         1363,
         1363,
         39,
         1364,
         39,
         39,
         39,
         39,
         1363,
         1363,
         1364,
         1364,
         39,
         39,
         40,
         39,
         1363,
         1363,
         39,
         1364,
         39,
         39,
         39,
         39,
         1363,
         1363,
         1364,
         1364,
         39,
         39,
         40,
         39,
         1363,
         1363,
         39,
         1364,
         39,
         39,
         39,
         39,
         1363,
         1363,
         1364,
         2345,
         39,
         39,
         40,
         39,
         1363,
         1363,
         39,
         1364,
         39,
         39,
         39,
         39,
         1363,
         1363,
         1364,
         1364,
         39,
         2346,
         2347,
         2346,
         2348,
         2348,
         2346,
         2349,
         2346,
         2346,
         2346,
         2346,
         2348,
         2348,
         2349,
         2349,
         2346,
         39,
         40,
         39,
         1363,
         1363,
         39,
         1364,
         39,
         39,
         39,
         39,
         1363,
         1363,
         1364,
         1364,
         39,
         39,
         40,
         39,
         1371,
         1371,
         39,
         1364,
         39,
         39,
         39,
         39,
         1371,
         1371,
         1364,
         1364,
         39,
         39,
         40,
         39,
         1371,
         1371,
         39,
         1364,
         39,
         39,
         39,
         39,
         1371,
         1371,
         1364,
         1364,
         39,
         39,
         40,
         39,
         1363,
         1363,
         39,
         1364,
         39,
         39,
         39,
         39,
         1363,
         1363,
         1364,
         1364,
         39,
         39,
         40,
         39,
         1363,
         1363,
         39,
         1364,
         39,
         39,
         39,
         39,
         1363,
         1363,
         1364,
         1364,
         39,
         39,
         40,
         39,
         1363,
         1363,
         39,
         1364,
         39,
         39,
         39,
         39,
         2858,
         2858,
         1364,
         1364,
         39,
         39,
         40,
         39,
         1363,
         1363,
         39,
         1364,
         39,
         39,
         39,
         39,
         1363,
         1363,
         1364,
         1364,
         39,
         41,
         42,
         41,
         1365,
         1365,
         41,
         1366,
         41,
         41,
         41,
         41,
         1365,
         1365,
         1366,
         1366,
         41,
         1367,
         1368,
         1367,
         1369,
         1369,
         1367,
         1370,
         1367,
         1367,
         1367,
         1367,
         1369,
         1369,
         1370,
         1370,
         1367,
         39,
         40,
         39,
         1371,
         1371,
         39,
         1364,
         39,
         39,
         39,
         39,
         1371,
         1371,
         1364,
         1364,
         39,
         39,
         40,
         39,
         1371,
         1371,
         39,
         1364,
         39,
         39,
         39,
         39,
         1371,
         1371,
         1364,
         1364,
         39,
         39,
         40,
         39,
         1363,
         1363,
         39,
         1364,
         39,
         39,
         39,
         39,
         1363,
         1363,
         1364,
         1364,
         39,
         39,
         40,
         39,
         1363,
         1363,
         39,
         1364,
         39,
         39,
         39,
         39,
         1363,
         1363,
         1364,
         1364,
         39,
         39,
         40,
         39,
         1363,
         1363,
         39,
         1364,
         39,
         39,
         39,
         39,
         1363,
         1363,
         1364,
         2345,
         39,
         39,
         40,
         39,
         1363,
         1363,
         39,
         1364,
         39,
         39,
         39,
         39,
         1363,
         1363,
         1364,
         1364,
         39,
         2346,
         2347,
         2346,
         2348,
         2348,
         2346,
         2349,
         2346,
         2346,
         2346,
         2346,
         2348,
         2348,
         2349,
         2349,
         2346,
         39,
         40,
         39,
         1363,
         1363,
         39,
         1364,
         39,
         39,
         39,
         39,
         1363,
         1363,
         1364,
         1364,
         39,
         39,
         40,
         39,
         1371,
         1371,
         39,
         1364,
         39,
         39,
         39,
         39,
         1371,
         1371,
         1364,
         1364,
         39,
         39,
         40,
         39,
         1371,
         1371,
         39,
         1364,
         39,
         39,
         39,
         39,
         1371,
         1371,
         1364,
         1364,
         39,
         39,
         40,
         39,
         1363,
         1363,
         39,
         1364,
         39,
         39,
         39,
         39,
         1363,
         1363,
         1364,
         1364,
         39,
         39,
         40,
         39,
         1363,
         1363,
         39,
         1364,
         39,
         39,
         39,
         39,
         1363,
         1363,
         1364,
         1364,
         39,
         39,
         40,
         39,
         1363,
         1363,
         39,
         1364,
         39,
         39,
         39,
         39,
         2858,
         2858,
         1364,
         1364,
         39,
         39,
         40,
         39,
         1363,
         1363,
         39,
         1364,
         39,
         39,
         39,
         39,
         1363,
         1363,
         1364,
         2345,
         39,
         41,
         42,
         41,
         1365,
         1365,
         41,
         1366,
         41,
         41,
         41,
         41,
         1365,
         1365,
         1366,
         2350,
         41,
         1395,
         1396,
         1395,
         1397,
         1397,
         1395,
         1398,
         1395,
         1395,
         1395,
         1395,
         1397,
         1397,
         1398,
         2355,
         1395,
         39,
         40,
         39,
         1371,
         1371,
         39,
         1364,
         39,
         39,
         39,
         39,
         1371,
         1371,
         1364,
         2345,
         39,
         39,
         40,
         39,
         1371,
         1371,
         39,
         1364,
         39,
         39,
         39,
         39,
         1371,
         1371,
         1364,
         2345,
         39,
         39,
         40,
         39,
         1363,
         1363,
         39,
         1364,
         39,
         39,
         39,
         39,
         1363,
         1363,
         1364,
         2345,
         39,
         39,
         40,
         39,
         1363,
         1363,
         39,
         1364,
         39,
         39,
         39,
         39,
         1363,
         1363,
         1364,
         2345,
         39,
         39,
         40,
         39,
         1363,
         1363,
         39,
         1364,
         39,
         39,
         39,
         39,
         1363,
         1363,
         1364,
         2345,
         39,
         39,
         40,
         39,
         1363,
         1363,
         39,
         1364,
         39,
         39,
         39,
         39,
         1363,
         1363,
         1364,
         2345,
         39,
         2346,
         2347,
         2346,
         2348,
         2348,
         2346,
         2349,
         2346,
         2346,
         2346,
         2346,
         2348,
         2348,
         2349,
         2361,
         2346,
         2362,
         2363,
         2362,
         2364,
         2364,
         2362,
         2365,
         2362,
         2362,
         2362,
         2362,
         2364,
         2364,
         2365,
         2366,
         2362,
         39,
         40,
         39,
         1371,
         1371,
         39,
         1364,
         39,
         39,
         39,
         39,
         1371,
         1371,
         1364,
         2345,
         39,
         39,
         40,
         39,
         1371,
         1371,
         39,
         1364,
         39,
         39,
         39,
         39,
         1371,
         1371,
         1364,
         2345,
         39,
         39,
         40,
         39,
         2367,
         2367,
         39,
         1364,
         39,
         39,
         39,
         39,
         2367,
         2367,
         1364,
         2345,
         39,
         39,
         40,
         39,
         2367,
         2367,
         39,
         1364,
         39,
         39,
         39,
         39,
         2367,
         2367,
         1364,
         2345,
         39,
         2362,
         2363,
         2362,
         2364,
         2364,
         2362,
         2365,
         2362,
         2362,
         2362,
         2362,
         2862,
         2862,
         2365,
         2366,
         2362,
         39,
         40,
         39,
         1363,
         1363,
         39,
         1364,
         39,
         39,
         39,
         39,
         1363,
         1363,
         1364,
         1364,
         39,
         41,
         42,
         41,
         1365,
         1365,
         41,
         1366,
         41,
         41,
         41,
         41,
         1365,
         1365,
         1366,
         1366,
         41,
         1367,
         1368,
         1367,
         1369,
         1369,
         1367,
         1370,
         1367,
         1367,
         1367,
         1367,
         1369,
         1369,
         1370,
         1370,
         1367,
         39,
         40,
         39,
         1371,
         1371,
         39,
         1364,
         39,
         39,
         39,
         39,
         1371,
         1371,
         1364,
         1364,
         39,
         39,
         40,
         39,
         1371,
         1371,
         39,
         1364,
         39,
         39,
         39,
         39,
         1371,
         1371,
         1364,
         1364,
         39,
         39,
         40,
         39,
         1363,
         1363,
         39,
         1364,
         39,
         39,
         39,
         39,
         1363,
         1363,
         1364,
         1364,
         39,
         39,
         40,
         39,
         1363,
         1363,
         39,
         1364,
         39,
         39,
         39,
         39,
         1363,
         1363,
         1364,
         1364,
         39,
         39,
         40,
         39,
         1363,
         1363,
         39,
         1364,
         39,
         39,
         39,
         39,
         1363,
         1363,
         1364,
         2345,
         39,
         2368,
         2369,
         2368,
         2370,
         2370,
         2368,
         2371,
         2368,
         2368,
         2368,
         2368,
         2370,
         2370,
         2371,
         2371,
         2368,
         2372,
         2373,
         2372,
         2374,
         2374,
         2372,
         2375,
         2372,
         2372,
         2372,
         2372,
         2374,
         2374,
         2375,
         2375,
         2372,
         39,
         40,
         39,
         1363,
         1363,
         39,
         1364,
         39,
         39,
         39,
         39,
         1363,
         1363,
         1364,
         1364,
         39,
         39,
         40,
         39,
         1371,
         1371,
         39,
         1364,
         39,
         39,
         39,
         39,
         1371,
         1371,
         1364,
         1364,
         39,
         39,
         40,
         39,
         1371,
         1371,
         39,
         1364,
         39,
         39,
         39,
         39,
         1371,
         1371,
         1364,
         1364,
         39,
         39,
         40,
         39,
         1363,
         1363,
         39,
         1364,
         39,
         39,
         39,
         39,
         1363,
         1363,
         1364,
         1364,
         39,
         39,
         40,
         39,
         1363,
         1363,
         39,
         1364,
         39,
         39,
         39,
         39,
         1363,
         1363,
         1364,
         1364,
         39,
         39,
         40,
         39,
         1363,
         1363,
         39,
         1364,
         39,
         39,
         39,
         39,
         2858,
         2858,
         1364,
         1364,
         39,
         2346,
         2347,
         2346,
         2348,
         2348,
         2346,
         2349,
         2346,
         2346,
         2346,
         2346,
         2348,
         2348,
         2349,
         2349,
         2346,
         2351,
         2352,
         2351,
         2353,
         2353,
         2351,
         2354,
         2351,
         2351,
         2351,
         2351,
         2353,
         2353,
         2354,
         2354,
         2351,
         2356,
         2357,
         2356,
         2358,
         2358,
         2356,
         2359,
         2356,
         2356,
         2356,
         2356,
         2358,
         2358,
         2359,
         2359,
         2356,
         2346,
         2347,
         2346,
         2360,
         2360,
         2346,
         2349,
         2346,
         2346,
         2346,
         2346,
         2360,
         2360,
         2349,
         2349,
         2346,
         2346,
         2347,
         2346,
         2360,
         2360,
         2346,
         2349,
         2346,
         2346,
         2346,
         2346,
         2360,
         2360,
         2349,
         2349,
         2346,
         2346,
         2347,
         2346,
         2348,
         2348,
         2346,
         2349,
         2346,
         2346,
         2346,
         2346,
         2348,
         2348,
         2349,
         2349,
         2346,
         2346,
         2347,
         2346,
         2348,
         2348,
         2346,
         2349,
         2346,
         2346,
         2346,
         2346,
         2348,
         2348,
         2349,
         2349,
         2346,
         2346,
         2347,
         2346,
         2348,
         2348,
         2346,
         2349,
         2346,
         2346,
         2346,
         2346,
         2348,
         2348,
         2349,
         2361,
         2346,
         2372,
         2373,
         2372,
         2374,
         2374,
         2372,
         2375,
         2372,
         2372,
         2372,
         2372,
         2374,
         2374,
         2375,
         2375,
         2372,
         2372,
         2373,
         2372,
         2374,
         2374,
         2372,
         2375,
         2372,
         2372,
         2372,
         2372,
         2374,
         2374,
         2375,
         2375,
         2372,
         2346,
         2347,
         2346,
         2348,
         2348,
         2346,
         2349,
         2346,
         2346,
         2346,
         2346,
         2348,
         2348,
         2349,
         2349,
         2346,
         2346,
         2347,
         2346,
         2360,
         2360,
         2346,
         2349,
         2346,
         2346,
         2346,
         2346,
         2360,
         2360,
         2349,
         2349,
         2346,
         2346,
         2347,
         2346,
         2360,
         2360,
         2346,
         2349,
         2346,
         2346,
         2346,
         2346,
         2360,
         2360,
         2349,
         2349,
         2346,
         2346,
         2347,
         2346,
         2348,
         2348,
         2346,
         2349,
         2346,
         2346,
         2346,
         2346,
         2348,
         2348,
         2349,
         2349,
         2346,
         2346,
         2347,
         2346,
         2348,
         2348,
         2346,
         2349,
         2346,
         2346,
         2346,
         2346,
         2348,
         2348,
         2349,
         2349,
         2346,
         2346,
         2347,
         2346,
         2348,
         2348,
         2346,
         2349,
         2346,
         2346,
         2346,
         2346,
         2863,
         2863,
         2349,
         2349,
         2346,
         39,
         40,
         39,
         1363,
         1363,
         39,
         1364,
         39,
         39,
         39,
         39,
         1363,
         1363,
         1364,
         1364,
         39,
         41,
         42,
         41,
         1365,
         1365,
         41,
         1366,
         41,
         41,
         41,
         41,
         1365,
         1365,
         1366,
         1366,
         41,
         1367,
         1368,
         1367,
         1369,
         1369,
         1367,
         1370,
         1367,
         1367,
         1367,
         1367,
         1369,
         1369,
         1370,
         1370,
         1367,
         39,
         40,
         39,
         1371,
         1371,
         39,
         1364,
         39,
         39,
         39,
         39,
         1371,
         1371,
         1364,
         1364,
         39,
         39,
         40,
         39,
         1371,
         1371,
         39,
         1364,
         39,
         39,
         39,
         39,
         1371,
         1371,
         1364,
         1364,
         39,
         39,
         40,
         39,
         1363,
         1363,
         39,
         1364,
         39,
         39,
         39,
         39,
         1363,
         1363,
         1364,
         1364,
         39,
         39,
         40,
         39,
         1363,
         1363,
         39,
         1364,
         39,
         39,
         39,
         39,
         1363,
         1363,
         1364,
         1364,
         39,
         2362,
         2363,
         2362,
         2364,
         2364,
         2362,
         2365,
         2362,
         2362,
         2362,
         2362,
         2364,
         2364,
         2365,
         2366,
         2362,
         39,
         40,
         39,
         1363,
         1363,
         39,
         1364,
         39,
         39,
         39,
         39,
         1363,
         1363,
         1364,
         1364,
         39,
         2346,
         2347,
         2346,
         2348,
         2348,
         2346,
         2349,
         2346,
         2346,
         2346,
         2346,
         2348,
         2348,
         2349,
         2349,
         2346,
         39,
         40,
         39,
         1363,
         1363,
         39,
         1364,
         39,
         39,
         39,
         39,
         1363,
         1363,
         1364,
         1364,
         39,
         39,
         40,
         39,
         1371,
         1371,
         39,
         1364,
         39,
         39,
         39,
         39,
         1371,
         1371,
         1364,
         1364,
         39,
         39,
         40,
         39,
         1371,
         1371,
         39,
         1364,
         39,
         39,
         39,
         39,
         1371,
         1371,
         1364,
         1364,
         39,
         39,
         40,
         39,
         1363,
         1363,
         39,
         1364,
         39,
         39,
         39,
         39,
         1363,
         1363,
         1364,
         1364,
         39,
         39,
         40,
         39,
         1363,
         1363,
         39,
         1364,
         39,
         39,
         39,
         39,
         1363,
         1363,
         1364,
         1364,
         39,
         39,
         40,
         39,
         1363,
         1363,
         39,
         1364,
         39,
         39,
         39,
         39,
         2858,
         2858,
         1364,
         1364,
         39,
         39,
         40,
         39,
         1371,
         1371,
         39,
         1364,
         39,
         39,
         39,
         39,
         1371,
         1371,
         1364,
         1364,
         39,
         1378,
         1379,
         1378,
         1380,
         1380,
         1378,
         1381,
         1378,
         1378,
         1378,
         1378,
         1380,
         1380,
         1381,
         1381,
         1378,
         1367,
         1368,
         1367,
         1394,
         1394,
         1367,
         1370,
         1367,
         1367,
         1367,
         1367,
         1394,
         1394,
         1370,
         1370,
         1367,
         39,
         40,
         39,
         1371,
         1371,
         39,
         1364,
         39,
         39,
         39,
         39,
         1371,
         1371,
         1364,
         1364,
         39,
         39,
         40,
         39,
         1371,
         1371,
         39,
         1364,
         39,
         39,
         39,
         39,
         1371,
         1371,
         1364,
         1364,
         39,
         39,
         40,
         39,
         1371,
         1371,
         39,
         1364,
         39,
         39,
         39,
         39,
         1371,
         1371,
         1364,
         1364,
         39,
         39,
         40,
         39,
         1371,
         1371,
         39,
         1364,
         39,
         39,
         39,
         39,
         1371,
         1371,
         1364,
         1364,
         39,
         39,
         40,
         39,
         1371,
         1371,
         39,
         1364,
         39,
         39,
         39,
         39,
         1371,
         1371,
         1364,
         2345,
         39,
         39,
         40,
         39,
         1371,
         1371,
         39,
         1364,
         39,
         39,
         39,
         39,
         1371,
         1371,
         1364,
         1364,
         39,
         2346,
         2347,
         2346,
         2360,
         2360,
         2346,
         2349,
         2346,
         2346,
         2346,
         2346,
         2360,
         2360,
         2349,
         2349,
         2346,
         39,
         40,
         39,
         1371,
         1371,
         39,
         1364,
         39,
         39,
         39,
         39,
         1371,
         1371,
         1364,
         1364,
         39,
         39,
         40,
         39,
         1371,
         1371,
         39,
         1364,
         39,
         39,
         39,
         39,
         1371,
         1371,
         1364,
         1364,
         39,
         39,
         40,
         39,
         1371,
         1371,
         39,
         1364,
         39,
         39,
         39,
         39,
         1371,
         1371,
         1364,
         1364,
         39,
         39,
         40,
         39,
         1371,
         1371,
         39,
         1364,
         39,
         39,
         39,
         39,
         1371,
         1371,
         1364,
         1364,
         39,
         39,
         40,
         39,
         1371,
         1371,
         39,
         1364,
         39,
         39,
         39,
         39,
         1371,
         1371,
         1364,
         1364,
         39,
         39,
         40,
         39,
         1371,
         1371,
         39,
         1364,
         39,
         39,
         39,
         39,
         2861,
         2861,
         1364,
         1364,
         39,
         39,
         40,
         39,
         1371,
         1371,
         39,
         1364,
         39,
         39,
         39,
         39,
         1371,
         1371,
         1364,
         1364,
         39,
         1382,
         1383,
         1382,
         1384,
         1384,
         1382,
         1385,
         1382,
         1382,
         1382,
         1382,
         1384,
         1384,
         1385,
         1385,
         1382,
         1367,
         1368,
         1367,
         1394,
         1394,
         1367,
         1370,
         1367,
         1367,
         1367,
         1367,
         1394,
         1394,
         1370,
         1370,
         1367,
         39,
         40,
         39,
         1371,
         1371,
         39,
         1364,
         39,
         39,
         39,
         39,
         1371,
         1371,
         1364,
         1364,
         39,
         39,
         40,
         39,
         1371,
         1371,
         39,
         1364,
         39,
         39,
         39,
         39,
         1371,
         1371,
         1364,
         1364,
         39,
         39,
         40,
         39,
         1371,
         1371,
         39,
         1364,
         39,
         39,
         39,
         39,
         1371,
         1371,
         1364,
         1364,
         39,
         39,
         40,
         39,
         1371,
         1371,
         39,
         1364,
         39,
         39,
         39,
         39,
         1371,
         1371,
         1364,
         1364,
         39,
         39,
         40,
         39,
         1371,
         1371,
         39,
         1364,
         39,
         39,
         39,
         39,
         1371,
         1371,
         1364,
         2345,
         39,
         39,
         40,
         39,
         1371,
         1371,
         39,
         1364,
         39,
         39,
         39,
         39,
         1371,
         1371,
         1364,
         1364,
         39,
         2346,
         2347,
         2346,
         2360,
         2360,
         2346,
         2349,
         2346,
         2346,
         2346,
         2346,
         2360,
         2360,
         2349,
         2349,
         2346,
         39,
         40,
         39,
         1371,
         1371,
         39,
         1364,
         39,
         39,
         39,
         39,
         1371,
         1371,
         1364,
         1364,
         39,
         39,
         40,
         39,
         1371,
         1371,
         39,
         1364,
         39,
         39,
         39,
         39,
         1371,
         1371,
         1364,
         1364,
         39,
         39,
         40,
         39,
         1371,
         1371,
         39,
         1364,
         39,
         39,
         39,
         39,
         1371,
         1371,
         1364,
         1364,
         39,
         39,
         40,
         39,
         1371,
         1371,
         39,
         1364,
         39,
         39,
         39,
         39,
         1371,
         1371,
         1364,
         1364,
         39,
         39,
         40,
         39,
         1371,
         1371,
         39,
         1364,
         39,
         39,
         39,
         39,
         1371,
         1371,
         1364,
         1364,
         39,
         39,
         40,
         39,
         1371,
         1371,
         39,
         1364,
         39,
         39,
         39,
         39,
         2861,
         2861,
         1364,
         1364,
         39,
         39,
         40,
         39,
         1363,
         1363,
         39,
         1364,
         39,
         39,
         39,
         39,
         1363,
         1363,
         1364,
         1364,
         39,
         41,
         42,
         41,
         1365,
         1365,
         41,
         1366,
         41,
         41,
         41,
         41,
         1365,
         1365,
         1366,
         1366,
         41,
         1367,
         1368,
         1367,
         1369,
         1369,
         1367,
         1370,
         1367,
         1367,
         1367,
         1367,
         1369,
         1369,
         1370,
         1370,
         1367,
         39,
         40,
         39,
         1371,
         1371,
         39,
         1364,
         39,
         39,
         39,
         39,
         1371,
         1371,
         1364,
         1364,
         39,
         39,
         40,
         39,
         1371,
         1371,
         39,
         1364,
         39,
         39,
         39,
         39,
         1371,
         1371,
         1364,
         1364,
         39,
         39,
         40,
         39,
         1363,
         1363,
         39,
         1364,
         39,
         39,
         39,
         39,
         1363,
         1363,
         1364,
         1364,
         39,
         39,
         40,
         39,
         1363,
         1363,
         39,
         1364,
         39,
         39,
         39,
         39,
         1363,
         1363,
         1364,
         1364,
         39,
         39,
         40,
         39,
         2367,
         2367,
         39,
         1364,
         39,
         39,
         39,
         39,
         2367,
         2367,
         1364,
         2345,
         39,
         39,
         40,
         39,
         1363,
         1363,
         39,
         1364,
         39,
         39,
         39,
         39,
         1363,
         1363,
         1364,
         1364,
         39,
         2346,
         2347,
         2346,
         2348,
         2348,
         2346,
         2349,
         2346,
         2346,
         2346,
         2346,
         2348,
         2348,
         2349,
         2349,
         2346,
         39,
         40,
         39,
         1363,
         1363,
         39,
         1364,
         39,
         39,
         39,
         39,
         1363,
         1363,
         1364,
         1364,
         39,
         39,
         40,
         39,
         1371,
         1371,
         39,
         1364,
         39,
         39,
         39,
         39,
         1371,
         1371,
         1364,
         1364,
         39,
         39,
         40,
         39,
         1371,
         1371,
         39,
         1364,
         39,
         39,
         39,
         39,
         1371,
         1371,
         1364,
         1364,
         39,
         39,
         40,
         39,
         1363,
         1363,
         39,
         1364,
         39,
         39,
         39,
         39,
         1363,
         1363,
         1364,
         1364,
         39,
         39,
         40,
         39,
         1363,
         1363,
         39,
         1364,
         39,
         39,
         39,
         39,
         1363,
         1363,
         1364,
         1364,
         39,
         39,
         40,
         39,
         1363,
         1363,
         39,
         1364,
         39,
         39,
         39,
         39,
         2858,
         2858,
         1364,
         1364,
         39,
         39,
         40,
         39,
         1363,
         1363,
         39,
         1364,
         39,
         39,
         39,
         39,
         1363,
         1363,
         1364,
         1364,
         39,
         41,
         42,
         41,
         1365,
         1365,
         41,
         1366,
         41,
         41,
         41,
         41,
         1365,
         1365,
         1366,
         1366,
         41,
         1367,
         1368,
         1367,
         1369,
         1369,
         1367,
         1370,
         1367,
         1367,
         1367,
         1367,
         1369,
         1369,
         1370,
         1370,
         1367,
         39,
         40,
         39,
         1371,
         1371,
         39,
         1364,
         39,
         39,
         39,
         39,
         1371,
         1371,
         1364,
         1364,
         39,
         39,
         40,
         39,
         1371,
         1371,
         39,
         1364,
         39,
         39,
         39,
         39,
         1371,
         1371,
         1364,
         1364,
         39,
         39,
         40,
         39,
         1363,
         1363,
         39,
         1364,
         39,
         39,
         39,
         39,
         1363,
         1363,
         1364,
         1364,
         39,
         39,
         40,
         39,
         1363,
         1363,
         39,
         1364,
         39,
         39,
         39,
         39,
         1363,
         1363,
         1364,
         1364,
         39,
         39,
         40,
         39,
         2367,
         2367,
         39,
         1364,
         39,
         39,
         39,
         39,
         2367,
         2367,
         1364,
         2345,
         39,
         39,
         40,
         39,
         1363,
         1363,
         39,
         1364,
         39,
         39,
         39,
         39,
         1363,
         1363,
         1364,
         1364,
         39,
         2346,
         2347,
         2346,
         2348,
         2348,
         2346,
         2349,
         2346,
         2346,
         2346,
         2346,
         2348,
         2348,
         2349,
         2349,
         2346,
         39,
         40,
         39,
         1363,
         1363,
         39,
         1364,
         39,
         39,
         39,
         39,
         1363,
         1363,
         1364,
         1364,
         39,
         39,
         40,
         39,
         1371,
         1371,
         39,
         1364,
         39,
         39,
         39,
         39,
         1371,
         1371,
         1364,
         1364,
         39,
         39,
         40,
         39,
         1371,
         1371,
         39,
         1364,
         39,
         39,
         39,
         39,
         1371,
         1371,
         1364,
         1364,
         39,
         39,
         40,
         39,
         1363,
         1363,
         39,
         1364,
         39,
         39,
         39,
         39,
         1363,
         1363,
         1364,
         1364,
         39,
         39,
         40,
         39,
         1363,
         1363,
         39,
         1364,
         39,
         39,
         39,
         39,
         1363,
         1363,
         1364,
         1364,
         39,
         39,
         40,
         39,
         1363,
         1363,
         39,
         1364,
         39,
         39,
         39,
         39,
         2858,
         2858,
         1364,
         1364,
         39,
         39,
         40,
         39,
         1363,
         1363,
         39,
         1364,
         39,
         39,
         39,
         39,
         2858,
         2858,
         1364,
         1364,
         39,
         41,
         42,
         41,
         1365,
         1365,
         41,
         1366,
         41,
         41,
         41,
         41,
         2859,
         2859,
         1366,
         1366,
         41,
         1367,
         1368,
         1367,
         1369,
         1369,
         1367,
         1370,
         1367,
         1367,
         1367,
         1367,
         2860,
         2860,
         1370,
         1370,
         1367,
         39,
         40,
         39,
         1371,
         1371,
         39,
         1364,
         39,
         39,
         39,
         39,
         2861,
         2861,
         1364,
         1364,
         39,
         39,
         40,
         39,
         1371,
         1371,
         39,
         1364,
         39,
         39,
         39,
         39,
         2861,
         2861,
         1364,
         1364,
         39,
         39,
         40,
         39,
         1363,
         1363,
         39,
         1364,
         39,
         39,
         39,
         39,
         2858,
         2858,
         1364,
         1364,
         39,
         39,
         40,
         39,
         1363,
         1363,
         39,
         1364,
         39,
         39,
         39,
         39,
         2858,
         2858,
         1364,
         1364,
         39,
         2362,
         2363,
         2362,
         2364,
         2364,
         2362,
         2365,
         2362,
         2362,
         2362,
         2362,
         2862,
         2862,
         2365,
         2366,
         2362,
         39,
         40,
         39,
         1363,
         1363,
         39,
         1364,
         39,
         39,
         39,
         39,
         2858,
         2858,
         1364,
         1364,
         39,
         2346,
         2347,
         2346,
         2348,
         2348,
         2346,
         2349,
         2346,
         2346,
         2346,
         2346,
         2863,
         2863,
         2349,
         2349,
         2346,
         39,
         40,
         39,
         1363,
         1363,
         39,
         1364,
         39,
         39,
         39,
         39,
         2858,
         2858,
         1364,
         1364,
         39,
         39,
         40,
         39,
         1371,
         1371,
         39,
         1364,
         39,
         39,
         39,
         39,
         2861,
         2861,
         1364,
         1364,
         39,
         39,
         40,
         39,
         1371,
         1371,
         39,
         1364,
         39,
         39,
         39,
         39,
         2861,
         2861,
         1364,
         1364,
         39,
         39,
         40,
         39,
         1363,
         1363,
         39,
         1364,
         39,
         39,
         39,
         39,
         2858,
         2858,
         1364,
         1364,
         39,
         39,
         40,
         39,
         1363,
         1363,
         39,
         1364,
         39,
         39,
         39,
         39,
         2858,
         2858,
         1364,
         1364,
         39,
         39,
         40,
         39,
         1363,
         1363,
         39,
         1364,
         39,
         39,
         39,
         39,
         2858,
         2858,
         1364,
         1364,
         39,
      },
   },
   [nir_op_ffmaz] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         4,
         4,
         4,
         4,
         4,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 6,
      .table = (const uint16_t []) {
      
         45,
         46,
         45,
         1399,
         1399,
         1400,
         47,
         48,
         47,
         1401,
         1401,
         1402,
         45,
         46,
         45,
         1399,
         1399,
         1400,
         45,
         46,
         45,
         1403,
         1403,
         1400,
         45,
         46,
         45,
         1403,
         1403,
         1400,
         45,
         46,
         45,
         1399,
         1399,
         1400,
         47,
         48,
         47,
         1401,
         1401,
         1402,
         49,
         50,
         49,
         1404,
         1404,
         1405,
         47,
         48,
         47,
         1401,
         1401,
         1402,
         1406,
         1407,
         1406,
         1408,
         1408,
         1409,
         1410,
         1411,
         1410,
         1412,
         1412,
         1413,
         47,
         48,
         47,
         1401,
         1401,
         1402,
         45,
         46,
         45,
         1399,
         1399,
         1400,
         47,
         48,
         47,
         1401,
         1401,
         1402,
         1414,
         1415,
         1414,
         1416,
         1416,
         1417,
         45,
         46,
         45,
         1403,
         1403,
         1400,
         45,
         46,
         45,
         1403,
         1403,
         1400,
         45,
         46,
         45,
         1399,
         1399,
         1400,
         45,
         46,
         45,
         1403,
         1403,
         1400,
         1406,
         1407,
         1406,
         1408,
         1408,
         1409,
         45,
         46,
         45,
         1403,
         1403,
         1400,
         45,
         46,
         45,
         1403,
         1403,
         1400,
         45,
         46,
         45,
         1403,
         1403,
         1400,
         45,
         46,
         45,
         1403,
         1403,
         1400,
         45,
         46,
         45,
         1403,
         1403,
         1400,
         1410,
         1411,
         1410,
         1412,
         1412,
         1413,
         45,
         46,
         45,
         1403,
         1403,
         1400,
         45,
         46,
         45,
         1403,
         1403,
         1400,
         45,
         46,
         45,
         1403,
         1403,
         1400,
         45,
         46,
         45,
         1403,
         1403,
         1400,
         45,
         46,
         45,
         1399,
         1399,
         1400,
         47,
         48,
         47,
         1401,
         1401,
         1402,
         45,
         46,
         45,
         1399,
         1399,
         1400,
         45,
         46,
         45,
         1403,
         1403,
         1400,
         45,
         46,
         45,
         1403,
         1403,
         1400,
         45,
         46,
         45,
         1399,
         1399,
         1400,
      },
   },
   [nir_op_iand] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         2,
         3,
         4,
         3,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         8,
         9,
         9,
         10,
         11,
         12,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         14,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         17,
         16,
         17,
         18,
         19,
         18,
         19,
         20,
         21,
         22,
         23,
         24,
         25,
         26,
         27,
         28,
         29,
         29,
         30,
         31,
         32,
         32,
         32,
         32,
         33,
         33,
         34,
         34,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         35,
         36,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         37,
         38,
         39,
         40,
         41,
         42,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         4,
         4,
         4,
         4,
         3,
         4,
         3,
         3,
         3,
         4,
         3,
         3,
         4,
         4,
         3,
         4,
         3,
         3,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         9,
         9,
         43,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         43,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         44,
         9,
         9,
         43,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         43,
         9,
         9,
         9,
         9,
         9,
         9,
         43,
         43,
         43,
         43,
         43,
         43,
         43,
         43,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         16,
         16,
         16,
         16,
         17,
         16,
         16,
         17,
         17,
         18,
         18,
         19,
         18,
         19,
         18,
         19,
         36,
         36,
         36,
         36,
         36,
         36,
         36,
         38,
         38,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         21,
         21,
         21,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         22,
         21,
         22,
         21,
         22,
         21,
         21,
         21,
         22,
         22,
         21,
         22,
         21,
         21,
         21,
         22,
         21,
         22,
         21,
         21,
         21,
         21,
         25,
         25,
         25,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         26,
         25,
         26,
         25,
         26,
         25,
         25,
         25,
         26,
         26,
         26,
         25,
         26,
         25,
         25,
         25,
         26,
         25,
         26,
         25,
         25,
         25,
         25,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         45,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         46,
         11,
         11,
         47,
         48,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         10,
         10,
         10,
         10,
         12,
         12,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         20,
         20,
         20,
         20,
         20,
         49,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         50,
         51,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         52,
         53,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         15,
         15,
         15,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         30,
         30,
         30,
         30,
         30,
         30,
         31,
         30,
         31,
         30,
         30,
         31,
         30,
         31,
         30,
         30,
         31,
         31,
         30,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         42,
         42,
         42,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         4,
         4,
         4,
         54,
         4,
         16,
         16,
         16,
         16,
         16,
         16,
         55,
         17,
         0,
         0,
         0,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         43,
         43,
         43,
         43,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         20,
         20,
         20,
         20,
         20,
         20,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         0,
         0,
         23,
         22,
         22,
         22,
         22,
         22,
         27,
         26,
         26,
         26,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         13,
         12,
         31,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         33,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         15,
         15,
         15,
         36,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         53,
         53,
         51,
         45,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         9,
         9,
         9,
         9,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         56,
         57,
         58,
         4,
         4,
         17,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         14,
         29,
         0,
         22,
         26,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         59,
         22,
         22,
         22,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         0,
         60,
         61,
         8,
         0,
         8,
         8,
         4,
         17,
         9,
         62,
         63,
         64,
         8,
         8,
         8,
         4,
         17,
         9,
         65,
         66,
         67,
         8,
         8,
         8,
         4,
         17,
         9,
         65,
      },
      
      .num_filtered_states = 68,
      .table = (const uint16_t []) {
      
         51,
         52,
         51,
         51,
         51,
         51,
         51,
         1045,
         1045,
         1046,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         1047,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         1048,
         51,
         1049,
         51,
         1050,
         51,
         1051,
         2442,
         1046,
         51,
         2443,
         51,
         51,
         2444,
         2445,
         2446,
         2447,
         2448,
         51,
         51,
         1047,
         1047,
         1047,
         1046,
         51,
         51,
         1046,
         51,
         51,
         1046,
         51,
         51,
         52,
         52,
         1052,
         52,
         1053,
         1054,
         52,
         1055,
         1056,
         1057,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1058,
         52,
         52,
         1059,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         52,
         1060,
         52,
         1061,
         52,
         1062,
         52,
         1063,
         2449,
         2450,
         2451,
         2452,
         52,
         52,
         2453,
         2454,
         2455,
         2456,
         2457,
         2772,
         2773,
         1059,
         1059,
         1059,
         2911,
         2913,
         2914,
         2921,
         2922,
         2923,
         2930,
         2931,
         2932,
         51,
         1052,
         51,
         51,
         51,
         51,
         51,
         1045,
         1045,
         1046,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         1047,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         1048,
         51,
         1049,
         51,
         1050,
         51,
         1051,
         2442,
         1046,
         51,
         2443,
         51,
         51,
         2444,
         2445,
         2446,
         2447,
         2448,
         51,
         51,
         1047,
         1047,
         1047,
         1046,
         51,
         51,
         1046,
         51,
         51,
         1046,
         51,
         51,
         51,
         52,
         51,
         51,
         1064,
         51,
         51,
         1045,
         1045,
         1046,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         1047,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         1048,
         51,
         1049,
         51,
         1050,
         51,
         1051,
         2442,
         1046,
         51,
         2443,
         51,
         51,
         2444,
         2445,
         2446,
         2447,
         2448,
         1064,
         51,
         1047,
         1047,
         1047,
         1046,
         1064,
         51,
         1046,
         1064,
         51,
         1046,
         1064,
         51,
         51,
         1053,
         51,
         1064,
         1064,
         51,
         51,
         1045,
         1045,
         1046,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         1047,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         1048,
         51,
         1049,
         51,
         1050,
         51,
         1051,
         2442,
         1046,
         51,
         2443,
         51,
         51,
         2444,
         2445,
         2446,
         2447,
         2448,
         1064,
         51,
         1047,
         1047,
         1047,
         1046,
         1064,
         51,
         1046,
         1064,
         51,
         1046,
         1064,
         51,
         51,
         1054,
         51,
         51,
         51,
         51,
         51,
         1045,
         1045,
         1046,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         1047,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         1048,
         51,
         1049,
         51,
         1050,
         51,
         1051,
         2442,
         1046,
         51,
         2443,
         51,
         51,
         2444,
         2445,
         2446,
         2447,
         2448,
         51,
         51,
         1047,
         1047,
         1047,
         1046,
         51,
         51,
         1046,
         51,
         51,
         1046,
         51,
         51,
         51,
         52,
         51,
         51,
         51,
         51,
         51,
         1045,
         1045,
         1046,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         1047,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         1048,
         51,
         1049,
         51,
         1050,
         51,
         1051,
         2442,
         1046,
         2458,
         2443,
         51,
         51,
         2444,
         2445,
         2446,
         2447,
         2448,
         51,
         51,
         1047,
         1047,
         1047,
         1046,
         51,
         51,
         1046,
         51,
         51,
         1046,
         51,
         51,
         1045,
         1055,
         1045,
         1045,
         1045,
         1045,
         1045,
         1065,
         1065,
         1066,
         1045,
         1045,
         1045,
         1045,
         1045,
         1045,
         1045,
         1045,
         1045,
         1045,
         1067,
         1045,
         1045,
         1045,
         1045,
         1045,
         1045,
         1045,
         1045,
         1045,
         1045,
         1045,
         1045,
         1045,
         1045,
         1045,
         1068,
         1045,
         1069,
         1045,
         1070,
         1045,
         1071,
         2459,
         1066,
         1045,
         2460,
         1045,
         1045,
         2461,
         2462,
         2463,
         2464,
         2465,
         1045,
         1045,
         1067,
         1067,
         1067,
         1066,
         1045,
         1045,
         1066,
         1045,
         1045,
         1066,
         1045,
         1045,
         1045,
         1056,
         1045,
         1045,
         1045,
         1045,
         1045,
         1065,
         1065,
         1066,
         1045,
         1045,
         1045,
         1045,
         1045,
         1072,
         1045,
         1045,
         1045,
         1045,
         1067,
         1045,
         1045,
         1045,
         1045,
         1045,
         1045,
         1045,
         1045,
         1045,
         1045,
         1045,
         1045,
         1045,
         1045,
         1045,
         1068,
         1045,
         1069,
         1045,
         1070,
         1045,
         1071,
         2459,
         1066,
         1045,
         2460,
         1045,
         1045,
         2461,
         2462,
         2463,
         2464,
         2465,
         1045,
         1045,
         1067,
         1067,
         1067,
         1066,
         1045,
         1045,
         1066,
         1045,
         1045,
         1066,
         1045,
         1045,
         1046,
         1057,
         1046,
         1046,
         1046,
         1046,
         1046,
         1066,
         1066,
         1073,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1074,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1075,
         1046,
         1076,
         1046,
         1077,
         1046,
         1078,
         2466,
         1073,
         1046,
         2467,
         1046,
         1046,
         2468,
         2469,
         2470,
         2471,
         2472,
         1046,
         1046,
         1074,
         1074,
         1074,
         1073,
         1046,
         1046,
         1073,
         1046,
         1046,
         1073,
         1046,
         1046,
         51,
         52,
         51,
         51,
         51,
         51,
         51,
         1045,
         1045,
         1046,
         51,
         51,
         1079,
         1079,
         51,
         51,
         51,
         51,
         51,
         51,
         1047,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         1048,
         51,
         1049,
         51,
         1050,
         51,
         1051,
         2442,
         1046,
         51,
         2443,
         51,
         51,
         2444,
         2445,
         2446,
         2447,
         2448,
         51,
         51,
         1047,
         1047,
         1047,
         1046,
         51,
         51,
         1046,
         51,
         51,
         1046,
         51,
         51,
         51,
         52,
         51,
         51,
         51,
         51,
         51,
         1045,
         1045,
         1046,
         51,
         1080,
         1079,
         1079,
         51,
         51,
         51,
         51,
         51,
         51,
         1047,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         1048,
         51,
         1049,
         51,
         1050,
         51,
         1051,
         2442,
         1046,
         51,
         2473,
         1080,
         1080,
         2444,
         2445,
         2446,
         2447,
         2448,
         51,
         51,
         1047,
         1047,
         1047,
         1046,
         51,
         51,
         1046,
         51,
         51,
         1046,
         51,
         51,
         51,
         52,
         51,
         51,
         51,
         51,
         51,
         1045,
         1045,
         1046,
         1079,
         1079,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         1047,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         1048,
         51,
         1049,
         51,
         1050,
         51,
         1051,
         2442,
         1046,
         51,
         2474,
         1079,
         1079,
         2444,
         2445,
         2446,
         2447,
         2448,
         51,
         51,
         1047,
         1047,
         1047,
         1046,
         51,
         51,
         1046,
         51,
         51,
         1046,
         51,
         51,
         51,
         52,
         51,
         51,
         51,
         51,
         51,
         1045,
         1045,
         1046,
         1079,
         1079,
         51,
         1081,
         51,
         51,
         51,
         51,
         51,
         51,
         1047,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         1048,
         51,
         1049,
         51,
         1050,
         51,
         1051,
         2442,
         1046,
         51,
         2474,
         1079,
         1079,
         2444,
         2445,
         2446,
         2447,
         2448,
         51,
         51,
         1047,
         1047,
         1047,
         1046,
         51,
         51,
         1046,
         51,
         51,
         1046,
         51,
         51,
         51,
         52,
         51,
         51,
         51,
         51,
         51,
         1045,
         1045,
         1046,
         51,
         51,
         51,
         51,
         1082,
         51,
         51,
         51,
         51,
         51,
         1047,
         1083,
         1083,
         1083,
         1083,
         1084,
         1084,
         1084,
         1084,
         1085,
         51,
         51,
         51,
         51,
         51,
         51,
         1048,
         51,
         1049,
         51,
         1050,
         51,
         1051,
         2442,
         1046,
         51,
         2443,
         51,
         51,
         2444,
         2445,
         2446,
         2447,
         2448,
         51,
         51,
         1047,
         1047,
         1047,
         1046,
         51,
         51,
         1046,
         51,
         51,
         1046,
         51,
         51,
         51,
         52,
         51,
         51,
         51,
         51,
         51,
         1045,
         1072,
         1046,
         51,
         51,
         51,
         51,
         51,
         1086,
         51,
         51,
         51,
         51,
         1047,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         1048,
         51,
         1049,
         51,
         1050,
         51,
         1051,
         2442,
         1046,
         51,
         2443,
         51,
         51,
         2444,
         2445,
         2446,
         2447,
         2448,
         51,
         51,
         1047,
         1047,
         1047,
         1046,
         51,
         51,
         1046,
         51,
         51,
         1046,
         51,
         51,
         51,
         52,
         51,
         51,
         51,
         51,
         51,
         1045,
         1045,
         1046,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         1087,
         51,
         51,
         1047,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         1048,
         51,
         1049,
         51,
         1050,
         51,
         1051,
         2442,
         1046,
         51,
         2443,
         51,
         51,
         2444,
         2445,
         2446,
         2447,
         2448,
         51,
         1087,
         1047,
         1047,
         1047,
         1046,
         51,
         1087,
         1046,
         51,
         1087,
         1046,
         51,
         1087,
         51,
         1058,
         51,
         51,
         51,
         51,
         51,
         1045,
         1045,
         1046,
         51,
         51,
         51,
         51,
         51,
         51,
         1087,
         1087,
         51,
         51,
         1047,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         1048,
         51,
         1049,
         51,
         1050,
         51,
         1051,
         2442,
         1046,
         51,
         2443,
         51,
         51,
         2444,
         2445,
         2446,
         2447,
         2448,
         51,
         1087,
         1047,
         1047,
         1047,
         1046,
         51,
         1087,
         1046,
         51,
         1087,
         1046,
         51,
         1087,
         51,
         52,
         51,
         51,
         51,
         51,
         51,
         1045,
         1045,
         1046,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         1088,
         1047,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         1048,
         51,
         1049,
         51,
         1050,
         51,
         1051,
         2442,
         1046,
         51,
         2443,
         51,
         51,
         2444,
         2445,
         2446,
         2447,
         2448,
         51,
         51,
         1047,
         1047,
         1047,
         1046,
         51,
         51,
         1046,
         51,
         51,
         1046,
         51,
         51,
         51,
         52,
         51,
         51,
         51,
         51,
         51,
         1045,
         1045,
         1046,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         1088,
         1088,
         1047,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         1048,
         51,
         1049,
         51,
         1050,
         51,
         1051,
         2442,
         1046,
         51,
         2443,
         51,
         51,
         2444,
         2445,
         2446,
         2447,
         2448,
         51,
         51,
         1047,
         1047,
         1047,
         1046,
         51,
         51,
         1046,
         51,
         51,
         1046,
         51,
         51,
         1047,
         1059,
         1047,
         1047,
         1047,
         1047,
         1047,
         1067,
         1067,
         1074,
         1047,
         1047,
         1047,
         1047,
         1047,
         1047,
         1047,
         1047,
         1047,
         1047,
         1089,
         1047,
         1047,
         1047,
         1047,
         1047,
         1047,
         1047,
         1047,
         1047,
         1047,
         1047,
         1047,
         1047,
         1047,
         1047,
         1090,
         1047,
         1091,
         1047,
         1092,
         1047,
         1093,
         2475,
         1074,
         1047,
         2476,
         1047,
         1047,
         2477,
         2478,
         2479,
         2480,
         2481,
         1047,
         1047,
         1089,
         1089,
         1089,
         1074,
         1047,
         1047,
         1074,
         1047,
         1047,
         1074,
         1047,
         1047,
         51,
         52,
         51,
         51,
         51,
         51,
         51,
         1045,
         1045,
         1046,
         51,
         51,
         51,
         51,
         1083,
         51,
         51,
         51,
         51,
         51,
         1047,
         1094,
         1094,
         1094,
         1094,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         1048,
         51,
         1049,
         51,
         1050,
         51,
         1051,
         2442,
         1046,
         51,
         2443,
         51,
         51,
         2444,
         2445,
         2446,
         2447,
         2448,
         51,
         51,
         1047,
         1047,
         1047,
         1046,
         51,
         51,
         1046,
         51,
         51,
         1046,
         51,
         51,
         51,
         52,
         51,
         51,
         51,
         51,
         51,
         1045,
         1045,
         1046,
         51,
         51,
         51,
         51,
         1083,
         51,
         51,
         51,
         51,
         51,
         1047,
         1094,
         1095,
         1096,
         1097,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         1048,
         51,
         1049,
         51,
         1050,
         51,
         1051,
         2442,
         1046,
         51,
         2443,
         51,
         51,
         2444,
         2445,
         2446,
         2447,
         2448,
         51,
         51,
         1047,
         1047,
         1047,
         1046,
         51,
         51,
         1046,
         51,
         51,
         1046,
         51,
         51,
         51,
         52,
         51,
         51,
         51,
         51,
         51,
         1045,
         1045,
         1046,
         51,
         51,
         51,
         51,
         1083,
         51,
         51,
         51,
         51,
         51,
         1047,
         1094,
         1096,
         1098,
         1099,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         1048,
         51,
         1049,
         51,
         1050,
         51,
         1051,
         2442,
         1046,
         51,
         2443,
         51,
         51,
         2444,
         2445,
         2446,
         2447,
         2448,
         51,
         51,
         1047,
         1047,
         1047,
         1046,
         51,
         51,
         1046,
         51,
         51,
         1046,
         51,
         51,
         51,
         52,
         51,
         51,
         51,
         51,
         51,
         1045,
         1045,
         1046,
         51,
         51,
         51,
         51,
         1083,
         51,
         51,
         51,
         51,
         51,
         1047,
         1094,
         1097,
         1099,
         1100,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         1048,
         51,
         1049,
         51,
         1050,
         51,
         1051,
         2442,
         1046,
         51,
         2443,
         51,
         51,
         2444,
         2445,
         2446,
         2447,
         2448,
         51,
         51,
         1047,
         1047,
         1047,
         1046,
         51,
         51,
         1046,
         51,
         51,
         1046,
         51,
         51,
         51,
         52,
         51,
         51,
         51,
         51,
         51,
         1045,
         1045,
         1046,
         51,
         51,
         51,
         51,
         1084,
         51,
         51,
         51,
         51,
         51,
         1047,
         51,
         51,
         51,
         51,
         1101,
         1101,
         1101,
         1101,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         1048,
         51,
         1049,
         51,
         1050,
         51,
         1051,
         2442,
         1046,
         51,
         2443,
         51,
         51,
         2444,
         2445,
         2446,
         2447,
         2448,
         51,
         51,
         1047,
         1047,
         1047,
         1046,
         51,
         51,
         1046,
         51,
         51,
         1046,
         51,
         51,
         51,
         52,
         51,
         51,
         51,
         51,
         51,
         1045,
         1045,
         1046,
         51,
         51,
         51,
         51,
         1084,
         51,
         51,
         51,
         51,
         51,
         1047,
         51,
         51,
         51,
         51,
         1101,
         1102,
         1103,
         1104,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         1048,
         51,
         1049,
         51,
         1050,
         51,
         1051,
         2442,
         1046,
         51,
         2443,
         51,
         51,
         2444,
         2445,
         2446,
         2447,
         2448,
         51,
         51,
         1047,
         1047,
         1047,
         1046,
         51,
         51,
         1046,
         51,
         51,
         1046,
         51,
         51,
         51,
         52,
         51,
         51,
         51,
         51,
         51,
         1045,
         1045,
         1046,
         51,
         51,
         51,
         51,
         1084,
         51,
         51,
         51,
         51,
         51,
         1047,
         51,
         51,
         51,
         51,
         1101,
         1103,
         1105,
         1106,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         1048,
         51,
         1049,
         51,
         1050,
         51,
         1051,
         2442,
         1046,
         51,
         2443,
         51,
         51,
         2444,
         2445,
         2446,
         2447,
         2448,
         51,
         51,
         1047,
         1047,
         1047,
         1046,
         51,
         51,
         1046,
         51,
         51,
         1046,
         51,
         51,
         51,
         52,
         51,
         51,
         51,
         51,
         51,
         1045,
         1045,
         1046,
         51,
         51,
         51,
         51,
         1084,
         51,
         51,
         51,
         51,
         51,
         1047,
         51,
         51,
         51,
         51,
         1101,
         1104,
         1106,
         1107,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         1048,
         51,
         1049,
         51,
         1050,
         51,
         1051,
         2442,
         1046,
         51,
         2443,
         51,
         51,
         2444,
         2445,
         2446,
         2447,
         2448,
         51,
         51,
         1047,
         1047,
         1047,
         1046,
         51,
         51,
         1046,
         51,
         51,
         1046,
         51,
         51,
         51,
         52,
         51,
         51,
         51,
         51,
         51,
         1045,
         1045,
         1046,
         51,
         51,
         51,
         51,
         1085,
         51,
         51,
         51,
         51,
         51,
         1047,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         1108,
         51,
         51,
         51,
         51,
         51,
         51,
         1048,
         51,
         1049,
         51,
         1050,
         51,
         1051,
         2442,
         1046,
         51,
         2443,
         51,
         51,
         2444,
         2445,
         2446,
         2447,
         2448,
         51,
         51,
         1047,
         1047,
         1047,
         1046,
         51,
         51,
         1046,
         51,
         51,
         1046,
         51,
         51,
         51,
         52,
         51,
         51,
         51,
         51,
         51,
         1045,
         1045,
         1046,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         1047,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         1109,
         1109,
         51,
         51,
         51,
         51,
         1048,
         51,
         1049,
         51,
         1050,
         51,
         1051,
         2442,
         1046,
         51,
         2443,
         51,
         51,
         2444,
         2445,
         2446,
         2447,
         2448,
         51,
         51,
         1047,
         1047,
         1047,
         1046,
         51,
         51,
         1046,
         51,
         51,
         1046,
         51,
         51,
         51,
         52,
         51,
         51,
         51,
         51,
         51,
         1045,
         1045,
         1046,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         1047,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         1109,
         1109,
         51,
         51,
         51,
         51,
         1048,
         51,
         1049,
         51,
         1050,
         51,
         1051,
         2442,
         1046,
         51,
         2443,
         51,
         51,
         2444,
         2445,
         2446,
         2447,
         2448,
         51,
         51,
         2905,
         2906,
         2907,
         1046,
         51,
         51,
         1046,
         51,
         51,
         1046,
         51,
         51,
         51,
         52,
         51,
         51,
         51,
         51,
         51,
         1045,
         1045,
         1046,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         1047,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         1110,
         51,
         51,
         51,
         1048,
         51,
         1049,
         51,
         1050,
         51,
         1051,
         2442,
         1046,
         51,
         2443,
         51,
         51,
         2444,
         2445,
         2446,
         2447,
         2448,
         51,
         51,
         1047,
         1047,
         1047,
         1046,
         51,
         51,
         1046,
         51,
         51,
         1046,
         51,
         51,
         51,
         52,
         51,
         51,
         51,
         51,
         51,
         1045,
         1045,
         1046,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         1047,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         1111,
         51,
         51,
         1048,
         51,
         1049,
         51,
         1050,
         51,
         1051,
         2442,
         1046,
         51,
         2443,
         51,
         51,
         2444,
         2445,
         2446,
         2447,
         2448,
         51,
         51,
         1047,
         1047,
         1047,
         1046,
         51,
         51,
         1046,
         51,
         51,
         1046,
         51,
         51,
         51,
         52,
         51,
         51,
         51,
         51,
         51,
         1045,
         1045,
         1046,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         1047,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         1112,
         51,
         1048,
         51,
         1049,
         51,
         1050,
         51,
         1051,
         2442,
         1046,
         51,
         2443,
         51,
         51,
         2444,
         2445,
         2446,
         2447,
         2448,
         51,
         51,
         1047,
         1047,
         1047,
         1046,
         51,
         51,
         1046,
         51,
         51,
         1046,
         51,
         51,
         51,
         52,
         51,
         51,
         51,
         51,
         51,
         1045,
         1045,
         1046,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         1047,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         1113,
         51,
         1049,
         51,
         1050,
         51,
         1051,
         2442,
         1046,
         51,
         2443,
         51,
         51,
         2444,
         2445,
         2446,
         2447,
         2448,
         51,
         51,
         1047,
         1047,
         1047,
         1046,
         51,
         51,
         1046,
         51,
         51,
         1046,
         51,
         51,
         1048,
         1060,
         1048,
         1048,
         1048,
         1048,
         1048,
         1068,
         1068,
         1075,
         1048,
         1048,
         1048,
         1048,
         1048,
         1048,
         1048,
         1048,
         1048,
         1048,
         1090,
         1048,
         1048,
         1048,
         1048,
         1048,
         1048,
         1048,
         1048,
         1048,
         1048,
         1048,
         1048,
         1048,
         1048,
         1113,
         1113,
         1048,
         1114,
         1048,
         1115,
         1048,
         1116,
         2482,
         1075,
         1048,
         2483,
         1048,
         1048,
         2484,
         2485,
         2486,
         2487,
         2488,
         1048,
         1048,
         1090,
         1090,
         1090,
         1075,
         1048,
         1048,
         1075,
         1048,
         1048,
         1075,
         1048,
         1048,
         51,
         52,
         51,
         51,
         51,
         51,
         51,
         1045,
         1045,
         1046,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         1047,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         1048,
         51,
         1117,
         51,
         1050,
         51,
         1051,
         2442,
         1046,
         51,
         2443,
         51,
         51,
         2444,
         2445,
         2446,
         2447,
         2448,
         51,
         51,
         1047,
         1047,
         1047,
         1046,
         51,
         51,
         1046,
         51,
         51,
         1046,
         51,
         51,
         1049,
         1061,
         1049,
         1049,
         1049,
         1049,
         1049,
         1069,
         1069,
         1076,
         1049,
         1049,
         1049,
         1049,
         1049,
         1049,
         1049,
         1049,
         1049,
         1049,
         1091,
         1049,
         1049,
         1049,
         1049,
         1049,
         1049,
         1049,
         1049,
         1049,
         1049,
         1049,
         1049,
         1049,
         1049,
         1049,
         1114,
         1117,
         1117,
         1049,
         1118,
         1049,
         1119,
         2489,
         1076,
         1049,
         2490,
         1049,
         1049,
         2491,
         2492,
         2493,
         2494,
         2495,
         1049,
         1049,
         1091,
         1091,
         1091,
         1076,
         1049,
         1049,
         1076,
         1049,
         1049,
         1076,
         1049,
         1049,
         51,
         52,
         51,
         51,
         51,
         51,
         51,
         1045,
         1045,
         1046,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         1047,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         1048,
         51,
         1049,
         51,
         1120,
         51,
         1051,
         2442,
         1046,
         51,
         2443,
         51,
         51,
         2444,
         2445,
         2446,
         2447,
         2448,
         51,
         51,
         1047,
         1047,
         1047,
         1046,
         51,
         51,
         1046,
         51,
         51,
         1046,
         51,
         51,
         1050,
         1062,
         1050,
         1050,
         1050,
         1050,
         1050,
         1070,
         1070,
         1077,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1092,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1050,
         1115,
         1050,
         1118,
         1120,
         1120,
         1050,
         1121,
         2496,
         1077,
         1050,
         2497,
         1050,
         1050,
         2498,
         2499,
         2500,
         2501,
         2502,
         1050,
         1050,
         1092,
         1092,
         1092,
         1077,
         1050,
         1050,
         1077,
         1050,
         1050,
         1077,
         1050,
         1050,
         51,
         52,
         51,
         51,
         51,
         51,
         51,
         1045,
         1045,
         1046,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         1047,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         1048,
         51,
         1049,
         51,
         1050,
         51,
         1122,
         2442,
         1046,
         51,
         2443,
         51,
         51,
         2444,
         2445,
         2446,
         2447,
         2448,
         51,
         51,
         1047,
         1047,
         1047,
         1046,
         51,
         51,
         1046,
         51,
         51,
         1046,
         51,
         51,
         1051,
         1063,
         1051,
         1051,
         1051,
         1051,
         1051,
         1071,
         1071,
         1078,
         1051,
         1051,
         1051,
         1051,
         1051,
         1051,
         1051,
         1051,
         1051,
         1051,
         1093,
         1051,
         1051,
         1051,
         1051,
         1051,
         1051,
         1051,
         1051,
         1051,
         1051,
         1051,
         1051,
         1051,
         1051,
         1051,
         1116,
         1051,
         1119,
         1051,
         1121,
         1122,
         1122,
         2503,
         1078,
         1051,
         2504,
         1051,
         1051,
         2505,
         2506,
         2507,
         2508,
         2509,
         1051,
         1051,
         1093,
         1093,
         1093,
         1078,
         1051,
         1051,
         1078,
         1051,
         1051,
         1078,
         1051,
         1051,
         2442,
         2449,
         2442,
         2442,
         2442,
         2442,
         2442,
         2459,
         2459,
         2466,
         2442,
         2442,
         2442,
         2442,
         2442,
         2442,
         2442,
         2442,
         2442,
         2442,
         2475,
         2442,
         2442,
         2442,
         2442,
         2442,
         2442,
         2442,
         2442,
         2442,
         2442,
         2442,
         2442,
         2442,
         2442,
         2442,
         2482,
         2442,
         2489,
         2442,
         2496,
         2442,
         2503,
         2466,
         2466,
         2442,
         2510,
         2442,
         2442,
         2511,
         2512,
         2513,
         2514,
         2515,
         2442,
         2442,
         2475,
         2475,
         2475,
         2466,
         2442,
         2442,
         2466,
         2442,
         2442,
         2466,
         2442,
         2442,
         1046,
         2450,
         1046,
         1046,
         1046,
         1046,
         1046,
         1066,
         1066,
         1073,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1074,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1075,
         1046,
         1076,
         1046,
         1077,
         1046,
         1078,
         2466,
         1073,
         1046,
         2467,
         1046,
         1046,
         2468,
         2469,
         2470,
         2471,
         2472,
         1046,
         1046,
         1074,
         1074,
         1074,
         1073,
         1046,
         1046,
         1073,
         1046,
         1046,
         1073,
         1046,
         1046,
         51,
         2451,
         51,
         51,
         51,
         51,
         2458,
         1045,
         1045,
         1046,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         1047,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         1048,
         51,
         1049,
         51,
         1050,
         51,
         1051,
         2442,
         1046,
         2516,
         2443,
         51,
         51,
         2444,
         2445,
         2446,
         2447,
         2448,
         51,
         51,
         1047,
         1047,
         1047,
         1046,
         51,
         51,
         1046,
         51,
         51,
         1046,
         51,
         51,
         2443,
         2452,
         2443,
         2443,
         2443,
         2443,
         2443,
         2460,
         2460,
         2467,
         2443,
         2473,
         2474,
         2474,
         2443,
         2443,
         2443,
         2443,
         2443,
         2443,
         2476,
         2443,
         2443,
         2443,
         2443,
         2443,
         2443,
         2443,
         2443,
         2443,
         2443,
         2443,
         2443,
         2443,
         2443,
         2443,
         2483,
         2443,
         2490,
         2443,
         2497,
         2443,
         2504,
         2510,
         2467,
         2443,
         2473,
         2473,
         2473,
         2517,
         2518,
         2519,
         2520,
         2521,
         2443,
         2443,
         2476,
         2476,
         2476,
         2467,
         2443,
         2443,
         2467,
         2443,
         2443,
         2467,
         2443,
         2443,
         51,
         52,
         51,
         51,
         51,
         51,
         51,
         1045,
         1045,
         1046,
         51,
         1080,
         1079,
         1079,
         51,
         51,
         51,
         51,
         51,
         51,
         1047,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         1048,
         51,
         1049,
         51,
         1050,
         51,
         1051,
         2442,
         1046,
         51,
         2473,
         1080,
         2522,
         2444,
         2445,
         2446,
         2447,
         2448,
         51,
         51,
         1047,
         1047,
         1047,
         1046,
         51,
         51,
         1046,
         51,
         51,
         1046,
         51,
         51,
         51,
         52,
         51,
         51,
         51,
         51,
         51,
         1045,
         1045,
         1046,
         51,
         1080,
         1079,
         1079,
         51,
         51,
         51,
         51,
         51,
         51,
         1047,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         1048,
         51,
         1049,
         51,
         1050,
         51,
         1051,
         2442,
         1046,
         51,
         2473,
         2522,
         1080,
         2444,
         2445,
         2446,
         2447,
         2448,
         51,
         51,
         1047,
         1047,
         1047,
         1046,
         51,
         51,
         1046,
         51,
         51,
         1046,
         51,
         51,
         2444,
         2453,
         2444,
         2444,
         2444,
         2444,
         2444,
         2461,
         2461,
         2468,
         2444,
         2444,
         2444,
         2444,
         2444,
         2444,
         2444,
         2444,
         2444,
         2444,
         2477,
         2444,
         2444,
         2444,
         2444,
         2444,
         2444,
         2444,
         2444,
         2444,
         2444,
         2444,
         2444,
         2444,
         2444,
         2444,
         2484,
         2444,
         2491,
         2444,
         2498,
         2444,
         2505,
         2511,
         2468,
         2444,
         2517,
         2444,
         2444,
         2477,
         2523,
         2524,
         2525,
         2526,
         2444,
         2444,
         2477,
         2477,
         2477,
         2468,
         2444,
         2444,
         2468,
         2444,
         2444,
         2468,
         2444,
         2444,
         2445,
         2454,
         2445,
         2445,
         2445,
         2445,
         2445,
         2462,
         2462,
         2469,
         2445,
         2445,
         2445,
         2445,
         2445,
         2445,
         2445,
         2445,
         2445,
         2445,
         2478,
         2445,
         2445,
         2445,
         2445,
         2445,
         2445,
         2445,
         2445,
         2445,
         2445,
         2445,
         2445,
         2445,
         2445,
         2445,
         2485,
         2445,
         2492,
         2445,
         2499,
         2445,
         2506,
         2512,
         2469,
         2445,
         2518,
         2445,
         2445,
         2523,
         2445,
         2527,
         2528,
         2529,
         2445,
         2445,
         2478,
         2478,
         2478,
         2469,
         2445,
         2445,
         2469,
         2445,
         2445,
         2469,
         2445,
         2445,
         2446,
         2455,
         2446,
         2446,
         2446,
         2446,
         2446,
         2463,
         2463,
         2470,
         2446,
         2446,
         2446,
         2446,
         2446,
         2446,
         2446,
         2446,
         2446,
         2446,
         2479,
         2446,
         2446,
         2446,
         2446,
         2446,
         2446,
         2446,
         2446,
         2446,
         2446,
         2446,
         2446,
         2446,
         2446,
         2446,
         2486,
         2446,
         2493,
         2446,
         2500,
         2446,
         2507,
         2513,
         2470,
         2446,
         2519,
         2446,
         2446,
         2524,
         2527,
         2446,
         2530,
         2531,
         2446,
         2446,
         2479,
         2479,
         2479,
         2470,
         2446,
         2446,
         2470,
         2446,
         2446,
         2470,
         2446,
         2446,
         2447,
         2456,
         2447,
         2447,
         2447,
         2447,
         2447,
         2464,
         2464,
         2471,
         2447,
         2447,
         2447,
         2447,
         2447,
         2447,
         2447,
         2447,
         2447,
         2447,
         2480,
         2447,
         2447,
         2447,
         2447,
         2447,
         2447,
         2447,
         2447,
         2447,
         2447,
         2447,
         2447,
         2447,
         2447,
         2447,
         2487,
         2447,
         2494,
         2447,
         2501,
         2447,
         2508,
         2514,
         2471,
         2447,
         2520,
         2447,
         2447,
         2525,
         2528,
         2530,
         2447,
         2532,
         2447,
         2447,
         2480,
         2480,
         2480,
         2471,
         2447,
         2447,
         2471,
         2447,
         2447,
         2471,
         2447,
         2447,
         2448,
         2457,
         2448,
         2448,
         2448,
         2448,
         2448,
         2465,
         2465,
         2472,
         2448,
         2448,
         2448,
         2448,
         2448,
         2448,
         2448,
         2448,
         2448,
         2448,
         2481,
         2448,
         2448,
         2448,
         2448,
         2448,
         2448,
         2448,
         2448,
         2448,
         2448,
         2448,
         2448,
         2448,
         2448,
         2448,
         2488,
         2448,
         2495,
         2448,
         2502,
         2448,
         2509,
         2515,
         2472,
         2448,
         2521,
         2448,
         2448,
         2526,
         2529,
         2531,
         2532,
         2533,
         2448,
         2448,
         2481,
         2481,
         2481,
         2472,
         2448,
         2448,
         2472,
         2448,
         2448,
         2472,
         2448,
         2448,
         51,
         2772,
         51,
         1064,
         1064,
         51,
         51,
         1045,
         1045,
         1046,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         1047,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         1048,
         51,
         1049,
         51,
         1050,
         51,
         1051,
         2442,
         1046,
         51,
         2443,
         51,
         51,
         2444,
         2445,
         2446,
         2447,
         2448,
         1064,
         51,
         1047,
         1047,
         1047,
         1046,
         1064,
         51,
         1046,
         1064,
         51,
         1046,
         1064,
         51,
         51,
         2773,
         51,
         51,
         51,
         51,
         51,
         1045,
         1045,
         1046,
         51,
         51,
         51,
         51,
         51,
         51,
         1087,
         1087,
         51,
         51,
         1047,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         1048,
         51,
         1049,
         51,
         1050,
         51,
         1051,
         2442,
         1046,
         51,
         2443,
         51,
         51,
         2444,
         2445,
         2446,
         2447,
         2448,
         51,
         1087,
         1047,
         1047,
         1047,
         1046,
         51,
         1087,
         1046,
         51,
         1087,
         1046,
         51,
         1087,
         1047,
         1059,
         1047,
         1047,
         1047,
         1047,
         1047,
         1067,
         1067,
         1074,
         1047,
         1047,
         1047,
         1047,
         1047,
         1047,
         1047,
         1047,
         1047,
         1047,
         1089,
         1047,
         1047,
         1047,
         1047,
         1047,
         1047,
         1047,
         1047,
         1047,
         1047,
         2905,
         1047,
         1047,
         1047,
         1047,
         1090,
         1047,
         1091,
         1047,
         1092,
         1047,
         1093,
         2475,
         1074,
         1047,
         2476,
         1047,
         1047,
         2477,
         2478,
         2479,
         2480,
         2481,
         1047,
         1047,
         1089,
         1089,
         1089,
         1074,
         1047,
         1047,
         1074,
         1047,
         1047,
         1074,
         1047,
         1047,
         1047,
         1059,
         1047,
         1047,
         1047,
         1047,
         1047,
         1067,
         1067,
         1074,
         1047,
         1047,
         1047,
         1047,
         1047,
         1047,
         1047,
         1047,
         1047,
         1047,
         1089,
         1047,
         1047,
         1047,
         1047,
         1047,
         1047,
         1047,
         1047,
         1047,
         1047,
         2906,
         1047,
         1047,
         1047,
         1047,
         1090,
         1047,
         1091,
         1047,
         1092,
         1047,
         1093,
         2475,
         1074,
         1047,
         2476,
         1047,
         1047,
         2477,
         2478,
         2479,
         2480,
         2481,
         1047,
         1047,
         1089,
         1089,
         1089,
         1074,
         1047,
         1047,
         1074,
         1047,
         1047,
         1074,
         1047,
         1047,
         1047,
         1059,
         1047,
         1047,
         1047,
         1047,
         1047,
         1067,
         1067,
         1074,
         1047,
         1047,
         1047,
         1047,
         1047,
         1047,
         1047,
         1047,
         1047,
         1047,
         1089,
         1047,
         1047,
         1047,
         1047,
         1047,
         1047,
         1047,
         1047,
         1047,
         1047,
         2907,
         1047,
         1047,
         1047,
         1047,
         1090,
         1047,
         1091,
         1047,
         1092,
         1047,
         1093,
         2475,
         1074,
         1047,
         2476,
         1047,
         1047,
         2477,
         2478,
         2479,
         2480,
         2481,
         1047,
         1047,
         1089,
         1089,
         1089,
         1074,
         1047,
         1047,
         1074,
         1047,
         1047,
         1074,
         1047,
         1047,
         1046,
         2911,
         1046,
         1046,
         1046,
         1046,
         1046,
         1066,
         1066,
         1073,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1074,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1075,
         1046,
         1076,
         1046,
         1077,
         1046,
         1078,
         2466,
         1073,
         1046,
         2467,
         1046,
         1046,
         2468,
         2469,
         2470,
         2471,
         2472,
         1046,
         1046,
         1074,
         1074,
         1074,
         1073,
         1046,
         1046,
         1073,
         1046,
         1046,
         1073,
         1046,
         1046,
         51,
         2913,
         51,
         1064,
         1064,
         51,
         51,
         1045,
         1045,
         1046,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         1047,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         1048,
         51,
         1049,
         51,
         1050,
         51,
         1051,
         2442,
         1046,
         51,
         2443,
         51,
         51,
         2444,
         2445,
         2446,
         2447,
         2448,
         1064,
         51,
         1047,
         1047,
         1047,
         1046,
         1064,
         51,
         1046,
         1064,
         51,
         1046,
         1064,
         51,
         51,
         2914,
         51,
         51,
         51,
         51,
         51,
         1045,
         1045,
         1046,
         51,
         51,
         51,
         51,
         51,
         51,
         1087,
         1087,
         51,
         51,
         1047,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         1048,
         51,
         1049,
         51,
         1050,
         51,
         1051,
         2442,
         1046,
         51,
         2443,
         51,
         51,
         2444,
         2445,
         2446,
         2447,
         2448,
         51,
         1087,
         1047,
         1047,
         1047,
         1046,
         51,
         1087,
         1046,
         51,
         1087,
         1046,
         51,
         1087,
         1046,
         2921,
         1046,
         1046,
         1046,
         1046,
         1046,
         1066,
         1066,
         1073,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1074,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1075,
         1046,
         1076,
         1046,
         1077,
         1046,
         1078,
         2466,
         1073,
         1046,
         2467,
         1046,
         1046,
         2468,
         2469,
         2470,
         2471,
         2472,
         1046,
         1046,
         1074,
         1074,
         1074,
         1073,
         1046,
         1046,
         1073,
         1046,
         1046,
         1073,
         1046,
         1046,
         51,
         2922,
         51,
         1064,
         1064,
         51,
         51,
         1045,
         1045,
         1046,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         1047,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         1048,
         51,
         1049,
         51,
         1050,
         51,
         1051,
         2442,
         1046,
         51,
         2443,
         51,
         51,
         2444,
         2445,
         2446,
         2447,
         2448,
         1064,
         51,
         1047,
         1047,
         1047,
         1046,
         1064,
         51,
         1046,
         1064,
         51,
         1046,
         1064,
         51,
         51,
         2923,
         51,
         51,
         51,
         51,
         51,
         1045,
         1045,
         1046,
         51,
         51,
         51,
         51,
         51,
         51,
         1087,
         1087,
         51,
         51,
         1047,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         1048,
         51,
         1049,
         51,
         1050,
         51,
         1051,
         2442,
         1046,
         51,
         2443,
         51,
         51,
         2444,
         2445,
         2446,
         2447,
         2448,
         51,
         1087,
         1047,
         1047,
         1047,
         1046,
         51,
         1087,
         1046,
         51,
         1087,
         1046,
         51,
         1087,
         1046,
         2930,
         1046,
         1046,
         1046,
         1046,
         1046,
         1066,
         1066,
         1073,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1074,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1046,
         1075,
         1046,
         1076,
         1046,
         1077,
         1046,
         1078,
         2466,
         1073,
         1046,
         2467,
         1046,
         1046,
         2468,
         2469,
         2470,
         2471,
         2472,
         1046,
         1046,
         1074,
         1074,
         1074,
         1073,
         1046,
         1046,
         1073,
         1046,
         1046,
         1073,
         1046,
         1046,
         51,
         2931,
         51,
         1064,
         1064,
         51,
         51,
         1045,
         1045,
         1046,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         1047,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         1048,
         51,
         1049,
         51,
         1050,
         51,
         1051,
         2442,
         1046,
         51,
         2443,
         51,
         51,
         2444,
         2445,
         2446,
         2447,
         2448,
         1064,
         51,
         1047,
         1047,
         1047,
         1046,
         1064,
         51,
         1046,
         1064,
         51,
         1046,
         1064,
         51,
         51,
         2932,
         51,
         51,
         51,
         51,
         51,
         1045,
         1045,
         1046,
         51,
         51,
         51,
         51,
         51,
         51,
         1087,
         1087,
         51,
         51,
         1047,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         51,
         1048,
         51,
         1049,
         51,
         1050,
         51,
         1051,
         2442,
         1046,
         51,
         2443,
         51,
         51,
         2444,
         2445,
         2446,
         2447,
         2448,
         51,
         1087,
         1047,
         1047,
         1047,
         1046,
         51,
         1087,
         1046,
         51,
         1087,
         1046,
         51,
         1087,
      },
   },
   [nir_op_ior] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         2,
         3,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         5,
         6,
         7,
         0,
         8,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         13,
         12,
         13,
         14,
         15,
         14,
         15,
         16,
         17,
         18,
         19,
         20,
         21,
         22,
         23,
         24,
         25,
         25,
         26,
         26,
         27,
         27,
         27,
         27,
         28,
         28,
         29,
         30,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         31,
         32,
         0,
         0,
         0,
         0,
         33,
         0,
         0,
         34,
         35,
         36,
         37,
         38,
         39,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         40,
         41,
         42,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         43,
         2,
         43,
         3,
         3,
         3,
         3,
         2,
         3,
         2,
         43,
         2,
         3,
         2,
         43,
         44,
         3,
         2,
         3,
         2,
         43,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         6,
         6,
         6,
         6,
         45,
         6,
         6,
         6,
         6,
         7,
         7,
         7,
         7,
         7,
         46,
         7,
         7,
         7,
         7,
         6,
         6,
         6,
         6,
         6,
         6,
         45,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         45,
         6,
         6,
         6,
         6,
         6,
         6,
         45,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         45,
         6,
         6,
         6,
         6,
         45,
         45,
         45,
         45,
         45,
         45,
         45,
         45,
         45,
         45,
         45,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         47,
         12,
         47,
         12,
         13,
         12,
         47,
         13,
         13,
         14,
         14,
         15,
         14,
         15,
         14,
         15,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         35,
         35,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         17,
         17,
         17,
         19,
         19,
         19,
         19,
         19,
         19,
         19,
         19,
         18,
         17,
         18,
         17,
         18,
         17,
         17,
         17,
         18,
         18,
         17,
         18,
         17,
         17,
         17,
         18,
         17,
         18,
         17,
         17,
         17,
         17,
         21,
         21,
         21,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         23,
         22,
         21,
         22,
         21,
         22,
         21,
         21,
         21,
         22,
         22,
         22,
         21,
         22,
         21,
         21,
         21,
         22,
         21,
         22,
         21,
         21,
         21,
         21,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         48,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         29,
         29,
         29,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         49,
         50,
         0,
         0,
         0,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         51,
         52,
         33,
         33,
         33,
         33,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         11,
         11,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         53,
         54,
         55,
         0,
         0,
         0,
         39,
         39,
         39,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         56,
         56,
         56,
         56,
         56,
         3,
         3,
         3,
         3,
         3,
         57,
         12,
         57,
         12,
         57,
         12,
         13,
         13,
         0,
         0,
         0,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         7,
         7,
         7,
         7,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         45,
         45,
         45,
         45,
         45,
         6,
         6,
         6,
         6,
         58,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         58,
         58,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         16,
         16,
         16,
         16,
         16,
         16,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         0,
         0,
         19,
         18,
         18,
         18,
         18,
         18,
         23,
         22,
         22,
         22,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         9,
         0,
         26,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         28,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         11,
         11,
         32,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         52,
         52,
         50,
         48,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         59,
         6,
         6,
         60,
         61,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         33,
         33,
         33,
         16,
         16,
         16,
         62,
         3,
         63,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         25,
         0,
         18,
         22,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         18,
         18,
         18,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         0,
         3,
         13,
         5,
         0,
         64,
         65,
         66,
         67,
         6,
         6,
         3,
         13,
         5,
         68,
         69,
         70,
         71,
         6,
         6,
         3,
         13,
         5,
         72,
         73,
         74,
         75,
         6,
         6,
      },
      
      .num_filtered_states = 76,
      .table = (const uint16_t []) {
      
         53,
         54,
         53,
         53,
         1123,
         1123,
         1124,
         1124,
         1125,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         1126,
         1127,
         1127,
         1127,
         1127,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         1128,
         53,
         53,
         1129,
         53,
         1130,
         53,
         1131,
         53,
         53,
         53,
         53,
         53,
         1124,
         1124,
         53,
         53,
         2376,
         2377,
         2378,
         2379,
         53,
         53,
         53,
         53,
         53,
         1124,
         1124,
         1123,
         1123,
         53,
         53,
         1123,
         1123,
         53,
         53,
         1123,
         1123,
         53,
         53,
         1123,
         1123,
         53,
         53,
         54,
         54,
         54,
         54,
         1132,
         1132,
         1133,
         1134,
         1135,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         1136,
         1137,
         1137,
         1137,
         1137,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         54,
         1138,
         54,
         54,
         1139,
         54,
         1140,
         54,
         1141,
         54,
         54,
         54,
         54,
         54,
         1133,
         1134,
         54,
         54,
         2380,
         2381,
         2382,
         2383,
         54,
         54,
         54,
         54,
         54,
         1133,
         1133,
         1132,
         1132,
         54,
         54,
         1132,
         1132,
         54,
         54,
         1132,
         1132,
         54,
         54,
         1132,
         1132,
         54,
         54,
         53,
         54,
         53,
         1142,
         1123,
         1123,
         1124,
         1124,
         1125,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         1126,
         1127,
         1127,
         1127,
         1127,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         1128,
         53,
         53,
         1129,
         53,
         1130,
         53,
         1131,
         53,
         53,
         53,
         53,
         1142,
         1124,
         1124,
         2384,
         53,
         2376,
         2377,
         2378,
         2379,
         53,
         53,
         53,
         53,
         2766,
         1124,
         1124,
         1123,
         1123,
         1142,
         53,
         1123,
         1123,
         1142,
         53,
         1123,
         1123,
         1142,
         53,
         1123,
         1123,
         1142,
         53,
         53,
         54,
         1142,
         1142,
         1123,
         1123,
         1124,
         1124,
         1125,
         53,
         53,
         53,
         53,
         1143,
         53,
         53,
         1126,
         1127,
         1127,
         1127,
         1127,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         1128,
         53,
         53,
         1129,
         53,
         1130,
         53,
         1131,
         53,
         53,
         53,
         1142,
         1142,
         1124,
         1124,
         2384,
         53,
         2376,
         2377,
         2378,
         2379,
         53,
         53,
         53,
         1142,
         2766,
         1124,
         1124,
         1123,
         1123,
         1142,
         1143,
         1123,
         1123,
         1142,
         1143,
         1123,
         1123,
         1142,
         1143,
         1123,
         1123,
         1142,
         1143,
         1123,
         1132,
         1123,
         1123,
         1144,
         1144,
         1145,
         1145,
         1146,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1147,
         1148,
         1148,
         1148,
         1148,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1149,
         1123,
         1123,
         1150,
         1123,
         1151,
         1123,
         1152,
         1123,
         1123,
         1123,
         1123,
         1123,
         1145,
         1145,
         1123,
         1123,
         2385,
         2386,
         2387,
         2388,
         1123,
         1123,
         1123,
         1123,
         1123,
         1145,
         1145,
         1144,
         1144,
         1123,
         1123,
         1144,
         1144,
         1123,
         1123,
         1144,
         1144,
         1123,
         1123,
         1144,
         1144,
         1123,
         1123,
         1123,
         1132,
         1123,
         1123,
         1144,
         1144,
         1145,
         1145,
         1146,
         1123,
         1123,
         1153,
         1123,
         1123,
         1123,
         1123,
         1147,
         1148,
         1148,
         1148,
         1148,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1149,
         1123,
         1123,
         1150,
         1123,
         1151,
         1123,
         1152,
         1123,
         1123,
         1123,
         1123,
         1123,
         1145,
         1145,
         1123,
         1123,
         2385,
         2386,
         2387,
         2388,
         1123,
         1123,
         1123,
         1123,
         1123,
         1145,
         1145,
         1144,
         1144,
         1123,
         1123,
         1144,
         1144,
         1123,
         1123,
         1144,
         1144,
         1123,
         1123,
         1144,
         1144,
         1123,
         1123,
         1124,
         1133,
         1124,
         1124,
         1145,
         1145,
         1124,
         1124,
         1154,
         1124,
         1124,
         1124,
         1124,
         1124,
         1124,
         1124,
         1155,
         1156,
         1156,
         1156,
         1156,
         1124,
         1124,
         1124,
         1124,
         1124,
         1124,
         1124,
         1124,
         1124,
         1124,
         1124,
         1157,
         1124,
         1124,
         1158,
         1124,
         1159,
         1124,
         1160,
         1124,
         1124,
         1124,
         1124,
         1124,
         1124,
         1124,
         1124,
         1124,
         2389,
         2390,
         2391,
         2392,
         1124,
         1124,
         1124,
         1124,
         1124,
         1124,
         1124,
         1145,
         1145,
         1124,
         1124,
         1145,
         1145,
         1124,
         1124,
         1145,
         1145,
         1124,
         1124,
         1145,
         1145,
         1124,
         1124,
         1124,
         1134,
         1124,
         1124,
         1145,
         1145,
         1124,
         1124,
         1154,
         1124,
         1124,
         1124,
         1124,
         1124,
         1124,
         1124,
         1155,
         1156,
         1156,
         1156,
         1156,
         1124,
         1124,
         1124,
         1124,
         1124,
         1124,
         1124,
         1124,
         1124,
         1124,
         1124,
         1157,
         1124,
         1124,
         1158,
         1124,
         1159,
         1124,
         1160,
         1124,
         1124,
         1124,
         1124,
         1124,
         1124,
         1124,
         1124,
         1124,
         2389,
         2390,
         2391,
         2392,
         1124,
         1124,
         1124,
         1124,
         1124,
         1124,
         1124,
         1145,
         1145,
         1124,
         1124,
         1145,
         1145,
         1124,
         1124,
         1145,
         1145,
         1124,
         1124,
         1145,
         1145,
         1124,
         1124,
         1125,
         1135,
         1125,
         1125,
         1146,
         1146,
         1154,
         1154,
         1161,
         1125,
         1125,
         1125,
         1125,
         1125,
         1125,
         1125,
         1162,
         1163,
         1163,
         1163,
         1163,
         1125,
         1125,
         1125,
         1125,
         1125,
         1125,
         1125,
         1125,
         1125,
         1164,
         1125,
         1165,
         1125,
         1125,
         1166,
         1125,
         1167,
         1125,
         1168,
         1125,
         1125,
         1125,
         1125,
         1125,
         1154,
         1154,
         1125,
         1125,
         2393,
         2394,
         2395,
         2396,
         1125,
         1125,
         1125,
         1125,
         1125,
         1154,
         1154,
         1146,
         1146,
         1125,
         1125,
         1146,
         1146,
         1125,
         1125,
         1146,
         1146,
         1125,
         1125,
         1146,
         1146,
         1125,
         1125,
         53,
         54,
         53,
         53,
         1123,
         1123,
         1124,
         1124,
         1125,
         1169,
         53,
         53,
         53,
         53,
         53,
         53,
         1126,
         1127,
         1127,
         1127,
         1127,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         1128,
         53,
         53,
         1129,
         53,
         1130,
         53,
         1131,
         53,
         53,
         53,
         53,
         53,
         1124,
         1124,
         53,
         53,
         2376,
         2377,
         2378,
         2379,
         53,
         53,
         53,
         53,
         53,
         1124,
         1124,
         1123,
         1123,
         53,
         53,
         1123,
         1123,
         53,
         53,
         1123,
         1123,
         53,
         53,
         1123,
         1123,
         53,
         53,
         53,
         54,
         53,
         53,
         1123,
         1123,
         1124,
         1124,
         1125,
         53,
         1170,
         53,
         53,
         53,
         53,
         53,
         1126,
         1127,
         1127,
         1127,
         1127,
         53,
         53,
         53,
         53,
         1171,
         53,
         53,
         53,
         53,
         53,
         53,
         1128,
         53,
         53,
         1129,
         53,
         1130,
         53,
         1131,
         53,
         53,
         53,
         53,
         53,
         1124,
         1124,
         53,
         53,
         2376,
         2377,
         2378,
         2379,
         53,
         53,
         53,
         53,
         53,
         1124,
         1124,
         1123,
         1123,
         53,
         53,
         1123,
         1123,
         53,
         53,
         1123,
         1123,
         53,
         53,
         1123,
         1123,
         53,
         53,
         53,
         54,
         53,
         53,
         1123,
         1153,
         1124,
         1124,
         1125,
         53,
         53,
         1172,
         53,
         53,
         53,
         53,
         1126,
         1127,
         1127,
         1127,
         1127,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         1128,
         53,
         53,
         1129,
         53,
         1130,
         53,
         1131,
         53,
         53,
         53,
         53,
         53,
         1124,
         1124,
         53,
         53,
         2376,
         2377,
         2378,
         2379,
         53,
         53,
         53,
         53,
         53,
         1124,
         1124,
         1153,
         1153,
         53,
         53,
         1153,
         1153,
         53,
         53,
         1153,
         1153,
         53,
         53,
         1153,
         1153,
         53,
         53,
         53,
         54,
         53,
         53,
         1123,
         1123,
         1124,
         1124,
         1125,
         53,
         53,
         53,
         53,
         1173,
         53,
         53,
         1126,
         1127,
         1127,
         1127,
         1127,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         1128,
         53,
         53,
         1129,
         53,
         1130,
         53,
         1131,
         53,
         53,
         53,
         2397,
         53,
         1124,
         1124,
         53,
         53,
         2376,
         2377,
         2378,
         2379,
         53,
         53,
         53,
         2767,
         53,
         1124,
         1124,
         1123,
         1123,
         53,
         1173,
         1123,
         1123,
         53,
         1173,
         1123,
         1123,
         53,
         1173,
         1123,
         1123,
         53,
         1173,
         53,
         54,
         53,
         1143,
         1123,
         1123,
         1124,
         1124,
         1125,
         53,
         53,
         53,
         1173,
         1173,
         53,
         53,
         1126,
         1127,
         1127,
         1127,
         1127,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         1128,
         53,
         53,
         1129,
         53,
         1130,
         53,
         1131,
         53,
         53,
         53,
         2397,
         1143,
         1124,
         1124,
         1173,
         53,
         2376,
         2377,
         2378,
         2379,
         53,
         53,
         53,
         2767,
         1173,
         1124,
         1124,
         1123,
         1123,
         1143,
         1173,
         1123,
         1123,
         1143,
         1173,
         1123,
         1123,
         1143,
         1173,
         1123,
         1123,
         1143,
         1173,
         53,
         54,
         53,
         53,
         1123,
         1123,
         1124,
         1124,
         1125,
         53,
         53,
         53,
         53,
         53,
         53,
         1174,
         1126,
         1127,
         1127,
         1127,
         1127,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         1128,
         53,
         53,
         1129,
         53,
         1130,
         53,
         1131,
         53,
         53,
         53,
         53,
         53,
         1124,
         1124,
         53,
         53,
         2376,
         2377,
         2378,
         2379,
         53,
         53,
         53,
         53,
         53,
         1124,
         1124,
         1123,
         1123,
         53,
         53,
         1123,
         1123,
         53,
         53,
         1123,
         1123,
         53,
         53,
         1123,
         1123,
         53,
         53,
         53,
         54,
         53,
         53,
         1123,
         1123,
         1124,
         1124,
         1125,
         53,
         53,
         53,
         53,
         53,
         1174,
         1174,
         1126,
         1127,
         1127,
         1127,
         1127,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         1128,
         53,
         53,
         1129,
         53,
         1130,
         53,
         1131,
         53,
         53,
         53,
         53,
         53,
         1124,
         1124,
         53,
         53,
         2376,
         2377,
         2378,
         2379,
         53,
         53,
         53,
         53,
         53,
         1124,
         1124,
         1123,
         1123,
         53,
         53,
         1123,
         1123,
         53,
         53,
         1123,
         1123,
         53,
         53,
         1123,
         1123,
         53,
         53,
         1126,
         1136,
         1126,
         1126,
         1147,
         1147,
         1155,
         1155,
         1162,
         1126,
         1126,
         1126,
         1126,
         1126,
         1126,
         1126,
         1175,
         1176,
         1176,
         1176,
         1176,
         1126,
         1126,
         1126,
         1126,
         1126,
         1126,
         1126,
         1126,
         1126,
         1126,
         1126,
         1177,
         1126,
         1126,
         1178,
         1126,
         1179,
         1126,
         1180,
         1126,
         1126,
         1126,
         1126,
         1126,
         1155,
         1155,
         1126,
         1126,
         2398,
         2399,
         2400,
         2401,
         1126,
         1126,
         1126,
         1126,
         1126,
         1155,
         1155,
         1147,
         1147,
         1126,
         1126,
         1147,
         1147,
         1126,
         1126,
         1147,
         1147,
         1126,
         1126,
         1147,
         1147,
         1126,
         1126,
         1127,
         1137,
         1127,
         1127,
         1148,
         1148,
         1156,
         1156,
         1163,
         1127,
         1127,
         1127,
         1127,
         1127,
         1127,
         1127,
         1176,
         1181,
         1181,
         1181,
         1181,
         1127,
         1127,
         1127,
         1127,
         1127,
         1127,
         1127,
         1127,
         1127,
         1127,
         1127,
         1182,
         1127,
         1127,
         1183,
         1127,
         1184,
         1127,
         1185,
         1127,
         1127,
         1127,
         1127,
         1127,
         2402,
         2402,
         1127,
         1127,
         2403,
         2404,
         2405,
         2406,
         1127,
         1127,
         1127,
         1127,
         1127,
         1156,
         1156,
         1148,
         1148,
         1127,
         1127,
         1148,
         1148,
         1127,
         1127,
         1148,
         1148,
         1127,
         1127,
         1148,
         1148,
         1127,
         1127,
         1127,
         1137,
         1127,
         1127,
         1148,
         1148,
         1156,
         1156,
         1163,
         1127,
         1127,
         1127,
         1127,
         1127,
         1127,
         1127,
         1176,
         1181,
         1186,
         1187,
         1188,
         1127,
         1127,
         1127,
         1127,
         1127,
         1127,
         1127,
         1127,
         1127,
         1127,
         1127,
         1182,
         1127,
         1127,
         1183,
         1127,
         1184,
         1127,
         1185,
         1127,
         1127,
         1127,
         1127,
         1127,
         2402,
         2402,
         1127,
         1127,
         2403,
         2404,
         2405,
         2406,
         1127,
         1127,
         1127,
         1127,
         1127,
         1156,
         1156,
         1148,
         1148,
         1127,
         1127,
         1148,
         1148,
         1127,
         1127,
         1148,
         1148,
         1127,
         1127,
         1148,
         1148,
         1127,
         1127,
         1127,
         1137,
         1127,
         1127,
         1148,
         1148,
         1156,
         1156,
         1163,
         1127,
         1127,
         1127,
         1127,
         1127,
         1127,
         1127,
         1176,
         1181,
         1187,
         1189,
         1190,
         1127,
         1127,
         1127,
         1127,
         1127,
         1127,
         1127,
         1127,
         1127,
         1127,
         1127,
         1182,
         1127,
         1127,
         1183,
         1127,
         1184,
         1127,
         1185,
         1127,
         1127,
         1127,
         1127,
         1127,
         2402,
         2402,
         1127,
         1127,
         2403,
         2404,
         2405,
         2406,
         1127,
         1127,
         1127,
         1127,
         1127,
         1156,
         1156,
         1148,
         1148,
         1127,
         1127,
         1148,
         1148,
         1127,
         1127,
         1148,
         1148,
         1127,
         1127,
         1148,
         1148,
         1127,
         1127,
         1127,
         1137,
         1127,
         1127,
         1148,
         1148,
         1156,
         1156,
         1163,
         1127,
         1127,
         1127,
         1127,
         1127,
         1127,
         1127,
         1176,
         1181,
         1188,
         1190,
         1191,
         1127,
         1127,
         1127,
         1127,
         1127,
         1127,
         1127,
         1127,
         1127,
         1127,
         1127,
         1182,
         1127,
         1127,
         1183,
         1127,
         1184,
         1127,
         1185,
         1127,
         1127,
         1127,
         1127,
         1127,
         2402,
         2402,
         1127,
         1127,
         2403,
         2404,
         2405,
         2406,
         1127,
         1127,
         1127,
         1127,
         1127,
         1156,
         1156,
         1148,
         1148,
         1127,
         1127,
         1148,
         1148,
         1127,
         1127,
         1148,
         1148,
         1127,
         1127,
         1148,
         1148,
         1127,
         1127,
         53,
         54,
         53,
         53,
         1123,
         1123,
         1124,
         1124,
         1125,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         1126,
         1127,
         1127,
         1127,
         1127,
         1192,
         1192,
         1192,
         1192,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         1128,
         53,
         53,
         1129,
         53,
         1130,
         53,
         1131,
         53,
         53,
         53,
         53,
         53,
         1124,
         1124,
         53,
         53,
         2376,
         2377,
         2378,
         2379,
         53,
         53,
         53,
         53,
         53,
         1124,
         1124,
         1123,
         1123,
         53,
         53,
         1123,
         1123,
         53,
         53,
         1123,
         1123,
         53,
         53,
         1123,
         1123,
         53,
         53,
         53,
         54,
         53,
         53,
         1123,
         1123,
         1124,
         1124,
         1125,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         1126,
         1127,
         1127,
         1127,
         1127,
         1192,
         1193,
         1194,
         1195,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         1128,
         53,
         53,
         1129,
         53,
         1130,
         53,
         1131,
         53,
         53,
         53,
         53,
         53,
         1124,
         1124,
         53,
         53,
         2376,
         2377,
         2378,
         2379,
         53,
         53,
         53,
         53,
         53,
         1124,
         1124,
         1123,
         1123,
         53,
         53,
         1123,
         1123,
         53,
         53,
         1123,
         1123,
         53,
         53,
         1123,
         1123,
         53,
         53,
         53,
         54,
         53,
         53,
         1123,
         1123,
         1124,
         1124,
         1125,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         1126,
         1127,
         1127,
         1127,
         1127,
         1192,
         1194,
         1196,
         1197,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         1128,
         53,
         53,
         1129,
         53,
         1130,
         53,
         1131,
         53,
         53,
         53,
         53,
         53,
         1124,
         1124,
         53,
         53,
         2376,
         2377,
         2378,
         2379,
         53,
         53,
         53,
         53,
         53,
         1124,
         1124,
         1123,
         1123,
         53,
         53,
         1123,
         1123,
         53,
         53,
         1123,
         1123,
         53,
         53,
         1123,
         1123,
         53,
         53,
         53,
         54,
         53,
         53,
         1123,
         1123,
         1124,
         1124,
         1125,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         1126,
         1127,
         1127,
         1127,
         1127,
         1192,
         1195,
         1197,
         1198,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         1128,
         53,
         53,
         1129,
         53,
         1130,
         53,
         1131,
         53,
         53,
         53,
         53,
         53,
         1124,
         1124,
         53,
         53,
         2376,
         2377,
         2378,
         2379,
         53,
         53,
         53,
         53,
         53,
         1124,
         1124,
         1123,
         1123,
         53,
         53,
         1123,
         1123,
         53,
         53,
         1123,
         1123,
         53,
         53,
         1123,
         1123,
         53,
         53,
         53,
         54,
         53,
         53,
         1123,
         1123,
         1124,
         1124,
         1125,
         53,
         1171,
         53,
         53,
         53,
         53,
         53,
         1126,
         1127,
         1127,
         1127,
         1127,
         53,
         53,
         53,
         53,
         1199,
         53,
         53,
         53,
         53,
         53,
         53,
         1128,
         53,
         53,
         1129,
         53,
         1130,
         53,
         1131,
         53,
         53,
         53,
         53,
         53,
         1124,
         1124,
         53,
         53,
         2376,
         2377,
         2378,
         2379,
         53,
         53,
         53,
         53,
         53,
         1124,
         1124,
         1123,
         1123,
         53,
         53,
         1123,
         1123,
         53,
         53,
         1123,
         1123,
         53,
         53,
         1123,
         1123,
         53,
         53,
         53,
         54,
         53,
         53,
         1123,
         1123,
         1124,
         1124,
         1125,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         1126,
         1127,
         1127,
         1127,
         1127,
         53,
         53,
         53,
         53,
         53,
         1200,
         53,
         53,
         53,
         53,
         53,
         1128,
         53,
         53,
         1129,
         53,
         1130,
         53,
         1131,
         53,
         53,
         53,
         53,
         53,
         1124,
         1124,
         53,
         53,
         2376,
         2377,
         2378,
         2379,
         53,
         53,
         53,
         53,
         53,
         1124,
         1124,
         1123,
         1123,
         53,
         53,
         1123,
         1123,
         53,
         53,
         1123,
         1123,
         53,
         53,
         1123,
         1123,
         53,
         53,
         53,
         54,
         53,
         53,
         1123,
         1123,
         1124,
         1124,
         1125,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         1126,
         1127,
         1127,
         1127,
         1127,
         53,
         53,
         53,
         53,
         53,
         53,
         1201,
         53,
         53,
         53,
         53,
         1128,
         53,
         53,
         1129,
         53,
         1130,
         53,
         1131,
         53,
         53,
         53,
         53,
         53,
         1124,
         1124,
         53,
         53,
         2376,
         2377,
         2378,
         2379,
         53,
         53,
         53,
         53,
         53,
         1124,
         1124,
         1123,
         1123,
         53,
         53,
         1123,
         1123,
         53,
         53,
         1123,
         1123,
         53,
         53,
         1123,
         1123,
         53,
         53,
         53,
         54,
         53,
         53,
         1123,
         1123,
         1124,
         1124,
         1125,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         1126,
         1127,
         1127,
         1127,
         1127,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         1202,
         53,
         53,
         53,
         1128,
         53,
         53,
         1129,
         53,
         1130,
         53,
         1131,
         53,
         53,
         53,
         53,
         53,
         1124,
         1124,
         53,
         53,
         2376,
         2377,
         2378,
         2379,
         53,
         53,
         53,
         53,
         53,
         1124,
         1124,
         1123,
         1123,
         53,
         53,
         1123,
         1123,
         53,
         53,
         1123,
         1123,
         53,
         53,
         1123,
         1123,
         53,
         53,
         53,
         54,
         53,
         53,
         1123,
         1123,
         1124,
         1124,
         1125,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         1126,
         1127,
         1127,
         1127,
         1127,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         1203,
         1203,
         53,
         1128,
         53,
         53,
         1129,
         53,
         1130,
         53,
         1131,
         53,
         53,
         53,
         53,
         53,
         1124,
         1124,
         53,
         53,
         2376,
         2377,
         2378,
         2379,
         53,
         53,
         53,
         53,
         53,
         1124,
         1124,
         1123,
         1123,
         53,
         53,
         1123,
         1123,
         53,
         53,
         1123,
         1123,
         53,
         53,
         1123,
         1123,
         53,
         53,
         53,
         54,
         53,
         53,
         1123,
         1123,
         1124,
         1124,
         1164,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         1126,
         1127,
         1127,
         1127,
         1127,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         1203,
         1203,
         53,
         1128,
         53,
         53,
         1129,
         53,
         1130,
         53,
         1131,
         53,
         53,
         53,
         53,
         53,
         1124,
         1124,
         53,
         53,
         2376,
         2377,
         2378,
         2379,
         53,
         53,
         53,
         53,
         53,
         1124,
         1124,
         1123,
         1123,
         53,
         53,
         1123,
         1123,
         53,
         53,
         1123,
         1123,
         53,
         53,
         1123,
         1123,
         53,
         53,
         53,
         54,
         53,
         53,
         1123,
         1123,
         1124,
         1124,
         1125,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         1126,
         1127,
         1127,
         1127,
         1127,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         1204,
         53,
         53,
         1129,
         53,
         1130,
         53,
         1131,
         53,
         53,
         53,
         53,
         53,
         1124,
         1124,
         53,
         53,
         2376,
         2377,
         2378,
         2379,
         53,
         53,
         53,
         53,
         53,
         1124,
         1124,
         1123,
         1123,
         53,
         53,
         1123,
         1123,
         53,
         53,
         1123,
         1123,
         53,
         53,
         1123,
         1123,
         53,
         53,
         1128,
         1138,
         1128,
         1128,
         1149,
         1149,
         1157,
         1157,
         1165,
         1128,
         1128,
         1128,
         1128,
         1128,
         1128,
         1128,
         1177,
         1182,
         1182,
         1182,
         1182,
         1128,
         1128,
         1128,
         1128,
         1128,
         1128,
         1128,
         1128,
         1128,
         1128,
         1204,
         1204,
         1128,
         1128,
         1205,
         1128,
         1206,
         1128,
         1207,
         1128,
         1128,
         1128,
         1128,
         1128,
         1157,
         1157,
         1128,
         1128,
         2407,
         2408,
         2409,
         2410,
         1128,
         1128,
         1128,
         1128,
         1128,
         1157,
         1157,
         1149,
         1149,
         1128,
         1128,
         1149,
         1149,
         1128,
         1128,
         1149,
         1149,
         1128,
         1128,
         1149,
         1149,
         1128,
         1128,
         53,
         54,
         53,
         53,
         1123,
         1123,
         1124,
         1124,
         1125,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         1126,
         1127,
         1127,
         1127,
         1127,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         1128,
         53,
         53,
         1129,
         53,
         1130,
         53,
         1131,
         53,
         53,
         53,
         53,
         2411,
         1124,
         1124,
         53,
         53,
         2376,
         2377,
         2378,
         2379,
         53,
         53,
         53,
         53,
         53,
         1124,
         1124,
         1123,
         1123,
         53,
         53,
         1123,
         1123,
         53,
         53,
         1123,
         1123,
         53,
         53,
         1123,
         1123,
         53,
         53,
         53,
         54,
         53,
         53,
         1123,
         1123,
         1124,
         1124,
         1125,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         1126,
         1127,
         1127,
         1127,
         1127,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         1128,
         53,
         53,
         1208,
         53,
         1130,
         53,
         1131,
         53,
         53,
         53,
         53,
         53,
         1124,
         1124,
         53,
         53,
         2376,
         2377,
         2378,
         2379,
         53,
         53,
         53,
         53,
         53,
         1124,
         1124,
         1123,
         1123,
         53,
         53,
         1123,
         1123,
         53,
         53,
         1123,
         1123,
         53,
         53,
         1123,
         1123,
         53,
         53,
         1129,
         1139,
         1129,
         1129,
         1150,
         1150,
         1158,
         1158,
         1166,
         1129,
         1129,
         1129,
         1129,
         1129,
         1129,
         1129,
         1178,
         1183,
         1183,
         1183,
         1183,
         1129,
         1129,
         1129,
         1129,
         1129,
         1129,
         1129,
         1129,
         1129,
         1129,
         1129,
         1205,
         1129,
         1208,
         1208,
         1129,
         1209,
         1129,
         1210,
         1129,
         1129,
         1129,
         1129,
         1129,
         1158,
         1158,
         1129,
         1129,
         2412,
         2413,
         2414,
         2415,
         1129,
         1129,
         1129,
         1129,
         1129,
         1158,
         1158,
         1150,
         1150,
         1129,
         1129,
         1150,
         1150,
         1129,
         1129,
         1150,
         1150,
         1129,
         1129,
         1150,
         1150,
         1129,
         1129,
         53,
         54,
         53,
         53,
         1123,
         1123,
         1124,
         1124,
         1125,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         1126,
         1127,
         1127,
         1127,
         1127,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         1128,
         53,
         53,
         1129,
         53,
         1211,
         53,
         1131,
         53,
         53,
         53,
         53,
         53,
         1124,
         1124,
         53,
         53,
         2376,
         2377,
         2378,
         2379,
         53,
         53,
         53,
         53,
         53,
         1124,
         1124,
         1123,
         1123,
         53,
         53,
         1123,
         1123,
         53,
         53,
         1123,
         1123,
         53,
         53,
         1123,
         1123,
         53,
         53,
         1130,
         1140,
         1130,
         1130,
         1151,
         1151,
         1159,
         1159,
         1167,
         1130,
         1130,
         1130,
         1130,
         1130,
         1130,
         1130,
         1179,
         1184,
         1184,
         1184,
         1184,
         1130,
         1130,
         1130,
         1130,
         1130,
         1130,
         1130,
         1130,
         1130,
         1130,
         1130,
         1206,
         1130,
         1130,
         1209,
         1211,
         1211,
         1130,
         1212,
         1130,
         1130,
         1130,
         1130,
         1130,
         1159,
         1159,
         1130,
         1130,
         2416,
         2417,
         2418,
         2419,
         1130,
         1130,
         1130,
         1130,
         1130,
         1159,
         1159,
         1151,
         1151,
         1130,
         1130,
         1151,
         1151,
         1130,
         1130,
         1151,
         1151,
         1130,
         1130,
         1151,
         1151,
         1130,
         1130,
         53,
         54,
         53,
         53,
         1123,
         1123,
         1124,
         1124,
         1125,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         1126,
         1127,
         1127,
         1127,
         1127,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         1128,
         53,
         53,
         1129,
         53,
         1130,
         53,
         1213,
         53,
         53,
         53,
         53,
         53,
         1124,
         1124,
         53,
         53,
         2376,
         2377,
         2378,
         2379,
         53,
         53,
         53,
         53,
         53,
         1124,
         1124,
         1123,
         1123,
         53,
         53,
         1123,
         1123,
         53,
         53,
         1123,
         1123,
         53,
         53,
         1123,
         1123,
         53,
         53,
         1131,
         1141,
         1131,
         1131,
         1152,
         1152,
         1160,
         1160,
         1168,
         1131,
         1131,
         1131,
         1131,
         1131,
         1131,
         1131,
         1180,
         1185,
         1185,
         1185,
         1185,
         1131,
         1131,
         1131,
         1131,
         1131,
         1131,
         1131,
         1131,
         1131,
         1131,
         1131,
         1207,
         1131,
         1131,
         1210,
         1131,
         1212,
         1213,
         1213,
         1131,
         1131,
         1131,
         1131,
         1131,
         1160,
         1160,
         1131,
         1131,
         2420,
         2421,
         2422,
         2423,
         1131,
         1131,
         1131,
         1131,
         1131,
         1160,
         1160,
         1152,
         1152,
         1131,
         1131,
         1152,
         1152,
         1131,
         1131,
         1152,
         1152,
         1131,
         1131,
         1152,
         1152,
         1131,
         1131,
         53,
         54,
         53,
         53,
         1123,
         1123,
         1124,
         1124,
         1125,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         1126,
         1127,
         1127,
         1127,
         1127,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         1128,
         53,
         53,
         1129,
         53,
         1130,
         53,
         1131,
         53,
         1214,
         1214,
         53,
         53,
         1124,
         1124,
         53,
         53,
         2376,
         2377,
         2378,
         2379,
         53,
         53,
         53,
         53,
         53,
         1124,
         1124,
         1123,
         1123,
         53,
         53,
         1123,
         1123,
         53,
         53,
         1123,
         1123,
         53,
         53,
         1123,
         1123,
         53,
         53,
         53,
         54,
         53,
         53,
         1123,
         1123,
         1124,
         1124,
         1125,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         1126,
         1127,
         1127,
         1127,
         1127,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         1128,
         53,
         53,
         1129,
         53,
         1130,
         53,
         1131,
         1214,
         53,
         1214,
         53,
         53,
         1124,
         1124,
         53,
         53,
         2376,
         2377,
         2378,
         2379,
         53,
         53,
         53,
         53,
         53,
         1124,
         1124,
         1123,
         1123,
         53,
         53,
         1123,
         1123,
         53,
         53,
         1123,
         1123,
         53,
         53,
         1123,
         1123,
         53,
         53,
         53,
         54,
         53,
         53,
         1123,
         1123,
         1124,
         1124,
         1125,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         1126,
         1127,
         1127,
         1127,
         1127,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         1128,
         53,
         53,
         1129,
         53,
         1130,
         53,
         1131,
         1214,
         1214,
         1214,
         53,
         53,
         1124,
         1124,
         53,
         53,
         2376,
         2377,
         2378,
         2379,
         53,
         53,
         53,
         53,
         53,
         1124,
         1124,
         1123,
         1123,
         53,
         53,
         1123,
         1123,
         53,
         53,
         1123,
         1123,
         53,
         53,
         1123,
         1123,
         53,
         53,
         53,
         54,
         53,
         1142,
         1123,
         1123,
         1124,
         1124,
         1125,
         53,
         53,
         53,
         2397,
         2397,
         53,
         53,
         1126,
         1127,
         1127,
         1127,
         1127,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         1128,
         53,
         53,
         1129,
         53,
         1130,
         53,
         1131,
         53,
         53,
         53,
         53,
         1142,
         1124,
         1124,
         2424,
         53,
         2376,
         2377,
         2378,
         2379,
         53,
         53,
         53,
         53,
         2768,
         1124,
         1124,
         1123,
         1123,
         1142,
         2397,
         1123,
         1123,
         1142,
         2397,
         1123,
         1123,
         1142,
         2397,
         1123,
         1123,
         1142,
         2397,
         53,
         54,
         1142,
         1142,
         1123,
         1123,
         1124,
         1124,
         1125,
         53,
         53,
         53,
         53,
         1143,
         53,
         53,
         1126,
         1127,
         1127,
         1127,
         1127,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         1128,
         2411,
         53,
         1129,
         53,
         1130,
         53,
         1131,
         53,
         53,
         53,
         1142,
         1142,
         1124,
         1124,
         2384,
         53,
         2376,
         2377,
         2425,
         2426,
         53,
         53,
         53,
         1142,
         2766,
         2769,
         2887,
         1123,
         1123,
         1142,
         1143,
         1123,
         1123,
         1142,
         1143,
         1123,
         1123,
         1142,
         1143,
         1123,
         1123,
         1142,
         1143,
         1124,
         1133,
         1124,
         1124,
         1145,
         1145,
         1124,
         1124,
         1154,
         1124,
         1124,
         1124,
         1124,
         1124,
         1124,
         1124,
         1155,
         2402,
         2402,
         2402,
         2402,
         1124,
         1124,
         1124,
         1124,
         1124,
         1124,
         1124,
         1124,
         1124,
         1124,
         1124,
         1157,
         1124,
         1124,
         1158,
         1124,
         1159,
         1124,
         1160,
         1124,
         1124,
         1124,
         1124,
         1124,
         1124,
         1124,
         1124,
         1124,
         2389,
         2390,
         2391,
         2392,
         1124,
         1124,
         1124,
         1124,
         1124,
         1124,
         1124,
         1145,
         1145,
         1124,
         1124,
         1145,
         1145,
         1124,
         1124,
         1145,
         1145,
         1124,
         1124,
         1145,
         1145,
         1124,
         1124,
         1124,
         1134,
         1124,
         1124,
         1145,
         1145,
         1124,
         1124,
         1154,
         1124,
         1124,
         1124,
         1124,
         1124,
         1124,
         1124,
         1155,
         2402,
         2402,
         2402,
         2402,
         1124,
         1124,
         1124,
         1124,
         1124,
         1124,
         1124,
         1124,
         1124,
         1124,
         1124,
         1157,
         1124,
         1124,
         1158,
         1124,
         1159,
         1124,
         1160,
         1124,
         1124,
         1124,
         1124,
         1124,
         1124,
         1124,
         1124,
         1124,
         2389,
         2390,
         2391,
         2392,
         1124,
         1124,
         1124,
         1124,
         1124,
         1124,
         1124,
         1145,
         1145,
         1124,
         1124,
         1145,
         1145,
         1124,
         1124,
         1145,
         1145,
         1124,
         1124,
         1145,
         1145,
         1124,
         1124,
         53,
         54,
         2384,
         2384,
         1123,
         1123,
         1124,
         1124,
         1125,
         53,
         53,
         53,
         53,
         1173,
         53,
         53,
         1126,
         1127,
         1127,
         1127,
         1127,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         1128,
         53,
         53,
         1129,
         53,
         1130,
         53,
         1131,
         53,
         53,
         53,
         2424,
         2384,
         1124,
         1124,
         53,
         53,
         2376,
         2377,
         2378,
         2379,
         53,
         53,
         53,
         2770,
         53,
         1124,
         1124,
         1123,
         1123,
         2384,
         1173,
         1123,
         1123,
         2384,
         1173,
         1123,
         1123,
         2384,
         1173,
         1123,
         1123,
         2384,
         1173,
         53,
         54,
         53,
         53,
         1123,
         1123,
         1124,
         1124,
         1125,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         1126,
         1127,
         1127,
         1127,
         1127,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         1128,
         53,
         53,
         1129,
         53,
         1130,
         53,
         1131,
         53,
         53,
         53,
         53,
         53,
         1124,
         1124,
         53,
         2427,
         2376,
         2377,
         2378,
         2379,
         53,
         53,
         53,
         53,
         53,
         1124,
         1124,
         1123,
         1123,
         53,
         53,
         1123,
         1123,
         53,
         53,
         1123,
         1123,
         53,
         53,
         1123,
         1123,
         53,
         53,
         2376,
         2380,
         2376,
         2376,
         2385,
         2385,
         2389,
         2389,
         2393,
         2376,
         2376,
         2376,
         2376,
         2376,
         2376,
         2376,
         2398,
         2403,
         2403,
         2403,
         2403,
         2376,
         2376,
         2376,
         2376,
         2376,
         2376,
         2376,
         2376,
         2376,
         2376,
         2376,
         2407,
         2376,
         2376,
         2412,
         2376,
         2416,
         2376,
         2420,
         2376,
         2376,
         2376,
         2376,
         2376,
         2389,
         2389,
         2376,
         2376,
         2376,
         2428,
         2429,
         2430,
         2376,
         2376,
         2376,
         2376,
         2376,
         2389,
         2389,
         2385,
         2385,
         2376,
         2376,
         2385,
         2385,
         2376,
         2376,
         2385,
         2385,
         2376,
         2376,
         2385,
         2385,
         2376,
         2376,
         2377,
         2381,
         2377,
         2377,
         2386,
         2386,
         2390,
         2390,
         2394,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2399,
         2404,
         2404,
         2404,
         2404,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2377,
         2408,
         2377,
         2377,
         2413,
         2377,
         2417,
         2377,
         2421,
         2377,
         2377,
         2377,
         2377,
         2377,
         2390,
         2390,
         2377,
         2377,
         2428,
         2377,
         2431,
         2432,
         2377,
         2377,
         2377,
         2377,
         2377,
         2390,
         2390,
         2386,
         2386,
         2377,
         2377,
         2386,
         2386,
         2377,
         2377,
         2386,
         2386,
         2377,
         2377,
         2386,
         2386,
         2377,
         2377,
         2378,
         2382,
         2378,
         2378,
         2387,
         2387,
         2391,
         2391,
         2395,
         2378,
         2378,
         2378,
         2378,
         2378,
         2378,
         2378,
         2400,
         2405,
         2405,
         2405,
         2405,
         2378,
         2378,
         2378,
         2378,
         2378,
         2378,
         2378,
         2378,
         2378,
         2378,
         2378,
         2409,
         2378,
         2378,
         2414,
         2378,
         2418,
         2378,
         2422,
         2378,
         2378,
         2378,
         2378,
         2425,
         2391,
         2391,
         2378,
         2378,
         2429,
         2431,
         2378,
         2433,
         2378,
         2378,
         2378,
         2378,
         2378,
         2391,
         2391,
         2387,
         2387,
         2378,
         2378,
         2387,
         2387,
         2378,
         2378,
         2387,
         2387,
         2378,
         2378,
         2387,
         2387,
         2378,
         2378,
         2379,
         2383,
         2379,
         2379,
         2388,
         2388,
         2392,
         2392,
         2396,
         2379,
         2379,
         2379,
         2379,
         2379,
         2379,
         2379,
         2401,
         2406,
         2406,
         2406,
         2406,
         2379,
         2379,
         2379,
         2379,
         2379,
         2379,
         2379,
         2379,
         2379,
         2379,
         2379,
         2410,
         2379,
         2379,
         2415,
         2379,
         2419,
         2379,
         2423,
         2379,
         2379,
         2379,
         2379,
         2426,
         2392,
         2392,
         2379,
         2379,
         2430,
         2432,
         2433,
         2434,
         2379,
         2379,
         2379,
         2379,
         2379,
         2392,
         2392,
         2388,
         2388,
         2379,
         2379,
         2388,
         2388,
         2379,
         2379,
         2388,
         2388,
         2379,
         2379,
         2388,
         2388,
         2379,
         2379,
         53,
         54,
         53,
         53,
         1123,
         1123,
         1124,
         1124,
         1125,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         1126,
         1127,
         1127,
         1127,
         1127,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         1128,
         53,
         53,
         1129,
         53,
         1130,
         53,
         1131,
         53,
         53,
         53,
         53,
         53,
         1124,
         1124,
         53,
         53,
         2376,
         2377,
         2378,
         2379,
         53,
         2435,
         2435,
         53,
         53,
         1124,
         1124,
         1123,
         1123,
         53,
         53,
         1123,
         1123,
         53,
         53,
         1123,
         1123,
         53,
         53,
         1123,
         1123,
         53,
         53,
         53,
         54,
         53,
         53,
         1123,
         1123,
         1124,
         1124,
         1125,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         1126,
         1127,
         1127,
         1127,
         1127,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         1128,
         53,
         53,
         1129,
         53,
         1130,
         53,
         1131,
         53,
         53,
         53,
         53,
         53,
         1124,
         1124,
         53,
         53,
         2376,
         2377,
         2378,
         2379,
         2435,
         53,
         2435,
         53,
         53,
         1124,
         1124,
         1123,
         1123,
         53,
         53,
         1123,
         1123,
         53,
         53,
         1123,
         1123,
         53,
         53,
         1123,
         1123,
         53,
         53,
         53,
         54,
         53,
         53,
         1123,
         1123,
         1124,
         1124,
         1125,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         1126,
         1127,
         1127,
         1127,
         1127,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         1128,
         53,
         53,
         1129,
         53,
         1130,
         53,
         1131,
         53,
         53,
         53,
         53,
         53,
         1124,
         1124,
         53,
         53,
         2376,
         2377,
         2378,
         2379,
         2435,
         2435,
         2435,
         53,
         53,
         1124,
         1124,
         1123,
         1123,
         53,
         53,
         1123,
         1123,
         53,
         53,
         1123,
         1123,
         53,
         53,
         1123,
         1123,
         53,
         53,
         53,
         54,
         53,
         1142,
         1123,
         1123,
         1124,
         1124,
         1125,
         53,
         53,
         53,
         2767,
         2767,
         53,
         53,
         1126,
         1127,
         1127,
         1127,
         1127,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         1128,
         53,
         53,
         1129,
         53,
         1130,
         53,
         1131,
         53,
         53,
         53,
         53,
         1142,
         1124,
         1124,
         2770,
         53,
         2376,
         2377,
         2378,
         2379,
         53,
         53,
         53,
         53,
         2771,
         1124,
         1124,
         1123,
         1123,
         1142,
         2767,
         1123,
         1123,
         1142,
         2767,
         1123,
         1123,
         1142,
         2767,
         1123,
         1123,
         1142,
         2767,
         53,
         54,
         2766,
         2766,
         1123,
         1123,
         1124,
         1124,
         1125,
         53,
         53,
         53,
         53,
         1173,
         53,
         53,
         1126,
         1127,
         1127,
         1127,
         1127,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         1128,
         53,
         53,
         1129,
         53,
         1130,
         53,
         1131,
         53,
         53,
         53,
         2768,
         2766,
         1124,
         1124,
         53,
         53,
         2376,
         2377,
         2378,
         2379,
         53,
         53,
         53,
         2771,
         53,
         1124,
         1124,
         1123,
         1123,
         2766,
         1173,
         1123,
         1123,
         2766,
         1173,
         1123,
         1123,
         2766,
         1173,
         1123,
         1123,
         2766,
         1173,
         1124,
         1133,
         1124,
         1124,
         1145,
         1145,
         1124,
         1124,
         1154,
         1124,
         1124,
         1124,
         1124,
         1124,
         1124,
         1124,
         1155,
         1156,
         1156,
         1156,
         1156,
         1124,
         1124,
         1124,
         1124,
         1124,
         1124,
         1124,
         1124,
         1124,
         1124,
         1124,
         1157,
         1124,
         1124,
         1158,
         1124,
         1159,
         1124,
         1160,
         1124,
         1124,
         1124,
         1124,
         2769,
         1124,
         1124,
         1124,
         1124,
         2389,
         2390,
         2391,
         2392,
         1124,
         1124,
         1124,
         1124,
         1124,
         1124,
         1124,
         1145,
         1145,
         1124,
         1124,
         1145,
         1145,
         1124,
         1124,
         1145,
         1145,
         1124,
         1124,
         1145,
         1145,
         1124,
         1124,
         1124,
         1133,
         1124,
         1124,
         1145,
         1145,
         1124,
         1124,
         1154,
         1124,
         1124,
         1124,
         1124,
         1124,
         1124,
         1124,
         1155,
         1156,
         1156,
         1156,
         1156,
         1124,
         1124,
         1124,
         1124,
         1124,
         1124,
         1124,
         1124,
         1124,
         1124,
         1124,
         1157,
         1124,
         1124,
         1158,
         1124,
         1159,
         1124,
         1160,
         1124,
         1124,
         1124,
         1124,
         2887,
         1124,
         1124,
         1124,
         1124,
         2389,
         2390,
         2391,
         2392,
         1124,
         1124,
         1124,
         1124,
         1124,
         1124,
         1124,
         1145,
         1145,
         1124,
         1124,
         1145,
         1145,
         1124,
         1124,
         1145,
         1145,
         1124,
         1124,
         1145,
         1145,
         1124,
         1124,
         1123,
         1132,
         1123,
         1123,
         1144,
         1144,
         1145,
         1145,
         1146,
         1123,
         1123,
         1153,
         1123,
         1123,
         1123,
         1123,
         1147,
         1148,
         1148,
         1148,
         1148,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1149,
         1123,
         1123,
         1150,
         1123,
         1151,
         1123,
         1152,
         1123,
         1123,
         1123,
         1123,
         1123,
         1145,
         1145,
         1123,
         1123,
         2385,
         2386,
         2387,
         2388,
         1123,
         1123,
         1123,
         1123,
         1123,
         1145,
         1145,
         1144,
         2888,
         1123,
         1123,
         1144,
         1144,
         1123,
         1123,
         1144,
         1144,
         1123,
         1123,
         1144,
         1144,
         1123,
         1123,
         1123,
         1132,
         1123,
         1123,
         1144,
         1144,
         1145,
         1145,
         1146,
         1123,
         1123,
         1153,
         1123,
         1123,
         1123,
         1123,
         1147,
         1148,
         1148,
         1148,
         1148,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1149,
         1123,
         1123,
         1150,
         1123,
         1151,
         1123,
         1152,
         1123,
         1123,
         1123,
         1123,
         1123,
         1145,
         1145,
         1123,
         1123,
         2385,
         2386,
         2387,
         2388,
         1123,
         1123,
         1123,
         1123,
         1123,
         1145,
         1145,
         2888,
         1144,
         1123,
         1123,
         1144,
         1144,
         1123,
         1123,
         1144,
         1144,
         1123,
         1123,
         1144,
         1144,
         1123,
         1123,
         53,
         54,
         1142,
         1142,
         1123,
         1123,
         1124,
         1124,
         1125,
         53,
         53,
         53,
         53,
         1143,
         53,
         53,
         1126,
         1127,
         1127,
         1127,
         1127,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         1128,
         53,
         53,
         1129,
         53,
         1130,
         53,
         1131,
         53,
         53,
         53,
         1142,
         1142,
         1124,
         1124,
         2384,
         53,
         2376,
         2377,
         2378,
         2379,
         53,
         53,
         53,
         1142,
         2766,
         1124,
         1124,
         1123,
         1123,
         1142,
         2889,
         1123,
         1123,
         1142,
         2889,
         1123,
         1123,
         1142,
         2889,
         1123,
         1123,
         1142,
         2889,
         53,
         54,
         53,
         1143,
         1123,
         1123,
         1124,
         1124,
         1125,
         53,
         53,
         53,
         1173,
         1173,
         53,
         53,
         1126,
         1127,
         1127,
         1127,
         1127,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         1128,
         53,
         53,
         1129,
         53,
         1130,
         53,
         1131,
         53,
         53,
         53,
         2397,
         1143,
         1124,
         1124,
         1173,
         53,
         2376,
         2377,
         2378,
         2379,
         53,
         53,
         53,
         2767,
         1173,
         1124,
         1124,
         1123,
         1123,
         2889,
         1173,
         1123,
         1123,
         2889,
         1173,
         1123,
         1123,
         2889,
         1173,
         1123,
         1123,
         2889,
         1173,
         1123,
         1132,
         1123,
         1123,
         1144,
         1144,
         1145,
         1145,
         1146,
         1123,
         1123,
         1153,
         1123,
         1123,
         1123,
         1123,
         1147,
         1148,
         1148,
         1148,
         1148,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1149,
         1123,
         1123,
         1150,
         1123,
         1151,
         1123,
         1152,
         1123,
         1123,
         1123,
         1123,
         1123,
         1145,
         1145,
         1123,
         1123,
         2385,
         2386,
         2387,
         2388,
         1123,
         1123,
         1123,
         1123,
         1123,
         1145,
         1145,
         1144,
         1144,
         1123,
         1123,
         1144,
         2917,
         1123,
         1123,
         1144,
         1144,
         1123,
         1123,
         1144,
         1144,
         1123,
         1123,
         1123,
         1132,
         1123,
         1123,
         1144,
         1144,
         1145,
         1145,
         1146,
         1123,
         1123,
         1153,
         1123,
         1123,
         1123,
         1123,
         1147,
         1148,
         1148,
         1148,
         1148,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1149,
         1123,
         1123,
         1150,
         1123,
         1151,
         1123,
         1152,
         1123,
         1123,
         1123,
         1123,
         1123,
         1145,
         1145,
         1123,
         1123,
         2385,
         2386,
         2387,
         2388,
         1123,
         1123,
         1123,
         1123,
         1123,
         1145,
         1145,
         1144,
         1144,
         1123,
         1123,
         2917,
         1144,
         1123,
         1123,
         1144,
         1144,
         1123,
         1123,
         1144,
         1144,
         1123,
         1123,
         53,
         54,
         1142,
         1142,
         1123,
         1123,
         1124,
         1124,
         1125,
         53,
         53,
         53,
         53,
         1143,
         53,
         53,
         1126,
         1127,
         1127,
         1127,
         1127,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         1128,
         53,
         53,
         1129,
         53,
         1130,
         53,
         1131,
         53,
         53,
         53,
         1142,
         1142,
         1124,
         1124,
         2384,
         53,
         2376,
         2377,
         2378,
         2379,
         53,
         53,
         53,
         1142,
         2766,
         1124,
         1124,
         1123,
         1123,
         1142,
         2889,
         1123,
         1123,
         1142,
         2918,
         1123,
         1123,
         1142,
         2918,
         1123,
         1123,
         1142,
         2918,
         53,
         54,
         53,
         1143,
         1123,
         1123,
         1124,
         1124,
         1125,
         53,
         53,
         53,
         1173,
         1173,
         53,
         53,
         1126,
         1127,
         1127,
         1127,
         1127,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         1128,
         53,
         53,
         1129,
         53,
         1130,
         53,
         1131,
         53,
         53,
         53,
         2397,
         1143,
         1124,
         1124,
         1173,
         53,
         2376,
         2377,
         2378,
         2379,
         53,
         53,
         53,
         2767,
         1173,
         1124,
         1124,
         1123,
         1123,
         2889,
         1173,
         1123,
         1123,
         2918,
         1173,
         1123,
         1123,
         2918,
         1173,
         1123,
         1123,
         2918,
         1173,
         1123,
         1132,
         1123,
         1123,
         1144,
         1144,
         1145,
         1145,
         1146,
         1123,
         1123,
         1153,
         1123,
         1123,
         1123,
         1123,
         1147,
         1148,
         1148,
         1148,
         1148,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1149,
         1123,
         1123,
         1150,
         1123,
         1151,
         1123,
         1152,
         1123,
         1123,
         1123,
         1123,
         1123,
         1145,
         1145,
         1123,
         1123,
         2385,
         2386,
         2387,
         2388,
         1123,
         1123,
         1123,
         1123,
         1123,
         1145,
         1145,
         1144,
         1144,
         1123,
         1123,
         1144,
         1144,
         1123,
         1123,
         1144,
         2926,
         1123,
         1123,
         1144,
         1144,
         1123,
         1123,
         1123,
         1132,
         1123,
         1123,
         1144,
         1144,
         1145,
         1145,
         1146,
         1123,
         1123,
         1153,
         1123,
         1123,
         1123,
         1123,
         1147,
         1148,
         1148,
         1148,
         1148,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1149,
         1123,
         1123,
         1150,
         1123,
         1151,
         1123,
         1152,
         1123,
         1123,
         1123,
         1123,
         1123,
         1145,
         1145,
         1123,
         1123,
         2385,
         2386,
         2387,
         2388,
         1123,
         1123,
         1123,
         1123,
         1123,
         1145,
         1145,
         1144,
         1144,
         1123,
         1123,
         1144,
         1144,
         1123,
         1123,
         2926,
         1144,
         1123,
         1123,
         1144,
         1144,
         1123,
         1123,
         53,
         54,
         1142,
         1142,
         1123,
         1123,
         1124,
         1124,
         1125,
         53,
         53,
         53,
         53,
         1143,
         53,
         53,
         1126,
         1127,
         1127,
         1127,
         1127,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         1128,
         53,
         53,
         1129,
         53,
         1130,
         53,
         1131,
         53,
         53,
         53,
         1142,
         1142,
         1124,
         1124,
         2384,
         53,
         2376,
         2377,
         2378,
         2379,
         53,
         53,
         53,
         1142,
         2766,
         1124,
         1124,
         1123,
         1123,
         1142,
         2889,
         1123,
         1123,
         1142,
         2918,
         1123,
         1123,
         1142,
         2927,
         1123,
         1123,
         1142,
         2927,
         53,
         54,
         53,
         1143,
         1123,
         1123,
         1124,
         1124,
         1125,
         53,
         53,
         53,
         1173,
         1173,
         53,
         53,
         1126,
         1127,
         1127,
         1127,
         1127,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         1128,
         53,
         53,
         1129,
         53,
         1130,
         53,
         1131,
         53,
         53,
         53,
         2397,
         1143,
         1124,
         1124,
         1173,
         53,
         2376,
         2377,
         2378,
         2379,
         53,
         53,
         53,
         2767,
         1173,
         1124,
         1124,
         1123,
         1123,
         2889,
         1173,
         1123,
         1123,
         2918,
         1173,
         1123,
         1123,
         2927,
         1173,
         1123,
         1123,
         2927,
         1173,
         1123,
         1132,
         1123,
         1123,
         1144,
         1144,
         1145,
         1145,
         1146,
         1123,
         1123,
         1153,
         1123,
         1123,
         1123,
         1123,
         1147,
         1148,
         1148,
         1148,
         1148,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1149,
         1123,
         1123,
         1150,
         1123,
         1151,
         1123,
         1152,
         1123,
         1123,
         1123,
         1123,
         1123,
         1145,
         1145,
         1123,
         1123,
         2385,
         2386,
         2387,
         2388,
         1123,
         1123,
         1123,
         1123,
         1123,
         1145,
         1145,
         1144,
         1144,
         1123,
         1123,
         1144,
         1144,
         1123,
         1123,
         1144,
         1144,
         1123,
         1123,
         1144,
         2935,
         1123,
         1123,
         1123,
         1132,
         1123,
         1123,
         1144,
         1144,
         1145,
         1145,
         1146,
         1123,
         1123,
         1153,
         1123,
         1123,
         1123,
         1123,
         1147,
         1148,
         1148,
         1148,
         1148,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1123,
         1149,
         1123,
         1123,
         1150,
         1123,
         1151,
         1123,
         1152,
         1123,
         1123,
         1123,
         1123,
         1123,
         1145,
         1145,
         1123,
         1123,
         2385,
         2386,
         2387,
         2388,
         1123,
         1123,
         1123,
         1123,
         1123,
         1145,
         1145,
         1144,
         1144,
         1123,
         1123,
         1144,
         1144,
         1123,
         1123,
         1144,
         1144,
         1123,
         1123,
         2935,
         1144,
         1123,
         1123,
         53,
         54,
         1142,
         1142,
         1123,
         1123,
         1124,
         1124,
         1125,
         53,
         53,
         53,
         53,
         1143,
         53,
         53,
         1126,
         1127,
         1127,
         1127,
         1127,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         1128,
         53,
         53,
         1129,
         53,
         1130,
         53,
         1131,
         53,
         53,
         53,
         1142,
         1142,
         1124,
         1124,
         2384,
         53,
         2376,
         2377,
         2378,
         2379,
         53,
         53,
         53,
         1142,
         2766,
         1124,
         1124,
         1123,
         1123,
         1142,
         2889,
         1123,
         1123,
         1142,
         2918,
         1123,
         1123,
         1142,
         2927,
         1123,
         1123,
         1142,
         2936,
         53,
         54,
         53,
         1143,
         1123,
         1123,
         1124,
         1124,
         1125,
         53,
         53,
         53,
         1173,
         1173,
         53,
         53,
         1126,
         1127,
         1127,
         1127,
         1127,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         1128,
         53,
         53,
         1129,
         53,
         1130,
         53,
         1131,
         53,
         53,
         53,
         2397,
         1143,
         1124,
         1124,
         1173,
         53,
         2376,
         2377,
         2378,
         2379,
         53,
         53,
         53,
         2767,
         1173,
         1124,
         1124,
         1123,
         1123,
         2889,
         1173,
         1123,
         1123,
         2918,
         1173,
         1123,
         1123,
         2927,
         1173,
         1123,
         1123,
         2936,
         1173,
      },
   },
   [nir_op_ieq] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         3,
         0,
         0,
         0,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         8,
         0,
         9,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         14,
         0,
         15,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         17,
         18,
         19,
         20,
         0,
         0,
         0,
         21,
         22,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         8,
         8,
         0,
         0,
         9,
         0,
         9,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         23,
         2,
         2,
         2,
         2,
         2,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         0,
         0,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         13,
         13,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         20,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         11,
         23,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         5,
         0,
         5,
         5,
         0,
         8,
         0,
         0,
         0,
         8,
         5,
         5,
         5,
         0,
         8,
         0,
         0,
         0,
         8,
         5,
         5,
         5,
         0,
         8,
         0,
         0,
      },
      
      .num_filtered_states = 24,
      .table = (const uint16_t []) {
      
         55,
         56,
         55,
         55,
         1568,
         1569,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         56,
         56,
         1570,
         1571,
         1572,
         1573,
         1574,
         1575,
         1576,
         1577,
         1578,
         1579,
         1580,
         1581,
         1582,
         1583,
         1584,
         1585,
         1586,
         1587,
         1588,
         1589,
         1590,
         2649,
         55,
         1570,
         55,
         55,
         1568,
         1569,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         1571,
         55,
         55,
         1568,
         1569,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         1568,
         1572,
         1568,
         1568,
         1568,
         1591,
         1568,
         1568,
         1568,
         1568,
         1568,
         1568,
         1568,
         1568,
         1568,
         1568,
         1568,
         1568,
         1568,
         1568,
         1568,
         1568,
         1568,
         1568,
         1569,
         1573,
         1569,
         1569,
         1591,
         1569,
         1569,
         1569,
         1569,
         1569,
         1569,
         1569,
         1569,
         1569,
         1569,
         1569,
         1569,
         1569,
         1569,
         1569,
         1569,
         1569,
         1569,
         1569,
         55,
         1574,
         55,
         55,
         1568,
         1569,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         1575,
         55,
         55,
         1568,
         1569,
         55,
         1592,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         1576,
         55,
         55,
         1568,
         1569,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         1577,
         55,
         55,
         1568,
         1569,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         1578,
         55,
         55,
         1568,
         1569,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         1579,
         55,
         55,
         1568,
         1569,
         55,
         55,
         55,
         55,
         55,
         1593,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         1580,
         55,
         55,
         1568,
         1569,
         55,
         55,
         55,
         55,
         55,
         55,
         1594,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         1581,
         55,
         55,
         1568,
         1569,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         1582,
         55,
         55,
         1568,
         1569,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         1583,
         55,
         55,
         1568,
         1569,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         1584,
         55,
         55,
         1568,
         1569,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         1585,
         55,
         55,
         1568,
         1569,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         1586,
         55,
         55,
         1568,
         1569,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         1587,
         55,
         55,
         1568,
         1569,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         1588,
         55,
         55,
         1568,
         1569,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         1589,
         55,
         55,
         1568,
         1569,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         1590,
         55,
         55,
         1568,
         1569,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         2649,
         55,
         55,
         1568,
         1569,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
         55,
      },
   },
   [nir_op_ine] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         3,
         0,
         0,
         0,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         8,
         0,
         9,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         13,
         14,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         17,
         18,
         19,
         0,
         0,
         0,
         20,
         21,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         8,
         8,
         0,
         0,
         9,
         0,
         9,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         22,
         2,
         2,
         2,
         2,
         2,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         19,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         23,
         0,
         23,
         0,
         23,
         0,
         23,
         23,
         0,
         23,
         23,
         24,
         0,
         0,
         24,
         0,
         0,
         24,
         0,
         24,
         24,
         24,
         0,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         11,
         10,
         22,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         23,
         23,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         11,
         11,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         5,
         0,
         5,
         5,
         0,
         8,
         0,
         0,
         0,
         8,
         5,
         5,
         5,
         0,
         8,
         0,
         0,
         0,
         8,
         5,
         5,
         5,
         0,
         8,
         0,
         0,
      },
      
      .num_filtered_states = 25,
      .table = (const uint16_t []) {
      
         57,
         58,
         57,
         57,
         1595,
         1596,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         58,
         58,
         1597,
         1598,
         1599,
         1600,
         1601,
         1602,
         1603,
         1604,
         1605,
         1606,
         1607,
         1608,
         1609,
         1610,
         1611,
         1612,
         1613,
         1614,
         1615,
         1616,
         2650,
         2877,
         2878,
         57,
         1597,
         57,
         57,
         1595,
         1596,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         1598,
         57,
         57,
         1595,
         1596,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         1595,
         1599,
         1595,
         1595,
         1595,
         1617,
         1595,
         1595,
         1595,
         1595,
         1595,
         1595,
         1595,
         1595,
         1595,
         1595,
         1595,
         1595,
         1595,
         1595,
         1595,
         1595,
         1595,
         1595,
         1595,
         1596,
         1600,
         1596,
         1596,
         1617,
         1596,
         1596,
         1596,
         1596,
         1596,
         1596,
         1596,
         1596,
         1596,
         1596,
         1596,
         1596,
         1596,
         1596,
         1596,
         1596,
         1596,
         1596,
         1596,
         1596,
         57,
         1601,
         57,
         57,
         1595,
         1596,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         1602,
         57,
         57,
         1595,
         1596,
         57,
         1618,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         1603,
         57,
         57,
         1595,
         1596,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         1604,
         57,
         57,
         1595,
         1596,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         1605,
         57,
         57,
         1595,
         1596,
         57,
         57,
         57,
         57,
         1619,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         1606,
         57,
         57,
         1595,
         1596,
         57,
         57,
         57,
         57,
         57,
         1620,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         1607,
         57,
         57,
         1595,
         1596,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         1608,
         57,
         57,
         1595,
         1596,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         1609,
         57,
         57,
         1595,
         1596,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         1610,
         57,
         57,
         1595,
         1596,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         1611,
         57,
         57,
         1595,
         1596,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         1612,
         57,
         57,
         1595,
         1596,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         1613,
         57,
         57,
         1595,
         1596,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         1614,
         57,
         57,
         1595,
         1596,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         1615,
         57,
         57,
         1595,
         1596,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         1616,
         57,
         57,
         1595,
         1596,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         2650,
         57,
         57,
         1595,
         1596,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         2651,
         57,
         57,
         57,
         2877,
         57,
         57,
         1595,
         1596,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         2878,
         57,
         57,
         1595,
         1596,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
         57,
      },
   },
   [nir_op_fsat] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         5,
         5,
         6,
         7,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         9,
         9,
         9,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 11,
      .table = (const uint16_t []) {
      
         59,
         1418,
         1419,
         1420,
         1421,
         2591,
         2592,
         2593,
         2594,
         2595,
         2596,
      },
   },
   [nir_op_umul_unorm_4x8_vc4] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         60,
         60,
         60,
      },
   },
   [nir_op_fsign] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         61,
      },
   },
   [nir_op_flrp] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 5,
      .table = (const uint16_t []) {
      
         62,
         63,
         62,
         62,
         1689,
         64,
         65,
         64,
         64,
         1690,
         1691,
         1692,
         1691,
         1691,
         1693,
         1694,
         1695,
         1694,
         1694,
         1696,
         62,
         63,
         62,
         62,
         1689,
         66,
         67,
         66,
         66,
         1697,
         68,
         69,
         68,
         68,
         1698,
         1699,
         1700,
         1699,
         1699,
         1701,
         1702,
         1703,
         1702,
         1702,
         1704,
         66,
         67,
         66,
         66,
         1697,
         62,
         63,
         62,
         62,
         1689,
         64,
         65,
         64,
         64,
         1690,
         1705,
         1706,
         1705,
         1705,
         1707,
         1694,
         1695,
         1694,
         1694,
         1696,
         62,
         63,
         62,
         62,
         1689,
         62,
         63,
         62,
         62,
         1689,
         64,
         65,
         64,
         64,
         1690,
         1691,
         1692,
         1691,
         1691,
         1693,
         1708,
         1709,
         1708,
         1708,
         1710,
         62,
         63,
         62,
         62,
         1689,
         62,
         63,
         62,
         62,
         1689,
         64,
         65,
         64,
         64,
         1690,
         1691,
         1692,
         1691,
         1691,
         1693,
         1694,
         1695,
         1694,
         1694,
         1696,
         62,
         63,
         62,
         62,
         1689,
      },
   },
   [nir_op_sdot_4x8_iadd] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         70,
         71,
         72,
         73,
         72,
         73,
         74,
         75,
      },
   },
   [nir_op_udot_4x8_uadd] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         76,
         77,
         78,
         79,
         78,
         79,
         80,
         81,
      },
   },
   [nir_op_sdot_4x8_iadd_sat] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         82,
         82,
         83,
         83,
         83,
         83,
         84,
         84,
      },
   },
   [nir_op_udot_4x8_uadd_sat] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         85,
         86,
         87,
         88,
         87,
         88,
         89,
         90,
      },
   },
   [nir_op_sdot_2x16_iadd] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         91,
         92,
         93,
         94,
         93,
         94,
         95,
         96,
      },
   },
   [nir_op_udot_2x16_uadd] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         97,
         98,
         99,
         100,
         99,
         100,
         101,
         102,
      },
   },
   [nir_op_sdot_2x16_iadd_sat] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         103,
         103,
         104,
         104,
         104,
         104,
         105,
         105,
      },
   },
   [nir_op_udot_2x16_uadd_sat] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         106,
         106,
         107,
         107,
         107,
         107,
         108,
         108,
      },
   },
   [nir_op_sudot_4x8_iadd] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         109,
         110,
         111,
         112,
         113,
         114,
         115,
         116,
      },
   },
   [nir_op_sudot_4x8_iadd_sat] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         117,
         117,
         118,
         118,
         119,
         119,
         120,
         120,
      },
   },
   [nir_op_bcsel] = {
      .filter = (const uint16_t []) {
         0,
         1,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         9,
         9,
         0,
         10,
         0,
         11,
         0,
         0,
         12,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         0,
         15,
         16,
         17,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         18,
         18,
         18,
         18,
         19,
         20,
         21,
         20,
         21,
         22,
         22,
         22,
         22,
         0,
         0,
         23,
         24,
         25,
         25,
         25,
         25,
         26,
         26,
         27,
         27,
         28,
         28,
         0,
         29,
         29,
         30,
         30,
         31,
         31,
         32,
         32,
         33,
         33,
         0,
         34,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         35,
         0,
         36,
         0,
         37,
         38,
         38,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         39,
         40,
         40,
         40,
         40,
         41,
         42,
         43,
         0,
         0,
         44,
         45,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         46,
         47,
         48,
         49,
         50,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         51,
         52,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         53,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         53,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         53,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         18,
         18,
         18,
         18,
         18,
         18,
         18,
         34,
         34,
         34,
         34,
         34,
         34,
         34,
         35,
         35,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         0,
         0,
         0,
         0,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         20,
         21,
         20,
         21,
         20,
         21,
         20,
         20,
         20,
         21,
         21,
         20,
         21,
         20,
         20,
         20,
         21,
         20,
         21,
         20,
         20,
         20,
         20,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         22,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         0,
         0,
         0,
         0,
         0,
         54,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         55,
         56,
         57,
         58,
         59,
         60,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         61,
         62,
         63,
         64,
         65,
         66,
         0,
         0,
         0,
         0,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         19,
         19,
         19,
         19,
         19,
         19,
         19,
         19,
         19,
         19,
         19,
         19,
         19,
         19,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         67,
         67,
         67,
         67,
         67,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         25,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         68,
         68,
         68,
         68,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         27,
         69,
         16,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         70,
         71,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         72,
         73,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         23,
         23,
         23,
         23,
         23,
         23,
         24,
         23,
         24,
         23,
         23,
         24,
         23,
         24,
         23,
         23,
         24,
         24,
         23,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         26,
         74,
         75,
         76,
         77,
         78,
         0,
         39,
         39,
         39,
         39,
         39,
         41,
         42,
         42,
         42,
         42,
         43,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         33,
         33,
         33,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         17,
         17,
         17,
         37,
         37,
         37,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         40,
         0,
         0,
         0,
         0,
         0,
         46,
         50,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         53,
         79,
         80,
         81,
         82,
         5,
         5,
         5,
         5,
         53,
         53,
         53,
         53,
         53,
         53,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         15,
         15,
         15,
         15,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         19,
         19,
         19,
         19,
         19,
         19,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         0,
         0,
         20,
         21,
         21,
         21,
         21,
         21,
         22,
         22,
         22,
         22,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         29,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         40,
         3,
         3,
         3,
         69,
         69,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         31,
         10,
         11,
         0,
         24,
         25,
         25,
         25,
         25,
         67,
         25,
         25,
         25,
         26,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         33,
         0,
         0,
         0,
         34,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         38,
         73,
         73,
         71,
         0,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         32,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         9,
         9,
         9,
         9,
         9,
         9,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         19,
         19,
         19,
         0,
         0,
         0,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         28,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         15,
         0,
         16,
         21,
         22,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         30,
         11,
         11,
         53,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         9,
         21,
         21,
         21,
         29,
         29,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         8,
         83,
         0,
         0,
         8,
         14,
         8,
         8,
         0,
         0,
         9,
         9,
         0,
         0,
         8,
         8,
         8,
         0,
         0,
         9,
         9,
         0,
         0,
         8,
         8,
         8,
         0,
         0,
         9,
         9,
      },
      
      .num_filtered_states = 84,
      .table = (const uint16_t []) {
      
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         123,
         124,
         123,
         469,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         470,
         123,
         123,
         471,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         121,
         122,
         472,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         473,
         474,
         473,
         475,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         476,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         121,
         122,
         121,
         467,
         477,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         479,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         480,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         481,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         482,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         483,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         484,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         485,
         486,
         485,
         487,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         488,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         490,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         491,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         492,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         493,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         494,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         495,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         496,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         497,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         498,
         499,
         498,
         500,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         501,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         502,
         503,
         502,
         504,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         505,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         506,
         507,
         506,
         508,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         509,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         510,
         511,
         510,
         512,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         513,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         514,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         515,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         516,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         517,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         518,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         519,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         520,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         521,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         522,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         523,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         2072,
         2073,
         2072,
         2074,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2075,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2076,
         2077,
         2076,
         2078,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2079,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2080,
         2081,
         2080,
         2082,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2083,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2084,
         2085,
         2084,
         2086,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2087,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         125,
         126,
         125,
         524,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         525,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         127,
         128,
         127,
         526,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         527,
         127,
         127,
         528,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         127,
         125,
         126,
         529,
         524,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         525,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         530,
         531,
         530,
         532,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         533,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         530,
         125,
         126,
         125,
         524,
         534,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         525,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         126,
         125,
         524,
         125,
         535,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         525,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         535,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         535,
         535,
         535,
         535,
         125,
         125,
         126,
         125,
         524,
         125,
         125,
         536,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         525,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         126,
         125,
         524,
         125,
         125,
         125,
         537,
         125,
         125,
         125,
         125,
         125,
         125,
         525,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         126,
         125,
         524,
         125,
         125,
         125,
         125,
         538,
         125,
         125,
         125,
         125,
         125,
         525,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         126,
         125,
         524,
         125,
         125,
         125,
         125,
         125,
         539,
         125,
         125,
         125,
         125,
         525,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         126,
         125,
         524,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         525,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         126,
         125,
         524,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         525,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         126,
         125,
         524,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         540,
         125,
         525,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         126,
         125,
         524,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         541,
         525,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         542,
         543,
         542,
         544,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         545,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         542,
         125,
         126,
         125,
         524,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         525,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         126,
         125,
         524,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         525,
         125,
         546,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         546,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         547,
         125,
         524,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         525,
         125,
         125,
         548,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         126,
         125,
         524,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         525,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         126,
         125,
         524,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         525,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         126,
         125,
         524,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         525,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         126,
         125,
         524,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         525,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         126,
         125,
         524,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         525,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         126,
         125,
         524,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         525,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         126,
         125,
         524,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         525,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         126,
         125,
         524,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         525,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         126,
         125,
         524,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         525,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         126,
         125,
         524,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         525,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         126,
         125,
         524,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         525,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         549,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         126,
         125,
         524,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         525,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         550,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         126,
         125,
         524,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         525,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         551,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         126,
         125,
         524,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         525,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         552,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         126,
         125,
         524,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         525,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         553,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         126,
         125,
         524,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         525,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         554,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         555,
         556,
         555,
         557,
         555,
         555,
         555,
         555,
         555,
         555,
         555,
         555,
         555,
         555,
         558,
         555,
         555,
         555,
         555,
         555,
         555,
         555,
         555,
         555,
         555,
         555,
         555,
         555,
         555,
         555,
         555,
         555,
         555,
         555,
         555,
         555,
         555,
         555,
         555,
         555,
         555,
         555,
         555,
         555,
         555,
         555,
         555,
         555,
         555,
         555,
         555,
         555,
         555,
         555,
         555,
         555,
         555,
         555,
         555,
         555,
         555,
         555,
         555,
         555,
         555,
         555,
         555,
         555,
         555,
         555,
         555,
         555,
         555,
         555,
         555,
         555,
         555,
         555,
         555,
         555,
         555,
         555,
         555,
         555,
         559,
         560,
         559,
         561,
         559,
         559,
         559,
         559,
         559,
         559,
         559,
         559,
         559,
         559,
         562,
         559,
         559,
         559,
         559,
         559,
         559,
         559,
         559,
         559,
         559,
         559,
         559,
         559,
         559,
         559,
         559,
         559,
         559,
         559,
         559,
         559,
         559,
         559,
         559,
         559,
         559,
         559,
         559,
         559,
         559,
         559,
         559,
         559,
         559,
         559,
         559,
         559,
         559,
         559,
         559,
         559,
         559,
         559,
         559,
         559,
         559,
         559,
         559,
         559,
         559,
         559,
         559,
         559,
         559,
         559,
         559,
         559,
         559,
         559,
         559,
         559,
         559,
         559,
         559,
         559,
         559,
         559,
         559,
         559,
         563,
         564,
         563,
         565,
         563,
         563,
         563,
         563,
         563,
         563,
         563,
         563,
         563,
         563,
         566,
         563,
         563,
         563,
         563,
         563,
         563,
         563,
         563,
         563,
         563,
         563,
         563,
         563,
         563,
         563,
         563,
         563,
         563,
         563,
         563,
         563,
         563,
         563,
         563,
         563,
         563,
         563,
         563,
         563,
         563,
         563,
         563,
         563,
         563,
         563,
         563,
         563,
         563,
         563,
         563,
         563,
         563,
         563,
         563,
         563,
         563,
         563,
         563,
         563,
         563,
         563,
         563,
         563,
         563,
         563,
         563,
         563,
         563,
         563,
         563,
         563,
         563,
         563,
         563,
         563,
         563,
         563,
         563,
         563,
         567,
         568,
         567,
         569,
         567,
         567,
         567,
         567,
         567,
         567,
         567,
         567,
         567,
         567,
         570,
         567,
         567,
         567,
         567,
         567,
         567,
         567,
         567,
         567,
         567,
         567,
         567,
         567,
         567,
         567,
         567,
         567,
         567,
         567,
         567,
         567,
         567,
         567,
         567,
         567,
         567,
         567,
         567,
         567,
         567,
         567,
         567,
         567,
         567,
         567,
         567,
         567,
         567,
         567,
         567,
         567,
         567,
         567,
         567,
         567,
         567,
         567,
         567,
         567,
         567,
         567,
         567,
         567,
         567,
         567,
         567,
         567,
         567,
         567,
         567,
         567,
         567,
         567,
         567,
         567,
         567,
         567,
         567,
         567,
         125,
         126,
         125,
         524,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         525,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         571,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         126,
         125,
         524,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         525,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         572,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         126,
         125,
         524,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         525,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         573,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         126,
         125,
         524,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         525,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         574,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         126,
         125,
         524,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         525,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         575,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         126,
         125,
         524,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         525,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         576,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         126,
         125,
         524,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         525,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         577,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         126,
         125,
         524,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         525,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         578,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         126,
         125,
         524,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         525,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         126,
         125,
         524,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         525,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         126,
         125,
         524,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         525,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         126,
         125,
         524,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         525,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         126,
         125,
         524,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         525,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         126,
         125,
         524,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         525,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         579,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         126,
         125,
         524,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         525,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         580,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         126,
         125,
         524,
         125,
         535,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         525,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         535,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         535,
         535,
         535,
         535,
         125,
         125,
         126,
         125,
         524,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         525,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         126,
         125,
         524,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         525,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         126,
         125,
         524,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         525,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         126,
         125,
         524,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         525,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         126,
         125,
         524,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         525,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         126,
         125,
         524,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         525,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         126,
         125,
         524,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         525,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         126,
         125,
         524,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         525,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         126,
         125,
         524,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         525,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         126,
         125,
         524,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         525,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         126,
         125,
         524,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         525,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         126,
         125,
         524,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         525,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         126,
         125,
         524,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         525,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         126,
         125,
         524,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         525,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         126,
         125,
         524,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         525,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         126,
         125,
         524,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         525,
         125,
         546,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         546,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         2088,
         2089,
         2088,
         2090,
         2088,
         2088,
         2088,
         2088,
         2088,
         2088,
         2088,
         2088,
         2088,
         2088,
         2091,
         2088,
         2088,
         2088,
         2088,
         2088,
         2088,
         2088,
         2088,
         2088,
         2088,
         2088,
         2088,
         2088,
         2088,
         2088,
         2088,
         2088,
         2088,
         2088,
         2088,
         2088,
         2088,
         2088,
         2088,
         2088,
         2088,
         2088,
         2088,
         2088,
         2088,
         2088,
         2088,
         2088,
         2088,
         2088,
         2088,
         2088,
         2088,
         2088,
         2088,
         2088,
         2088,
         2088,
         2088,
         2088,
         2088,
         2088,
         2088,
         2088,
         2088,
         2088,
         2088,
         2088,
         2088,
         2088,
         2088,
         2088,
         2088,
         2088,
         2088,
         2088,
         2088,
         2088,
         2088,
         2088,
         2088,
         2088,
         2088,
         2088,
         2092,
         2093,
         2092,
         2094,
         2092,
         2092,
         2092,
         2092,
         2092,
         2092,
         2092,
         2092,
         2092,
         2092,
         2095,
         2092,
         2092,
         2092,
         2092,
         2092,
         2092,
         2092,
         2092,
         2092,
         2092,
         2092,
         2092,
         2092,
         2092,
         2092,
         2092,
         2092,
         2092,
         2092,
         2092,
         2092,
         2092,
         2092,
         2092,
         2092,
         2092,
         2092,
         2092,
         2092,
         2092,
         2092,
         2092,
         2092,
         2092,
         2092,
         2092,
         2092,
         2092,
         2092,
         2092,
         2092,
         2092,
         2092,
         2092,
         2092,
         2092,
         2092,
         2092,
         2092,
         2092,
         2092,
         2092,
         2092,
         2092,
         2092,
         2092,
         2092,
         2092,
         2092,
         2092,
         2092,
         2092,
         2092,
         2092,
         2092,
         2092,
         2092,
         2092,
         2092,
         2096,
         2097,
         2096,
         2098,
         2096,
         2096,
         2096,
         2096,
         2096,
         2096,
         2096,
         2096,
         2096,
         2096,
         2099,
         2096,
         2096,
         2096,
         2096,
         2096,
         2096,
         2096,
         2096,
         2096,
         2096,
         2096,
         2096,
         2096,
         2096,
         2096,
         2096,
         2096,
         2096,
         2096,
         2096,
         2096,
         2096,
         2096,
         2096,
         2096,
         2096,
         2096,
         2096,
         2096,
         2096,
         2096,
         2096,
         2096,
         2096,
         2096,
         2096,
         2096,
         2096,
         2096,
         2096,
         2096,
         2096,
         2096,
         2096,
         2096,
         2096,
         2096,
         2096,
         2096,
         2096,
         2096,
         2096,
         2096,
         2096,
         2096,
         2096,
         2096,
         2096,
         2096,
         2096,
         2096,
         2096,
         2096,
         2096,
         2096,
         2096,
         2096,
         2096,
         2096,
         2100,
         2101,
         2100,
         2102,
         2100,
         2100,
         2100,
         2100,
         2100,
         2100,
         2100,
         2100,
         2100,
         2100,
         2103,
         2100,
         2100,
         2100,
         2100,
         2100,
         2100,
         2100,
         2100,
         2100,
         2100,
         2100,
         2100,
         2100,
         2100,
         2100,
         2100,
         2100,
         2100,
         2100,
         2100,
         2100,
         2100,
         2100,
         2100,
         2100,
         2100,
         2100,
         2100,
         2100,
         2100,
         2100,
         2100,
         2100,
         2100,
         2100,
         2100,
         2100,
         2100,
         2100,
         2100,
         2100,
         2100,
         2100,
         2100,
         2100,
         2100,
         2100,
         2100,
         2100,
         2100,
         2100,
         2100,
         2100,
         2100,
         2100,
         2100,
         2100,
         2100,
         2100,
         2100,
         2100,
         2100,
         2100,
         2100,
         2100,
         2100,
         2100,
         2100,
         2100,
         125,
         126,
         125,
         524,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         525,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         126,
         125,
         524,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         525,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         126,
         125,
         524,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         525,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         126,
         125,
         524,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         525,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         126,
         125,
         524,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         525,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         126,
         125,
         524,
         125,
         535,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         525,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         535,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         535,
         535,
         535,
         535,
         125,
         125,
         126,
         125,
         524,
         125,
         535,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         525,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         535,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         535,
         535,
         535,
         535,
         125,
         125,
         126,
         125,
         524,
         125,
         535,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         525,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         535,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         535,
         535,
         535,
         535,
         125,
         125,
         126,
         125,
         524,
         125,
         535,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         525,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         535,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         535,
         535,
         535,
         535,
         125,
         125,
         126,
         125,
         524,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         525,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         125,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         123,
         124,
         123,
         469,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         470,
         123,
         123,
         471,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         121,
         122,
         472,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         473,
         474,
         473,
         475,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         476,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         121,
         122,
         121,
         467,
         477,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         479,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         480,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         481,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         482,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         483,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         484,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         485,
         486,
         485,
         487,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         488,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         490,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         491,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         492,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         493,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         494,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         495,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         496,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         497,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         498,
         499,
         498,
         500,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         501,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         502,
         503,
         502,
         504,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         505,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         506,
         507,
         506,
         508,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         509,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         510,
         511,
         510,
         512,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         513,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         514,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         515,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         516,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         517,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         518,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         519,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         520,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         521,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         522,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         523,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         2072,
         2073,
         2072,
         2074,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2075,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2076,
         2077,
         2076,
         2078,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2079,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2080,
         2081,
         2080,
         2082,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2083,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2084,
         2085,
         2084,
         2086,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2087,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         123,
         124,
         123,
         469,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         470,
         123,
         123,
         471,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         121,
         122,
         472,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         473,
         474,
         473,
         475,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         476,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         121,
         122,
         121,
         467,
         477,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         479,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         480,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         481,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         482,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         483,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         484,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         485,
         486,
         485,
         487,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         488,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         490,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         491,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         492,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         493,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         494,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         495,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         496,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         497,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         498,
         499,
         498,
         500,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         501,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         502,
         503,
         502,
         504,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         505,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         506,
         507,
         506,
         508,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         509,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         510,
         511,
         510,
         512,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         513,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         514,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         515,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         516,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         517,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         518,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         519,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         520,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         521,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         522,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         523,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         2072,
         2073,
         2072,
         2074,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2075,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2076,
         2077,
         2076,
         2078,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2079,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2080,
         2081,
         2080,
         2082,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2083,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2084,
         2085,
         2084,
         2086,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2087,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         123,
         124,
         123,
         469,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         470,
         123,
         123,
         471,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         121,
         122,
         472,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         473,
         474,
         473,
         475,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         476,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         121,
         122,
         121,
         467,
         477,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         479,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         480,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         481,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         482,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         483,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         484,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         485,
         486,
         485,
         487,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         488,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         490,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         491,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         492,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         493,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         494,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         495,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         496,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         497,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         498,
         499,
         498,
         500,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         501,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         502,
         503,
         502,
         504,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         505,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         506,
         507,
         506,
         508,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         509,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         510,
         511,
         510,
         512,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         513,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         514,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         515,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         516,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         517,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         518,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         519,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         520,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         521,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         522,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         523,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         2072,
         2073,
         2072,
         2074,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2075,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2076,
         2077,
         2076,
         2078,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2079,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2080,
         2081,
         2080,
         2082,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2083,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2084,
         2085,
         2084,
         2086,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2087,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         123,
         124,
         123,
         469,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         470,
         123,
         123,
         471,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         121,
         122,
         472,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         473,
         474,
         473,
         475,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         476,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         121,
         122,
         121,
         467,
         477,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         479,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         480,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         481,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         482,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         483,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         484,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         485,
         486,
         485,
         487,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         488,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         490,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         491,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         492,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         493,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         494,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         495,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         496,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         497,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         498,
         499,
         498,
         500,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         501,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         502,
         503,
         502,
         504,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         505,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         506,
         507,
         506,
         508,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         509,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         510,
         511,
         510,
         512,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         513,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         514,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         515,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         516,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         517,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         518,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         519,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         520,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         521,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         522,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         523,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         2072,
         2073,
         2072,
         2074,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2075,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2076,
         2077,
         2076,
         2078,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2079,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2080,
         2081,
         2080,
         2082,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2083,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2084,
         2085,
         2084,
         2086,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2087,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         123,
         124,
         123,
         469,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         470,
         123,
         123,
         471,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         121,
         122,
         472,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         473,
         474,
         473,
         475,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         476,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         121,
         122,
         121,
         467,
         477,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         479,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         480,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         481,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         482,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         483,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         484,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         485,
         486,
         485,
         487,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         488,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         490,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         491,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         492,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         493,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         494,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         495,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         496,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         497,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         498,
         499,
         498,
         500,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         501,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         502,
         503,
         502,
         504,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         505,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         506,
         507,
         506,
         508,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         509,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         510,
         511,
         510,
         512,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         513,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         514,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         515,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         516,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         517,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         518,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         519,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         520,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         521,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         522,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         523,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         2072,
         2073,
         2072,
         2074,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2075,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2076,
         2077,
         2076,
         2078,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2079,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2080,
         2081,
         2080,
         2082,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2083,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2084,
         2085,
         2084,
         2086,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2087,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         123,
         124,
         123,
         469,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         470,
         123,
         123,
         471,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         121,
         122,
         472,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         473,
         474,
         473,
         475,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         476,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         121,
         122,
         121,
         467,
         477,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         479,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         480,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         481,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         482,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         483,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         484,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         485,
         486,
         485,
         487,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         488,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         490,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         491,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         492,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         493,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         494,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         495,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         496,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         497,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         498,
         499,
         498,
         500,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         501,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         502,
         503,
         502,
         504,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         505,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         506,
         507,
         506,
         508,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         509,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         510,
         511,
         510,
         512,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         513,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         514,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         515,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         516,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         517,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         518,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         519,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         520,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         521,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         522,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         523,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         2072,
         2073,
         2072,
         2074,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2075,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2076,
         2077,
         2076,
         2078,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2079,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2080,
         2081,
         2080,
         2082,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2083,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2084,
         2085,
         2084,
         2086,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2087,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         123,
         124,
         123,
         469,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         470,
         123,
         123,
         471,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         121,
         122,
         472,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         473,
         474,
         473,
         475,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         476,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         121,
         122,
         121,
         467,
         477,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         479,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         480,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         481,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         482,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         483,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         484,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         485,
         486,
         485,
         487,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         488,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         490,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         491,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         492,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         493,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         494,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         495,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         496,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         497,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         498,
         499,
         498,
         500,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         501,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         502,
         503,
         502,
         504,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         505,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         506,
         507,
         506,
         508,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         509,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         510,
         511,
         510,
         512,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         513,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         514,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         515,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         516,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         517,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         518,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         519,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         520,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         521,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         522,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         523,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         2072,
         2073,
         2072,
         2074,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2075,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2076,
         2077,
         2076,
         2078,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2079,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2080,
         2081,
         2080,
         2082,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2083,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2084,
         2085,
         2084,
         2086,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2087,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         123,
         124,
         123,
         469,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         470,
         123,
         123,
         471,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         121,
         122,
         472,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         473,
         474,
         473,
         475,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         476,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         121,
         122,
         121,
         467,
         477,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         479,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         480,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         481,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         482,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         483,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         484,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         485,
         486,
         485,
         487,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         488,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         490,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         491,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         492,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         493,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         494,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         495,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         496,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         497,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         498,
         499,
         498,
         500,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         501,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         502,
         503,
         502,
         504,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         505,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         506,
         507,
         506,
         508,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         509,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         510,
         511,
         510,
         512,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         513,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         514,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         515,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         516,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         517,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         518,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         519,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         520,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         521,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         522,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         523,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         2072,
         2073,
         2072,
         2074,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2075,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2076,
         2077,
         2076,
         2078,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2079,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2080,
         2081,
         2080,
         2082,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2083,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2084,
         2085,
         2084,
         2086,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2087,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         123,
         124,
         123,
         469,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         470,
         123,
         123,
         471,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         2742,
         123,
         2743,
         123,
         121,
         122,
         472,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         473,
         474,
         473,
         475,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         476,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         121,
         122,
         121,
         467,
         477,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         479,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         480,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         481,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         482,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         483,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         484,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         485,
         486,
         485,
         487,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         488,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         490,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         491,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         492,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         493,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         494,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         495,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         496,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         497,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         498,
         499,
         498,
         500,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         501,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         502,
         503,
         502,
         504,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         505,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         506,
         507,
         506,
         508,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         509,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         510,
         511,
         510,
         512,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         513,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         514,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         515,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         516,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         517,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         518,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         519,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         520,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         521,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         2744,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         2745,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         522,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         523,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         2072,
         2073,
         2072,
         2074,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2075,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2076,
         2077,
         2076,
         2078,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2079,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2080,
         2081,
         2080,
         2082,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2083,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2084,
         2085,
         2084,
         2086,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2087,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         123,
         124,
         123,
         469,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         470,
         123,
         123,
         471,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         121,
         122,
         472,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         473,
         474,
         473,
         475,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         476,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         121,
         122,
         121,
         467,
         477,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         479,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         480,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         481,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         482,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         483,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         484,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         485,
         486,
         485,
         487,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         488,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         490,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         491,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         492,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         493,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         494,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         495,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         496,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         497,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         498,
         499,
         498,
         500,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         501,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         502,
         503,
         502,
         504,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         505,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         506,
         507,
         506,
         508,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         509,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         510,
         511,
         510,
         512,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         513,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         514,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         515,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         516,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         517,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         518,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         519,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         520,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         521,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         581,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         582,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         583,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         584,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         585,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         522,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         523,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         2072,
         2073,
         2072,
         2074,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2075,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2076,
         2077,
         2076,
         2078,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2079,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2080,
         2081,
         2080,
         2082,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2083,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2084,
         2085,
         2084,
         2086,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2087,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         2746,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         2747,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         2748,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         2749,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         123,
         124,
         123,
         469,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         470,
         123,
         123,
         471,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         121,
         122,
         472,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         473,
         474,
         473,
         475,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         476,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         121,
         122,
         121,
         467,
         477,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         479,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         480,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         481,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         482,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         483,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         484,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         485,
         486,
         485,
         487,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         488,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         490,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         491,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         492,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         493,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         494,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         495,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         496,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         497,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         498,
         499,
         498,
         500,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         501,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         502,
         503,
         502,
         504,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         505,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         506,
         507,
         506,
         508,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         509,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         510,
         511,
         510,
         512,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         513,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         514,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         515,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         516,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         517,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         518,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         519,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         520,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         521,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         522,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         523,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         2072,
         2073,
         2072,
         2074,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2075,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2076,
         2077,
         2076,
         2078,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2079,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2080,
         2081,
         2080,
         2082,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2083,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2084,
         2085,
         2084,
         2086,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2087,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         123,
         124,
         123,
         469,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         470,
         123,
         123,
         471,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         121,
         122,
         472,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         473,
         474,
         473,
         475,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         476,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         121,
         122,
         121,
         467,
         477,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         479,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         480,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         481,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         482,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         483,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         484,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         485,
         486,
         485,
         487,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         488,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         490,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         491,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         492,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         493,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         494,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         495,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         496,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         497,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         498,
         499,
         498,
         500,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         501,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         502,
         503,
         502,
         504,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         505,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         506,
         507,
         506,
         508,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         509,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         510,
         511,
         510,
         512,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         513,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         514,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         515,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         516,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         517,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         518,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         519,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         520,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         521,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         522,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         523,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         2072,
         2073,
         2072,
         2074,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2075,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2076,
         2077,
         2076,
         2078,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2079,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2080,
         2081,
         2080,
         2082,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2083,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2084,
         2085,
         2084,
         2086,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2087,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         123,
         124,
         123,
         469,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         470,
         123,
         123,
         471,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         121,
         122,
         472,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         473,
         474,
         473,
         475,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         476,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         121,
         122,
         121,
         467,
         477,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         479,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         480,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         481,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         482,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         483,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         484,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         485,
         486,
         485,
         487,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         488,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         490,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         491,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         492,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         493,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         494,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         495,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         496,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         497,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         498,
         499,
         498,
         500,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         501,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         502,
         503,
         502,
         504,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         505,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         506,
         507,
         506,
         508,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         509,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         510,
         511,
         510,
         512,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         513,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         514,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         515,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         516,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         517,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         518,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         519,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         520,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         521,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         522,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         523,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         2072,
         2073,
         2072,
         2074,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2075,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2076,
         2077,
         2076,
         2078,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2079,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2080,
         2081,
         2080,
         2082,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2083,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2084,
         2085,
         2084,
         2086,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2087,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         586,
         587,
         586,
         588,
         586,
         586,
         586,
         586,
         586,
         586,
         586,
         586,
         586,
         586,
         589,
         586,
         586,
         590,
         586,
         586,
         586,
         586,
         586,
         586,
         586,
         586,
         586,
         586,
         586,
         586,
         586,
         586,
         586,
         586,
         586,
         586,
         586,
         586,
         586,
         586,
         586,
         586,
         586,
         586,
         586,
         586,
         586,
         586,
         586,
         586,
         586,
         586,
         586,
         586,
         586,
         586,
         586,
         586,
         586,
         586,
         586,
         586,
         586,
         586,
         586,
         586,
         586,
         586,
         586,
         2104,
         586,
         586,
         586,
         586,
         586,
         586,
         586,
         586,
         586,
         586,
         586,
         586,
         586,
         2912,
         121,
         122,
         472,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         473,
         474,
         473,
         475,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         476,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         121,
         122,
         121,
         467,
         477,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         479,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         480,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         481,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         482,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         483,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         484,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         485,
         486,
         485,
         487,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         488,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         490,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         491,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         492,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         493,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         494,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         495,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         496,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         497,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         498,
         499,
         498,
         500,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         501,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         502,
         503,
         502,
         504,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         505,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         506,
         507,
         506,
         508,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         509,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         510,
         511,
         510,
         512,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         513,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         514,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         515,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         516,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         517,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         518,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         519,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         520,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         521,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         522,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         523,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         2072,
         2073,
         2072,
         2074,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2075,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2076,
         2077,
         2076,
         2078,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2079,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2080,
         2081,
         2080,
         2082,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2083,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2084,
         2085,
         2084,
         2086,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2087,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         123,
         124,
         123,
         469,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         470,
         123,
         123,
         471,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         121,
         122,
         472,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         473,
         474,
         473,
         475,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         476,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         121,
         122,
         121,
         467,
         477,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         479,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         480,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         481,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         482,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         483,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         484,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         485,
         486,
         485,
         487,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         488,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         490,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         491,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         492,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         493,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         494,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         495,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         496,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         497,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         498,
         499,
         498,
         500,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         501,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         502,
         503,
         502,
         504,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         505,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         506,
         507,
         506,
         508,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         509,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         510,
         511,
         510,
         512,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         513,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         514,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         515,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         516,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         517,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         518,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         519,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         520,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         521,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         522,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         523,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         2072,
         2073,
         2072,
         2074,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2075,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2076,
         2077,
         2076,
         2078,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2079,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2080,
         2081,
         2080,
         2082,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2083,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2084,
         2085,
         2084,
         2086,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2087,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         123,
         124,
         123,
         469,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         470,
         123,
         123,
         471,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         121,
         122,
         472,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         473,
         474,
         473,
         475,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         476,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         121,
         122,
         121,
         467,
         477,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         479,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         480,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         481,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         482,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         483,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         484,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         485,
         486,
         485,
         487,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         488,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         490,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         491,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         492,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         493,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         494,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         495,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         496,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         497,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         498,
         499,
         498,
         500,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         501,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         502,
         503,
         502,
         504,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         505,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         506,
         507,
         506,
         508,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         509,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         510,
         511,
         510,
         512,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         513,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         514,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         515,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         516,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         517,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         518,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         519,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         520,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         521,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         522,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         523,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         2072,
         2073,
         2072,
         2074,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2075,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2076,
         2077,
         2076,
         2078,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2079,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2080,
         2081,
         2080,
         2082,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2083,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2084,
         2085,
         2084,
         2086,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2087,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         123,
         124,
         123,
         469,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         470,
         123,
         123,
         471,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         121,
         122,
         472,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         473,
         474,
         473,
         475,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         476,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         121,
         122,
         121,
         467,
         477,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         479,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         480,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         481,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         482,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         483,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         484,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         485,
         486,
         485,
         487,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         488,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         490,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         491,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         492,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         493,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         494,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         495,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         496,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         497,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         498,
         499,
         498,
         500,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         501,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         502,
         503,
         502,
         504,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         505,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         506,
         507,
         506,
         508,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         509,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         510,
         511,
         510,
         512,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         513,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         514,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         515,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         516,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         517,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         518,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         519,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         520,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         521,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         522,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         523,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         2072,
         2073,
         2072,
         2074,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2075,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2076,
         2077,
         2076,
         2078,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2079,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2080,
         2081,
         2080,
         2082,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2083,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2084,
         2085,
         2084,
         2086,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2087,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         591,
         592,
         591,
         593,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         594,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         595,
         596,
         595,
         597,
         595,
         595,
         595,
         595,
         595,
         595,
         595,
         595,
         595,
         595,
         598,
         595,
         595,
         599,
         595,
         595,
         595,
         595,
         595,
         595,
         595,
         595,
         595,
         595,
         595,
         595,
         595,
         595,
         595,
         595,
         595,
         595,
         595,
         595,
         595,
         595,
         595,
         595,
         595,
         595,
         595,
         595,
         595,
         595,
         595,
         595,
         595,
         595,
         595,
         595,
         595,
         595,
         595,
         595,
         595,
         595,
         595,
         595,
         595,
         595,
         595,
         595,
         595,
         595,
         595,
         595,
         595,
         595,
         595,
         595,
         595,
         595,
         595,
         595,
         595,
         595,
         595,
         595,
         595,
         595,
         591,
         592,
         600,
         593,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         594,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         601,
         602,
         601,
         603,
         601,
         601,
         601,
         601,
         601,
         601,
         601,
         601,
         601,
         601,
         604,
         601,
         601,
         601,
         601,
         601,
         601,
         601,
         601,
         601,
         601,
         601,
         601,
         601,
         601,
         601,
         601,
         601,
         601,
         601,
         601,
         601,
         601,
         601,
         601,
         601,
         601,
         601,
         601,
         601,
         601,
         601,
         601,
         601,
         601,
         601,
         601,
         601,
         601,
         601,
         601,
         601,
         601,
         601,
         601,
         601,
         601,
         601,
         601,
         601,
         601,
         601,
         601,
         601,
         601,
         601,
         601,
         601,
         601,
         601,
         601,
         601,
         601,
         601,
         601,
         601,
         601,
         601,
         601,
         601,
         591,
         592,
         591,
         593,
         605,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         594,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         592,
         591,
         593,
         591,
         606,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         594,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         606,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         606,
         606,
         606,
         606,
         591,
         591,
         592,
         591,
         593,
         591,
         591,
         607,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         594,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         592,
         591,
         593,
         591,
         591,
         591,
         608,
         591,
         591,
         591,
         591,
         591,
         591,
         594,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         592,
         591,
         593,
         591,
         591,
         591,
         591,
         609,
         591,
         591,
         591,
         591,
         591,
         594,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         592,
         591,
         593,
         591,
         591,
         591,
         591,
         591,
         610,
         591,
         591,
         591,
         591,
         594,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         592,
         591,
         593,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         594,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         592,
         591,
         593,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         594,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         592,
         591,
         593,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         611,
         591,
         594,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         592,
         591,
         593,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         612,
         594,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         613,
         614,
         613,
         615,
         613,
         613,
         613,
         613,
         613,
         613,
         613,
         613,
         613,
         613,
         616,
         613,
         613,
         613,
         613,
         613,
         613,
         613,
         613,
         613,
         613,
         613,
         613,
         613,
         613,
         613,
         613,
         613,
         613,
         613,
         613,
         613,
         613,
         613,
         613,
         613,
         613,
         613,
         613,
         613,
         613,
         613,
         613,
         613,
         613,
         613,
         613,
         613,
         613,
         613,
         613,
         613,
         613,
         613,
         613,
         613,
         613,
         613,
         613,
         613,
         613,
         613,
         613,
         613,
         613,
         613,
         613,
         613,
         613,
         613,
         613,
         613,
         613,
         613,
         613,
         613,
         613,
         613,
         613,
         613,
         591,
         592,
         591,
         593,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         594,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         592,
         591,
         593,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         594,
         591,
         617,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         617,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         618,
         591,
         593,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         594,
         591,
         591,
         619,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         592,
         591,
         593,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         594,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         592,
         591,
         593,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         594,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         592,
         591,
         593,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         594,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         592,
         591,
         593,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         594,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         592,
         591,
         593,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         594,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         592,
         591,
         593,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         594,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         592,
         591,
         593,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         594,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         592,
         591,
         593,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         594,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         592,
         591,
         593,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         594,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         592,
         591,
         593,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         594,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         592,
         591,
         593,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         594,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         620,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         592,
         591,
         593,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         594,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         621,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         592,
         591,
         593,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         594,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         622,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         592,
         591,
         593,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         594,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         623,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         592,
         591,
         593,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         594,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         624,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         592,
         591,
         593,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         594,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         625,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         626,
         627,
         626,
         628,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         629,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         626,
         630,
         631,
         630,
         632,
         630,
         630,
         630,
         630,
         630,
         630,
         630,
         630,
         630,
         630,
         633,
         630,
         630,
         630,
         630,
         630,
         630,
         630,
         630,
         630,
         630,
         630,
         630,
         630,
         630,
         630,
         630,
         630,
         630,
         630,
         630,
         630,
         630,
         630,
         630,
         630,
         630,
         630,
         630,
         630,
         630,
         630,
         630,
         630,
         630,
         630,
         630,
         630,
         630,
         630,
         630,
         630,
         630,
         630,
         630,
         630,
         630,
         630,
         630,
         630,
         630,
         630,
         630,
         630,
         630,
         630,
         630,
         630,
         630,
         630,
         630,
         630,
         630,
         630,
         630,
         630,
         630,
         630,
         630,
         630,
         634,
         635,
         634,
         636,
         634,
         634,
         634,
         634,
         634,
         634,
         634,
         634,
         634,
         634,
         637,
         634,
         634,
         634,
         634,
         634,
         634,
         634,
         634,
         634,
         634,
         634,
         634,
         634,
         634,
         634,
         634,
         634,
         634,
         634,
         634,
         634,
         634,
         634,
         634,
         634,
         634,
         634,
         634,
         634,
         634,
         634,
         634,
         634,
         634,
         634,
         634,
         634,
         634,
         634,
         634,
         634,
         634,
         634,
         634,
         634,
         634,
         634,
         634,
         634,
         634,
         634,
         634,
         634,
         634,
         634,
         634,
         634,
         634,
         634,
         634,
         634,
         634,
         634,
         634,
         634,
         634,
         634,
         634,
         634,
         638,
         639,
         638,
         640,
         638,
         638,
         638,
         638,
         638,
         638,
         638,
         638,
         638,
         638,
         641,
         638,
         638,
         638,
         638,
         638,
         638,
         638,
         638,
         638,
         638,
         638,
         638,
         638,
         638,
         638,
         638,
         638,
         638,
         638,
         638,
         638,
         638,
         638,
         638,
         638,
         638,
         638,
         638,
         638,
         638,
         638,
         638,
         638,
         638,
         638,
         638,
         638,
         638,
         638,
         638,
         638,
         638,
         638,
         638,
         638,
         638,
         638,
         638,
         638,
         638,
         638,
         638,
         638,
         638,
         638,
         638,
         638,
         638,
         638,
         638,
         638,
         638,
         638,
         638,
         638,
         638,
         638,
         638,
         638,
         591,
         592,
         591,
         593,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         594,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         642,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         592,
         591,
         593,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         594,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         643,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         592,
         591,
         593,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         594,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         644,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         592,
         591,
         593,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         594,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         645,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         592,
         591,
         593,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         594,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         646,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         592,
         591,
         593,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         594,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         647,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         592,
         591,
         593,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         594,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         648,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         592,
         591,
         593,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         594,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         649,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         592,
         591,
         593,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         594,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         592,
         591,
         593,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         594,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         592,
         591,
         593,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         594,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         592,
         591,
         593,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         594,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         592,
         591,
         593,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         594,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         592,
         591,
         593,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         594,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         650,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         592,
         591,
         593,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         594,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         651,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         592,
         591,
         593,
         591,
         606,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         594,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         606,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         606,
         606,
         606,
         606,
         591,
         591,
         592,
         591,
         593,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         594,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         592,
         591,
         593,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         594,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         592,
         591,
         593,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         594,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         592,
         591,
         593,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         594,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         592,
         591,
         593,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         594,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         592,
         591,
         593,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         594,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         592,
         591,
         593,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         594,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         592,
         591,
         593,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         594,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         592,
         591,
         593,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         594,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         592,
         591,
         593,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         594,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         592,
         591,
         593,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         594,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         592,
         591,
         593,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         594,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         592,
         591,
         593,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         594,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         592,
         591,
         593,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         594,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         592,
         591,
         593,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         594,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         592,
         591,
         593,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         594,
         591,
         617,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         617,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         2105,
         2106,
         2105,
         2107,
         2105,
         2105,
         2105,
         2105,
         2105,
         2105,
         2105,
         2105,
         2105,
         2105,
         2108,
         2105,
         2105,
         2105,
         2105,
         2105,
         2105,
         2105,
         2105,
         2105,
         2105,
         2105,
         2105,
         2105,
         2105,
         2105,
         2105,
         2105,
         2105,
         2105,
         2105,
         2105,
         2105,
         2105,
         2105,
         2105,
         2105,
         2105,
         2105,
         2105,
         2105,
         2105,
         2105,
         2105,
         2105,
         2105,
         2105,
         2105,
         2105,
         2105,
         2105,
         2105,
         2105,
         2105,
         2105,
         2105,
         2105,
         2105,
         2105,
         2105,
         2105,
         2105,
         2105,
         2105,
         2105,
         2105,
         2105,
         2105,
         2105,
         2105,
         2105,
         2105,
         2105,
         2105,
         2105,
         2105,
         2105,
         2105,
         2105,
         2105,
         2109,
         2110,
         2109,
         2111,
         2109,
         2109,
         2109,
         2109,
         2109,
         2109,
         2109,
         2109,
         2109,
         2109,
         2112,
         2109,
         2109,
         2109,
         2109,
         2109,
         2109,
         2109,
         2109,
         2109,
         2109,
         2109,
         2109,
         2109,
         2109,
         2109,
         2109,
         2109,
         2109,
         2109,
         2109,
         2109,
         2109,
         2109,
         2109,
         2109,
         2109,
         2109,
         2109,
         2109,
         2109,
         2109,
         2109,
         2109,
         2109,
         2109,
         2109,
         2109,
         2109,
         2109,
         2109,
         2109,
         2109,
         2109,
         2109,
         2109,
         2109,
         2109,
         2109,
         2109,
         2109,
         2109,
         2109,
         2109,
         2109,
         2109,
         2109,
         2109,
         2109,
         2109,
         2109,
         2109,
         2109,
         2109,
         2109,
         2109,
         2109,
         2109,
         2109,
         2109,
         2113,
         2114,
         2113,
         2115,
         2113,
         2113,
         2113,
         2113,
         2113,
         2113,
         2113,
         2113,
         2113,
         2113,
         2116,
         2113,
         2113,
         2113,
         2113,
         2113,
         2113,
         2113,
         2113,
         2113,
         2113,
         2113,
         2113,
         2113,
         2113,
         2113,
         2113,
         2113,
         2113,
         2113,
         2113,
         2113,
         2113,
         2113,
         2113,
         2113,
         2113,
         2113,
         2113,
         2113,
         2113,
         2113,
         2113,
         2113,
         2113,
         2113,
         2113,
         2113,
         2113,
         2113,
         2113,
         2113,
         2113,
         2113,
         2113,
         2113,
         2113,
         2113,
         2113,
         2113,
         2113,
         2113,
         2113,
         2113,
         2113,
         2113,
         2113,
         2113,
         2113,
         2113,
         2113,
         2113,
         2113,
         2113,
         2113,
         2113,
         2113,
         2113,
         2113,
         2113,
         2117,
         2118,
         2117,
         2119,
         2117,
         2117,
         2117,
         2117,
         2117,
         2117,
         2117,
         2117,
         2117,
         2117,
         2120,
         2117,
         2117,
         2117,
         2117,
         2117,
         2117,
         2117,
         2117,
         2117,
         2117,
         2117,
         2117,
         2117,
         2117,
         2117,
         2117,
         2117,
         2117,
         2117,
         2117,
         2117,
         2117,
         2117,
         2117,
         2117,
         2117,
         2117,
         2117,
         2117,
         2117,
         2117,
         2117,
         2117,
         2117,
         2117,
         2117,
         2117,
         2117,
         2117,
         2117,
         2117,
         2117,
         2117,
         2117,
         2117,
         2117,
         2117,
         2117,
         2117,
         2117,
         2117,
         2117,
         2117,
         2117,
         2117,
         2117,
         2117,
         2117,
         2117,
         2117,
         2117,
         2117,
         2117,
         2117,
         2117,
         2117,
         2117,
         2117,
         2117,
         591,
         592,
         591,
         593,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         594,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         592,
         591,
         593,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         594,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         592,
         591,
         593,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         594,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         592,
         591,
         593,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         594,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         592,
         591,
         593,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         594,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         592,
         591,
         593,
         591,
         606,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         594,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         606,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         606,
         606,
         606,
         606,
         591,
         591,
         592,
         591,
         593,
         591,
         606,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         594,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         606,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         606,
         606,
         606,
         606,
         591,
         591,
         592,
         591,
         593,
         591,
         606,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         594,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         606,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         606,
         606,
         606,
         606,
         591,
         591,
         592,
         591,
         593,
         591,
         606,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         594,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         606,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         606,
         606,
         606,
         606,
         591,
         591,
         592,
         591,
         593,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         594,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         591,
         652,
         653,
         652,
         654,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         656,
         657,
         656,
         658,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         659,
         656,
         656,
         660,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         652,
         653,
         661,
         654,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         662,
         663,
         662,
         664,
         662,
         662,
         662,
         662,
         662,
         662,
         662,
         662,
         662,
         662,
         665,
         662,
         662,
         662,
         662,
         662,
         662,
         662,
         662,
         662,
         662,
         662,
         662,
         662,
         662,
         662,
         662,
         662,
         662,
         662,
         662,
         662,
         662,
         662,
         662,
         662,
         662,
         662,
         662,
         662,
         662,
         662,
         662,
         662,
         662,
         662,
         662,
         662,
         662,
         662,
         662,
         662,
         662,
         662,
         662,
         662,
         662,
         662,
         662,
         662,
         662,
         662,
         662,
         662,
         662,
         662,
         662,
         662,
         662,
         662,
         662,
         662,
         662,
         662,
         662,
         662,
         662,
         662,
         662,
         662,
         652,
         653,
         652,
         654,
         666,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         653,
         652,
         654,
         652,
         667,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         667,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         667,
         667,
         667,
         667,
         652,
         652,
         653,
         652,
         654,
         652,
         652,
         668,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         653,
         652,
         654,
         652,
         652,
         652,
         669,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         653,
         652,
         654,
         652,
         652,
         652,
         652,
         670,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         653,
         652,
         654,
         652,
         652,
         652,
         652,
         652,
         671,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         653,
         652,
         654,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         653,
         652,
         654,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         653,
         652,
         654,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         672,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         653,
         652,
         654,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         673,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         674,
         675,
         674,
         676,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         677,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         652,
         653,
         652,
         654,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         653,
         652,
         654,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         678,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         678,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         679,
         652,
         654,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         680,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         653,
         652,
         654,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         653,
         652,
         654,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         653,
         652,
         654,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         653,
         652,
         654,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         653,
         652,
         654,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         653,
         652,
         654,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         653,
         652,
         654,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         653,
         652,
         654,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         653,
         652,
         654,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         653,
         652,
         654,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         653,
         652,
         654,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         681,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         653,
         652,
         654,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         682,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         653,
         652,
         654,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         683,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         653,
         652,
         654,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         684,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         653,
         652,
         654,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         685,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         653,
         652,
         654,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         686,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         687,
         688,
         687,
         689,
         687,
         687,
         687,
         687,
         687,
         687,
         687,
         687,
         687,
         687,
         690,
         687,
         687,
         687,
         687,
         687,
         687,
         687,
         687,
         687,
         687,
         687,
         687,
         687,
         687,
         687,
         687,
         687,
         687,
         687,
         687,
         687,
         687,
         687,
         687,
         687,
         687,
         687,
         687,
         687,
         687,
         687,
         687,
         687,
         687,
         687,
         687,
         687,
         687,
         687,
         687,
         687,
         687,
         687,
         687,
         687,
         687,
         687,
         687,
         687,
         687,
         687,
         687,
         687,
         687,
         687,
         687,
         687,
         687,
         687,
         687,
         687,
         687,
         687,
         687,
         687,
         687,
         687,
         687,
         687,
         691,
         692,
         691,
         693,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         694,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         695,
         696,
         695,
         697,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         698,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         699,
         700,
         699,
         701,
         699,
         699,
         699,
         699,
         699,
         699,
         699,
         699,
         699,
         699,
         702,
         699,
         699,
         699,
         699,
         699,
         699,
         699,
         699,
         699,
         699,
         699,
         699,
         699,
         699,
         699,
         699,
         699,
         699,
         699,
         699,
         699,
         699,
         699,
         699,
         699,
         699,
         699,
         699,
         699,
         699,
         699,
         699,
         699,
         699,
         699,
         699,
         699,
         699,
         699,
         699,
         699,
         699,
         699,
         699,
         699,
         699,
         699,
         699,
         699,
         699,
         699,
         699,
         699,
         699,
         699,
         699,
         699,
         699,
         699,
         699,
         699,
         699,
         699,
         699,
         699,
         699,
         699,
         699,
         699,
         652,
         653,
         652,
         654,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         703,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         653,
         652,
         654,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         704,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         653,
         652,
         654,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         705,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         653,
         652,
         654,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         706,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         653,
         652,
         654,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         707,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         653,
         652,
         654,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         708,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         653,
         652,
         654,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         709,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         653,
         652,
         654,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         710,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         653,
         652,
         654,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         653,
         652,
         654,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         653,
         652,
         654,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         653,
         652,
         654,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         653,
         652,
         654,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         653,
         652,
         654,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         711,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         653,
         652,
         654,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         712,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         653,
         652,
         654,
         652,
         667,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         667,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         667,
         667,
         667,
         667,
         652,
         652,
         653,
         652,
         654,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         653,
         652,
         654,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         653,
         652,
         654,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         653,
         652,
         654,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         653,
         652,
         654,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         653,
         652,
         654,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         653,
         652,
         654,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         653,
         652,
         654,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         653,
         652,
         654,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         653,
         652,
         654,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         653,
         652,
         654,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         653,
         652,
         654,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         653,
         652,
         654,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         653,
         652,
         654,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         653,
         652,
         654,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         653,
         652,
         654,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         678,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         678,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         2121,
         2122,
         2121,
         2123,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2124,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2125,
         2126,
         2125,
         2127,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2128,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2129,
         2130,
         2129,
         2131,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2132,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2133,
         2134,
         2133,
         2135,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2136,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         652,
         653,
         652,
         654,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         653,
         652,
         654,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         653,
         652,
         654,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         653,
         652,
         654,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         653,
         652,
         654,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         653,
         652,
         654,
         652,
         667,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         667,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         667,
         667,
         667,
         667,
         652,
         652,
         653,
         652,
         654,
         652,
         667,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         667,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         667,
         667,
         667,
         667,
         652,
         652,
         653,
         652,
         654,
         652,
         667,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         667,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         667,
         667,
         667,
         667,
         652,
         652,
         653,
         652,
         654,
         652,
         667,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         667,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         667,
         667,
         667,
         667,
         652,
         652,
         653,
         652,
         654,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         653,
         652,
         654,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         656,
         657,
         656,
         658,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         659,
         656,
         656,
         660,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         713,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         656,
         652,
         653,
         661,
         654,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         714,
         715,
         714,
         716,
         714,
         714,
         714,
         714,
         714,
         714,
         714,
         714,
         714,
         714,
         717,
         714,
         714,
         714,
         714,
         714,
         714,
         714,
         714,
         714,
         714,
         714,
         714,
         714,
         714,
         714,
         714,
         714,
         714,
         714,
         714,
         714,
         714,
         714,
         714,
         714,
         714,
         714,
         714,
         714,
         714,
         714,
         714,
         714,
         714,
         714,
         714,
         714,
         714,
         714,
         714,
         714,
         714,
         714,
         714,
         714,
         714,
         714,
         714,
         714,
         714,
         714,
         714,
         714,
         714,
         714,
         714,
         714,
         714,
         714,
         714,
         714,
         714,
         714,
         714,
         714,
         714,
         714,
         714,
         714,
         652,
         653,
         652,
         654,
         666,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         653,
         652,
         654,
         652,
         667,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         667,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         667,
         667,
         667,
         667,
         652,
         652,
         653,
         652,
         654,
         652,
         652,
         668,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         653,
         652,
         654,
         652,
         652,
         652,
         669,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         653,
         652,
         654,
         652,
         652,
         652,
         652,
         670,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         653,
         652,
         654,
         652,
         652,
         652,
         652,
         652,
         671,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         653,
         652,
         654,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         653,
         652,
         654,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         653,
         652,
         654,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         672,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         653,
         652,
         654,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         673,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         674,
         675,
         674,
         676,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         677,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         674,
         652,
         653,
         652,
         654,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         653,
         652,
         654,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         678,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         678,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         679,
         652,
         654,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         680,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         653,
         652,
         654,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         653,
         652,
         654,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         653,
         652,
         654,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         653,
         652,
         654,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         653,
         652,
         654,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         653,
         652,
         654,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         653,
         652,
         654,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         653,
         652,
         654,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         653,
         652,
         654,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         653,
         652,
         654,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         653,
         652,
         654,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         681,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         653,
         652,
         654,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         682,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         653,
         652,
         654,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         683,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         653,
         652,
         654,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         684,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         653,
         652,
         654,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         685,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         653,
         652,
         654,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         686,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         687,
         688,
         687,
         689,
         687,
         687,
         687,
         687,
         687,
         687,
         687,
         687,
         687,
         687,
         690,
         687,
         687,
         687,
         687,
         687,
         687,
         687,
         687,
         687,
         687,
         687,
         687,
         687,
         687,
         687,
         687,
         687,
         687,
         687,
         687,
         687,
         687,
         687,
         687,
         687,
         687,
         687,
         687,
         687,
         687,
         687,
         687,
         687,
         687,
         687,
         687,
         687,
         687,
         687,
         687,
         687,
         687,
         687,
         687,
         687,
         687,
         687,
         687,
         687,
         687,
         687,
         687,
         687,
         687,
         687,
         687,
         687,
         687,
         687,
         687,
         687,
         687,
         687,
         687,
         687,
         687,
         687,
         687,
         687,
         691,
         692,
         691,
         693,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         694,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         691,
         695,
         696,
         695,
         697,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         698,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         695,
         699,
         700,
         699,
         701,
         699,
         699,
         699,
         699,
         699,
         699,
         699,
         699,
         699,
         699,
         702,
         699,
         699,
         699,
         699,
         699,
         699,
         699,
         699,
         699,
         699,
         699,
         699,
         699,
         699,
         699,
         699,
         699,
         699,
         699,
         699,
         699,
         699,
         699,
         699,
         699,
         699,
         699,
         699,
         699,
         699,
         699,
         699,
         699,
         699,
         699,
         699,
         699,
         699,
         699,
         699,
         699,
         699,
         699,
         699,
         699,
         699,
         699,
         699,
         699,
         699,
         699,
         699,
         699,
         699,
         699,
         699,
         699,
         699,
         699,
         699,
         699,
         699,
         699,
         699,
         699,
         699,
         699,
         699,
         699,
         652,
         653,
         652,
         654,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         703,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         653,
         652,
         654,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         704,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         653,
         652,
         654,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         705,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         653,
         652,
         654,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         706,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         653,
         652,
         654,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         707,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         653,
         652,
         654,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         708,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         653,
         652,
         654,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         709,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         653,
         652,
         654,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         710,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         653,
         652,
         654,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         653,
         652,
         654,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         653,
         652,
         654,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         653,
         652,
         654,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         653,
         652,
         654,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         653,
         652,
         654,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         711,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         653,
         652,
         654,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         712,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         653,
         652,
         654,
         652,
         667,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         667,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         667,
         667,
         667,
         667,
         652,
         652,
         653,
         652,
         654,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         653,
         652,
         654,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         653,
         652,
         654,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         653,
         652,
         654,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         653,
         652,
         654,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         653,
         652,
         654,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         653,
         652,
         654,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         653,
         652,
         654,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         653,
         652,
         654,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         653,
         652,
         654,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         653,
         652,
         654,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         653,
         652,
         654,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         653,
         652,
         654,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         653,
         652,
         654,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         653,
         652,
         654,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         653,
         652,
         654,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         678,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         678,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         2121,
         2122,
         2121,
         2123,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2124,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2121,
         2125,
         2126,
         2125,
         2127,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2128,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2125,
         2129,
         2130,
         2129,
         2131,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2132,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2129,
         2133,
         2134,
         2133,
         2135,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2136,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         2133,
         652,
         653,
         652,
         654,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         653,
         652,
         654,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         653,
         652,
         654,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         653,
         652,
         654,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         653,
         652,
         654,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         653,
         652,
         654,
         652,
         667,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         667,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         667,
         667,
         667,
         667,
         652,
         652,
         653,
         652,
         654,
         652,
         667,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         667,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         667,
         667,
         667,
         667,
         652,
         652,
         653,
         652,
         654,
         652,
         667,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         667,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         667,
         667,
         667,
         667,
         652,
         652,
         653,
         652,
         654,
         652,
         667,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         667,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         667,
         667,
         667,
         667,
         652,
         652,
         653,
         652,
         654,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         655,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         652,
         718,
         719,
         718,
         720,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         721,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         722,
         723,
         722,
         724,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         725,
         722,
         722,
         726,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         722,
         718,
         719,
         727,
         720,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         721,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         728,
         729,
         728,
         730,
         728,
         728,
         728,
         728,
         728,
         728,
         728,
         728,
         728,
         728,
         731,
         728,
         728,
         728,
         728,
         728,
         728,
         728,
         728,
         728,
         728,
         728,
         728,
         728,
         728,
         728,
         728,
         728,
         728,
         728,
         728,
         728,
         728,
         728,
         728,
         728,
         728,
         728,
         728,
         728,
         728,
         728,
         728,
         728,
         728,
         728,
         728,
         728,
         728,
         728,
         728,
         728,
         728,
         728,
         728,
         728,
         728,
         728,
         728,
         728,
         728,
         728,
         728,
         728,
         728,
         728,
         728,
         728,
         728,
         728,
         728,
         728,
         728,
         728,
         728,
         728,
         728,
         728,
         728,
         728,
         718,
         719,
         718,
         720,
         732,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         721,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         719,
         718,
         720,
         718,
         733,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         721,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         733,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         733,
         733,
         733,
         733,
         718,
         718,
         719,
         718,
         720,
         718,
         718,
         734,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         721,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         719,
         718,
         720,
         718,
         718,
         718,
         735,
         718,
         718,
         718,
         718,
         718,
         718,
         721,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         719,
         718,
         720,
         718,
         718,
         718,
         718,
         736,
         718,
         718,
         718,
         718,
         718,
         721,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         719,
         718,
         720,
         718,
         718,
         718,
         718,
         718,
         737,
         718,
         718,
         718,
         718,
         721,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         719,
         718,
         720,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         721,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         719,
         718,
         720,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         721,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         719,
         718,
         720,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         738,
         718,
         721,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         719,
         718,
         720,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         739,
         721,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         740,
         741,
         740,
         742,
         740,
         740,
         740,
         740,
         740,
         740,
         740,
         740,
         740,
         740,
         743,
         740,
         740,
         740,
         740,
         740,
         740,
         740,
         740,
         740,
         740,
         740,
         740,
         740,
         740,
         740,
         740,
         740,
         740,
         740,
         740,
         740,
         740,
         740,
         740,
         740,
         740,
         740,
         740,
         740,
         740,
         740,
         740,
         740,
         740,
         740,
         740,
         740,
         740,
         740,
         740,
         740,
         740,
         740,
         740,
         740,
         740,
         740,
         740,
         740,
         740,
         740,
         740,
         740,
         740,
         740,
         740,
         740,
         740,
         740,
         740,
         740,
         740,
         740,
         740,
         740,
         740,
         740,
         740,
         740,
         718,
         719,
         718,
         720,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         721,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         719,
         718,
         720,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         721,
         718,
         744,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         744,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         745,
         718,
         720,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         721,
         718,
         718,
         746,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         719,
         718,
         720,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         721,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         719,
         718,
         720,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         721,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         719,
         718,
         720,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         721,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         719,
         718,
         720,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         721,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         719,
         718,
         720,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         721,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         719,
         718,
         720,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         721,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         719,
         718,
         720,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         721,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         719,
         718,
         720,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         721,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         719,
         718,
         720,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         721,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         719,
         718,
         720,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         721,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         719,
         718,
         720,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         721,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         747,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         719,
         718,
         720,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         721,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         748,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         719,
         718,
         720,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         721,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         749,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         719,
         718,
         720,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         721,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         750,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         719,
         718,
         720,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         721,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         751,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         719,
         718,
         720,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         721,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         752,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         753,
         754,
         753,
         755,
         753,
         753,
         753,
         753,
         753,
         753,
         753,
         753,
         753,
         753,
         756,
         753,
         753,
         753,
         753,
         753,
         753,
         753,
         753,
         753,
         753,
         753,
         753,
         753,
         753,
         753,
         753,
         753,
         753,
         753,
         753,
         753,
         753,
         753,
         753,
         753,
         753,
         753,
         753,
         753,
         753,
         753,
         753,
         753,
         753,
         753,
         753,
         753,
         753,
         753,
         753,
         753,
         753,
         753,
         753,
         753,
         753,
         753,
         753,
         753,
         753,
         753,
         753,
         753,
         753,
         753,
         753,
         753,
         753,
         753,
         753,
         753,
         753,
         753,
         753,
         753,
         753,
         753,
         753,
         753,
         757,
         758,
         757,
         759,
         757,
         757,
         757,
         757,
         757,
         757,
         757,
         757,
         757,
         757,
         760,
         757,
         757,
         757,
         757,
         757,
         757,
         757,
         757,
         757,
         757,
         757,
         757,
         757,
         757,
         757,
         757,
         757,
         757,
         757,
         757,
         757,
         757,
         757,
         757,
         757,
         757,
         757,
         757,
         757,
         757,
         757,
         757,
         757,
         757,
         757,
         757,
         757,
         757,
         757,
         757,
         757,
         757,
         757,
         757,
         757,
         757,
         757,
         757,
         757,
         757,
         757,
         757,
         757,
         757,
         757,
         757,
         757,
         757,
         757,
         757,
         757,
         757,
         757,
         757,
         757,
         757,
         757,
         757,
         757,
         761,
         762,
         761,
         763,
         761,
         761,
         761,
         761,
         761,
         761,
         761,
         761,
         761,
         761,
         764,
         761,
         761,
         761,
         761,
         761,
         761,
         761,
         761,
         761,
         761,
         761,
         761,
         761,
         761,
         761,
         761,
         761,
         761,
         761,
         761,
         761,
         761,
         761,
         761,
         761,
         761,
         761,
         761,
         761,
         761,
         761,
         761,
         761,
         761,
         761,
         761,
         761,
         761,
         761,
         761,
         761,
         761,
         761,
         761,
         761,
         761,
         761,
         761,
         761,
         761,
         761,
         761,
         761,
         761,
         761,
         761,
         761,
         761,
         761,
         761,
         761,
         761,
         761,
         761,
         761,
         761,
         761,
         761,
         761,
         765,
         766,
         765,
         767,
         765,
         765,
         765,
         765,
         765,
         765,
         765,
         765,
         765,
         765,
         768,
         765,
         765,
         765,
         765,
         765,
         765,
         765,
         765,
         765,
         765,
         765,
         765,
         765,
         765,
         765,
         765,
         765,
         765,
         765,
         765,
         765,
         765,
         765,
         765,
         765,
         765,
         765,
         765,
         765,
         765,
         765,
         765,
         765,
         765,
         765,
         765,
         765,
         765,
         765,
         765,
         765,
         765,
         765,
         765,
         765,
         765,
         765,
         765,
         765,
         765,
         765,
         765,
         765,
         765,
         765,
         765,
         765,
         765,
         765,
         765,
         765,
         765,
         765,
         765,
         765,
         765,
         765,
         765,
         765,
         718,
         719,
         718,
         720,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         721,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         769,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         719,
         718,
         720,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         721,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         770,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         719,
         718,
         720,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         721,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         771,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         719,
         718,
         720,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         721,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         772,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         719,
         718,
         720,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         721,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         773,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         719,
         718,
         720,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         721,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         774,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         719,
         718,
         720,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         721,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         775,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         719,
         718,
         720,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         721,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         776,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         719,
         718,
         720,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         721,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         719,
         718,
         720,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         721,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         719,
         718,
         720,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         721,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         719,
         718,
         720,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         721,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         719,
         718,
         720,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         721,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         719,
         718,
         720,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         721,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         777,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         719,
         718,
         720,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         721,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         778,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         719,
         718,
         720,
         718,
         733,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         721,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         733,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         733,
         733,
         733,
         733,
         718,
         718,
         719,
         718,
         720,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         721,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         719,
         718,
         720,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         721,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         719,
         718,
         720,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         721,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         719,
         718,
         720,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         721,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         719,
         718,
         720,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         721,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         719,
         718,
         720,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         721,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         719,
         718,
         720,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         721,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         719,
         718,
         720,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         721,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         719,
         718,
         720,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         721,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         719,
         718,
         720,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         721,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         719,
         718,
         720,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         721,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         719,
         718,
         720,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         721,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         719,
         718,
         720,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         721,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         719,
         718,
         720,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         721,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         719,
         718,
         720,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         721,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         719,
         718,
         720,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         721,
         718,
         744,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         744,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         2137,
         2138,
         2137,
         2139,
         2137,
         2137,
         2137,
         2137,
         2137,
         2137,
         2137,
         2137,
         2137,
         2137,
         2140,
         2137,
         2137,
         2137,
         2137,
         2137,
         2137,
         2137,
         2137,
         2137,
         2137,
         2137,
         2137,
         2137,
         2137,
         2137,
         2137,
         2137,
         2137,
         2137,
         2137,
         2137,
         2137,
         2137,
         2137,
         2137,
         2137,
         2137,
         2137,
         2137,
         2137,
         2137,
         2137,
         2137,
         2137,
         2137,
         2137,
         2137,
         2137,
         2137,
         2137,
         2137,
         2137,
         2137,
         2137,
         2137,
         2137,
         2137,
         2137,
         2137,
         2137,
         2137,
         2137,
         2137,
         2137,
         2137,
         2137,
         2137,
         2137,
         2137,
         2137,
         2137,
         2137,
         2137,
         2137,
         2137,
         2137,
         2137,
         2137,
         2137,
         2141,
         2142,
         2141,
         2143,
         2141,
         2141,
         2141,
         2141,
         2141,
         2141,
         2141,
         2141,
         2141,
         2141,
         2144,
         2141,
         2141,
         2141,
         2141,
         2141,
         2141,
         2141,
         2141,
         2141,
         2141,
         2141,
         2141,
         2141,
         2141,
         2141,
         2141,
         2141,
         2141,
         2141,
         2141,
         2141,
         2141,
         2141,
         2141,
         2141,
         2141,
         2141,
         2141,
         2141,
         2141,
         2141,
         2141,
         2141,
         2141,
         2141,
         2141,
         2141,
         2141,
         2141,
         2141,
         2141,
         2141,
         2141,
         2141,
         2141,
         2141,
         2141,
         2141,
         2141,
         2141,
         2141,
         2141,
         2141,
         2141,
         2141,
         2141,
         2141,
         2141,
         2141,
         2141,
         2141,
         2141,
         2141,
         2141,
         2141,
         2141,
         2141,
         2141,
         2141,
         2145,
         2146,
         2145,
         2147,
         2145,
         2145,
         2145,
         2145,
         2145,
         2145,
         2145,
         2145,
         2145,
         2145,
         2148,
         2145,
         2145,
         2145,
         2145,
         2145,
         2145,
         2145,
         2145,
         2145,
         2145,
         2145,
         2145,
         2145,
         2145,
         2145,
         2145,
         2145,
         2145,
         2145,
         2145,
         2145,
         2145,
         2145,
         2145,
         2145,
         2145,
         2145,
         2145,
         2145,
         2145,
         2145,
         2145,
         2145,
         2145,
         2145,
         2145,
         2145,
         2145,
         2145,
         2145,
         2145,
         2145,
         2145,
         2145,
         2145,
         2145,
         2145,
         2145,
         2145,
         2145,
         2145,
         2145,
         2145,
         2145,
         2145,
         2145,
         2145,
         2145,
         2145,
         2145,
         2145,
         2145,
         2145,
         2145,
         2145,
         2145,
         2145,
         2145,
         2145,
         2149,
         2150,
         2149,
         2151,
         2149,
         2149,
         2149,
         2149,
         2149,
         2149,
         2149,
         2149,
         2149,
         2149,
         2152,
         2149,
         2149,
         2149,
         2149,
         2149,
         2149,
         2149,
         2149,
         2149,
         2149,
         2149,
         2149,
         2149,
         2149,
         2149,
         2149,
         2149,
         2149,
         2149,
         2149,
         2149,
         2149,
         2149,
         2149,
         2149,
         2149,
         2149,
         2149,
         2149,
         2149,
         2149,
         2149,
         2149,
         2149,
         2149,
         2149,
         2149,
         2149,
         2149,
         2149,
         2149,
         2149,
         2149,
         2149,
         2149,
         2149,
         2149,
         2149,
         2149,
         2149,
         2149,
         2149,
         2149,
         2149,
         2149,
         2149,
         2149,
         2149,
         2149,
         2149,
         2149,
         2149,
         2149,
         2149,
         2149,
         2149,
         2149,
         2149,
         2149,
         718,
         719,
         718,
         720,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         721,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         719,
         718,
         720,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         721,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         719,
         718,
         720,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         721,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         719,
         718,
         720,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         721,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         719,
         718,
         720,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         721,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         719,
         718,
         720,
         718,
         733,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         721,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         733,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         733,
         733,
         733,
         733,
         718,
         718,
         719,
         718,
         720,
         718,
         733,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         721,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         733,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         733,
         733,
         733,
         733,
         718,
         718,
         719,
         718,
         720,
         718,
         733,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         721,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         733,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         733,
         733,
         733,
         733,
         718,
         718,
         719,
         718,
         720,
         718,
         733,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         721,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         733,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         733,
         733,
         733,
         733,
         718,
         718,
         719,
         718,
         720,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         721,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         718,
         779,
         780,
         779,
         781,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         783,
         784,
         783,
         785,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         786,
         783,
         783,
         787,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         779,
         780,
         788,
         781,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         789,
         790,
         789,
         791,
         789,
         789,
         789,
         789,
         789,
         789,
         789,
         789,
         789,
         789,
         792,
         789,
         789,
         789,
         789,
         789,
         789,
         789,
         789,
         789,
         789,
         789,
         789,
         789,
         789,
         789,
         789,
         789,
         789,
         789,
         789,
         789,
         789,
         789,
         789,
         789,
         789,
         789,
         789,
         789,
         789,
         789,
         789,
         789,
         789,
         789,
         789,
         789,
         789,
         789,
         789,
         789,
         789,
         789,
         789,
         789,
         789,
         789,
         789,
         789,
         789,
         789,
         789,
         789,
         789,
         789,
         789,
         789,
         789,
         789,
         789,
         789,
         789,
         789,
         789,
         789,
         789,
         789,
         789,
         789,
         779,
         780,
         779,
         781,
         793,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         780,
         779,
         781,
         779,
         794,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         794,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         794,
         794,
         794,
         794,
         779,
         779,
         780,
         779,
         781,
         779,
         779,
         795,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         780,
         779,
         781,
         779,
         779,
         779,
         796,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         780,
         779,
         781,
         779,
         779,
         779,
         779,
         797,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         780,
         779,
         781,
         779,
         779,
         779,
         779,
         779,
         798,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         780,
         779,
         781,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         780,
         779,
         781,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         780,
         779,
         781,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         799,
         779,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         780,
         779,
         781,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         800,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         801,
         802,
         801,
         803,
         801,
         801,
         801,
         801,
         801,
         801,
         801,
         801,
         801,
         801,
         804,
         801,
         801,
         801,
         801,
         801,
         801,
         801,
         801,
         801,
         801,
         801,
         801,
         801,
         801,
         801,
         801,
         801,
         801,
         801,
         801,
         801,
         801,
         801,
         801,
         801,
         801,
         801,
         801,
         801,
         801,
         801,
         801,
         801,
         801,
         801,
         801,
         801,
         801,
         801,
         801,
         801,
         801,
         801,
         801,
         801,
         801,
         801,
         801,
         801,
         801,
         801,
         801,
         801,
         801,
         801,
         801,
         801,
         801,
         801,
         801,
         801,
         801,
         801,
         801,
         801,
         801,
         801,
         801,
         801,
         779,
         780,
         779,
         781,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         780,
         779,
         781,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         805,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         805,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         806,
         779,
         781,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         807,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         780,
         779,
         781,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         780,
         779,
         781,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         780,
         779,
         781,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         780,
         779,
         781,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         780,
         779,
         781,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         780,
         779,
         781,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         780,
         779,
         781,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         780,
         779,
         781,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         780,
         779,
         781,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         780,
         779,
         781,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         780,
         779,
         781,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         808,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         780,
         779,
         781,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         809,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         780,
         779,
         781,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         810,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         780,
         779,
         781,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         811,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         780,
         779,
         781,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         812,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         780,
         779,
         781,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         813,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         814,
         815,
         814,
         816,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         817,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         818,
         819,
         818,
         820,
         818,
         818,
         818,
         818,
         818,
         818,
         818,
         818,
         818,
         818,
         821,
         818,
         818,
         818,
         818,
         818,
         818,
         818,
         818,
         818,
         818,
         818,
         818,
         818,
         818,
         818,
         818,
         818,
         818,
         818,
         818,
         818,
         818,
         818,
         818,
         818,
         818,
         818,
         818,
         818,
         818,
         818,
         818,
         818,
         818,
         818,
         818,
         818,
         818,
         818,
         818,
         818,
         818,
         818,
         818,
         818,
         818,
         818,
         818,
         818,
         818,
         818,
         818,
         818,
         818,
         818,
         818,
         818,
         818,
         818,
         818,
         818,
         818,
         818,
         818,
         818,
         818,
         818,
         818,
         818,
         822,
         823,
         822,
         824,
         822,
         822,
         822,
         822,
         822,
         822,
         822,
         822,
         822,
         822,
         825,
         822,
         822,
         822,
         822,
         822,
         822,
         822,
         822,
         822,
         822,
         822,
         822,
         822,
         822,
         822,
         822,
         822,
         822,
         822,
         822,
         822,
         822,
         822,
         822,
         822,
         822,
         822,
         822,
         822,
         822,
         822,
         822,
         822,
         822,
         822,
         822,
         822,
         822,
         822,
         822,
         822,
         822,
         822,
         822,
         822,
         822,
         822,
         822,
         822,
         822,
         822,
         822,
         822,
         822,
         822,
         822,
         822,
         822,
         822,
         822,
         822,
         822,
         822,
         822,
         822,
         822,
         822,
         822,
         822,
         826,
         827,
         826,
         828,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         829,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         779,
         780,
         779,
         781,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         830,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         780,
         779,
         781,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         831,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         780,
         779,
         781,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         832,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         780,
         779,
         781,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         833,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         780,
         779,
         781,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         834,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         780,
         779,
         781,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         835,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         780,
         779,
         781,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         836,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         780,
         779,
         781,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         837,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         780,
         779,
         781,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         780,
         779,
         781,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         780,
         779,
         781,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         780,
         779,
         781,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         780,
         779,
         781,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         780,
         779,
         781,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         838,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         780,
         779,
         781,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         839,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         780,
         779,
         781,
         779,
         794,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         794,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         794,
         794,
         794,
         794,
         779,
         779,
         780,
         779,
         781,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         780,
         779,
         781,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         780,
         779,
         781,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         780,
         779,
         781,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         780,
         779,
         781,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         780,
         779,
         781,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         780,
         779,
         781,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         780,
         779,
         781,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         780,
         779,
         781,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         780,
         779,
         781,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         780,
         779,
         781,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         780,
         779,
         781,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         780,
         779,
         781,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         780,
         779,
         781,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         780,
         779,
         781,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         780,
         779,
         781,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         805,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         805,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         2153,
         2154,
         2153,
         2155,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2156,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2157,
         2158,
         2157,
         2159,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2160,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2161,
         2162,
         2161,
         2163,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2164,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2165,
         2166,
         2165,
         2167,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         2168,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         779,
         780,
         779,
         781,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         780,
         779,
         781,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         780,
         779,
         781,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         780,
         779,
         781,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         780,
         779,
         781,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         780,
         779,
         781,
         779,
         794,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         794,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         794,
         794,
         794,
         794,
         779,
         779,
         780,
         779,
         781,
         779,
         794,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         794,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         794,
         794,
         794,
         794,
         779,
         779,
         780,
         779,
         781,
         779,
         794,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         794,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         794,
         794,
         794,
         794,
         779,
         779,
         780,
         779,
         781,
         779,
         794,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         794,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         794,
         794,
         794,
         794,
         779,
         779,
         780,
         779,
         781,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         780,
         779,
         781,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         783,
         784,
         783,
         785,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         786,
         783,
         783,
         787,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         783,
         779,
         780,
         788,
         781,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         789,
         790,
         789,
         791,
         789,
         789,
         789,
         789,
         789,
         789,
         789,
         789,
         789,
         789,
         792,
         789,
         789,
         789,
         789,
         789,
         789,
         789,
         789,
         789,
         789,
         789,
         789,
         789,
         789,
         789,
         789,
         789,
         789,
         789,
         789,
         789,
         789,
         789,
         789,
         789,
         789,
         789,
         789,
         789,
         789,
         789,
         789,
         789,
         789,
         789,
         789,
         789,
         789,
         789,
         789,
         789,
         789,
         789,
         789,
         789,
         789,
         789,
         789,
         789,
         789,
         789,
         789,
         789,
         789,
         789,
         789,
         789,
         789,
         789,
         789,
         789,
         789,
         789,
         789,
         789,
         789,
         789,
         789,
         789,
         779,
         780,
         779,
         781,
         793,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         780,
         779,
         781,
         779,
         794,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         794,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         794,
         794,
         794,
         794,
         779,
         779,
         780,
         779,
         781,
         779,
         779,
         795,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         780,
         779,
         781,
         779,
         779,
         779,
         796,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         780,
         779,
         781,
         779,
         779,
         779,
         779,
         797,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         780,
         779,
         781,
         779,
         779,
         779,
         779,
         779,
         798,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         780,
         779,
         781,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         780,
         779,
         781,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         780,
         779,
         781,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         799,
         779,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         780,
         779,
         781,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         800,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         801,
         802,
         801,
         803,
         801,
         801,
         801,
         801,
         801,
         801,
         801,
         801,
         801,
         801,
         804,
         801,
         801,
         801,
         801,
         801,
         801,
         801,
         801,
         801,
         801,
         801,
         801,
         801,
         801,
         801,
         801,
         801,
         801,
         801,
         801,
         801,
         801,
         801,
         801,
         801,
         801,
         801,
         801,
         801,
         801,
         801,
         801,
         801,
         801,
         801,
         801,
         801,
         801,
         801,
         801,
         801,
         801,
         801,
         801,
         801,
         801,
         801,
         801,
         801,
         801,
         801,
         801,
         801,
         801,
         801,
         801,
         801,
         801,
         801,
         801,
         801,
         801,
         801,
         801,
         801,
         801,
         801,
         801,
         801,
         779,
         780,
         779,
         781,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         780,
         779,
         781,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         805,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         805,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         806,
         779,
         781,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         807,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         780,
         779,
         781,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         780,
         779,
         781,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         780,
         779,
         781,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         780,
         779,
         781,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         780,
         779,
         781,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         780,
         779,
         781,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         780,
         779,
         781,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         780,
         779,
         781,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         780,
         779,
         781,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         780,
         779,
         781,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         780,
         779,
         781,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         808,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         780,
         779,
         781,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         809,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         780,
         779,
         781,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         810,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         780,
         779,
         781,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         811,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         780,
         779,
         781,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         812,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         780,
         779,
         781,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         813,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         814,
         815,
         814,
         816,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         817,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         814,
         818,
         819,
         818,
         820,
         818,
         818,
         818,
         818,
         818,
         818,
         818,
         818,
         818,
         818,
         821,
         818,
         818,
         818,
         818,
         818,
         818,
         818,
         818,
         818,
         818,
         818,
         818,
         818,
         818,
         818,
         818,
         818,
         818,
         818,
         818,
         818,
         818,
         818,
         818,
         818,
         818,
         818,
         818,
         818,
         818,
         818,
         818,
         818,
         818,
         818,
         818,
         818,
         818,
         818,
         818,
         818,
         818,
         818,
         818,
         818,
         818,
         818,
         818,
         818,
         818,
         818,
         818,
         818,
         818,
         818,
         818,
         818,
         818,
         818,
         818,
         818,
         818,
         818,
         818,
         818,
         818,
         818,
         818,
         818,
         822,
         823,
         822,
         824,
         822,
         822,
         822,
         822,
         822,
         822,
         822,
         822,
         822,
         822,
         825,
         822,
         822,
         822,
         822,
         822,
         822,
         822,
         822,
         822,
         822,
         822,
         822,
         822,
         822,
         822,
         822,
         822,
         822,
         822,
         822,
         822,
         822,
         822,
         822,
         822,
         822,
         822,
         822,
         822,
         822,
         822,
         822,
         822,
         822,
         822,
         822,
         822,
         822,
         822,
         822,
         822,
         822,
         822,
         822,
         822,
         822,
         822,
         822,
         822,
         822,
         822,
         822,
         822,
         822,
         822,
         822,
         822,
         822,
         822,
         822,
         822,
         822,
         822,
         822,
         822,
         822,
         822,
         822,
         822,
         826,
         827,
         826,
         828,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         829,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         826,
         779,
         780,
         779,
         781,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         830,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         780,
         779,
         781,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         831,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         780,
         779,
         781,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         832,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         780,
         779,
         781,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         833,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         780,
         779,
         781,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         834,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         780,
         779,
         781,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         835,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         780,
         779,
         781,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         836,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         780,
         779,
         781,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         837,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         780,
         779,
         781,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         780,
         779,
         781,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         780,
         779,
         781,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         780,
         779,
         781,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         780,
         779,
         781,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         780,
         779,
         781,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         838,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         780,
         779,
         781,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         839,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         780,
         779,
         781,
         779,
         794,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         794,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         794,
         794,
         794,
         794,
         779,
         779,
         780,
         779,
         781,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         779,
         2169,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         780,
         779,
         781,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         780,
         779,
         781,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         780,
         779,
         781,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         780,
         779,
         781,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         780,
         779,
         781,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         780,
         779,
         781,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         780,
         779,
         781,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         780,
         779,
         781,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         780,
         779,
         781,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         780,
         779,
         781,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         780,
         779,
         781,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         780,
         779,
         781,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         780,
         779,
         781,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         780,
         779,
         781,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         780,
         779,
         781,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         805,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         805,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         2153,
         2154,
         2153,
         2155,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2156,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2153,
         2157,
         2158,
         2157,
         2159,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2160,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2157,
         2161,
         2162,
         2161,
         2163,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2164,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2161,
         2165,
         2166,
         2165,
         2167,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         2168,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         2165,
         779,
         780,
         779,
         781,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         780,
         779,
         781,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         780,
         779,
         781,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         780,
         779,
         781,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         780,
         779,
         781,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         780,
         779,
         781,
         779,
         794,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         794,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         794,
         794,
         794,
         794,
         779,
         779,
         780,
         779,
         781,
         779,
         794,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         794,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         794,
         794,
         794,
         794,
         779,
         779,
         780,
         779,
         781,
         779,
         794,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         794,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         794,
         794,
         794,
         794,
         779,
         779,
         780,
         779,
         781,
         779,
         794,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         794,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         794,
         794,
         794,
         794,
         779,
         779,
         780,
         779,
         781,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         782,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         779,
         840,
         841,
         840,
         842,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         844,
         845,
         844,
         846,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         847,
         844,
         844,
         848,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         2170,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         2170,
         2170,
         2170,
         2170,
         844,
         840,
         841,
         849,
         842,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         850,
         851,
         850,
         852,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         853,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         840,
         841,
         840,
         842,
         854,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         841,
         840,
         842,
         840,
         855,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         855,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         855,
         855,
         855,
         855,
         840,
         840,
         841,
         840,
         842,
         840,
         840,
         856,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         841,
         840,
         842,
         840,
         840,
         840,
         857,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         841,
         840,
         842,
         840,
         840,
         840,
         840,
         858,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         841,
         840,
         842,
         840,
         840,
         840,
         840,
         840,
         859,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         841,
         840,
         842,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         841,
         840,
         842,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         841,
         840,
         842,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         860,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         841,
         840,
         842,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         861,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         862,
         863,
         862,
         864,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         865,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         840,
         841,
         840,
         842,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         841,
         840,
         842,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         866,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         866,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         867,
         840,
         842,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         868,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         841,
         840,
         842,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         841,
         840,
         842,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         841,
         840,
         842,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         841,
         840,
         842,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         841,
         840,
         842,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         841,
         840,
         842,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         841,
         840,
         842,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         841,
         840,
         842,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         841,
         840,
         842,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         841,
         840,
         842,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         841,
         840,
         842,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         869,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         841,
         840,
         842,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         870,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         841,
         840,
         842,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         871,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         841,
         840,
         842,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         872,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         841,
         840,
         842,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         873,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         841,
         840,
         842,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         874,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         875,
         876,
         875,
         877,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         878,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         879,
         880,
         879,
         881,
         879,
         879,
         879,
         879,
         879,
         879,
         879,
         879,
         879,
         879,
         882,
         879,
         879,
         879,
         879,
         879,
         879,
         879,
         879,
         879,
         879,
         879,
         879,
         879,
         879,
         879,
         879,
         879,
         879,
         879,
         879,
         879,
         879,
         879,
         879,
         879,
         879,
         879,
         879,
         879,
         879,
         879,
         879,
         879,
         879,
         879,
         879,
         879,
         879,
         879,
         879,
         879,
         879,
         879,
         879,
         879,
         879,
         879,
         879,
         879,
         879,
         879,
         879,
         879,
         879,
         879,
         879,
         879,
         879,
         879,
         879,
         879,
         879,
         879,
         879,
         879,
         879,
         879,
         879,
         879,
         883,
         884,
         883,
         885,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         886,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         887,
         888,
         887,
         889,
         887,
         887,
         887,
         887,
         887,
         887,
         887,
         887,
         887,
         887,
         890,
         887,
         887,
         887,
         887,
         887,
         887,
         887,
         887,
         887,
         887,
         887,
         887,
         887,
         887,
         887,
         887,
         887,
         887,
         887,
         887,
         887,
         887,
         887,
         887,
         887,
         887,
         887,
         887,
         887,
         887,
         887,
         887,
         887,
         887,
         887,
         887,
         887,
         887,
         887,
         887,
         887,
         887,
         887,
         887,
         887,
         887,
         887,
         887,
         887,
         887,
         887,
         887,
         887,
         887,
         887,
         887,
         887,
         887,
         887,
         887,
         887,
         887,
         887,
         887,
         887,
         887,
         887,
         887,
         887,
         840,
         841,
         840,
         842,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         891,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         841,
         840,
         842,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         892,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         841,
         840,
         842,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         893,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         841,
         840,
         842,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         894,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         841,
         840,
         842,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         895,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         841,
         840,
         842,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         896,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         841,
         840,
         842,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         897,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         841,
         840,
         842,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         898,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         841,
         840,
         842,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         841,
         840,
         842,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         841,
         840,
         842,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         841,
         840,
         842,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         841,
         840,
         842,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         841,
         840,
         842,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         899,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         841,
         840,
         842,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         900,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         841,
         840,
         842,
         840,
         855,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         855,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         855,
         855,
         855,
         855,
         840,
         840,
         841,
         840,
         842,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         841,
         840,
         842,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         841,
         840,
         842,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         841,
         840,
         842,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         841,
         840,
         842,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         841,
         840,
         842,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         841,
         840,
         842,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         841,
         840,
         842,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         841,
         840,
         842,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         841,
         840,
         842,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         841,
         840,
         842,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         841,
         840,
         842,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         841,
         840,
         842,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         841,
         840,
         842,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         841,
         840,
         842,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         841,
         840,
         842,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         866,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         866,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         2171,
         2172,
         2171,
         2173,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2174,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2175,
         2176,
         2175,
         2177,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2178,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2179,
         2180,
         2179,
         2181,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2182,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2183,
         2184,
         2183,
         2185,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         2186,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         840,
         841,
         840,
         842,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         841,
         840,
         842,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         841,
         840,
         842,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         841,
         840,
         842,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         841,
         840,
         842,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         841,
         840,
         842,
         840,
         855,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         855,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         855,
         855,
         855,
         855,
         840,
         840,
         841,
         840,
         842,
         840,
         855,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         855,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         855,
         855,
         855,
         855,
         840,
         840,
         841,
         840,
         842,
         840,
         855,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         855,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         855,
         855,
         855,
         855,
         840,
         840,
         841,
         840,
         842,
         840,
         855,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         855,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         855,
         855,
         855,
         855,
         840,
         840,
         841,
         840,
         842,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         905,
         906,
         905,
         907,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         908,
         905,
         905,
         909,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         901,
         902,
         910,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         911,
         912,
         911,
         913,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         914,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         901,
         902,
         901,
         903,
         915,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         916,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         916,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         916,
         916,
         916,
         916,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         917,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         918,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         919,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         920,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         921,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         922,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         923,
         924,
         923,
         925,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         926,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         927,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         927,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         928,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         929,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         930,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         931,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         932,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         933,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         934,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         935,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         936,
         937,
         936,
         938,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         939,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         940,
         941,
         940,
         942,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         943,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         944,
         945,
         944,
         946,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         947,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         948,
         949,
         948,
         950,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         951,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         952,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         953,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         954,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         955,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         956,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         957,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         958,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         959,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         960,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         961,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         916,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         916,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         916,
         916,
         916,
         916,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         927,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         927,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         2187,
         2188,
         2187,
         2189,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2190,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2191,
         2192,
         2191,
         2193,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2194,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2195,
         2196,
         2195,
         2197,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2198,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2199,
         2200,
         2199,
         2201,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2202,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         916,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         916,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         916,
         916,
         916,
         916,
         901,
         901,
         902,
         901,
         903,
         901,
         916,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         916,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         916,
         916,
         916,
         916,
         901,
         901,
         902,
         901,
         903,
         901,
         916,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         916,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         916,
         916,
         916,
         916,
         901,
         901,
         902,
         901,
         903,
         901,
         916,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         916,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         916,
         916,
         916,
         916,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         962,
         963,
         962,
         964,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         966,
         967,
         966,
         968,
         966,
         966,
         966,
         966,
         966,
         966,
         966,
         966,
         966,
         966,
         969,
         966,
         966,
         970,
         966,
         966,
         966,
         966,
         966,
         966,
         966,
         966,
         966,
         966,
         966,
         966,
         966,
         966,
         966,
         966,
         966,
         966,
         966,
         966,
         966,
         966,
         966,
         966,
         966,
         966,
         966,
         966,
         966,
         966,
         966,
         966,
         966,
         966,
         966,
         966,
         966,
         966,
         966,
         966,
         966,
         966,
         966,
         966,
         966,
         966,
         966,
         966,
         966,
         966,
         966,
         966,
         966,
         966,
         966,
         966,
         966,
         966,
         966,
         966,
         966,
         966,
         966,
         966,
         966,
         966,
         962,
         963,
         971,
         964,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         972,
         973,
         972,
         974,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         975,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         962,
         963,
         962,
         964,
         976,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         963,
         962,
         964,
         962,
         977,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         977,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         977,
         977,
         977,
         977,
         962,
         962,
         963,
         962,
         964,
         962,
         962,
         978,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         963,
         962,
         964,
         962,
         962,
         962,
         979,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         963,
         962,
         964,
         962,
         962,
         962,
         962,
         980,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         963,
         962,
         964,
         962,
         962,
         962,
         962,
         962,
         981,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         963,
         962,
         964,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         963,
         962,
         964,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         963,
         962,
         964,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         982,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         963,
         962,
         964,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         983,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         984,
         985,
         984,
         986,
         984,
         984,
         984,
         984,
         984,
         984,
         984,
         984,
         984,
         984,
         987,
         984,
         984,
         984,
         984,
         984,
         984,
         984,
         984,
         984,
         984,
         984,
         984,
         984,
         984,
         984,
         984,
         984,
         984,
         984,
         984,
         984,
         984,
         984,
         984,
         984,
         984,
         984,
         984,
         984,
         984,
         984,
         984,
         984,
         984,
         984,
         984,
         984,
         984,
         984,
         984,
         984,
         984,
         984,
         984,
         984,
         984,
         984,
         984,
         984,
         984,
         984,
         984,
         984,
         984,
         984,
         984,
         984,
         984,
         984,
         984,
         984,
         984,
         984,
         984,
         984,
         984,
         984,
         984,
         984,
         962,
         963,
         962,
         964,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         963,
         962,
         964,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         988,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         988,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         989,
         962,
         964,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         990,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         963,
         962,
         964,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         963,
         962,
         964,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         963,
         962,
         964,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         963,
         962,
         964,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         963,
         962,
         964,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         963,
         962,
         964,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         963,
         962,
         964,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         963,
         962,
         964,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         963,
         962,
         964,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         963,
         962,
         964,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         963,
         962,
         964,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         991,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         963,
         962,
         964,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         992,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         963,
         962,
         964,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         993,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         963,
         962,
         964,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         994,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         963,
         962,
         964,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         995,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         963,
         962,
         964,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         996,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         997,
         998,
         997,
         999,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         1000,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         1001,
         1002,
         1001,
         1003,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1004,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1005,
         1006,
         1005,
         1007,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1008,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1009,
         1010,
         1009,
         1011,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         1012,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         962,
         963,
         962,
         964,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         1013,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         963,
         962,
         964,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         1014,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         963,
         962,
         964,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         1015,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         963,
         962,
         964,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         1016,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         963,
         962,
         964,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         1017,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         963,
         962,
         964,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         1018,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         963,
         962,
         964,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         1019,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         963,
         962,
         964,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         1020,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         963,
         962,
         964,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         963,
         962,
         964,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         963,
         962,
         964,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         963,
         962,
         964,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         963,
         962,
         964,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         963,
         962,
         964,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         1021,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         963,
         962,
         964,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         1022,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         2203,
         962,
         964,
         962,
         977,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         977,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         977,
         977,
         977,
         977,
         962,
         962,
         963,
         962,
         964,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         963,
         962,
         964,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         963,
         962,
         964,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         963,
         962,
         964,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         963,
         962,
         964,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         963,
         962,
         964,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         963,
         962,
         964,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         963,
         962,
         964,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         963,
         962,
         964,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         963,
         962,
         964,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         963,
         962,
         964,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         963,
         962,
         964,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         963,
         962,
         964,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         963,
         962,
         964,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         963,
         962,
         964,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         963,
         962,
         964,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         988,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         988,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         2204,
         2205,
         2204,
         2206,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2207,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2208,
         2209,
         2208,
         2210,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2211,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2212,
         2213,
         2212,
         2214,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2215,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2216,
         2217,
         2216,
         2218,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         2219,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         962,
         963,
         962,
         964,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         963,
         962,
         964,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         963,
         962,
         964,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         963,
         962,
         964,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         963,
         962,
         964,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         2203,
         962,
         964,
         962,
         977,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         977,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         977,
         977,
         977,
         977,
         962,
         962,
         2203,
         962,
         964,
         962,
         977,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         977,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         977,
         977,
         977,
         977,
         962,
         962,
         2203,
         962,
         964,
         962,
         977,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         977,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         977,
         977,
         977,
         977,
         962,
         962,
         2203,
         962,
         964,
         962,
         977,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         977,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         977,
         977,
         977,
         977,
         962,
         962,
         963,
         962,
         964,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         123,
         124,
         123,
         469,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         470,
         123,
         123,
         471,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         121,
         122,
         472,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         473,
         474,
         473,
         475,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         476,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         121,
         122,
         121,
         467,
         477,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         479,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         480,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         481,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         482,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         483,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         484,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         485,
         486,
         485,
         487,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         488,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         490,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         491,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         492,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         493,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         494,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         495,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         496,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         497,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         498,
         499,
         498,
         500,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         501,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         502,
         503,
         502,
         504,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         505,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         506,
         507,
         506,
         508,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         509,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         510,
         511,
         510,
         512,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         513,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         514,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         515,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         516,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         517,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         518,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         519,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         520,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         521,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         522,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         523,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         2072,
         2073,
         2072,
         2074,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2075,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2076,
         2077,
         2076,
         2078,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2079,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2080,
         2081,
         2080,
         2082,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2083,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2084,
         2085,
         2084,
         2086,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2087,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         123,
         124,
         123,
         469,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         470,
         123,
         123,
         471,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         121,
         122,
         472,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         473,
         474,
         473,
         475,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         476,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         121,
         122,
         121,
         467,
         477,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         479,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         480,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         481,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         482,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         483,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         484,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         485,
         486,
         485,
         487,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         488,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         490,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         491,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         492,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         493,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         494,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         495,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         496,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         497,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         498,
         499,
         498,
         500,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         501,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         502,
         503,
         502,
         504,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         505,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         506,
         507,
         506,
         508,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         509,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         510,
         511,
         510,
         512,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         513,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         514,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         515,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         516,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         517,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         518,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         519,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         520,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         521,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         522,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         523,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         2072,
         2073,
         2072,
         2074,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2075,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2076,
         2077,
         2076,
         2078,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2079,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2080,
         2081,
         2080,
         2082,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2083,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2084,
         2085,
         2084,
         2086,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2087,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         123,
         124,
         123,
         469,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         470,
         123,
         123,
         471,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         121,
         122,
         472,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         473,
         474,
         473,
         475,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         476,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         121,
         122,
         121,
         467,
         477,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         479,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         480,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         481,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         482,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         483,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         484,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         485,
         486,
         485,
         487,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         488,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         490,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         491,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         492,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         493,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         494,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         495,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         496,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         497,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         498,
         499,
         498,
         500,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         501,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         502,
         503,
         502,
         504,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         505,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         506,
         507,
         506,
         508,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         509,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         510,
         511,
         510,
         512,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         513,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         514,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         515,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         516,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         517,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         518,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         519,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         520,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         521,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         522,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         523,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         2072,
         2073,
         2072,
         2074,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2075,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2076,
         2077,
         2076,
         2078,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2079,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2080,
         2081,
         2080,
         2082,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2083,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2084,
         2085,
         2084,
         2086,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2087,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         123,
         124,
         123,
         469,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         470,
         123,
         123,
         471,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         121,
         122,
         472,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         473,
         474,
         473,
         475,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         476,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         121,
         122,
         121,
         467,
         477,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         479,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         480,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         481,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         482,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         483,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         484,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         485,
         486,
         485,
         487,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         488,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         490,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         491,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         492,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         493,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         494,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         495,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         496,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         497,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         498,
         499,
         498,
         500,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         501,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         502,
         503,
         502,
         504,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         505,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         506,
         507,
         506,
         508,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         509,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         510,
         511,
         510,
         512,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         513,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         514,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         515,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         516,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         517,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         518,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         519,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         520,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         521,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         522,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         523,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         2072,
         2073,
         2072,
         2074,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2075,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2076,
         2077,
         2076,
         2078,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2079,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2080,
         2081,
         2080,
         2082,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2083,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2084,
         2085,
         2084,
         2086,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2087,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         123,
         124,
         123,
         469,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         470,
         123,
         123,
         471,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         121,
         122,
         472,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         473,
         474,
         473,
         475,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         476,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         121,
         122,
         121,
         467,
         477,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         479,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         480,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         481,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         482,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         483,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         484,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         485,
         486,
         485,
         487,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         488,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         490,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         491,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         492,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         493,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         494,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         495,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         496,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         497,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         498,
         499,
         498,
         500,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         501,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         502,
         503,
         502,
         504,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         505,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         506,
         507,
         506,
         508,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         509,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         510,
         511,
         510,
         512,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         513,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         514,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         515,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         516,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         517,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         518,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         519,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         520,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         521,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         522,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         523,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         2072,
         2073,
         2072,
         2074,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2075,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2076,
         2077,
         2076,
         2078,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2079,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2080,
         2081,
         2080,
         2082,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2083,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2084,
         2085,
         2084,
         2086,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2087,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         123,
         124,
         123,
         469,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         470,
         123,
         123,
         471,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         121,
         122,
         472,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         473,
         474,
         473,
         475,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         476,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         121,
         122,
         121,
         467,
         477,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         479,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         480,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         481,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         482,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         483,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         484,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         485,
         486,
         485,
         487,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         488,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         490,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         491,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         492,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         493,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         494,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         495,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         496,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         497,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         498,
         499,
         498,
         500,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         501,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         502,
         503,
         502,
         504,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         505,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         506,
         507,
         506,
         508,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         509,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         510,
         511,
         510,
         512,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         513,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         514,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         515,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         516,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         517,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         518,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         519,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         520,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         521,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         522,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         523,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         2072,
         2073,
         2072,
         2074,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2075,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2076,
         2077,
         2076,
         2078,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2079,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2080,
         2081,
         2080,
         2082,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2083,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2084,
         2085,
         2084,
         2086,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2087,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         123,
         124,
         123,
         469,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         470,
         123,
         123,
         471,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         121,
         122,
         472,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         473,
         474,
         473,
         475,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         476,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         121,
         122,
         121,
         467,
         477,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         479,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         480,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         481,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         482,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         483,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         484,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         485,
         486,
         485,
         487,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         488,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         490,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         491,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         492,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         493,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         494,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         495,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         496,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         497,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         498,
         499,
         498,
         500,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         501,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         502,
         503,
         502,
         504,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         505,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         506,
         507,
         506,
         508,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         509,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         510,
         511,
         510,
         512,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         513,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         514,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         515,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         516,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         517,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         518,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         519,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         520,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         521,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         522,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         523,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         2072,
         2073,
         2072,
         2074,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2075,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2076,
         2077,
         2076,
         2078,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2079,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2080,
         2081,
         2080,
         2082,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2083,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2084,
         2085,
         2084,
         2086,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2087,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         123,
         124,
         123,
         469,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         470,
         123,
         123,
         471,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         121,
         122,
         472,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         473,
         474,
         473,
         475,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         476,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         121,
         122,
         121,
         467,
         477,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         479,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         480,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         481,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         482,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         483,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         484,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         485,
         486,
         485,
         487,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         488,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         490,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         491,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         492,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         493,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         494,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         495,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         496,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         497,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         498,
         499,
         498,
         500,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         501,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         502,
         503,
         502,
         504,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         505,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         506,
         507,
         506,
         508,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         509,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         510,
         511,
         510,
         512,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         513,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         514,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         515,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         516,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         517,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         518,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         519,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         520,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         521,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         522,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         523,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         2072,
         2073,
         2072,
         2074,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2075,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2076,
         2077,
         2076,
         2078,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2079,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2080,
         2081,
         2080,
         2082,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2083,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2084,
         2085,
         2084,
         2086,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2087,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         123,
         124,
         123,
         469,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         470,
         123,
         123,
         471,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         121,
         122,
         472,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         473,
         474,
         473,
         475,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         476,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         121,
         122,
         121,
         467,
         477,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         479,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         480,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         481,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         482,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         483,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         484,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         485,
         486,
         485,
         487,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         488,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         490,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         491,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         492,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         493,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         494,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         495,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         496,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         497,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         498,
         499,
         498,
         500,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         501,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         502,
         503,
         502,
         504,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         505,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         506,
         507,
         506,
         508,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         509,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         510,
         511,
         510,
         512,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         513,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         514,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         515,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         516,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         517,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         518,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         519,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         520,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         521,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         522,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         523,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         2072,
         2073,
         2072,
         2074,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2075,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2076,
         2077,
         2076,
         2078,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2079,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2080,
         2081,
         2080,
         2082,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2083,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2084,
         2085,
         2084,
         2086,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2087,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         123,
         124,
         123,
         469,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         470,
         123,
         123,
         471,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         121,
         122,
         472,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         473,
         474,
         473,
         475,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         476,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         121,
         122,
         121,
         467,
         477,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         479,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         480,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         481,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         482,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         483,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         484,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         485,
         486,
         485,
         487,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         488,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         490,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         491,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         492,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         493,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         494,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         495,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         496,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         497,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         498,
         499,
         498,
         500,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         501,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         502,
         503,
         502,
         504,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         505,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         506,
         507,
         506,
         508,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         509,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         510,
         511,
         510,
         512,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         513,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         514,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         515,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         516,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         517,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         518,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         519,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         520,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         521,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         522,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         523,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         2072,
         2073,
         2072,
         2074,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2075,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2076,
         2077,
         2076,
         2078,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2079,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2080,
         2081,
         2080,
         2082,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2083,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2084,
         2085,
         2084,
         2086,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2087,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         123,
         124,
         123,
         469,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         470,
         123,
         123,
         471,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         121,
         122,
         472,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         473,
         474,
         473,
         475,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         476,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         121,
         122,
         121,
         467,
         477,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         479,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         480,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         481,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         482,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         483,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         484,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         485,
         486,
         485,
         487,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         488,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         490,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         491,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         492,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         493,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         494,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         495,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         496,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         497,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         498,
         499,
         498,
         500,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         501,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         502,
         503,
         502,
         504,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         505,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         506,
         507,
         506,
         508,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         509,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         510,
         511,
         510,
         512,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         513,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         514,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         515,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         516,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         517,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         518,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         519,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         520,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         521,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         522,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         523,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         2072,
         2073,
         2072,
         2074,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2075,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2076,
         2077,
         2076,
         2078,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2079,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2080,
         2081,
         2080,
         2082,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2083,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2084,
         2085,
         2084,
         2086,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2087,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         123,
         124,
         123,
         469,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         470,
         123,
         123,
         471,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         121,
         122,
         472,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         473,
         474,
         473,
         475,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         476,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         121,
         122,
         121,
         467,
         477,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         479,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         480,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         481,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         482,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         483,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         484,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         485,
         486,
         485,
         487,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         488,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         490,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         491,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         492,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         493,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         494,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         495,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         496,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         497,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         498,
         499,
         498,
         500,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         501,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         502,
         503,
         502,
         504,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         505,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         506,
         507,
         506,
         508,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         509,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         510,
         511,
         510,
         512,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         513,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         514,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         515,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         516,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         517,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         518,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         519,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         520,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         521,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         522,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         523,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         2072,
         2073,
         2072,
         2074,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2075,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2076,
         2077,
         2076,
         2078,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2079,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2080,
         2081,
         2080,
         2082,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2083,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2084,
         2085,
         2084,
         2086,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2087,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         123,
         124,
         123,
         469,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         470,
         123,
         123,
         471,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         121,
         122,
         472,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         473,
         474,
         473,
         475,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         476,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         121,
         122,
         121,
         467,
         477,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         479,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         480,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         481,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         482,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         483,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         484,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         485,
         486,
         485,
         487,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         488,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         490,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         491,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         492,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         493,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         494,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         495,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         496,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         497,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         498,
         499,
         498,
         500,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         501,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         502,
         503,
         502,
         504,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         505,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         506,
         507,
         506,
         508,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         509,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         510,
         511,
         510,
         512,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         513,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         514,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         515,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         516,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         517,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         518,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         519,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         520,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         521,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         522,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         523,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         2072,
         2073,
         2072,
         2074,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2075,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2076,
         2077,
         2076,
         2078,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2079,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2080,
         2081,
         2080,
         2082,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2083,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2084,
         2085,
         2084,
         2086,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2087,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         123,
         124,
         123,
         469,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         470,
         123,
         123,
         471,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         121,
         122,
         472,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         473,
         474,
         473,
         475,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         476,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         121,
         122,
         121,
         467,
         477,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         479,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         480,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         481,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         482,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         483,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         484,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         485,
         486,
         485,
         487,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         488,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         490,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         491,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         492,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         493,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         494,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         495,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         496,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         497,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         498,
         499,
         498,
         500,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         501,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         502,
         503,
         502,
         504,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         505,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         506,
         507,
         506,
         508,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         509,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         510,
         511,
         510,
         512,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         513,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         514,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         515,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         516,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         517,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         518,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         519,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         520,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         521,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         522,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         523,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         2072,
         2073,
         2072,
         2074,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2075,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2076,
         2077,
         2076,
         2078,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2079,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2080,
         2081,
         2080,
         2082,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2083,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2084,
         2085,
         2084,
         2086,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2087,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         123,
         124,
         123,
         469,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         470,
         123,
         123,
         471,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         121,
         122,
         472,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         473,
         474,
         473,
         475,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         476,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         121,
         122,
         121,
         467,
         477,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         479,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         480,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         481,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         482,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         483,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         484,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         485,
         486,
         485,
         487,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         488,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         490,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         491,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         492,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         493,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         494,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         495,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         496,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         497,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         498,
         499,
         498,
         500,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         501,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         502,
         503,
         502,
         504,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         505,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         506,
         507,
         506,
         508,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         509,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         510,
         511,
         510,
         512,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         513,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         514,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         515,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         516,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         517,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         518,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         519,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         520,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         521,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         522,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         523,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         2072,
         2073,
         2072,
         2074,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2075,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2076,
         2077,
         2076,
         2078,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2079,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2080,
         2081,
         2080,
         2082,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2083,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2084,
         2085,
         2084,
         2086,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2087,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         123,
         124,
         123,
         469,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         470,
         123,
         123,
         471,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         121,
         122,
         472,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         473,
         474,
         473,
         475,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         476,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         121,
         122,
         121,
         467,
         477,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         479,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         480,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         481,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         482,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         483,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         484,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         485,
         486,
         485,
         487,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         488,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         490,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         491,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         492,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         493,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         494,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         495,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         496,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         497,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         498,
         499,
         498,
         500,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         501,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         502,
         503,
         502,
         504,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         505,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         506,
         507,
         506,
         508,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         509,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         510,
         511,
         510,
         512,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         513,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         514,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         515,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         516,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         517,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         518,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         519,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         520,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         521,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         522,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         523,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         2072,
         2073,
         2072,
         2074,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2075,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2076,
         2077,
         2076,
         2078,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2079,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2080,
         2081,
         2080,
         2082,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2083,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2084,
         2085,
         2084,
         2086,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2087,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         123,
         124,
         123,
         469,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         470,
         123,
         123,
         471,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         121,
         122,
         472,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         473,
         474,
         473,
         475,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         476,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         121,
         122,
         121,
         467,
         477,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         479,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         480,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         481,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         482,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         483,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         484,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         485,
         486,
         485,
         487,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         488,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         490,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         491,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         492,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         493,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         494,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         495,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         496,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         497,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         498,
         499,
         498,
         500,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         501,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         502,
         503,
         502,
         504,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         505,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         506,
         507,
         506,
         508,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         509,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         510,
         511,
         510,
         512,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         513,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         514,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         515,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         516,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         517,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         518,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         519,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         520,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         521,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         522,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         523,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         2072,
         2073,
         2072,
         2074,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2075,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2076,
         2077,
         2076,
         2078,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2079,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2080,
         2081,
         2080,
         2082,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2083,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2084,
         2085,
         2084,
         2086,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2087,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         123,
         124,
         123,
         469,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         470,
         123,
         123,
         471,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         121,
         122,
         472,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         473,
         474,
         473,
         475,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         476,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         121,
         122,
         121,
         467,
         477,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         479,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         480,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         481,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         482,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         483,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         484,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         485,
         486,
         485,
         487,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         488,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         490,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         491,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         492,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         493,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         494,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         495,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         496,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         497,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         498,
         499,
         498,
         500,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         501,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         502,
         503,
         502,
         504,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         505,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         506,
         507,
         506,
         508,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         509,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         510,
         511,
         510,
         512,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         513,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         514,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         515,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         516,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         517,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         518,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         519,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         520,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         521,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         522,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         523,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         2072,
         2073,
         2072,
         2074,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2075,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2076,
         2077,
         2076,
         2078,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2079,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2080,
         2081,
         2080,
         2082,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2083,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2084,
         2085,
         2084,
         2086,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2087,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         123,
         124,
         123,
         469,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         470,
         123,
         123,
         471,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         121,
         122,
         472,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         473,
         474,
         473,
         475,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         476,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         121,
         122,
         121,
         467,
         477,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         479,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         480,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         481,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         482,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         483,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         484,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         485,
         486,
         485,
         487,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         488,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         490,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         491,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         492,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         493,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         494,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         495,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         496,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         497,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         498,
         499,
         498,
         500,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         501,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         502,
         503,
         502,
         504,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         505,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         506,
         507,
         506,
         508,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         509,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         510,
         511,
         510,
         512,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         513,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         514,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         515,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         516,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         517,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         518,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         519,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         520,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         521,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         522,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         523,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         2072,
         2073,
         2072,
         2074,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2075,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2076,
         2077,
         2076,
         2078,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2079,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2080,
         2081,
         2080,
         2082,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2083,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2084,
         2085,
         2084,
         2086,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2087,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         123,
         124,
         123,
         469,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         470,
         123,
         123,
         471,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         121,
         122,
         472,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         473,
         474,
         473,
         475,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         476,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         121,
         122,
         121,
         467,
         477,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         479,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         480,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         481,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         482,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         483,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         484,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         485,
         486,
         485,
         487,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         488,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         490,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         491,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         492,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         493,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         494,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         495,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         496,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         497,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         498,
         499,
         498,
         500,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         501,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         502,
         503,
         502,
         504,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         505,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         506,
         507,
         506,
         508,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         509,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         510,
         511,
         510,
         512,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         513,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         514,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         515,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         516,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         517,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         518,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         519,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         520,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         521,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         522,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         523,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         2072,
         2073,
         2072,
         2074,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2075,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2076,
         2077,
         2076,
         2078,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2079,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2080,
         2081,
         2080,
         2082,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2083,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2084,
         2085,
         2084,
         2086,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2087,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         123,
         124,
         123,
         469,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         470,
         123,
         123,
         471,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         121,
         122,
         472,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         473,
         474,
         473,
         475,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         476,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         121,
         122,
         121,
         467,
         477,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         479,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         480,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         481,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         482,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         483,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         484,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         485,
         486,
         485,
         487,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         488,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         490,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         491,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         492,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         493,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         494,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         495,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         496,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         497,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         498,
         499,
         498,
         500,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         501,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         502,
         503,
         502,
         504,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         505,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         506,
         507,
         506,
         508,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         509,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         510,
         511,
         510,
         512,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         513,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         514,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         515,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         516,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         517,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         518,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         519,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         520,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         521,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         522,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         523,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         2072,
         2073,
         2072,
         2074,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2075,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2076,
         2077,
         2076,
         2078,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2079,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2080,
         2081,
         2080,
         2082,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2083,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2084,
         2085,
         2084,
         2086,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2087,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         123,
         124,
         123,
         469,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         470,
         123,
         123,
         471,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         121,
         122,
         472,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         473,
         474,
         473,
         475,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         476,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         121,
         122,
         121,
         467,
         477,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         479,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         480,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         481,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         482,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         483,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         484,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         485,
         486,
         485,
         487,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         488,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         490,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         491,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         492,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         493,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         494,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         495,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         496,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         497,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         498,
         499,
         498,
         500,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         501,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         502,
         503,
         502,
         504,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         505,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         506,
         507,
         506,
         508,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         509,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         510,
         511,
         510,
         512,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         513,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         514,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         515,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         516,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         517,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         518,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         519,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         520,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         521,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         522,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         523,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         2072,
         2073,
         2072,
         2074,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2075,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2076,
         2077,
         2076,
         2078,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2079,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2080,
         2081,
         2080,
         2082,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2083,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2084,
         2085,
         2084,
         2086,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2087,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         123,
         124,
         123,
         469,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         470,
         123,
         123,
         471,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         121,
         122,
         472,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         473,
         474,
         473,
         475,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         476,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         121,
         122,
         121,
         467,
         477,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         479,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         480,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         481,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         482,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         483,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         484,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         485,
         486,
         485,
         487,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         488,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         490,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         491,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         492,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         493,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         494,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         495,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         496,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         497,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         498,
         499,
         498,
         500,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         501,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         502,
         503,
         502,
         504,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         505,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         506,
         507,
         506,
         508,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         509,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         510,
         511,
         510,
         512,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         513,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         514,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         515,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         516,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         517,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         518,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         519,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         520,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         521,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         522,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         523,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         2072,
         2073,
         2072,
         2074,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2075,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2076,
         2077,
         2076,
         2078,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2079,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2080,
         2081,
         2080,
         2082,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2083,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2084,
         2085,
         2084,
         2086,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2087,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         123,
         124,
         123,
         469,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         470,
         123,
         123,
         471,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         121,
         122,
         472,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         473,
         474,
         473,
         475,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         476,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         121,
         122,
         121,
         467,
         477,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         479,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         480,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         481,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         482,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         483,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         484,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         485,
         486,
         485,
         487,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         488,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         490,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         491,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         492,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         493,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         494,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         495,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         496,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         497,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         498,
         499,
         498,
         500,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         501,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         502,
         503,
         502,
         504,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         505,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         506,
         507,
         506,
         508,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         509,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         510,
         511,
         510,
         512,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         513,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         514,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         515,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         516,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         517,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         518,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         519,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         520,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         521,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         522,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         523,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         2072,
         2073,
         2072,
         2074,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2075,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2076,
         2077,
         2076,
         2078,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2079,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2080,
         2081,
         2080,
         2082,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2083,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2084,
         2085,
         2084,
         2086,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2087,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         123,
         124,
         123,
         469,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         470,
         123,
         123,
         471,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         121,
         122,
         472,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         473,
         474,
         473,
         475,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         476,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         121,
         122,
         121,
         467,
         477,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         479,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         480,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         481,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         482,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         483,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         484,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         485,
         486,
         485,
         487,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         488,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         490,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         491,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         492,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         493,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         494,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         495,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         496,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         497,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         498,
         499,
         498,
         500,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         501,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         502,
         503,
         502,
         504,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         505,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         506,
         507,
         506,
         508,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         509,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         510,
         511,
         510,
         512,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         513,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         514,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         515,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         516,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         517,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         518,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         519,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         520,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         521,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         522,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         523,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         2072,
         2073,
         2072,
         2074,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2075,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2076,
         2077,
         2076,
         2078,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2079,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2080,
         2081,
         2080,
         2082,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2083,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2084,
         2085,
         2084,
         2086,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2087,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         123,
         124,
         123,
         469,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         470,
         123,
         123,
         471,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         121,
         122,
         472,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         473,
         474,
         473,
         475,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         476,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         121,
         122,
         121,
         467,
         477,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         479,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         480,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         481,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         482,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         483,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         484,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         485,
         486,
         485,
         487,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         488,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         490,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         491,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         492,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         493,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         494,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         495,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         496,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         497,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         498,
         499,
         498,
         500,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         501,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         502,
         503,
         502,
         504,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         505,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         506,
         507,
         506,
         508,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         509,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         510,
         511,
         510,
         512,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         513,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         514,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         515,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         516,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         517,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         518,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         519,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         520,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         521,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         522,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         523,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         2072,
         2073,
         2072,
         2074,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2075,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2076,
         2077,
         2076,
         2078,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2079,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2080,
         2081,
         2080,
         2082,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2083,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2084,
         2085,
         2084,
         2086,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2087,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         123,
         124,
         123,
         469,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         470,
         123,
         123,
         471,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         121,
         122,
         472,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         473,
         474,
         473,
         475,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         476,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         121,
         122,
         121,
         467,
         477,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         479,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         480,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         481,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         482,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         483,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         484,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         485,
         486,
         485,
         487,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         488,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         490,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         491,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         492,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         493,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         494,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         495,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         496,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         497,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         498,
         499,
         498,
         500,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         501,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         502,
         503,
         502,
         504,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         505,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         506,
         507,
         506,
         508,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         509,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         510,
         511,
         510,
         512,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         513,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         514,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         515,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         516,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         517,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         518,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         519,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         520,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         521,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         522,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         523,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         2072,
         2073,
         2072,
         2074,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2075,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2076,
         2077,
         2076,
         2078,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2079,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2080,
         2081,
         2080,
         2082,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2083,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2084,
         2085,
         2084,
         2086,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2087,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         123,
         124,
         123,
         469,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         470,
         123,
         123,
         471,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         2750,
         2742,
         123,
         2743,
         123,
         121,
         122,
         472,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         473,
         474,
         473,
         475,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         476,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         121,
         122,
         121,
         467,
         477,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         479,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         480,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         481,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         482,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         483,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         484,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         485,
         486,
         485,
         487,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         488,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         490,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         491,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         492,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         493,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         494,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         495,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         496,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         497,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         498,
         499,
         498,
         500,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         501,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         502,
         503,
         502,
         504,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         505,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         506,
         507,
         506,
         508,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         509,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         510,
         511,
         510,
         512,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         513,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         514,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         515,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         516,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         517,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         518,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         519,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         520,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         521,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         2751,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         2744,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         2745,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         522,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         523,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         2072,
         2073,
         2072,
         2074,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2075,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2076,
         2077,
         2076,
         2078,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2079,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2080,
         2081,
         2080,
         2082,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2083,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2084,
         2085,
         2084,
         2086,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2087,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         123,
         124,
         123,
         469,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         470,
         123,
         123,
         471,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         2752,
         123,
         2743,
         123,
         121,
         122,
         472,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         473,
         474,
         473,
         475,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         476,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         121,
         122,
         121,
         467,
         477,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         479,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         480,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         481,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         482,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         483,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         484,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         485,
         486,
         485,
         487,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         488,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         490,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         491,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         492,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         493,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         494,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         495,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         496,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         497,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         498,
         499,
         498,
         500,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         501,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         502,
         503,
         502,
         504,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         505,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         506,
         507,
         506,
         508,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         509,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         510,
         511,
         510,
         512,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         513,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         514,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         515,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         516,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         517,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         518,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         519,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         520,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         521,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         2753,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         2745,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         522,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         523,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         2072,
         2073,
         2072,
         2074,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2075,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2076,
         2077,
         2076,
         2078,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2079,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2080,
         2081,
         2080,
         2082,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2083,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2084,
         2085,
         2084,
         2086,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2087,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         123,
         124,
         123,
         469,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         470,
         123,
         123,
         471,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         2742,
         2754,
         2743,
         123,
         121,
         122,
         472,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         473,
         474,
         473,
         475,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         476,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         121,
         122,
         121,
         467,
         477,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         479,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         480,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         481,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         482,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         483,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         484,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         485,
         486,
         485,
         487,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         488,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         490,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         491,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         492,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         493,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         494,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         495,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         496,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         497,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         498,
         499,
         498,
         500,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         501,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         502,
         503,
         502,
         504,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         505,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         506,
         507,
         506,
         508,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         509,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         510,
         511,
         510,
         512,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         513,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         514,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         515,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         516,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         517,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         518,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         519,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         520,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         521,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         2744,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         2755,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         2745,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         522,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         523,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         2072,
         2073,
         2072,
         2074,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2075,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2076,
         2077,
         2076,
         2078,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2079,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2080,
         2081,
         2080,
         2082,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2083,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2084,
         2085,
         2084,
         2086,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2087,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         123,
         124,
         123,
         469,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         470,
         123,
         123,
         471,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         2742,
         123,
         2756,
         123,
         121,
         122,
         472,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         473,
         474,
         473,
         475,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         476,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         121,
         122,
         121,
         467,
         477,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         479,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         480,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         481,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         482,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         483,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         484,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         485,
         486,
         485,
         487,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         488,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         490,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         491,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         492,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         493,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         494,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         495,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         496,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         497,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         498,
         499,
         498,
         500,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         501,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         502,
         503,
         502,
         504,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         505,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         506,
         507,
         506,
         508,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         509,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         510,
         511,
         510,
         512,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         513,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         514,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         515,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         516,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         517,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         518,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         519,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         520,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         521,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         2744,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         2757,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         522,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         523,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         2072,
         2073,
         2072,
         2074,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2075,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2076,
         2077,
         2076,
         2078,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2079,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2080,
         2081,
         2080,
         2082,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2083,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2084,
         2085,
         2084,
         2086,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2087,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         123,
         124,
         123,
         469,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         470,
         123,
         123,
         471,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         2742,
         123,
         2743,
         123,
         121,
         122,
         472,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         473,
         474,
         473,
         475,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         476,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         121,
         122,
         121,
         467,
         477,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         2220,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         479,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         480,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         481,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         482,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         483,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         484,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         485,
         486,
         485,
         487,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         488,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         490,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         491,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         492,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         493,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         494,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         495,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         496,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         497,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         498,
         499,
         498,
         500,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         501,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         502,
         503,
         502,
         504,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         505,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         506,
         507,
         506,
         508,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         509,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         510,
         511,
         510,
         512,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         513,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         514,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         515,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         516,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         517,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         518,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         519,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         520,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         521,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         2744,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         2745,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         522,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         523,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         2220,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         2072,
         2073,
         2072,
         2074,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2075,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2076,
         2077,
         2076,
         2078,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2079,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2080,
         2081,
         2080,
         2082,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2083,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2084,
         2085,
         2084,
         2086,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2087,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         2220,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         2220,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         2220,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         2220,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         123,
         124,
         123,
         469,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         470,
         123,
         123,
         471,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         2742,
         123,
         2743,
         123,
         121,
         122,
         472,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         473,
         474,
         473,
         475,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         476,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         121,
         122,
         121,
         467,
         477,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         479,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         480,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         481,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         482,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         483,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         484,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         485,
         486,
         485,
         487,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         488,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         490,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         491,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         492,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         493,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         494,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         495,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         496,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         497,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         498,
         499,
         498,
         500,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         501,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         502,
         503,
         502,
         504,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         505,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         506,
         507,
         506,
         508,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         509,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         510,
         511,
         510,
         512,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         513,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         514,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         515,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         516,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         517,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         518,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         519,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         520,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         521,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         2744,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         2745,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         522,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         523,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         2221,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         2072,
         2073,
         2072,
         2074,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2075,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2076,
         2077,
         2076,
         2078,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2079,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2080,
         2081,
         2080,
         2082,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2083,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2084,
         2085,
         2084,
         2086,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2087,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         2221,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         2221,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         2221,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         2221,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         123,
         124,
         123,
         469,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         470,
         123,
         123,
         471,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         121,
         122,
         472,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         473,
         474,
         473,
         475,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         476,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         121,
         122,
         121,
         467,
         477,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         479,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         480,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         481,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         482,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         483,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         484,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         485,
         486,
         485,
         487,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         488,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         490,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         491,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         492,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         493,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         494,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         495,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         496,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         497,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         498,
         499,
         498,
         500,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         501,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         502,
         503,
         502,
         504,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         505,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         506,
         507,
         506,
         508,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         509,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         510,
         511,
         510,
         512,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         513,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         514,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         515,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         516,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         517,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         518,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         519,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         520,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         521,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         581,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         582,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         583,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         584,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         585,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         522,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         523,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         2072,
         2073,
         2072,
         2074,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2075,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2076,
         2077,
         2076,
         2078,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2079,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2080,
         2081,
         2080,
         2082,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2083,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2084,
         2085,
         2084,
         2086,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2087,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         2758,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         2759,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         2746,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         2747,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         2748,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         2749,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         123,
         124,
         123,
         469,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         470,
         123,
         123,
         471,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         121,
         122,
         472,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         473,
         474,
         473,
         475,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         476,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         121,
         122,
         121,
         467,
         477,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         479,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         480,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         481,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         482,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         483,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         484,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         485,
         486,
         485,
         487,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         488,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         490,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         491,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         492,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         493,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         494,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         495,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         496,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         497,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         498,
         499,
         498,
         500,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         501,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         502,
         503,
         502,
         504,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         505,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         506,
         507,
         506,
         508,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         509,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         510,
         511,
         510,
         512,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         513,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         514,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         515,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         516,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         517,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         518,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         519,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         520,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         521,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         581,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         582,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         583,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         584,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         585,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         522,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         523,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         2072,
         2073,
         2072,
         2074,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2075,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2076,
         2077,
         2076,
         2078,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2079,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2080,
         2081,
         2080,
         2082,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2083,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2084,
         2085,
         2084,
         2086,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2087,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         2760,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         2761,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         2748,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         2749,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         123,
         124,
         123,
         469,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         470,
         123,
         123,
         471,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         121,
         122,
         472,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         473,
         474,
         473,
         475,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         476,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         121,
         122,
         121,
         467,
         477,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         479,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         480,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         481,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         482,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         483,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         484,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         485,
         486,
         485,
         487,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         488,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         490,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         491,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         492,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         493,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         494,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         495,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         496,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         497,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         498,
         499,
         498,
         500,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         501,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         502,
         503,
         502,
         504,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         505,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         506,
         507,
         506,
         508,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         509,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         510,
         511,
         510,
         512,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         513,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         514,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         515,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         516,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         517,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         518,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         519,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         520,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         521,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         581,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         582,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         583,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         584,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         585,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         522,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         523,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         2072,
         2073,
         2072,
         2074,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2075,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2076,
         2077,
         2076,
         2078,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2079,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2080,
         2081,
         2080,
         2082,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2083,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2084,
         2085,
         2084,
         2086,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2087,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         2746,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         2747,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         2762,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         2763,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         2748,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         2749,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         123,
         124,
         123,
         469,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         470,
         123,
         123,
         471,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         121,
         122,
         472,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         473,
         474,
         473,
         475,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         476,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         121,
         122,
         121,
         467,
         477,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         479,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         480,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         481,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         482,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         483,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         484,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         485,
         486,
         485,
         487,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         488,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         490,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         491,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         492,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         493,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         494,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         495,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         496,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         497,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         498,
         499,
         498,
         500,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         501,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         502,
         503,
         502,
         504,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         505,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         506,
         507,
         506,
         508,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         509,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         510,
         511,
         510,
         512,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         513,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         514,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         515,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         516,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         517,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         518,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         519,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         520,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         521,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         581,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         582,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         583,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         584,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         585,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         522,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         523,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         2072,
         2073,
         2072,
         2074,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2075,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2076,
         2077,
         2076,
         2078,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2079,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2080,
         2081,
         2080,
         2082,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2083,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2084,
         2085,
         2084,
         2086,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2087,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         2746,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         2747,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         2764,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         2765,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         123,
         124,
         123,
         469,
         123,
         2222,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         470,
         123,
         123,
         471,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         2222,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         2222,
         2222,
         2222,
         2222,
         123,
         121,
         122,
         472,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         473,
         474,
         473,
         475,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         476,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         121,
         122,
         121,
         467,
         477,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         479,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         480,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         481,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         482,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         483,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         484,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         485,
         486,
         485,
         487,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         488,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         490,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         491,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         492,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         493,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         494,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         495,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         496,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         497,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         498,
         499,
         498,
         500,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         501,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         502,
         503,
         502,
         504,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         505,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         506,
         507,
         506,
         508,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         509,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         510,
         511,
         510,
         512,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         513,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         514,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         515,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         516,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         517,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         518,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         519,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         520,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         521,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         581,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         582,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         583,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         584,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         585,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         522,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         523,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         2072,
         2073,
         2072,
         2074,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2075,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2076,
         2077,
         2076,
         2078,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2079,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2080,
         2081,
         2080,
         2082,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2083,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2084,
         2085,
         2084,
         2086,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2087,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         2746,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         2747,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         2748,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         2749,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         123,
         124,
         123,
         469,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         470,
         123,
         123,
         471,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         2223,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         2223,
         2223,
         2223,
         2223,
         123,
         121,
         122,
         472,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         473,
         474,
         473,
         475,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         476,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         121,
         122,
         121,
         467,
         477,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         479,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         480,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         481,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         482,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         483,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         484,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         485,
         486,
         485,
         487,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         488,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         490,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         491,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         492,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         493,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         494,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         495,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         496,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         497,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         498,
         499,
         498,
         500,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         501,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         502,
         503,
         502,
         504,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         505,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         506,
         507,
         506,
         508,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         509,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         510,
         511,
         510,
         512,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         513,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         514,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         515,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         516,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         517,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         518,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         519,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         520,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         521,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         581,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         582,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         583,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         584,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         585,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         522,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         523,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         2072,
         2073,
         2072,
         2074,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2075,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2076,
         2077,
         2076,
         2078,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2079,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2080,
         2081,
         2080,
         2082,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2083,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2084,
         2085,
         2084,
         2086,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2087,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         2746,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         2747,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         2748,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         2749,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         840,
         841,
         840,
         842,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         844,
         845,
         844,
         846,
         844,
         2224,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         847,
         844,
         844,
         848,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         2225,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         844,
         2225,
         2225,
         2225,
         2225,
         844,
         840,
         841,
         849,
         842,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         850,
         851,
         850,
         852,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         853,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         850,
         840,
         841,
         840,
         842,
         854,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         841,
         840,
         842,
         840,
         855,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         855,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         855,
         855,
         855,
         855,
         840,
         840,
         841,
         840,
         842,
         840,
         840,
         856,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         841,
         840,
         842,
         840,
         840,
         840,
         857,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         841,
         840,
         842,
         840,
         840,
         840,
         840,
         858,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         841,
         840,
         842,
         840,
         840,
         840,
         840,
         840,
         859,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         841,
         840,
         842,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         841,
         840,
         842,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         841,
         840,
         842,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         860,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         841,
         840,
         842,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         861,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         862,
         863,
         862,
         864,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         865,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         862,
         840,
         841,
         840,
         842,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         841,
         840,
         842,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         866,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         866,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         867,
         840,
         842,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         868,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         841,
         840,
         842,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         841,
         840,
         842,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         841,
         840,
         842,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         841,
         840,
         842,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         841,
         840,
         842,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         841,
         840,
         842,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         841,
         840,
         842,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         841,
         840,
         842,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         841,
         840,
         842,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         841,
         840,
         842,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         841,
         840,
         842,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         869,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         841,
         840,
         842,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         870,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         841,
         840,
         842,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         871,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         841,
         840,
         842,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         872,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         841,
         840,
         842,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         873,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         841,
         840,
         842,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         874,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         875,
         876,
         875,
         877,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         878,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         875,
         879,
         880,
         879,
         881,
         879,
         879,
         879,
         879,
         879,
         879,
         879,
         879,
         879,
         879,
         882,
         879,
         879,
         879,
         879,
         879,
         879,
         879,
         879,
         879,
         879,
         879,
         879,
         879,
         879,
         879,
         879,
         879,
         879,
         879,
         879,
         879,
         879,
         879,
         879,
         879,
         879,
         879,
         879,
         879,
         879,
         879,
         879,
         879,
         879,
         879,
         879,
         879,
         879,
         879,
         879,
         879,
         879,
         879,
         879,
         879,
         879,
         879,
         879,
         879,
         879,
         879,
         879,
         879,
         879,
         879,
         879,
         879,
         879,
         879,
         879,
         879,
         879,
         879,
         879,
         879,
         879,
         879,
         879,
         879,
         883,
         884,
         883,
         885,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         886,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         883,
         887,
         888,
         887,
         889,
         887,
         887,
         887,
         887,
         887,
         887,
         887,
         887,
         887,
         887,
         890,
         887,
         887,
         887,
         887,
         887,
         887,
         887,
         887,
         887,
         887,
         887,
         887,
         887,
         887,
         887,
         887,
         887,
         887,
         887,
         887,
         887,
         887,
         887,
         887,
         887,
         887,
         887,
         887,
         887,
         887,
         887,
         887,
         887,
         887,
         887,
         887,
         887,
         887,
         887,
         887,
         887,
         887,
         887,
         887,
         887,
         887,
         887,
         887,
         887,
         887,
         887,
         887,
         887,
         887,
         887,
         887,
         887,
         887,
         887,
         887,
         887,
         887,
         887,
         887,
         887,
         887,
         887,
         887,
         887,
         840,
         841,
         840,
         842,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         891,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         841,
         840,
         842,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         892,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         841,
         840,
         842,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         893,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         841,
         840,
         842,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         894,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         841,
         840,
         842,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         895,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         841,
         840,
         842,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         896,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         841,
         840,
         842,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         897,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         841,
         840,
         842,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         898,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         841,
         840,
         842,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         841,
         840,
         842,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         841,
         840,
         842,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         841,
         840,
         842,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         841,
         840,
         842,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         841,
         840,
         842,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         899,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         841,
         840,
         842,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         900,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         841,
         840,
         842,
         840,
         855,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         855,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         855,
         855,
         855,
         855,
         840,
         840,
         841,
         840,
         842,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         841,
         840,
         842,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         841,
         840,
         842,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         841,
         840,
         842,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         841,
         840,
         842,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         841,
         840,
         842,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         841,
         840,
         842,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         841,
         840,
         842,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         841,
         840,
         842,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         841,
         840,
         842,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         841,
         840,
         842,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         841,
         840,
         842,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         841,
         840,
         842,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         841,
         840,
         842,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         841,
         840,
         842,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         841,
         840,
         842,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         866,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         866,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         2171,
         2172,
         2171,
         2173,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2174,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2171,
         2175,
         2176,
         2175,
         2177,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2178,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2175,
         2179,
         2180,
         2179,
         2181,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2182,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2179,
         2183,
         2184,
         2183,
         2185,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         2186,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         2183,
         840,
         841,
         840,
         842,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         841,
         840,
         842,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         841,
         840,
         842,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         841,
         840,
         842,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         841,
         840,
         842,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         841,
         840,
         842,
         840,
         855,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         855,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         855,
         855,
         855,
         855,
         840,
         840,
         841,
         840,
         842,
         840,
         855,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         855,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         855,
         855,
         855,
         855,
         840,
         840,
         841,
         840,
         842,
         840,
         855,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         855,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         855,
         855,
         855,
         855,
         840,
         840,
         841,
         840,
         842,
         840,
         855,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         855,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         855,
         855,
         855,
         855,
         840,
         840,
         841,
         840,
         842,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         843,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         840,
         962,
         963,
         962,
         964,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         966,
         967,
         966,
         968,
         966,
         966,
         966,
         966,
         966,
         966,
         966,
         966,
         966,
         966,
         969,
         966,
         966,
         970,
         966,
         966,
         966,
         966,
         966,
         966,
         966,
         966,
         966,
         966,
         966,
         966,
         966,
         966,
         966,
         966,
         966,
         966,
         966,
         966,
         966,
         966,
         966,
         966,
         966,
         966,
         966,
         966,
         966,
         966,
         966,
         966,
         966,
         966,
         966,
         966,
         966,
         966,
         966,
         966,
         966,
         966,
         966,
         966,
         966,
         966,
         966,
         966,
         966,
         966,
         966,
         966,
         966,
         966,
         966,
         966,
         966,
         966,
         966,
         966,
         966,
         966,
         966,
         966,
         966,
         966,
         962,
         963,
         971,
         964,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         972,
         973,
         972,
         974,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         975,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         972,
         962,
         963,
         962,
         964,
         976,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         2226,
         962,
         964,
         962,
         977,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         977,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         977,
         977,
         977,
         977,
         962,
         962,
         963,
         962,
         964,
         962,
         962,
         978,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         963,
         962,
         964,
         962,
         962,
         962,
         979,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         963,
         962,
         964,
         962,
         962,
         962,
         962,
         980,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         963,
         962,
         964,
         962,
         962,
         962,
         962,
         962,
         981,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         963,
         962,
         964,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         963,
         962,
         964,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         963,
         962,
         964,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         982,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         963,
         962,
         964,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         983,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         984,
         985,
         984,
         986,
         984,
         984,
         984,
         984,
         984,
         984,
         984,
         984,
         984,
         984,
         987,
         984,
         984,
         984,
         984,
         984,
         984,
         984,
         984,
         984,
         984,
         984,
         984,
         984,
         984,
         984,
         984,
         984,
         984,
         984,
         984,
         984,
         984,
         984,
         984,
         984,
         984,
         984,
         984,
         984,
         984,
         984,
         984,
         984,
         984,
         984,
         984,
         984,
         984,
         984,
         984,
         984,
         984,
         984,
         984,
         984,
         984,
         984,
         984,
         984,
         984,
         984,
         984,
         984,
         984,
         984,
         984,
         984,
         984,
         984,
         984,
         984,
         984,
         984,
         984,
         984,
         984,
         984,
         984,
         984,
         962,
         963,
         962,
         964,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         963,
         962,
         964,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         988,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         988,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         989,
         962,
         964,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         990,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         963,
         962,
         964,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         963,
         962,
         964,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         963,
         962,
         964,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         963,
         962,
         964,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         963,
         962,
         964,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         963,
         962,
         964,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         963,
         962,
         964,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         963,
         962,
         964,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         963,
         962,
         964,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         963,
         962,
         964,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         963,
         962,
         964,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         991,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         963,
         962,
         964,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         992,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         963,
         962,
         964,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         993,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         963,
         962,
         964,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         994,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         963,
         962,
         964,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         995,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         963,
         962,
         964,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         996,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         997,
         998,
         997,
         999,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         1000,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         997,
         1001,
         1002,
         1001,
         1003,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1004,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1001,
         1005,
         1006,
         1005,
         1007,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1008,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1005,
         1009,
         1010,
         1009,
         1011,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         1012,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         1009,
         962,
         963,
         962,
         964,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         1013,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         963,
         962,
         964,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         1014,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         963,
         962,
         964,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         1015,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         963,
         962,
         964,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         1016,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         963,
         962,
         964,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         1017,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         963,
         962,
         964,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         1018,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         963,
         962,
         964,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         1019,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         963,
         962,
         964,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         1020,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         963,
         962,
         964,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         963,
         962,
         964,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         963,
         962,
         964,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         963,
         962,
         964,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         963,
         962,
         964,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         963,
         962,
         964,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         1021,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         963,
         962,
         964,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         1022,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         2227,
         962,
         964,
         962,
         977,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         977,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         977,
         977,
         977,
         977,
         962,
         962,
         963,
         962,
         964,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         963,
         962,
         964,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         963,
         962,
         964,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         963,
         962,
         964,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         963,
         962,
         964,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         963,
         962,
         964,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         963,
         962,
         964,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         963,
         962,
         964,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         963,
         962,
         964,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         963,
         962,
         964,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         963,
         962,
         964,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         963,
         962,
         964,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         963,
         962,
         964,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         963,
         962,
         964,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         963,
         962,
         964,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         963,
         962,
         964,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         988,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         988,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         2204,
         2205,
         2204,
         2206,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2207,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2204,
         2208,
         2209,
         2208,
         2210,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2211,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2208,
         2212,
         2213,
         2212,
         2214,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2215,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2212,
         2216,
         2217,
         2216,
         2218,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         2219,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         2216,
         962,
         963,
         962,
         964,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         963,
         962,
         964,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         963,
         962,
         964,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         963,
         962,
         964,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         963,
         962,
         964,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         2227,
         962,
         964,
         962,
         977,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         977,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         977,
         977,
         977,
         977,
         962,
         962,
         2227,
         962,
         964,
         962,
         977,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         977,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         977,
         977,
         977,
         977,
         962,
         962,
         2227,
         962,
         964,
         962,
         977,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         977,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         977,
         977,
         977,
         977,
         962,
         962,
         2227,
         962,
         964,
         962,
         977,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         977,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         977,
         977,
         977,
         977,
         962,
         962,
         963,
         962,
         964,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         965,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         962,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         123,
         124,
         123,
         469,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         470,
         123,
         123,
         471,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         121,
         122,
         472,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         473,
         474,
         473,
         475,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         476,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         121,
         122,
         121,
         467,
         477,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         479,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         480,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         481,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         482,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         483,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         484,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         485,
         486,
         485,
         487,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         488,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         490,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         491,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         492,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         493,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         494,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         495,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         496,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         497,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         498,
         499,
         498,
         500,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         501,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         502,
         503,
         502,
         504,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         505,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         506,
         507,
         506,
         508,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         509,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         510,
         511,
         510,
         512,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         513,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         514,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         515,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         516,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         517,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         518,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         519,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         520,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         521,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         522,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         523,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         2072,
         2073,
         2072,
         2074,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2075,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2076,
         2077,
         2076,
         2078,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2079,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2080,
         2081,
         2080,
         2082,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2083,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2084,
         2085,
         2084,
         2086,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2087,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         123,
         124,
         123,
         469,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         470,
         123,
         123,
         471,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         121,
         122,
         472,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         473,
         474,
         473,
         475,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         476,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         121,
         122,
         121,
         467,
         477,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         479,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         480,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         481,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         482,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         483,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         484,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         485,
         486,
         485,
         487,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         488,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         490,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         491,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         492,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         493,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         494,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         495,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         496,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         497,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         498,
         499,
         498,
         500,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         501,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         502,
         503,
         502,
         504,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         505,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         506,
         507,
         506,
         508,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         509,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         510,
         511,
         510,
         512,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         513,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         514,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         515,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         516,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         517,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         518,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         519,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         520,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         521,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         522,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         523,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         2072,
         2073,
         2072,
         2074,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2075,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2076,
         2077,
         2076,
         2078,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2079,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2080,
         2081,
         2080,
         2082,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2083,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2084,
         2085,
         2084,
         2086,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2087,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         123,
         124,
         123,
         469,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         470,
         123,
         123,
         471,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         121,
         122,
         472,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         473,
         474,
         473,
         475,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         476,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         121,
         122,
         121,
         467,
         477,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         479,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         480,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         481,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         482,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         483,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         484,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         485,
         486,
         485,
         487,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         488,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         490,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         491,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         492,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         493,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         494,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         495,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         496,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         497,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         498,
         499,
         498,
         500,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         501,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         502,
         503,
         502,
         504,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         505,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         506,
         507,
         506,
         508,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         509,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         510,
         511,
         510,
         512,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         513,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         514,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         515,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         516,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         517,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         518,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         519,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         520,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         521,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         522,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         523,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         2072,
         2073,
         2072,
         2074,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2075,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2076,
         2077,
         2076,
         2078,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2079,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2080,
         2081,
         2080,
         2082,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2083,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2084,
         2085,
         2084,
         2086,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2087,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         123,
         124,
         123,
         469,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         470,
         123,
         123,
         471,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         121,
         122,
         472,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         473,
         474,
         473,
         475,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         476,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         121,
         122,
         121,
         467,
         477,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         479,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         480,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         481,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         482,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         483,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         484,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         485,
         486,
         485,
         487,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         488,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         490,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         491,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         492,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         493,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         494,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         495,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         496,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         497,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         498,
         499,
         498,
         500,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         501,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         502,
         503,
         502,
         504,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         505,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         506,
         507,
         506,
         508,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         509,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         510,
         511,
         510,
         512,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         513,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         514,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         515,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         516,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         517,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         518,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         519,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         520,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         521,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         522,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         523,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         2072,
         2073,
         2072,
         2074,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2075,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2076,
         2077,
         2076,
         2078,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2079,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2080,
         2081,
         2080,
         2082,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2083,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2084,
         2085,
         2084,
         2086,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2087,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         123,
         124,
         123,
         469,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         470,
         123,
         123,
         471,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         121,
         122,
         472,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         473,
         474,
         473,
         475,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         476,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         121,
         122,
         121,
         467,
         477,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         479,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         480,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         481,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         482,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         483,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         484,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         485,
         486,
         485,
         487,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         488,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         490,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         491,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         492,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         493,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         494,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         495,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         496,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         497,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         498,
         499,
         498,
         500,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         501,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         502,
         503,
         502,
         504,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         505,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         506,
         507,
         506,
         508,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         509,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         510,
         511,
         510,
         512,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         513,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         514,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         515,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         516,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         517,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         518,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         519,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         520,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         521,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         522,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         523,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         2072,
         2073,
         2072,
         2074,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2075,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2076,
         2077,
         2076,
         2078,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2079,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2080,
         2081,
         2080,
         2082,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2083,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2084,
         2085,
         2084,
         2086,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2087,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         905,
         906,
         905,
         907,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         908,
         905,
         905,
         909,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         901,
         902,
         910,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         911,
         912,
         911,
         913,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         914,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         901,
         902,
         901,
         903,
         915,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         916,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         916,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         916,
         916,
         916,
         916,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         917,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         918,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         919,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         920,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         921,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         922,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         923,
         924,
         923,
         925,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         926,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         927,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         927,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         928,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         929,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         930,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         931,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         932,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         933,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         934,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         935,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         936,
         937,
         936,
         938,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         939,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         940,
         941,
         940,
         942,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         943,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         944,
         945,
         944,
         946,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         947,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         948,
         949,
         948,
         950,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         951,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         952,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         953,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         954,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         955,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         956,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         957,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         958,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         959,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         2228,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         960,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         961,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         916,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         916,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         916,
         916,
         916,
         916,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         927,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         927,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         2187,
         2188,
         2187,
         2189,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2190,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2191,
         2192,
         2191,
         2193,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2194,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2195,
         2196,
         2195,
         2197,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2198,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2199,
         2200,
         2199,
         2201,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2202,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         916,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         916,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         916,
         916,
         916,
         916,
         901,
         901,
         902,
         901,
         903,
         901,
         916,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         916,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         916,
         916,
         916,
         916,
         901,
         901,
         902,
         901,
         903,
         901,
         916,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         916,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         916,
         916,
         916,
         916,
         901,
         901,
         902,
         901,
         903,
         901,
         916,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         916,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         916,
         916,
         916,
         916,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         905,
         906,
         905,
         907,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         908,
         905,
         905,
         909,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         901,
         902,
         910,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         911,
         912,
         911,
         913,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         914,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         901,
         902,
         901,
         903,
         915,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         916,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         916,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         916,
         916,
         916,
         916,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         917,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         918,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         919,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         920,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         921,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         922,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         923,
         924,
         923,
         925,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         926,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         927,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         927,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         928,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         929,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         930,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         931,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         932,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         933,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         934,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         935,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         936,
         937,
         936,
         938,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         939,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         940,
         941,
         940,
         942,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         943,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         944,
         945,
         944,
         946,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         947,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         948,
         949,
         948,
         950,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         951,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         952,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         953,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         954,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         955,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         956,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         957,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         958,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         959,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         2229,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         960,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         961,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         916,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         916,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         916,
         916,
         916,
         916,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         927,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         927,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         2187,
         2188,
         2187,
         2189,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2190,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2191,
         2192,
         2191,
         2193,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2194,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2195,
         2196,
         2195,
         2197,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2198,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2199,
         2200,
         2199,
         2201,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2202,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         916,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         916,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         916,
         916,
         916,
         916,
         901,
         901,
         902,
         901,
         903,
         901,
         916,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         916,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         916,
         916,
         916,
         916,
         901,
         901,
         902,
         901,
         903,
         901,
         916,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         916,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         916,
         916,
         916,
         916,
         901,
         901,
         902,
         901,
         903,
         901,
         916,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         916,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         916,
         916,
         916,
         916,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         905,
         906,
         905,
         907,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         908,
         905,
         905,
         909,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         901,
         902,
         910,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         911,
         912,
         911,
         913,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         914,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         901,
         902,
         901,
         903,
         915,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         916,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         916,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         916,
         916,
         916,
         916,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         917,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         918,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         919,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         920,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         921,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         922,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         923,
         924,
         923,
         925,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         926,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         927,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         927,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         928,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         929,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         930,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         931,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         932,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         933,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         934,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         935,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         936,
         937,
         936,
         938,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         939,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         940,
         941,
         940,
         942,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         943,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         944,
         945,
         944,
         946,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         947,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         948,
         949,
         948,
         950,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         951,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         952,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         953,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         954,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         955,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         956,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         957,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         958,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         959,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         2230,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         960,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         961,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         916,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         916,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         916,
         916,
         916,
         916,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         927,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         927,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         2187,
         2188,
         2187,
         2189,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2190,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2191,
         2192,
         2191,
         2193,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2194,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2195,
         2196,
         2195,
         2197,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2198,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2199,
         2200,
         2199,
         2201,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2202,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         916,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         916,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         916,
         916,
         916,
         916,
         901,
         901,
         902,
         901,
         903,
         901,
         916,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         916,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         916,
         916,
         916,
         916,
         901,
         901,
         902,
         901,
         903,
         901,
         916,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         916,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         916,
         916,
         916,
         916,
         901,
         901,
         902,
         901,
         903,
         901,
         916,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         916,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         916,
         916,
         916,
         916,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         905,
         906,
         905,
         907,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         908,
         905,
         905,
         909,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         901,
         902,
         910,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         911,
         912,
         911,
         913,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         914,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         901,
         902,
         901,
         903,
         915,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         916,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         916,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         916,
         916,
         916,
         916,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         917,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         918,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         919,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         920,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         921,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         922,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         923,
         924,
         923,
         925,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         926,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         927,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         927,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         928,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         929,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         930,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         931,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         932,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         933,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         934,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         935,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         936,
         937,
         936,
         938,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         939,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         940,
         941,
         940,
         942,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         943,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         944,
         945,
         944,
         946,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         947,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         948,
         949,
         948,
         950,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         951,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         952,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         953,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         954,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         955,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         956,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         957,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         958,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         959,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         2231,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         960,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         961,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         916,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         916,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         916,
         916,
         916,
         916,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         927,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         927,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         2187,
         2188,
         2187,
         2189,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2190,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2191,
         2192,
         2191,
         2193,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2194,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2195,
         2196,
         2195,
         2197,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2198,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2199,
         2200,
         2199,
         2201,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2202,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         916,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         916,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         916,
         916,
         916,
         916,
         901,
         901,
         902,
         901,
         903,
         901,
         916,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         916,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         916,
         916,
         916,
         916,
         901,
         901,
         902,
         901,
         903,
         901,
         916,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         916,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         916,
         916,
         916,
         916,
         901,
         901,
         902,
         901,
         903,
         901,
         916,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         916,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         916,
         916,
         916,
         916,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         905,
         906,
         905,
         907,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         908,
         905,
         905,
         909,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         905,
         901,
         902,
         910,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         911,
         912,
         911,
         913,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         914,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         911,
         901,
         902,
         901,
         903,
         915,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         916,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         916,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         916,
         916,
         916,
         916,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         917,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         918,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         919,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         920,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         921,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         922,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         923,
         924,
         923,
         925,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         926,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         923,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         927,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         927,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         928,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         929,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         930,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         931,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         932,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         933,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         934,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         935,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         936,
         937,
         936,
         938,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         939,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         936,
         940,
         941,
         940,
         942,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         943,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         940,
         944,
         945,
         944,
         946,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         947,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         944,
         948,
         949,
         948,
         950,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         951,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         948,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         952,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         953,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         954,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         955,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         956,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         957,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         958,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         959,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         2232,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         960,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         961,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         916,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         916,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         916,
         916,
         916,
         916,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         927,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         927,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         2187,
         2188,
         2187,
         2189,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2190,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2187,
         2191,
         2192,
         2191,
         2193,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2194,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2191,
         2195,
         2196,
         2195,
         2197,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2198,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2195,
         2199,
         2200,
         2199,
         2201,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2202,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         2199,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         902,
         901,
         903,
         901,
         916,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         916,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         916,
         916,
         916,
         916,
         901,
         901,
         902,
         901,
         903,
         901,
         916,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         916,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         916,
         916,
         916,
         916,
         901,
         901,
         902,
         901,
         903,
         901,
         916,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         916,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         916,
         916,
         916,
         916,
         901,
         901,
         902,
         901,
         903,
         901,
         916,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         916,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         916,
         916,
         916,
         916,
         901,
         901,
         902,
         901,
         903,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         904,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         901,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         123,
         124,
         123,
         469,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         470,
         123,
         123,
         471,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         121,
         122,
         472,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         473,
         474,
         473,
         475,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         476,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         121,
         122,
         121,
         467,
         477,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         479,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         480,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         481,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         482,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         483,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         484,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         485,
         486,
         485,
         487,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         488,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         490,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         491,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         492,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         493,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         494,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         495,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         496,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         497,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         498,
         499,
         498,
         500,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         501,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         502,
         503,
         502,
         504,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         505,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         506,
         507,
         506,
         508,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         509,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         510,
         511,
         510,
         512,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         513,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         514,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         515,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         516,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         517,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         518,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         519,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         520,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         521,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         522,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         523,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         2072,
         2073,
         2072,
         2074,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2075,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2076,
         2077,
         2076,
         2078,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2079,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2080,
         2081,
         2080,
         2082,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2083,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2084,
         2085,
         2084,
         2086,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2087,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         123,
         124,
         123,
         469,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         470,
         123,
         123,
         471,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         121,
         122,
         472,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         473,
         474,
         473,
         475,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         476,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         121,
         122,
         121,
         467,
         477,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         479,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         480,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         481,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         482,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         483,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         484,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         485,
         486,
         485,
         487,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         488,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         490,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         491,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         492,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         493,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         494,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         495,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         496,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         497,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         498,
         499,
         498,
         500,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         501,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         502,
         503,
         502,
         504,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         505,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         506,
         507,
         506,
         508,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         509,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         510,
         511,
         510,
         512,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         513,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         514,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         515,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         516,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         517,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         518,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         519,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         520,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         521,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         522,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         523,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         2072,
         2073,
         2072,
         2074,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2075,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2076,
         2077,
         2076,
         2078,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2079,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2080,
         2081,
         2080,
         2082,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2083,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2084,
         2085,
         2084,
         2086,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2087,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         123,
         124,
         123,
         469,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         470,
         123,
         123,
         471,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         121,
         122,
         472,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         473,
         474,
         473,
         475,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         476,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         121,
         122,
         121,
         467,
         477,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         479,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         480,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         481,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         482,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         483,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         484,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         485,
         486,
         485,
         487,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         488,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         490,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         491,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         492,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         493,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         494,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         495,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         496,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         497,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         498,
         499,
         498,
         500,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         501,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         502,
         503,
         502,
         504,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         505,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         506,
         507,
         506,
         508,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         509,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         510,
         511,
         510,
         512,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         513,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         514,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         515,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         516,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         517,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         518,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         519,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         520,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         521,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         522,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         523,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         2072,
         2073,
         2072,
         2074,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2075,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2076,
         2077,
         2076,
         2078,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2079,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2080,
         2081,
         2080,
         2082,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2083,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2084,
         2085,
         2084,
         2086,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2087,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         123,
         124,
         123,
         469,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         470,
         123,
         123,
         471,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         121,
         122,
         472,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         473,
         474,
         473,
         475,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         476,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         121,
         122,
         121,
         467,
         477,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         479,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         480,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         481,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         482,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         483,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         484,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         485,
         486,
         485,
         487,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         488,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         490,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         491,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         492,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         493,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         494,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         495,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         496,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         497,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         498,
         499,
         498,
         500,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         501,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         502,
         503,
         502,
         504,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         505,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         506,
         507,
         506,
         508,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         509,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         510,
         511,
         510,
         512,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         513,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         514,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         515,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         516,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         517,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         518,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         519,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         520,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         521,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         522,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         523,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         2072,
         2073,
         2072,
         2074,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2075,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2076,
         2077,
         2076,
         2078,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2079,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2080,
         2081,
         2080,
         2082,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2083,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2084,
         2085,
         2084,
         2086,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2087,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         123,
         124,
         123,
         469,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         470,
         123,
         123,
         471,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         123,
         121,
         122,
         472,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         473,
         474,
         473,
         475,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         476,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         473,
         121,
         122,
         121,
         467,
         477,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         479,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         480,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         481,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         482,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         483,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         484,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         485,
         486,
         485,
         487,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         488,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         485,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         490,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         491,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         492,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         493,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         494,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         495,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         496,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         497,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         498,
         499,
         498,
         500,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         501,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         498,
         502,
         503,
         502,
         504,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         505,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         502,
         506,
         507,
         506,
         508,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         509,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         506,
         510,
         511,
         510,
         512,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         513,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         510,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         514,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         515,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         516,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         517,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         518,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         519,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         520,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         521,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         522,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         523,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         489,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         2072,
         2073,
         2072,
         2074,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2075,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2072,
         2076,
         2077,
         2076,
         2078,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2079,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2076,
         2080,
         2081,
         2080,
         2082,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2083,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2080,
         2084,
         2085,
         2084,
         2086,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2087,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         2084,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         478,
         478,
         478,
         478,
         121,
         121,
         122,
         121,
         467,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         468,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
         121,
      },
   },
   [nir_op_feq] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         3,
         0,
         0,
         4,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         12,
         13,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         17,
         2,
         2,
         2,
         2,
         2,
         18,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         4,
         4,
         4,
         4,
         4,
         19,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         20,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         9,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         8,
         0,
         0,
         0,
         13,
         13,
         13,
         13,
         14,
         14,
         14,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         6,
         6,
         4,
         4,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         4,
         4,
         4,
         21,
         4,
         4,
         0,
         2,
         2,
         18,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         21,
         4,
         4,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 22,
      .table = (const uint16_t []) {
      
         129,
         130,
         1422,
         129,
         1423,
         1423,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         1422,
         1422,
         1423,
         129,
         1423,
         130,
         130,
         1424,
         1425,
         1426,
         1427,
         1428,
         1429,
         1430,
         1431,
         130,
         1432,
         1433,
         1434,
         1435,
         2290,
         2291,
         2292,
         1424,
         2293,
         2294,
         2864,
         1422,
         1424,
         1436,
         1422,
         1437,
         1437,
         1422,
         1422,
         1422,
         1422,
         1422,
         1422,
         1422,
         1422,
         1422,
         1422,
         1422,
         1436,
         1436,
         1437,
         1422,
         1437,
         129,
         1425,
         1422,
         129,
         1423,
         1423,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         1422,
         1422,
         1423,
         129,
         1423,
         1423,
         1426,
         1437,
         1423,
         1423,
         1423,
         1423,
         1423,
         1423,
         1423,
         1423,
         1423,
         1423,
         1423,
         1423,
         1423,
         1423,
         1437,
         1437,
         1423,
         1423,
         1423,
         1423,
         1427,
         1437,
         1423,
         1423,
         1423,
         1423,
         1423,
         1423,
         1423,
         1423,
         1423,
         1423,
         1423,
         1423,
         1423,
         1423,
         1437,
         1437,
         1423,
         1423,
         1423,
         129,
         1428,
         1422,
         129,
         1423,
         1423,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         1422,
         1422,
         1423,
         129,
         1423,
         129,
         1429,
         1422,
         129,
         1423,
         1423,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         1422,
         1422,
         1423,
         129,
         1423,
         129,
         1430,
         1422,
         129,
         1423,
         1423,
         129,
         129,
         1438,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         1422,
         2295,
         1423,
         129,
         1423,
         129,
         1431,
         1422,
         129,
         1423,
         1423,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         1422,
         1422,
         1423,
         129,
         1423,
         129,
         130,
         1422,
         129,
         1423,
         1423,
         129,
         129,
         129,
         129,
         1439,
         129,
         129,
         129,
         129,
         129,
         129,
         1422,
         1422,
         1423,
         129,
         1423,
         129,
         1432,
         1422,
         129,
         1423,
         1423,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         1422,
         1422,
         1423,
         129,
         1423,
         129,
         1433,
         1422,
         129,
         1423,
         1423,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         1422,
         1422,
         1423,
         129,
         1423,
         129,
         1434,
         1422,
         129,
         1423,
         1423,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         1422,
         1422,
         1423,
         129,
         1423,
         129,
         1435,
         1422,
         129,
         1423,
         1423,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         1422,
         1422,
         1423,
         129,
         1423,
         129,
         2290,
         1422,
         129,
         1423,
         1423,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         1422,
         1422,
         1423,
         129,
         1423,
         129,
         2291,
         1422,
         129,
         1423,
         1423,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         1422,
         1422,
         1423,
         129,
         1423,
         1422,
         2292,
         1436,
         1422,
         1437,
         1437,
         1422,
         1422,
         1422,
         1422,
         1422,
         1422,
         1422,
         1422,
         1422,
         1422,
         1422,
         1436,
         1436,
         1437,
         1422,
         1437,
         1422,
         1424,
         1436,
         1422,
         1437,
         1437,
         1422,
         1422,
         2295,
         1422,
         1422,
         1422,
         1422,
         1422,
         1422,
         1422,
         1422,
         1436,
         2296,
         1437,
         1422,
         1437,
         1423,
         2293,
         1437,
         1423,
         1423,
         1423,
         1423,
         1423,
         1423,
         1423,
         1423,
         1423,
         1423,
         1423,
         1423,
         1423,
         1423,
         1437,
         1437,
         1423,
         1423,
         1423,
         129,
         2294,
         1422,
         129,
         1423,
         1423,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         129,
         1422,
         1422,
         1423,
         129,
         1423,
         1423,
         2864,
         1437,
         1423,
         1423,
         1423,
         1423,
         1423,
         1423,
         1423,
         1423,
         1423,
         1423,
         1423,
         1423,
         1423,
         1423,
         1437,
         1437,
         1423,
         1423,
         1423,
      },
   },
   [nir_op_fexp2] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         3,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         4,
         1,
         1,
         1,
         1,
         3,
         1,
         1,
         1,
         1,
         1,
         3,
         1,
         1,
         3,
         1,
         3,
         1,
         1,
         3,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         3,
         3,
         3,
         3,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         3,
         3,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 6,
      .table = (const uint16_t []) {
      
         131,
         1777,
         1778,
         2617,
         2618,
         2866,
      },
   },
   [nir_search_op_b2f] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         1,
         0,
         1,
         0,
         1,
         0,
         0,
         0,
         1,
         1,
         0,
         1,
         0,
         0,
         0,
         1,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         132,
         1954,
         1955,
         1956,
      },
   },
   [nir_op_ftrunc] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         133,
      },
   },
   [nir_op_ffloor] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         134,
      },
   },
   [nir_op_ffract] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         135,
      },
   },
   [nir_op_fceil] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         136,
      },
   },
   [nir_search_op_b2i] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         3,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         2,
         0,
         2,
         0,
         2,
         0,
         0,
         0,
         2,
         2,
         0,
         2,
         0,
         0,
         0,
         2,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         5,
         1,
         1,
         1,
         1,
         1,
         1,
         6,
         6,
         7,
         7,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 8,
      .table = (const uint16_t []) {
      
         137,
         1849,
         1850,
         1851,
         1852,
         2685,
         2686,
         2687,
      },
   },
   [nir_op_fdph] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         138,
      },
   },
   [nir_op_fdot4] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         139,
         1944,
         1945,
         1946,
         1944,
         1944,
         1945,
         1946,
         1945,
         1945,
         1945,
         1946,
         1946,
         1946,
         1946,
         1946,
      },
   },
   [nir_op_vec4] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         140,
         141,
         140,
         142,
         140,
         141,
         140,
         143,
         140,
         141,
         140,
         142,
         140,
         141,
         140,
         143,
      },
   },
   [nir_op_fdot3] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         144,
         1947,
         1948,
         1947,
         1947,
         1948,
         1948,
         1948,
         1948,
      },
   },
   [nir_op_vec3] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         145,
         146,
         145,
         147,
         145,
         146,
         145,
         147,
      },
   },
   [nir_op_fdot2] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         148,
         149,
         1949,
         149,
         149,
         1950,
         1949,
         1950,
         1949,
      },
   },
   [nir_op_vec2] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         150,
         151,
         150,
         150,
         152,
         153,
         152,
         152,
         150,
         151,
         150,
         1269,
         150,
         151,
         150,
         150,
      },
   },
   [nir_op_fsum2] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         154,
      },
   },
   [nir_op_ushr] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         2,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         8,
         0,
         2,
         0,
         0,
         0,
         2,
         0,
         0,
         2,
         2,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         11,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         2,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         4,
         13,
         0,
         3,
         3,
         8,
         4,
         14,
         9,
         2,
         4,
         15,
         3,
         3,
         8,
         4,
         16,
         9,
         2,
         4,
         17,
         3,
         3,
         8,
         4,
         0,
         9,
      },
      
      .num_filtered_states = 18,
      .table = (const uint16_t []) {
      
         155,
         156,
         155,
         1243,
         155,
         1244,
         155,
         2279,
         2280,
         155,
         155,
         1243,
         155,
         1243,
         155,
         1243,
         155,
         1243,
         157,
         158,
         157,
         1245,
         157,
         1246,
         157,
         2281,
         2282,
         157,
         157,
         1245,
         157,
         1245,
         157,
         1245,
         157,
         1245,
         1247,
         1248,
         1247,
         1249,
         1247,
         1250,
         1247,
         2283,
         2284,
         1247,
         1247,
         1249,
         1247,
         1249,
         1247,
         1249,
         1247,
         1249,
         155,
         156,
         155,
         1243,
         155,
         1244,
         155,
         2279,
         2280,
         155,
         155,
         1243,
         155,
         1243,
         155,
         1243,
         155,
         1243,
         155,
         1251,
         155,
         1243,
         155,
         1244,
         155,
         2279,
         2280,
         155,
         155,
         1243,
         155,
         1243,
         155,
         1243,
         155,
         1243,
         155,
         156,
         155,
         1243,
         155,
         1244,
         155,
         2279,
         2280,
         155,
         155,
         1243,
         155,
         1243,
         155,
         1243,
         155,
         1243,
         155,
         1252,
         155,
         1243,
         155,
         1244,
         155,
         2279,
         2280,
         155,
         155,
         1243,
         155,
         1243,
         155,
         1243,
         155,
         1243,
         155,
         156,
         155,
         1243,
         155,
         1244,
         155,
         2279,
         2280,
         155,
         155,
         1243,
         155,
         1243,
         155,
         1243,
         155,
         1243,
         1247,
         1248,
         1247,
         1249,
         1247,
         1250,
         1247,
         2283,
         2284,
         1247,
         1247,
         1249,
         1247,
         1249,
         1247,
         1249,
         1247,
         1249,
         155,
         2285,
         155,
         1243,
         155,
         1244,
         155,
         2279,
         2280,
         155,
         155,
         1243,
         155,
         1243,
         155,
         1243,
         155,
         1243,
         155,
         2286,
         155,
         1243,
         155,
         1244,
         155,
         2279,
         2280,
         155,
         155,
         1243,
         155,
         1243,
         155,
         1243,
         155,
         1243,
         155,
         2814,
         155,
         1243,
         155,
         1244,
         155,
         2279,
         2280,
         155,
         155,
         1243,
         155,
         1243,
         155,
         1243,
         155,
         1243,
         155,
         2910,
         155,
         1243,
         155,
         1244,
         155,
         2279,
         2280,
         155,
         155,
         1243,
         155,
         1243,
         155,
         1243,
         155,
         1243,
         155,
         2916,
         155,
         1243,
         155,
         1244,
         155,
         2279,
         2280,
         155,
         155,
         1243,
         155,
         1243,
         155,
         1243,
         155,
         1243,
         155,
         2920,
         155,
         1243,
         155,
         1244,
         155,
         2279,
         2280,
         155,
         155,
         1243,
         155,
         1243,
         155,
         1243,
         155,
         1243,
         155,
         2925,
         155,
         1243,
         155,
         1244,
         155,
         2279,
         2280,
         155,
         155,
         1243,
         155,
         1243,
         155,
         1243,
         155,
         1243,
         155,
         2929,
         155,
         1243,
         155,
         1244,
         155,
         2279,
         2280,
         155,
         155,
         1243,
         155,
         1243,
         155,
         1243,
         155,
         1243,
         155,
         2934,
         155,
         1243,
         155,
         1244,
         155,
         2279,
         2280,
         155,
         155,
         1243,
         155,
         1243,
         155,
         1243,
         155,
         1243,
      },
   },
   [nir_op_ishr] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         2,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         0,
         2,
         0,
         0,
         0,
         2,
         0,
         0,
         2,
         2,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         5,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         4,
         0,
         4,
         4,
         2,
         0,
         0,
         0,
         2,
         0,
         4,
         4,
         4,
         2,
         0,
         0,
         0,
         2,
         0,
         4,
         4,
         4,
         2,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 6,
      .table = (const uint16_t []) {
      
         159,
         160,
         159,
         159,
         1253,
         159,
         161,
         162,
         161,
         161,
         1254,
         161,
         159,
         1255,
         159,
         159,
         1253,
         159,
         1256,
         1257,
         1256,
         1256,
         1258,
         1256,
         159,
         160,
         159,
         159,
         1253,
         159,
         159,
         1259,
         159,
         159,
         1253,
         159,
      },
   },
   [nir_op_inot] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         4,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         6,
         7,
         8,
         8,
         8,
         8,
         9,
         9,
         9,
         9,
         10,
         10,
         11,
         11,
         12,
         12,
         12,
         12,
         13,
         13,
         14,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         15,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         17,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         18,
         19,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         20,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         6,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         7,
         7,
         21,
         22,
         0,
         0,
         0,
         0,
         0,
         21,
         0,
         0,
         22,
         0,
         0,
         0,
         0,
         0,
         0,
         21,
         22,
         0,
         0,
         0,
         0,
         0,
         21,
         22,
         0,
         0,
         0,
         0,
         0,
         22,
         22,
         21,
         22,
         0,
         0,
         0,
         0,
         0,
         21,
         22,
         0,
         0,
         0,
         0,
         0,
         21,
         22,
         0,
         0,
         0,
         0,
         0,
         21,
         22,
         0,
         0,
         0,
         0,
         0,
         21,
         22,
         0,
         0,
         0,
         0,
         0,
         23,
         21,
         21,
         21,
         21,
         21,
         0,
         22,
         22,
         22,
         22,
         22,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         8,
         8,
         8,
         8,
         9,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         3,
         3,
         11,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         10,
         0,
         8,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 24,
      .table = (const uint16_t []) {
      
         163,
         1675,
         1676,
         1677,
         1678,
         1679,
         1680,
         1681,
         1682,
         1683,
         1684,
         1685,
         1686,
         1687,
         1688,
         2436,
         2437,
         2438,
         2439,
         2440,
         2441,
         2809,
         2810,
         2811,
      },
   },
   [nir_op_flt] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         3,
         4,
         0,
         0,
         5,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         10,
         11,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         13,
         2,
         14,
         2,
         2,
         2,
         2,
         2,
         15,
         2,
         2,
         2,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         16,
         5,
         17,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         16,
         5,
         5,
         5,
         5,
         18,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         10,
         10,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         11,
         7,
         7,
         7,
         7,
         7,
         7,
         16,
         5,
         17,
         17,
         17,
         17,
         17,
         17,
         6,
         6,
         16,
         16,
         5,
         16,
         16,
         5,
         0,
         19,
         2,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         6,
         20,
         6,
         6,
         6,
         6,
         21,
         16,
         16,
         16,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         16,
         16,
         16,
         5,
         5,
         5,
         5,
         16,
         5,
         5,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         22,
         9,
         9,
         22,
         9,
         9,
         22,
         9,
         22,
         22,
         9,
         22,
         9,
         22,
         9,
         22,
         22,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         11,
         0,
         17,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 23,
      .table = (const uint16_t []) {
      
         164,
         165,
         1440,
         164,
         164,
         164,
         164,
         164,
         164,
         1441,
         164,
         1442,
         164,
         1440,
         1440,
         1440,
         164,
         164,
         164,
         1440,
         164,
         164,
         1441,
         166,
         167,
         1443,
         1444,
         1445,
         166,
         166,
         1446,
         1447,
         1448,
         1449,
         1450,
         166,
         1443,
         1443,
         1443,
         166,
         166,
         2536,
         1443,
         166,
         166,
         1448,
         164,
         1451,
         1452,
         164,
         164,
         164,
         164,
         164,
         164,
         1441,
         164,
         1442,
         164,
         1452,
         1452,
         1452,
         164,
         164,
         164,
         1452,
         164,
         164,
         1441,
         164,
         165,
         1440,
         164,
         164,
         164,
         164,
         164,
         164,
         1441,
         164,
         1442,
         164,
         1440,
         1440,
         1440,
         164,
         164,
         164,
         1440,
         164,
         164,
         1441,
         164,
         1453,
         1440,
         164,
         164,
         164,
         164,
         164,
         164,
         1441,
         164,
         1442,
         164,
         1440,
         1440,
         1440,
         164,
         164,
         164,
         1440,
         164,
         164,
         1441,
         1454,
         1455,
         1456,
         1454,
         1454,
         1454,
         1454,
         1454,
         1454,
         1457,
         1454,
         1458,
         1454,
         1456,
         1456,
         1456,
         1454,
         1454,
         1454,
         1456,
         1454,
         1454,
         1457,
         1454,
         1459,
         1456,
         1454,
         1454,
         1454,
         1454,
         1454,
         1454,
         1457,
         1454,
         1458,
         1454,
         1456,
         1456,
         1456,
         1454,
         1454,
         1454,
         1456,
         1454,
         1454,
         1457,
         164,
         165,
         1440,
         164,
         164,
         164,
         164,
         164,
         164,
         1441,
         164,
         1442,
         164,
         1440,
         1440,
         1440,
         164,
         164,
         164,
         1440,
         164,
         164,
         1441,
         164,
         1460,
         1440,
         164,
         164,
         164,
         164,
         164,
         164,
         1441,
         164,
         1442,
         164,
         1440,
         1440,
         1440,
         164,
         164,
         164,
         1440,
         164,
         164,
         1441,
         1461,
         1462,
         1463,
         1461,
         1461,
         1461,
         1461,
         1461,
         1461,
         1464,
         1461,
         1465,
         1461,
         1463,
         1463,
         1463,
         1461,
         1461,
         1461,
         1463,
         1461,
         1461,
         1464,
         164,
         1466,
         1440,
         164,
         164,
         164,
         164,
         164,
         164,
         1441,
         164,
         1442,
         164,
         1440,
         1440,
         1440,
         164,
         164,
         164,
         1440,
         164,
         164,
         1441,
         1467,
         1468,
         1469,
         1467,
         1467,
         1467,
         1467,
         1467,
         1467,
         1470,
         1467,
         1471,
         1467,
         1469,
         1469,
         1469,
         1467,
         1467,
         1467,
         1469,
         1467,
         1467,
         1470,
         164,
         165,
         1440,
         164,
         164,
         164,
         164,
         164,
         164,
         1441,
         164,
         1442,
         1472,
         1440,
         1440,
         1440,
         164,
         164,
         164,
         1440,
         164,
         164,
         1441,
         164,
         2537,
         1452,
         164,
         164,
         164,
         164,
         164,
         164,
         1441,
         164,
         1442,
         164,
         1452,
         1452,
         1452,
         164,
         164,
         164,
         1452,
         164,
         164,
         1441,
         164,
         2538,
         1452,
         164,
         164,
         164,
         164,
         164,
         164,
         1441,
         164,
         1442,
         164,
         1452,
         1452,
         1452,
         164,
         164,
         164,
         1452,
         164,
         164,
         1441,
         164,
         2539,
         1452,
         164,
         164,
         164,
         164,
         164,
         164,
         1441,
         164,
         1442,
         164,
         1452,
         1452,
         1452,
         164,
         164,
         164,
         1452,
         164,
         164,
         1441,
         1454,
         2540,
         1456,
         1454,
         1454,
         1454,
         1454,
         1454,
         1454,
         1457,
         1454,
         1458,
         1454,
         1456,
         1456,
         1456,
         1454,
         1454,
         1454,
         1456,
         1454,
         1454,
         1457,
         1454,
         2541,
         1456,
         1454,
         1454,
         1454,
         1454,
         1454,
         1454,
         1457,
         1454,
         1458,
         1454,
         1456,
         1456,
         1456,
         1454,
         1454,
         1454,
         1456,
         1454,
         1454,
         1457,
         1454,
         1455,
         1456,
         1454,
         1454,
         1454,
         1454,
         1454,
         1454,
         1457,
         1454,
         1458,
         1454,
         1456,
         1456,
         1456,
         1454,
         1454,
         1454,
         1456,
         1454,
         1454,
         1457,
         164,
         2867,
         1452,
         164,
         164,
         164,
         164,
         164,
         164,
         1441,
         164,
         1442,
         164,
         1452,
         1452,
         1452,
         164,
         164,
         164,
         1452,
         164,
         164,
         1441,
         1454,
         2890,
         1456,
         1454,
         1454,
         1454,
         1454,
         1454,
         1454,
         1457,
         1454,
         1458,
         1454,
         1456,
         1456,
         1456,
         1454,
         1454,
         1454,
         1456,
         1454,
         1454,
         1457,
         1454,
         2891,
         1456,
         1454,
         1454,
         1454,
         1454,
         1454,
         1454,
         1457,
         1454,
         1458,
         1454,
         1456,
         1456,
         1456,
         1454,
         1454,
         1454,
         1456,
         1454,
         1454,
         1457,
         1461,
         2892,
         1463,
         1461,
         1461,
         1461,
         1461,
         1461,
         1461,
         1464,
         1461,
         1465,
         1461,
         1463,
         1463,
         1463,
         1461,
         1461,
         1461,
         1463,
         1461,
         1461,
         1464,
      },
   },
   [nir_op_fge] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         3,
         4,
         0,
         0,
         5,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         11,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         14,
         2,
         15,
         2,
         2,
         2,
         2,
         2,
         16,
         2,
         2,
         2,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         5,
         5,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         5,
         5,
         5,
         5,
         5,
         17,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         11,
         11,
         11,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         12,
         7,
         7,
         7,
         7,
         7,
         7,
         5,
         5,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         18,
         2,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         0,
         6,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 19,
      .table = (const uint16_t []) {
      
         168,
         169,
         1473,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         1474,
         168,
         1475,
         168,
         1473,
         1473,
         1473,
         168,
         1473,
         170,
         171,
         1476,
         1477,
         1478,
         170,
         170,
         170,
         1479,
         1480,
         1481,
         1482,
         1483,
         170,
         1476,
         1476,
         1476,
         2542,
         1476,
         168,
         1484,
         1485,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         1474,
         168,
         1475,
         168,
         1485,
         1485,
         1485,
         168,
         1485,
         168,
         169,
         1473,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         1474,
         168,
         1475,
         168,
         1473,
         1473,
         1473,
         168,
         1473,
         168,
         1486,
         1473,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         1474,
         168,
         1475,
         168,
         1473,
         1473,
         1473,
         168,
         1473,
         1487,
         1488,
         1489,
         1487,
         1487,
         1487,
         1487,
         1487,
         1487,
         1487,
         1490,
         1487,
         1491,
         1487,
         1489,
         1489,
         1489,
         1487,
         1489,
         1487,
         1492,
         1489,
         1487,
         1487,
         1487,
         1487,
         1487,
         1487,
         1487,
         1490,
         1487,
         1491,
         1487,
         1489,
         1489,
         1489,
         1487,
         1489,
         168,
         1493,
         1473,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         1474,
         168,
         1475,
         168,
         1473,
         1473,
         1473,
         168,
         1473,
         168,
         1494,
         1473,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         1474,
         168,
         1475,
         168,
         1473,
         1473,
         1473,
         168,
         1473,
         168,
         169,
         1473,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         1474,
         168,
         1475,
         168,
         1473,
         1473,
         1473,
         168,
         1473,
         1495,
         1496,
         1497,
         1495,
         1495,
         1495,
         1495,
         1495,
         1495,
         1495,
         1498,
         1495,
         1499,
         1495,
         1497,
         1497,
         1497,
         1495,
         1497,
         168,
         1500,
         1473,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         1474,
         168,
         1475,
         168,
         1473,
         1473,
         1473,
         168,
         1473,
         1501,
         1502,
         1503,
         1501,
         1501,
         1501,
         1501,
         1501,
         1501,
         1501,
         1504,
         1501,
         1505,
         1501,
         1503,
         1503,
         1503,
         1501,
         1503,
         168,
         169,
         1473,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         1474,
         168,
         1475,
         1506,
         1473,
         1473,
         1473,
         168,
         1473,
         168,
         2543,
         1485,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         1474,
         168,
         1475,
         168,
         1485,
         1485,
         1485,
         168,
         1485,
         168,
         2544,
         1485,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         1474,
         168,
         1475,
         168,
         1485,
         1485,
         1485,
         168,
         1485,
         168,
         2545,
         1485,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         1474,
         168,
         1475,
         168,
         1485,
         1485,
         1485,
         168,
         1485,
         1487,
         1488,
         1489,
         1487,
         1487,
         1487,
         1487,
         1487,
         1487,
         1487,
         1490,
         1487,
         1491,
         1487,
         1489,
         1489,
         1489,
         1487,
         1489,
         168,
         2868,
         1485,
         168,
         168,
         168,
         168,
         168,
         168,
         168,
         1474,
         168,
         1475,
         168,
         1485,
         1485,
         1485,
         168,
         1485,
      },
   },
   [nir_op_fneu] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         3,
         0,
         0,
         4,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         12,
         13,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         17,
         2,
         2,
         2,
         2,
         2,
         18,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         4,
         4,
         4,
         4,
         4,
         19,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         20,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         9,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         8,
         0,
         0,
         0,
         13,
         13,
         13,
         13,
         14,
         14,
         14,
         14,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         6,
         6,
         4,
         4,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         4,
         4,
         4,
         21,
         4,
         4,
         0,
         2,
         2,
         18,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         21,
         4,
         4,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 22,
      .table = (const uint16_t []) {
      
         172,
         173,
         1507,
         172,
         1508,
         1508,
         172,
         172,
         172,
         172,
         172,
         172,
         172,
         172,
         172,
         172,
         172,
         1507,
         1507,
         1508,
         172,
         1508,
         173,
         173,
         1509,
         1510,
         1511,
         1512,
         1513,
         1514,
         1515,
         1516,
         173,
         1517,
         1518,
         1519,
         1520,
         2297,
         2298,
         2299,
         1509,
         2300,
         2301,
         2865,
         1507,
         1509,
         1521,
         1507,
         1522,
         1522,
         1507,
         1507,
         1507,
         1507,
         1507,
         1507,
         1507,
         1507,
         1507,
         1507,
         1507,
         1521,
         1521,
         1522,
         1507,
         1522,
         172,
         1510,
         1507,
         172,
         1508,
         1508,
         172,
         172,
         172,
         172,
         172,
         172,
         172,
         172,
         172,
         172,
         172,
         1507,
         1507,
         1508,
         172,
         1508,
         1508,
         1511,
         1522,
         1508,
         1508,
         1508,
         1508,
         1508,
         1508,
         1508,
         1508,
         1508,
         1508,
         1508,
         1508,
         1508,
         1508,
         1522,
         1522,
         1508,
         1508,
         1508,
         1508,
         1512,
         1522,
         1508,
         1508,
         1508,
         1508,
         1508,
         1508,
         1508,
         1508,
         1508,
         1508,
         1508,
         1508,
         1508,
         1508,
         1522,
         1522,
         1508,
         1508,
         1508,
         172,
         1513,
         1507,
         172,
         1508,
         1508,
         172,
         172,
         172,
         172,
         172,
         172,
         172,
         172,
         172,
         172,
         172,
         1507,
         1507,
         1508,
         172,
         1508,
         172,
         1514,
         1507,
         172,
         1508,
         1508,
         172,
         172,
         172,
         172,
         172,
         172,
         172,
         172,
         172,
         172,
         172,
         1507,
         1507,
         1508,
         172,
         1508,
         172,
         1515,
         1507,
         172,
         1508,
         1508,
         172,
         172,
         1523,
         172,
         172,
         172,
         172,
         172,
         172,
         172,
         172,
         1507,
         2302,
         1508,
         172,
         1508,
         172,
         1516,
         1507,
         172,
         1508,
         1508,
         172,
         172,
         172,
         172,
         172,
         172,
         172,
         172,
         172,
         172,
         172,
         1507,
         1507,
         1508,
         172,
         1508,
         172,
         173,
         1507,
         172,
         1508,
         1508,
         172,
         172,
         172,
         172,
         1524,
         172,
         172,
         172,
         172,
         172,
         172,
         1507,
         1507,
         1508,
         172,
         1508,
         172,
         1517,
         1507,
         172,
         1508,
         1508,
         172,
         172,
         172,
         172,
         172,
         172,
         172,
         172,
         172,
         172,
         172,
         1507,
         1507,
         1508,
         172,
         1508,
         172,
         1518,
         1507,
         172,
         1508,
         1508,
         172,
         172,
         172,
         172,
         172,
         172,
         172,
         172,
         172,
         172,
         172,
         1507,
         1507,
         1508,
         172,
         1508,
         172,
         1519,
         1507,
         172,
         1508,
         1508,
         172,
         172,
         172,
         172,
         172,
         172,
         172,
         172,
         172,
         172,
         172,
         1507,
         1507,
         1508,
         172,
         1508,
         172,
         1520,
         1507,
         172,
         1508,
         1508,
         172,
         172,
         172,
         172,
         172,
         172,
         172,
         172,
         172,
         172,
         172,
         1507,
         1507,
         1508,
         172,
         1508,
         172,
         2297,
         1507,
         172,
         1508,
         1508,
         172,
         172,
         172,
         172,
         172,
         172,
         172,
         172,
         172,
         172,
         172,
         1507,
         1507,
         1508,
         172,
         1508,
         172,
         2298,
         1507,
         172,
         1508,
         1508,
         172,
         172,
         172,
         172,
         172,
         172,
         172,
         172,
         172,
         172,
         172,
         1507,
         1507,
         1508,
         172,
         1508,
         1507,
         2299,
         1521,
         1507,
         1522,
         1522,
         1507,
         1507,
         1507,
         1507,
         1507,
         1507,
         1507,
         1507,
         1507,
         1507,
         1507,
         1521,
         1521,
         1522,
         1507,
         1522,
         1507,
         1509,
         1521,
         1507,
         1522,
         1522,
         1507,
         1507,
         2302,
         1507,
         1507,
         1507,
         1507,
         1507,
         1507,
         1507,
         1507,
         1521,
         2303,
         1522,
         1507,
         1522,
         1508,
         2300,
         1522,
         1508,
         1508,
         1508,
         1508,
         1508,
         1508,
         1508,
         1508,
         1508,
         1508,
         1508,
         1508,
         1508,
         1508,
         1522,
         1522,
         1508,
         1508,
         1508,
         172,
         2301,
         1507,
         172,
         1508,
         1508,
         172,
         172,
         172,
         172,
         172,
         172,
         172,
         172,
         172,
         172,
         172,
         1507,
         1507,
         1508,
         172,
         1508,
         1508,
         2865,
         1522,
         1508,
         1508,
         1508,
         1508,
         1508,
         1508,
         1508,
         1508,
         1508,
         1508,
         1508,
         1508,
         1508,
         1508,
         1522,
         1522,
         1508,
         1508,
         1508,
      },
   },
   [nir_op_ilt] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         4,
         5,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         4,
         4,
         4,
         4,
         4,
         3,
         3,
         3,
         3,
         3,
         3,
         5,
         5,
         5,
         6,
         6,
         6,
         6,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         4,
         4,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         5,
         5,
         5,
         6,
         6,
         6,
         6,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         4,
         4,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 9,
      .table = (const uint16_t []) {
      
         174,
         175,
         174,
         1863,
         1863,
         1864,
         1864,
         174,
         174,
         174,
         175,
         1865,
         1863,
         1866,
         1864,
         1867,
         1868,
         174,
         174,
         1869,
         174,
         1863,
         1863,
         1864,
         1864,
         174,
         174,
         1870,
         1871,
         1870,
         1872,
         1872,
         1873,
         1873,
         1870,
         1870,
         1870,
         1874,
         1870,
         1872,
         1872,
         1873,
         1873,
         1870,
         1870,
         1875,
         1876,
         1875,
         1877,
         1877,
         1878,
         1878,
         1875,
         1875,
         1875,
         1879,
         1875,
         1877,
         1877,
         1878,
         1878,
         1875,
         1875,
         174,
         1880,
         174,
         1863,
         1863,
         1864,
         1864,
         1881,
         174,
         174,
         2652,
         174,
         1863,
         1863,
         1864,
         1864,
         174,
         174,
      },
   },
   [nir_op_ult] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         7,
         8,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         6,
         6,
         13,
         7,
         7,
         12,
         12,
         12,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         9,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         7,
         7,
         12,
         12,
         6,
         6,
         6,
         6,
         6,
         8,
         8,
         8,
         9,
         9,
         9,
         8,
         8,
         8,
         8,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         0,
         11,
         6,
         6,
         7,
         7,
         12,
         12,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         4,
         4,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         0,
         0,
         0,
         3,
         0,
         3,
         3,
         0,
         0,
         4,
         4,
         0,
         0,
         3,
         3,
         3,
         0,
         0,
         4,
         4,
         0,
         0,
         3,
         3,
         3,
         0,
         0,
         4,
         4,
      },
      
      .num_filtered_states = 14,
      .table = (const uint16_t []) {
      
         176,
         177,
         176,
         1711,
         176,
         176,
         1712,
         1712,
         1713,
         1713,
         176,
         176,
         2653,
         2653,
         178,
         179,
         178,
         1714,
         178,
         1715,
         1716,
         1717,
         1718,
         1719,
         1720,
         2654,
         2655,
         2656,
         1721,
         1722,
         1721,
         1723,
         1721,
         1721,
         1724,
         1724,
         1725,
         1725,
         1721,
         1721,
         2657,
         2657,
         176,
         177,
         176,
         1711,
         176,
         176,
         1712,
         1712,
         1713,
         1713,
         176,
         176,
         2653,
         2653,
         1726,
         1727,
         1726,
         1728,
         1726,
         1726,
         1729,
         1729,
         1730,
         1730,
         1726,
         1726,
         2658,
         2658,
         176,
         1731,
         176,
         1711,
         176,
         176,
         1712,
         1712,
         1713,
         1713,
         176,
         176,
         2653,
         2653,
         1732,
         1733,
         1732,
         1734,
         1732,
         1732,
         1735,
         1735,
         1736,
         1736,
         1732,
         1732,
         2659,
         2659,
         1732,
         1737,
         1732,
         1734,
         1732,
         1732,
         1735,
         1735,
         1736,
         1736,
         1732,
         1732,
         2659,
         2659,
         1738,
         1739,
         1738,
         1740,
         1738,
         1738,
         1741,
         1741,
         1742,
         1742,
         1738,
         1738,
         2660,
         2660,
         1738,
         1743,
         1738,
         1740,
         1738,
         1738,
         1741,
         1741,
         1742,
         1742,
         1738,
         1738,
         2660,
         2660,
         176,
         1744,
         176,
         1711,
         176,
         176,
         1712,
         1712,
         1713,
         1713,
         1745,
         176,
         2653,
         2653,
         176,
         177,
         176,
         1711,
         176,
         176,
         1712,
         1712,
         1713,
         1713,
         176,
         176,
         2653,
         2653,
         1732,
         1733,
         1732,
         1734,
         1732,
         1732,
         1735,
         1735,
         1736,
         1736,
         1732,
         1732,
         2659,
         2659,
         1732,
         1737,
         1732,
         1734,
         1732,
         1732,
         1735,
         1735,
         1736,
         1736,
         1732,
         1732,
         2659,
         2659,
      },
   },
   [nir_op_ige] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         4,
         5,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         9,
         10,
         11,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         4,
         4,
         4,
         4,
         4,
         3,
         3,
         3,
         3,
         3,
         3,
         5,
         5,
         5,
         6,
         6,
         6,
         6,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         4,
         4,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         5,
         5,
         5,
         6,
         6,
         6,
         6,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         4,
         4,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 14,
      .table = (const uint16_t []) {
      
         180,
         181,
         180,
         1882,
         1882,
         1883,
         1883,
         180,
         180,
         180,
         180,
         180,
         180,
         180,
         180,
         181,
         1884,
         1882,
         1885,
         1883,
         1886,
         1887,
         180,
         180,
         180,
         180,
         180,
         180,
         180,
         1888,
         180,
         1882,
         1882,
         1883,
         1883,
         180,
         180,
         180,
         180,
         180,
         180,
         180,
         1889,
         1890,
         1889,
         1891,
         1891,
         1892,
         1892,
         1889,
         1889,
         1889,
         1889,
         1889,
         1889,
         1889,
         1889,
         1893,
         1889,
         1891,
         1891,
         1892,
         1892,
         1889,
         1889,
         1889,
         1889,
         1889,
         1889,
         1889,
         1894,
         1895,
         1894,
         1896,
         1896,
         1897,
         1897,
         1894,
         1894,
         1894,
         1894,
         1894,
         1894,
         1894,
         1894,
         1898,
         1894,
         1896,
         1896,
         1897,
         1897,
         1894,
         1894,
         1894,
         1894,
         1894,
         1894,
         1894,
         180,
         1899,
         180,
         1882,
         1882,
         1883,
         1883,
         1900,
         180,
         180,
         180,
         180,
         180,
         180,
         180,
         1901,
         180,
         1882,
         1882,
         1883,
         1883,
         180,
         180,
         180,
         180,
         180,
         180,
         180,
         180,
         1902,
         180,
         1882,
         1882,
         1883,
         1883,
         180,
         180,
         180,
         180,
         180,
         180,
         180,
         180,
         1903,
         180,
         1882,
         1882,
         1883,
         1883,
         180,
         180,
         180,
         180,
         180,
         180,
         180,
         180,
         1904,
         180,
         1882,
         1882,
         1883,
         1883,
         180,
         180,
         180,
         180,
         180,
         180,
         180,
         180,
         1905,
         180,
         1882,
         1882,
         1883,
         1883,
         180,
         180,
         180,
         180,
         180,
         180,
         180,
         180,
         2661,
         180,
         1882,
         1882,
         1883,
         1883,
         180,
         180,
         180,
         180,
         180,
         180,
         180,
      },
   },
   [nir_op_uge] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         7,
         8,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         7,
         7,
         7,
         6,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         9,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         7,
         7,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         8,
         8,
         8,
         9,
         9,
         9,
         8,
         8,
         8,
         8,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         0,
         0,
         6,
         6,
         7,
         7,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         4,
         4,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         0,
         0,
         0,
         3,
         0,
         3,
         3,
         0,
         0,
         4,
         4,
         0,
         0,
         3,
         3,
         3,
         0,
         0,
         4,
         4,
         0,
         0,
         3,
         3,
         3,
         0,
         0,
         4,
         4,
      },
      
      .num_filtered_states = 11,
      .table = (const uint16_t []) {
      
         182,
         182,
         182,
         1746,
         182,
         182,
         1747,
         1747,
         1748,
         1748,
         182,
         183,
         183,
         183,
         1749,
         183,
         1750,
         1751,
         1752,
         1753,
         1754,
         1755,
         1756,
         1756,
         1756,
         1757,
         1756,
         1756,
         1758,
         1758,
         1759,
         1759,
         1756,
         182,
         182,
         182,
         1746,
         182,
         182,
         1747,
         1747,
         1748,
         1748,
         182,
         1760,
         1760,
         1760,
         1761,
         1760,
         1760,
         1762,
         1762,
         1763,
         1763,
         1760,
         182,
         1764,
         182,
         1746,
         182,
         182,
         1747,
         1747,
         1748,
         1748,
         182,
         1765,
         1765,
         1765,
         1766,
         1765,
         1765,
         1767,
         1767,
         1768,
         1768,
         1765,
         1765,
         1769,
         1765,
         1766,
         1765,
         1765,
         1767,
         1767,
         1768,
         1768,
         1765,
         1770,
         1770,
         1770,
         1771,
         1770,
         1770,
         1772,
         1772,
         1773,
         1773,
         1770,
         1770,
         1774,
         1770,
         1771,
         1770,
         1770,
         1772,
         1772,
         1773,
         1773,
         1770,
         182,
         1775,
         182,
         1746,
         182,
         182,
         1747,
         1747,
         1748,
         1748,
         1776,
      },
   },
   [nir_op_fmin] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         0,
         7,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         9,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         10,
         2,
         2,
         11,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         12,
         6,
         6,
         6,
         6,
         6,
         12,
         6,
         6,
         6,
         12,
         6,
         12,
         6,
         6,
         12,
         7,
         7,
         7,
         8,
         8,
         8,
         8,
         8,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         12,
         6,
         6,
         12,
         12,
         6,
         6,
         12,
         12,
         12,
         6,
         6,
         12,
         6,
         12,
         6,
         12,
         7,
         7,
         13,
         7,
         8,
         8,
         8,
         14,
         14,
         8,
         13,
         7,
         7,
         7,
         13,
         7,
         7,
         7,
         13,
         7,
         13,
         7,
         7,
         13,
         7,
         13,
         4,
         4,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         15,
         2,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         12,
         12,
         6,
         6,
         6,
         6,
         6,
         12,
         12,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 16,
      .table = (const uint16_t []) {
      
         184,
         185,
         1525,
         1526,
         184,
         184,
         1527,
         1528,
         1528,
         2546,
         1525,
         2547,
         2548,
         2815,
         2815,
         2816,
         185,
         185,
         1529,
         1530,
         1531,
         1532,
         1533,
         1534,
         1535,
         2549,
         1529,
         2550,
         2551,
         2817,
         2818,
         2819,
         1525,
         1529,
         1525,
         1536,
         1525,
         1525,
         1537,
         1538,
         1538,
         2546,
         1525,
         2547,
         2552,
         2820,
         2820,
         2816,
         1526,
         1530,
         1536,
         1526,
         1526,
         1526,
         1539,
         1540,
         1540,
         2553,
         1536,
         2554,
         2555,
         2821,
         2821,
         2822,
         184,
         1531,
         1525,
         1526,
         184,
         184,
         1527,
         1528,
         1528,
         2546,
         1525,
         2547,
         2548,
         2815,
         2815,
         2816,
         184,
         1532,
         1525,
         1526,
         184,
         1541,
         1527,
         1528,
         1528,
         2546,
         1525,
         2547,
         2548,
         2815,
         2815,
         2816,
         1527,
         1533,
         1537,
         1539,
         1527,
         1527,
         1527,
         1542,
         1542,
         2556,
         1537,
         2557,
         2548,
         2823,
         2823,
         2824,
         1528,
         1534,
         1538,
         1540,
         1528,
         1528,
         1542,
         1528,
         1528,
         2558,
         1538,
         2559,
         2560,
         2815,
         2815,
         2825,
         1528,
         1535,
         1538,
         1540,
         1528,
         1528,
         1542,
         1528,
         1528,
         2558,
         1538,
         2559,
         2560,
         2815,
         2815,
         2825,
         2546,
         2549,
         2546,
         2553,
         2546,
         2546,
         2556,
         2558,
         2558,
         2546,
         2546,
         2561,
         2562,
         2826,
         2826,
         2827,
         1525,
         1529,
         1525,
         1536,
         1525,
         1525,
         1537,
         1538,
         1538,
         2546,
         2563,
         2547,
         2552,
         2820,
         2820,
         2816,
         2547,
         2550,
         2547,
         2554,
         2547,
         2547,
         2557,
         2559,
         2559,
         2561,
         2547,
         2547,
         2564,
         2828,
         2828,
         2829,
         2548,
         2551,
         2552,
         2555,
         2548,
         2548,
         2548,
         2560,
         2560,
         2562,
         2552,
         2564,
         2548,
         2830,
         2830,
         2831,
         2815,
         2817,
         2820,
         2821,
         2815,
         2815,
         2823,
         2815,
         2815,
         2826,
         2820,
         2828,
         2830,
         2815,
         2815,
         2832,
         2815,
         2818,
         2820,
         2821,
         2815,
         2815,
         2823,
         2815,
         2815,
         2826,
         2820,
         2828,
         2830,
         2815,
         2815,
         2832,
         2816,
         2819,
         2816,
         2822,
         2816,
         2816,
         2824,
         2825,
         2825,
         2827,
         2816,
         2829,
         2831,
         2832,
         2832,
         2816,
      },
   },
   [nir_search_op_i2f] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         3,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 6,
      .table = (const uint16_t []) {
      
         186,
         1925,
         1926,
         1927,
         1928,
         2908,
      },
   },
   [nir_op_fmax] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         8,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         9,
         2,
         10,
         2,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         6,
         6,
         6,
         6,
         6,
         13,
         13,
         0,
         0,
         12,
         0,
         12,
         0,
         12,
         7,
         7,
         14,
         7,
         7,
         7,
         7,
         14,
         7,
         14,
         14,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         12,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         14,
         7,
         7,
         7,
         7,
         7,
         14,
         7,
         14,
         7,
         7,
         7,
         14,
         14,
         14,
         14,
         7,
         7,
         14,
         7,
         7,
         14,
         14,
         4,
         4,
         4,
         4,
         4,
         4,
         0,
         0,
         11,
         11,
         11,
         11,
         11,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         15,
         0,
         0,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         13,
         13,
         6,
         12,
         12,
         0,
         12,
         0,
         12,
         12,
         0,
         12,
         0,
         12,
         0,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 17,
      .table = (const uint16_t []) {
      
         187,
         188,
         1543,
         1544,
         187,
         187,
         187,
         1545,
         2565,
         1543,
         2566,
         187,
         2567,
         2567,
         2568,
         187,
         187,
         188,
         188,
         1546,
         1547,
         1548,
         188,
         1549,
         1550,
         2569,
         1546,
         2570,
         2571,
         2572,
         2573,
         2574,
         2893,
         2894,
         1543,
         1546,
         1543,
         1551,
         1543,
         1543,
         1543,
         1552,
         2565,
         1543,
         2566,
         1543,
         2575,
         2575,
         2576,
         1543,
         1543,
         1544,
         1547,
         1551,
         1544,
         1544,
         1544,
         1544,
         1553,
         2577,
         1551,
         2578,
         1544,
         2579,
         2579,
         2580,
         1544,
         1544,
         187,
         1548,
         1543,
         1544,
         187,
         187,
         187,
         1545,
         2565,
         1543,
         2566,
         187,
         2567,
         2567,
         2568,
         187,
         187,
         187,
         188,
         1543,
         1544,
         187,
         1554,
         187,
         1545,
         2565,
         1543,
         2566,
         187,
         2567,
         2567,
         2568,
         187,
         187,
         187,
         1549,
         1543,
         1544,
         187,
         187,
         187,
         1545,
         2565,
         1543,
         2566,
         187,
         2567,
         2567,
         2568,
         187,
         187,
         1545,
         1550,
         1552,
         1553,
         1545,
         1545,
         1545,
         1545,
         2581,
         1552,
         2582,
         1545,
         2583,
         2583,
         2568,
         1545,
         1545,
         2565,
         2569,
         2565,
         2577,
         2565,
         2565,
         2565,
         2581,
         2565,
         2565,
         2584,
         2565,
         2585,
         2585,
         2586,
         2565,
         2565,
         1543,
         1546,
         1543,
         1551,
         1543,
         1543,
         1543,
         1552,
         2565,
         2587,
         2566,
         1543,
         2575,
         2575,
         2576,
         1543,
         1543,
         2566,
         2570,
         2566,
         2578,
         2566,
         2566,
         2566,
         2582,
         2584,
         2566,
         2566,
         2566,
         2588,
         2588,
         2589,
         2566,
         2566,
         187,
         2571,
         1543,
         1544,
         187,
         187,
         187,
         1545,
         2565,
         1543,
         2566,
         187,
         2567,
         2567,
         2568,
         187,
         187,
         2567,
         2572,
         2575,
         2579,
         2567,
         2567,
         2567,
         2583,
         2585,
         2575,
         2588,
         2567,
         2567,
         2567,
         2590,
         2567,
         2567,
         2567,
         2573,
         2575,
         2579,
         2567,
         2567,
         2567,
         2583,
         2585,
         2575,
         2588,
         2567,
         2567,
         2567,
         2590,
         2567,
         2567,
         2568,
         2574,
         2576,
         2580,
         2568,
         2568,
         2568,
         2568,
         2586,
         2576,
         2589,
         2568,
         2590,
         2590,
         2568,
         2568,
         2568,
         187,
         2893,
         1543,
         1544,
         187,
         187,
         187,
         1545,
         2565,
         1543,
         2566,
         187,
         2567,
         2567,
         2568,
         187,
         187,
         187,
         2894,
         1543,
         1544,
         187,
         187,
         187,
         1545,
         2565,
         1543,
         2566,
         187,
         2567,
         2567,
         2568,
         187,
         187,
      },
   },
   [nir_op_imin] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         5,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         7,
         2,
         2,
         8,
         2,
         2,
         2,
         2,
         2,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         9,
         4,
         4,
         4,
         9,
         4,
         4,
         4,
         9,
         4,
         9,
         4,
         9,
         5,
         5,
         5,
         6,
         6,
         6,
         6,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         9,
         4,
         9,
         9,
         4,
         9,
         9,
         4,
         9,
         9,
         4,
         5,
         10,
         5,
         6,
         11,
         11,
         6,
         10,
         5,
         5,
         10,
         5,
         5,
         10,
         10,
         5,
         5,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         4,
         9,
         4,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 12,
      .table = (const uint16_t []) {
      
         189,
         190,
         1621,
         1622,
         1623,
         1624,
         1624,
         2619,
         1621,
         2620,
         2869,
         2869,
         190,
         190,
         1625,
         1626,
         1627,
         1628,
         1629,
         2621,
         1625,
         2622,
         2870,
         2871,
         1621,
         1625,
         1621,
         1630,
         1631,
         1632,
         1632,
         2619,
         1621,
         2623,
         2872,
         2872,
         1622,
         1626,
         1630,
         1622,
         1633,
         1634,
         1634,
         2624,
         1630,
         2625,
         2873,
         2873,
         1623,
         1627,
         1631,
         1633,
         1623,
         1635,
         1635,
         2626,
         1631,
         2620,
         2874,
         2874,
         1624,
         1628,
         1632,
         1634,
         1635,
         1624,
         1624,
         2627,
         1632,
         2628,
         2869,
         2869,
         1624,
         1629,
         1632,
         1634,
         1635,
         1624,
         1624,
         2627,
         1632,
         2628,
         2869,
         2869,
         2619,
         2621,
         2619,
         2624,
         2626,
         2627,
         2627,
         2619,
         2619,
         2629,
         2875,
         2875,
         1621,
         1625,
         1621,
         1630,
         1631,
         1632,
         1632,
         2619,
         2630,
         2623,
         2872,
         2872,
         2620,
         2622,
         2623,
         2625,
         2620,
         2628,
         2628,
         2629,
         2623,
         2620,
         2876,
         2876,
         2869,
         2870,
         2872,
         2873,
         2874,
         2869,
         2869,
         2875,
         2872,
         2876,
         2869,
         2869,
         2869,
         2871,
         2872,
         2873,
         2874,
         2869,
         2869,
         2875,
         2872,
         2876,
         2869,
         2869,
      },
   },
   [nir_op_imax] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         6,
         2,
         2,
         7,
         2,
         2,
         2,
         2,
         2,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         4,
         4,
         4,
         9,
         9,
         0,
         0,
         8,
         0,
         8,
         8,
         5,
         5,
         10,
         5,
         5,
         5,
         10,
         5,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         0,
         0,
         0,
         0,
         8,
         8,
         0,
         0,
         5,
         5,
         10,
         5,
         5,
         5,
         10,
         5,
         10,
         5,
         5,
         10,
         10,
         10,
         5,
         10,
         5,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         9,
         9,
         8,
         8,
         8,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 11,
      .table = (const uint16_t []) {
      
         191,
         192,
         1636,
         1637,
         191,
         1638,
         2631,
         1636,
         2632,
         2632,
         2633,
         192,
         192,
         1639,
         1640,
         1641,
         1642,
         2634,
         1639,
         2635,
         2636,
         2637,
         1636,
         1639,
         1636,
         1643,
         1636,
         1644,
         2631,
         1636,
         2638,
         2638,
         2639,
         1637,
         1640,
         1643,
         1637,
         1637,
         1645,
         2640,
         1643,
         2641,
         2641,
         2642,
         191,
         1641,
         1636,
         1637,
         191,
         1638,
         2631,
         1636,
         2632,
         2632,
         2633,
         1638,
         1642,
         1644,
         1645,
         1638,
         1638,
         2643,
         1644,
         2644,
         2644,
         2633,
         2631,
         2634,
         2631,
         2640,
         2631,
         2643,
         2631,
         2631,
         2645,
         2645,
         2646,
         1636,
         1639,
         1636,
         1643,
         1636,
         1644,
         2631,
         2647,
         2638,
         2638,
         2639,
         2632,
         2635,
         2638,
         2641,
         2632,
         2644,
         2645,
         2638,
         2632,
         2632,
         2648,
         2632,
         2636,
         2638,
         2641,
         2632,
         2644,
         2645,
         2638,
         2632,
         2632,
         2648,
         2633,
         2637,
         2639,
         2642,
         2633,
         2633,
         2646,
         2639,
         2648,
         2648,
         2633,
      },
   },
   [nir_op_umin] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         8,
         5,
         5,
         8,
         5,
         5,
         8,
         5,
         5,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         8,
         5,
         8,
         5,
         8,
         8,
         5,
         8,
         5,
         8,
         6,
         10,
         6,
         6,
         10,
         6,
         6,
         10,
         6,
         10,
         6,
         10,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         5,
         5,
         5,
         5,
         5,
         5,
         8,
         8,
         5,
         5,
         5,
         8,
         8,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         3,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 11,
      .table = (const uint16_t []) {
      
         193,
         194,
         1779,
         1779,
         193,
         1780,
         1781,
         2662,
         2663,
         2728,
         2729,
         194,
         194,
         1782,
         1782,
         194,
         1783,
         1784,
         2664,
         2665,
         2730,
         2731,
         1779,
         1782,
         1779,
         1785,
         1779,
         1786,
         1787,
         2666,
         2667,
         2732,
         2733,
         1779,
         1782,
         1785,
         1785,
         1779,
         1786,
         1787,
         2666,
         2667,
         2732,
         2733,
         193,
         194,
         1779,
         1779,
         1788,
         1780,
         1781,
         2662,
         2663,
         2728,
         2729,
         1780,
         1783,
         1786,
         1786,
         1780,
         1780,
         1789,
         2668,
         2663,
         2734,
         2735,
         1781,
         1784,
         1787,
         1787,
         1781,
         1789,
         1781,
         2669,
         2670,
         2736,
         2729,
         2662,
         2664,
         2666,
         2666,
         2662,
         2668,
         2669,
         2671,
         2672,
         2737,
         2738,
         2663,
         2665,
         2667,
         2667,
         2663,
         2663,
         2670,
         2672,
         2663,
         2739,
         2740,
         2728,
         2730,
         2732,
         2732,
         2728,
         2734,
         2736,
         2737,
         2739,
         2728,
         2741,
         2729,
         2731,
         2733,
         2733,
         2729,
         2735,
         2729,
         2738,
         2740,
         2741,
         2729,
      },
   },
   [nir_op_umax] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         5,
         0,
         0,
         5,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         0,
         0,
         3,
         3,
         6,
         3,
         3,
         6,
         6,
         6,
         3,
         3,
         6,
         6,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         5,
         0,
         5,
         0,
         5,
         0,
         5,
         5,
         0,
         5,
         0,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 7,
      .table = (const uint16_t []) {
      
         195,
         196,
         195,
         1929,
         2673,
         2674,
         2675,
         196,
         196,
         196,
         1930,
         2676,
         2677,
         2678,
         195,
         196,
         1931,
         1929,
         2673,
         2674,
         2675,
         1929,
         1930,
         1929,
         1929,
         2679,
         2680,
         2675,
         2673,
         2676,
         2673,
         2679,
         2681,
         2682,
         2683,
         2674,
         2677,
         2674,
         2680,
         2682,
         2674,
         2684,
         2675,
         2678,
         2675,
         2675,
         2683,
         2684,
         2675,
      },
   },
   [nir_op_extract_u8] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         2,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         3,
         0,
         4,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         0,
         2,
         0,
         0,
         0,
         2,
         0,
         0,
         2,
         2,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         3,
         3,
         0,
         0,
         4,
         0,
         4,
         0,
         4,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         3,
         0,
         0,
         0,
         0,
         2,
         3,
         0,
         0,
         2,
         3,
         0,
         0,
         0,
         2,
         3,
         0,
         0,
         2,
         3,
         0,
         0,
         0,
         2,
         3,
         0,
         0,
      },
      
      .num_filtered_states = 10,
      .table = (const uint16_t []) {
      
         197,
         198,
         197,
         197,
         197,
         197,
         197,
         197,
         197,
         197,
         197,
         198,
         197,
         197,
         197,
         197,
         197,
         197,
         197,
         197,
         197,
         1260,
         197,
         197,
         197,
         197,
         197,
         197,
         197,
         197,
         197,
         1261,
         197,
         197,
         197,
         197,
         197,
         197,
         197,
         197,
         197,
         1262,
         197,
         197,
         197,
         197,
         197,
         197,
         197,
         197,
         197,
         1263,
         197,
         197,
         197,
         197,
         197,
         197,
         197,
         197,
         197,
         1264,
         197,
         197,
         197,
         197,
         197,
         197,
         197,
         197,
         197,
         1265,
         197,
         197,
         197,
         197,
         197,
         197,
         197,
         197,
         197,
         1266,
         197,
         197,
         197,
         197,
         197,
         197,
         197,
         197,
         197,
         2688,
         197,
         197,
         197,
         197,
         197,
         197,
         197,
         197,
      },
   },
   [nir_search_op_f2i] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 7,
      .table = (const uint16_t []) {
      
         199,
         1646,
         1647,
         1648,
         1649,
         1650,
         1651,
      },
   },
   [nir_search_op_f2u] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 7,
      .table = (const uint16_t []) {
      
         200,
         1652,
         1653,
         1654,
         1655,
         1656,
         1657,
      },
   },
   [nir_search_op_f2f] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         0,
         4,
         4,
         4,
         0,
         0,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 11,
      .table = (const uint16_t []) {
      
         201,
         1658,
         1659,
         1660,
         1661,
         1662,
         1663,
         1664,
         1665,
         1666,
         1667,
      },
   },
   [nir_search_op_i2i] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         3,
         3,
         3,
         3,
         0,
         4,
         4,
         4,
         0,
         0,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         7,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         6,
         7,
         7,
         7,
         7,
         7,
         7,
         11,
         7,
         7,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 12,
      .table = (const uint16_t []) {
      
         202,
         1792,
         1793,
         1794,
         1795,
         1796,
         1797,
         1798,
         1799,
         1800,
         1801,
         2726,
      },
   },
   [nir_search_op_u2u] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         3,
         3,
         3,
         3,
         0,
         4,
         4,
         4,
         0,
         0,
         5,
         5,
         5,
         5,
         0,
         0,
         6,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         0,
         0,
         0,
         8,
         9,
         0,
         10,
         0,
         0,
         0,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         0,
         0,
         0,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         0,
         0,
         5,
         13,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         14,
         9,
         9,
         9,
         9,
         9,
         15,
         9,
         9,
         9,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         11,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         17,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         18,
         9,
         9,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         1,
         0,
         1,
         1,
         0,
         6,
         0,
         0,
         0,
         6,
         1,
         1,
         1,
         0,
         6,
         0,
         0,
         0,
         6,
         1,
         1,
         1,
         0,
         6,
         0,
         0,
      },
      
      .num_filtered_states = 19,
      .table = (const uint16_t []) {
      
         203,
         1802,
         1803,
         1804,
         1805,
         1806,
         1807,
         1808,
         1809,
         1810,
         1811,
         1812,
         1813,
         1814,
         2724,
         2725,
         2806,
         2807,
         2808,
      },
   },
   [nir_op_f2fmp] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         0,
         4,
         4,
         4,
         0,
         0,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 8,
      .table = (const uint16_t []) {
      
         204,
         1668,
         1669,
         1670,
         1671,
         1672,
         1673,
         1674,
      },
   },
   [nir_op_i2imp] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         2,
         2,
         2,
         2,
         0,
         3,
         3,
         3,
         0,
         0,
         4,
         4,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         6,
         0,
         7,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         5,
         5,
         6,
         6,
         6,
         6,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         7,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         8,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 9,
      .table = (const uint16_t []) {
      
         205,
         1932,
         1933,
         1934,
         1935,
         1936,
         1937,
         1938,
         1939,
      },
   },
   [nir_op_extract_i8] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         2,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         0,
         2,
         0,
         0,
         0,
         2,
         0,
         0,
         2,
         2,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         206,
         207,
         206,
         206,
         206,
         207,
         206,
         206,
         206,
         1267,
         206,
         206,
         206,
         1268,
         206,
         206,
      },
   },
   [nir_op_extract_i16] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         208,
         209,
         208,
         209,
      },
   },
   [nir_op_extract_u16] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 5,
      .table = (const uint16_t []) {
      
         210,
         211,
         210,
         210,
         210,
         210,
         211,
         210,
         210,
         210,
         210,
         1957,
         210,
         210,
         210,
         210,
         1958,
         210,
         210,
         210,
         210,
         1959,
         210,
         210,
         210,
      },
   },
   [nir_op_ixor] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         2,
         3,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         5,
         4,
         5,
         6,
         7,
         6,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         11,
         12,
         13,
         14,
         15,
         16,
         17,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         3,
         3,
         3,
         3,
         2,
         3,
         2,
         2,
         2,
         3,
         2,
         2,
         3,
         3,
         2,
         3,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         16,
         16,
         16,
         16,
         17,
         17,
         17,
         17,
         17,
         17,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         4,
         4,
         4,
         4,
         4,
         5,
         4,
         4,
         5,
         5,
         6,
         6,
         7,
         6,
         7,
         6,
         7,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         11,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         18,
         19,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         20,
         21,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         15,
         15,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         3,
         3,
         3,
         3,
         3,
         4,
         4,
         4,
         4,
         4,
         4,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         16,
         16,
         16,
         16,
         17,
         17,
         17,
         17,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         21,
         21,
         19,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         5,
         0,
         0,
         0,
         0,
         3,
         5,
         0,
         0,
         3,
         5,
         0,
         0,
         0,
         3,
         5,
         0,
         0,
         3,
         5,
         0,
         0,
         0,
         3,
         5,
         0,
         0,
      },
      
      .num_filtered_states = 22,
      .table = (const uint16_t []) {
      
         212,
         213,
         212,
         212,
         212,
         212,
         212,
         212,
         212,
         1215,
         212,
         1216,
         212,
         1217,
         212,
         1218,
         1219,
         1219,
         2689,
         2690,
         2691,
         2692,
         213,
         213,
         213,
         213,
         213,
         213,
         213,
         213,
         213,
         1220,
         213,
         1221,
         213,
         1222,
         213,
         1223,
         1224,
         1225,
         2693,
         2694,
         2695,
         2696,
         212,
         213,
         212,
         1226,
         212,
         212,
         212,
         212,
         212,
         1215,
         212,
         1216,
         212,
         1217,
         212,
         1218,
         1219,
         1219,
         2689,
         2690,
         2691,
         2692,
         212,
         213,
         1226,
         1226,
         212,
         212,
         212,
         212,
         212,
         1215,
         212,
         1216,
         212,
         1217,
         212,
         1218,
         1219,
         1219,
         2689,
         2690,
         2691,
         2692,
         212,
         213,
         212,
         212,
         212,
         1227,
         212,
         212,
         212,
         1215,
         212,
         1216,
         212,
         1217,
         212,
         1218,
         1219,
         1219,
         2689,
         2690,
         2691,
         2692,
         212,
         213,
         212,
         212,
         1227,
         1227,
         212,
         212,
         212,
         1215,
         212,
         1216,
         212,
         1217,
         212,
         1218,
         1219,
         1219,
         2689,
         2690,
         2691,
         2692,
         212,
         213,
         212,
         212,
         212,
         212,
         212,
         1228,
         212,
         1215,
         212,
         1216,
         212,
         1217,
         212,
         1218,
         1219,
         1219,
         2689,
         2690,
         2691,
         2692,
         212,
         213,
         212,
         212,
         212,
         212,
         1228,
         1228,
         212,
         1215,
         212,
         1216,
         212,
         1217,
         212,
         1218,
         1219,
         1219,
         2689,
         2690,
         2691,
         2692,
         212,
         213,
         212,
         212,
         212,
         212,
         212,
         212,
         212,
         1229,
         212,
         1216,
         212,
         1217,
         212,
         1218,
         1219,
         1219,
         2689,
         2690,
         2691,
         2692,
         1215,
         1220,
         1215,
         1215,
         1215,
         1215,
         1215,
         1215,
         1229,
         1229,
         1215,
         1230,
         1215,
         1231,
         1215,
         1232,
         1233,
         1233,
         2697,
         2698,
         2699,
         2700,
         212,
         213,
         212,
         212,
         212,
         212,
         212,
         212,
         212,
         1215,
         212,
         1234,
         212,
         1217,
         212,
         1218,
         1219,
         1219,
         2689,
         2690,
         2691,
         2692,
         1216,
         1221,
         1216,
         1216,
         1216,
         1216,
         1216,
         1216,
         1216,
         1230,
         1234,
         1234,
         1216,
         1235,
         1216,
         1236,
         1237,
         1237,
         2701,
         2702,
         2703,
         2704,
         212,
         213,
         212,
         212,
         212,
         212,
         212,
         212,
         212,
         1215,
         212,
         1216,
         212,
         1238,
         212,
         1218,
         1219,
         1219,
         2689,
         2690,
         2691,
         2692,
         1217,
         1222,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1217,
         1231,
         1217,
         1235,
         1238,
         1238,
         1217,
         1239,
         1240,
         1240,
         2705,
         2706,
         2707,
         2708,
         212,
         213,
         212,
         212,
         212,
         212,
         212,
         212,
         212,
         1215,
         212,
         1216,
         212,
         1217,
         212,
         1241,
         1219,
         1219,
         2689,
         2690,
         2691,
         2692,
         1218,
         1223,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1218,
         1232,
         1218,
         1236,
         1218,
         1239,
         1241,
         1241,
         1242,
         1242,
         2709,
         2710,
         2711,
         2712,
         1219,
         1224,
         1219,
         1219,
         1219,
         1219,
         1219,
         1219,
         1219,
         1233,
         1219,
         1237,
         1219,
         1240,
         1219,
         1242,
         1219,
         1219,
         2713,
         2714,
         2715,
         2716,
         1219,
         1225,
         1219,
         1219,
         1219,
         1219,
         1219,
         1219,
         1219,
         1233,
         1219,
         1237,
         1219,
         1240,
         1219,
         1242,
         1219,
         1219,
         2713,
         2714,
         2715,
         2716,
         2689,
         2693,
         2689,
         2689,
         2689,
         2689,
         2689,
         2689,
         2689,
         2697,
         2689,
         2701,
         2689,
         2705,
         2689,
         2709,
         2713,
         2713,
         2689,
         2717,
         2718,
         2719,
         2690,
         2694,
         2690,
         2690,
         2690,
         2690,
         2690,
         2690,
         2690,
         2698,
         2690,
         2702,
         2690,
         2706,
         2690,
         2710,
         2714,
         2714,
         2717,
         2690,
         2720,
         2721,
         2691,
         2695,
         2691,
         2691,
         2691,
         2691,
         2691,
         2691,
         2691,
         2699,
         2691,
         2703,
         2691,
         2707,
         2691,
         2711,
         2715,
         2715,
         2718,
         2720,
         2691,
         2722,
         2692,
         2696,
         2692,
         2692,
         2692,
         2692,
         2692,
         2692,
         2692,
         2700,
         2692,
         2704,
         2692,
         2708,
         2692,
         2712,
         2716,
         2716,
         2719,
         2721,
         2722,
         2723,
      },
   },
   [nir_op_slt] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         214,
      },
   },
   [nir_op_sge] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         215,
      },
   },
   [nir_op_seq] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         3,
         4,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 6,
      .table = (const uint16_t []) {
      
         216,
         216,
         216,
         216,
         216,
         216,
         216,
         216,
         1960,
         1961,
         1962,
         1963,
         216,
         1960,
         216,
         216,
         216,
         216,
         216,
         1961,
         216,
         216,
         216,
         216,
         216,
         1962,
         216,
         216,
         216,
         216,
         216,
         1963,
         216,
         216,
         216,
         216,
      },
   },
   [nir_op_sne] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         3,
         4,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         4,
         4,
         4,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 6,
      .table = (const uint16_t []) {
      
         217,
         217,
         217,
         217,
         217,
         217,
         217,
         217,
         1964,
         1965,
         1966,
         1967,
         217,
         1964,
         217,
         217,
         217,
         217,
         217,
         1965,
         217,
         217,
         217,
         217,
         217,
         1966,
         217,
         217,
         217,
         217,
         217,
         1967,
         217,
         217,
         217,
         217,
      },
   },
   [nir_op_fall_equal2] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         218,
      },
   },
   [nir_op_fall_equal3] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         219,
      },
   },
   [nir_op_fall_equal4] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         220,
      },
   },
   [nir_op_fall_equal8] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         221,
      },
   },
   [nir_op_fall_equal16] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         222,
      },
   },
   [nir_op_fany_nequal2] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         223,
      },
   },
   [nir_op_fany_nequal3] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         224,
      },
   },
   [nir_op_fany_nequal4] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         225,
      },
   },
   [nir_op_fany_nequal8] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         226,
      },
   },
   [nir_op_fany_nequal16] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         227,
      },
   },
   [nir_op_ball_iequal2] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         228,
         228,
         228,
         228,
         228,
         228,
         1839,
         1840,
         228,
         1839,
         228,
         228,
         228,
         1840,
         228,
         228,
      },
   },
   [nir_op_ball_iequal3] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         229,
         229,
         229,
         229,
         229,
         229,
         1841,
         1842,
         229,
         1841,
         229,
         229,
         229,
         1842,
         229,
         229,
      },
   },
   [nir_op_ball_iequal4] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         230,
         230,
         230,
         230,
         230,
         230,
         1843,
         1844,
         230,
         1843,
         230,
         230,
         230,
         1844,
         230,
         230,
      },
   },
   [nir_op_ball_iequal8] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         231,
         231,
         231,
         231,
         231,
         231,
         1845,
         1846,
         231,
         1845,
         231,
         231,
         231,
         1846,
         231,
         231,
      },
   },
   [nir_op_ball_iequal16] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         232,
         232,
         232,
         232,
         232,
         232,
         1847,
         1848,
         232,
         1847,
         232,
         232,
         232,
         1848,
         232,
         232,
      },
   },
   [nir_op_ball_fequal2] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         233,
      },
   },
   [nir_op_ball_fequal3] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         234,
      },
   },
   [nir_op_ball_fequal4] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         235,
      },
   },
   [nir_op_ball_fequal8] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         236,
      },
   },
   [nir_op_ball_fequal16] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         237,
      },
   },
   [nir_op_bany_inequal2] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         238,
         238,
         238,
         238,
         238,
         238,
         1853,
         1854,
         238,
         1853,
         238,
         238,
         238,
         1854,
         238,
         238,
      },
   },
   [nir_op_bany_inequal3] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         239,
         239,
         239,
         239,
         239,
         239,
         1855,
         1856,
         239,
         1855,
         239,
         239,
         239,
         1856,
         239,
         239,
      },
   },
   [nir_op_bany_inequal4] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         240,
         240,
         240,
         240,
         240,
         240,
         1857,
         1858,
         240,
         1857,
         240,
         240,
         240,
         1858,
         240,
         240,
      },
   },
   [nir_op_bany_inequal8] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         241,
         241,
         241,
         241,
         241,
         241,
         1859,
         1860,
         241,
         1859,
         241,
         241,
         241,
         1860,
         241,
         241,
      },
   },
   [nir_op_bany_inequal16] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         242,
         242,
         242,
         242,
         242,
         242,
         1861,
         1862,
         242,
         1861,
         242,
         242,
         242,
         1862,
         242,
         242,
      },
   },
   [nir_op_bany_fnequal2] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         243,
      },
   },
   [nir_op_bany_fnequal3] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         244,
      },
   },
   [nir_op_bany_fnequal4] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         245,
      },
   },
   [nir_op_bany_fnequal8] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         246,
      },
   },
   [nir_op_bany_fnequal16] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         247,
      },
   },
   [nir_op_isub] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         248,
         248,
         249,
         249,
      },
   },
   [nir_op_urol] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         250,
      },
   },
   [nir_op_uror] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         251,
      },
   },
   [nir_op_flog2] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         3,
         4,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         4,
         4,
         4,
         4,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 6,
      .table = (const uint16_t []) {
      
         252,
         1907,
         1908,
         1909,
         1910,
         1911,
      },
   },
   [nir_op_fpow] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         253,
         254,
         253,
         253,
         255,
         256,
         255,
         255,
         253,
         1968,
         253,
         253,
         253,
         2613,
         253,
         253,
      },
   },
   [nir_op_fsqrt] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         257,
         1912,
      },
   },
   [nir_op_frcp] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         3,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         3,
         3,
         3,
         3,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 5,
      .table = (const uint16_t []) {
      
         258,
         1913,
         1914,
         1915,
         1916,
      },
   },
   [nir_op_frsq] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         259,
         1917,
      },
   },
   [nir_op_fdiv] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         260,
         260,
         261,
         261,
      },
   },
   [nir_op_fsin] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         262,
      },
   },
   [nir_op_fcos] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         263,
      },
   },
   [nir_op_fcsel] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         264,
      },
   },
   [nir_op_f2imp] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         265,
         1918,
         1919,
      },
   },
   [nir_op_f2ump] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         266,
         1920,
         1921,
      },
   },
   [nir_op_i2fmp] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         267,
         1940,
         1941,
      },
   },
   [nir_op_u2fmp] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         268,
         1942,
         1943,
      },
   },
   [nir_op_fround_even] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         269,
      },
   },
   [nir_op_pack_64_2x32_split] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         270,
         270,
         270,
         270,
         270,
         1270,
         270,
         270,
         270,
      },
   },
   [nir_op_unpack_64_2x32_split_y] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 6,
      .table = (const uint16_t []) {
      
         271,
         1815,
         1816,
         1817,
         1818,
         1819,
      },
   },
   [nir_op_pack_64_2x32] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         272,
         1971,
         2535,
      },
   },
   [nir_op_unpack_64_2x32] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         273,
         1969,
         1970,
      },
   },
   [nir_op_unpack_double_2x32_dxil] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         274,
         1973,
      },
   },
   [nir_op_pack_double_2x32_dxil] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         275,
         1972,
      },
   },
   [nir_op_unpack_32_2x16_split_x] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         276,
         1820,
         1821,
      },
   },
   [nir_op_unpack_32_2x16_split_y] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         277,
         1822,
      },
   },
   [nir_op_ubfe] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         3,
         0,
         3,
         0,
         3,
         0,
         3,
         3,
         0,
         3,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         0,
         278,
         1823,
         2880,
         0,
         279,
         1823,
         2880,
         1824,
         1825,
         1826,
         2881,
         0,
         278,
         1823,
         2880,
         0,
         278,
         1823,
         2880,
         0,
         279,
         1823,
         2880,
         1824,
         1825,
         1826,
         2881,
         0,
         278,
         1823,
         2880,
         0,
         278,
         1823,
         2880,
         0,
         279,
         1823,
         2880,
         1824,
         1825,
         1826,
         2881,
         0,
         278,
         1823,
         2880,
         0,
         278,
         1823,
         2880,
         0,
         279,
         1823,
         2880,
         1824,
         1825,
         1826,
         2881,
         0,
         278,
         1823,
         2880,
      },
   },
   [nir_op_ibfe] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         3,
         0,
         3,
         0,
         3,
         0,
         3,
         3,
         0,
         3,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         0,
         280,
         1827,
         2882,
         0,
         281,
         1827,
         2882,
         1828,
         1829,
         1830,
         2883,
         0,
         280,
         1827,
         2882,
         0,
         280,
         1827,
         2882,
         0,
         281,
         1827,
         2882,
         1828,
         1829,
         1830,
         2883,
         0,
         280,
         1827,
         2882,
         0,
         280,
         1827,
         2882,
         0,
         281,
         1827,
         2882,
         1828,
         1829,
         1830,
         2883,
         0,
         280,
         1827,
         2882,
         0,
         280,
         1827,
         2882,
         0,
         281,
         1827,
         2882,
         1828,
         1829,
         1830,
         2883,
         0,
         280,
         1827,
         2882,
      },
   },
   [nir_op_pack_32_2x16_split] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         282,
      },
   },
   [nir_op_unpack_half_2x16_split_x] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         1,
         0,
         1,
         1,
         0,
         2,
         0,
         0,
         0,
         2,
         1,
         1,
         1,
         0,
         2,
         0,
         0,
         0,
         2,
         1,
         1,
         1,
         0,
         2,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         283,
         1831,
         1832,
         1833,
      },
   },
   [nir_op_unpack_half_2x16_split_y] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         284,
         1834,
      },
   },
   [nir_op_pack_half_2x16] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         0,
         1951,
         1952,
         1953,
      },
   },
   [nir_op_pack_half_2x16_split] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         285,
         286,
         287,
         288,
      },
   },
   [nir_op_pack_32_4x8_split] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         289,
      },
   },
   [nir_op_ussub_4x8_vc4] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         290,
         0,
         290,
      },
   },
   [nir_op_fsub] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         291,
      },
   },
   [nir_op_uabs_usub] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         292,
      },
   },
   [nir_op_uabs_isub] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         293,
      },
   },
   [nir_op_find_lsb] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         294,
         1974,
      },
   },
   [nir_op_ifind_msb] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         295,
      },
   },
   [nir_op_ufind_msb] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         296,
      },
   },
   [nir_op_ifind_msb_rev] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         297,
      },
   },
   [nir_op_ufind_msb_rev] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         298,
         1975,
      },
   },
   [nir_op_bitfield_reverse] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         299,
      },
   },
   [nir_op_fmod] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         300,
      },
   },
   [nir_op_frem] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         301,
      },
   },
   [nir_op_uadd_carry] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         302,
      },
   },
   [nir_op_usub_borrow] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         303,
      },
   },
   [nir_op_bitfield_insert] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         304,
      },
   },
   [nir_op_ihadd] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         305,
      },
   },
   [nir_op_uhadd] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         306,
      },
   },
   [nir_op_irhadd] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         307,
      },
   },
   [nir_op_urhadd] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         308,
      },
   },
   [nir_op_imul_32x16] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         309,
      },
   },
   [nir_op_umul_32x16] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         310,
      },
   },
   [nir_op_ibitfield_extract] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         311,
      },
   },
   [nir_op_ubitfield_extract] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         312,
      },
   },
   [nir_op_bitfield_select] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         2,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         0,
         313,
         0,
         0,
         313,
         0,
         1790,
         1791,
         1790,
         0,
         313,
         0,
         0,
         313,
         0,
         1790,
         1791,
         1790,
         0,
         313,
         0,
         0,
         313,
         0,
         1790,
         1791,
         1790,
      },
   },
   [nir_op_bfm] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         3,
         0,
         3,
         0,
         3,
         0,
         3,
         3,
         0,
         3,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         0,
         314,
         1835,
         0,
         0,
         314,
         1835,
         0,
         1836,
         1837,
         1838,
         1836,
         2884,
         2885,
         2886,
         2884,
      },
   },
   [nir_op_uclz] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         315,
      },
   },
   [nir_op_pack_unorm_2x16] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         316,
      },
   },
   [nir_op_pack_unorm_4x8] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         317,
      },
   },
   [nir_op_pack_snorm_2x16] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         318,
      },
   },
   [nir_op_pack_snorm_4x8] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         319,
      },
   },
   [nir_op_unpack_unorm_2x16] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         320,
      },
   },
   [nir_op_unpack_unorm_4x8] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         321,
      },
   },
   [nir_op_unpack_snorm_2x16] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         322,
      },
   },
   [nir_op_unpack_snorm_4x8] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         323,
      },
   },
   [nir_op_isign] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         324,
         1906,
      },
   },
   [nir_op_amul] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         325,
      },
   },
   [nir_op_umul24] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         326,
      },
   },
   [nir_op_umad24] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         327,
      },
   },
   [nir_op_imul24_relaxed] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         328,
      },
   },
   [nir_op_umad24_relaxed] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         329,
      },
   },
   [nir_op_umul24_relaxed] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         330,
      },
   },
   [nir_op_imad24_ir3] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         331,
         332,
         333,
         332,
         333,
         334,
         335,
      },
   },
   [nir_op_imul24] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         336,
         336,
         336,
      },
   },
   [nir_op_b2b1] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         337,
      },
   },
   [nir_op_b2b8] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         338,
      },
   },
   [nir_op_b2b16] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         339,
      },
   },
   [nir_op_b2b32] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         340,
      },
   },
   [nir_op_ldexp] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         341,
      },
   },
   [nir_op_fddx] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         342,
      },
   },
   [nir_op_fddx_fine] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         343,
      },
   },
   [nir_op_fddx_coarse] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         344,
      },
   },
   [nir_op_fddy] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         345,
      },
   },
   [nir_op_fddy_fine] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         346,
      },
   },
   [nir_op_fddy_coarse] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         347,
      },
   },
   [nir_op_umul_low] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         348,
         348,
         348,
      },
   },
   [nir_op_imadsh_mix16] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         0,
         349,
         349,
         350,
         350,
         351,
         351,
      },
   },
   [nir_op_fsin_amd] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         352,
      },
   },
   [nir_op_fcos_amd] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         353,
      },
   },
   [nir_op_fisnormal] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         354,
      },
   },
};

/* Mapping from state index to offset in transforms (0 being no transforms) */
static const uint16_t nir_opt_algebraic_transform_offsets[] = {
   0,
   0,
   0,
   1,
   0,
   12,
   15,
   17,
   21,
   23,
   25,
   27,
   30,
   34,
   37,
   42,
   0,
   0,
   47,
   0,
   49,
   0,
   0,
   51,
   0,
   55,
   57,
   63,
   70,
   76,
   83,
   86,
   90,
   93,
   97,
   0,
   100,
   107,
   111,
   117,
   124,
   134,
   146,
   161,
   174,
   190,
   196,
   203,
   212,
   222,
   232,
   243,
   245,
   257,
   259,
   267,
   269,
   275,
   277,
   283,
   286,
   289,
   291,
   293,
   297,
   300,
   305,
   308,
   313,
   317,
   323,
   325,
   327,
   330,
   333,
   337,
   341,
   343,
   345,
   348,
   351,
   355,
   359,
   361,
   364,
   368,
   370,
   373,
   376,
   380,
   384,
   389,
   391,
   393,
   396,
   399,
   403,
   407,
   409,
   411,
   414,
   417,
   421,
   425,
   427,
   430,
   434,
   436,
   439,
   443,
   445,
   447,
   450,
   453,
   456,
   459,
   464,
   469,
   471,
   474,
   477,
   482,
   486,
   491,
   496,
   520,
   526,
   533,
   540,
   566,
   568,
   0,
   0,
   571,
   576,
   581,
   586,
   0,
   589,
   591,
   0,
   0,
   0,
   0,
   593,
   0,
   0,
   0,
   595,
   597,
   0,
   0,
   0,
   0,
   600,
   0,
   602,
   608,
   610,
   0,
   617,
   623,
   626,
   0,
   634,
   639,
   644,
   649,
   654,
   659,
   664,
   669,
   674,
   676,
   679,
   684,
   690,
   692,
   695,
   699,
   704,
   709,
   715,
   717,
   719,
   721,
   0,
   724,
   726,
   728,
   730,
   732,
   734,
   736,
   738,
   742,
   744,
   748,
   750,
   0,
   0,
   754,
   758,
   764,
   0,
   0,
   770,
   772,
   776,
   778,
   781,
   783,
   786,
   788,
   794,
   796,
   798,
   800,
   802,
   804,
   806,
   808,
   810,
   812,
   814,
   816,
   818,
   820,
   822,
   824,
   826,
   828,
   830,
   832,
   834,
   836,
   838,
   840,
   842,
   844,
   846,
   848,
   850,
   852,
   854,
   856,
   858,
   860,
   862,
   864,
   866,
   871,
   0,
   876,
   878,
   883,
   886,
   892,
   0,
   0,
   894,
   896,
   899,
   901,
   903,
   0,
   0,
   0,
   0,
   905,
   907,
   909,
   0,
   0,
   0,
   0,
   911,
   914,
   917,
   919,
   928,
   930,
   938,
   941,
   943,
   945,
   947,
   949,
   951,
   0,
   953,
   956,
   958,
   960,
   962,
   964,
   967,
   0,
   0,
   0,
   969,
   971,
   973,
   975,
   977,
   981,
   984,
   987,
   990,
   993,
   995,
   997,
   1000,
   1003,
   0,
   1005,
   1007,
   1009,
   1011,
   1013,
   1015,
   1017,
   1019,
   1021,
   1023,
   1025,
   1027,
   1029,
   1031,
   1034,
   1037,
   1040,
   1042,
   1045,
   1049,
   1053,
   1058,
   1062,
   1064,
   1066,
   1068,
   1070,
   1074,
   1076,
   1078,
   1080,
   1082,
   1084,
   1086,
   1088,
   1090,
   1092,
   0,
   0,
   1095,
   1099,
   1101,
   1104,
   1107,
   1109,
   1111,
   1123,
   1136,
   1148,
   1160,
   1172,
   1185,
   1198,
   1210,
   1222,
   1226,
   1230,
   1233,
   1236,
   1238,
   1243,
   1247,
   1251,
   1255,
   1259,
   1262,
   1264,
   1269,
   0,
   1271,
   1273,
   1275,
   1277,
   1279,
   1282,
   1285,
   1288,
   1290,
   1292,
   1294,
   1297,
   1300,
   1303,
   1307,
   1311,
   1315,
   1319,
   1323,
   1328,
   1331,
   1335,
   1339,
   1342,
   1345,
   1347,
   1349,
   1352,
   1355,
   1358,
   1361,
   1364,
   1367,
   1371,
   1375,
   1379,
   1382,
   1385,
   1387,
   1389,
   1391,
   1393,
   1396,
   1399,
   1402,
   1404,
   1406,
   1409,
   1412,
   1415,
   1419,
   1423,
   1427,
   1430,
   1433,
   1436,
   1439,
   1443,
   1447,
   1451,
   1454,
   1457,
   1460,
   1464,
   1468,
   1472,
   1475,
   1478,
   1482,
   1486,
   1490,
   1493,
   1496,
   1501,
   1506,
   1510,
   1514,
   1519,
   1523,
   1527,
   1531,
   1535,
   1538,
   1540,
   1544,
   1550,
   1555,
   1562,
   1567,
   1575,
   1579,
   1584,
   1589,
   1595,
   1600,
   1608,
   1616,
   1624,
   1632,
   1640,
   1646,
   1656,
   1662,
   1669,
   1675,
   1687,
   1692,
   1697,
   1704,
   1712,
   1720,
   1728,
   1736,
   1744,
   1752,
   1758,
   1765,
   1771,
   1779,
   1785,
   1792,
   1798,
   1806,
   1811,
   1817,
   1822,
   1829,
   1834,
   1840,
   1845,
   1852,
   1860,
   1865,
   1873,
   1878,
   1883,
   1888,
   1893,
   1898,
   1903,
   1908,
   1914,
   1922,
   1929,
   1938,
   1945,
   1955,
   1961,
   1968,
   1975,
   1983,
   1990,
   2000,
   2010,
   2020,
   2030,
   2040,
   2048,
   2060,
   2068,
   2077,
   2085,
   2099,
   2106,
   2113,
   2122,
   2132,
   2142,
   2152,
   2162,
   2172,
   2182,
   2190,
   2199,
   2207,
   2217,
   2225,
   2234,
   2242,
   2252,
   2259,
   2267,
   2274,
   2283,
   2290,
   2298,
   2305,
   2314,
   2324,
   2331,
   2341,
   2348,
   2355,
   2362,
   2369,
   2376,
   2383,
   2390,
   2396,
   2403,
   2409,
   2416,
   2422,
   2427,
   2451,
   2456,
   2463,
   2468,
   2473,
   2479,
   2484,
   2491,
   2497,
   2522,
   2528,
   2536,
   2542,
   2551,
   2556,
   2562,
   2568,
   2575,
   2581,
   2590,
   2599,
   2608,
   2617,
   2626,
   2633,
   2644,
   2651,
   2659,
   2666,
   2679,
   2685,
   2691,
   2699,
   2708,
   2717,
   2726,
   2735,
   2744,
   2753,
   2760,
   2768,
   2775,
   2784,
   2791,
   2799,
   2806,
   2815,
   2821,
   2828,
   2834,
   2842,
   2848,
   2855,
   2861,
   2869,
   2878,
   2884,
   2893,
   2899,
   2905,
   2911,
   2917,
   2923,
   2929,
   2935,
   2941,
   2948,
   2954,
   2962,
   2969,
   2995,
   3002,
   3011,
   3018,
   3028,
   3034,
   3041,
   3048,
   3056,
   3063,
   3073,
   3083,
   3093,
   3103,
   3113,
   3121,
   3133,
   3141,
   3150,
   3158,
   3172,
   3179,
   3186,
   3195,
   3205,
   3215,
   3225,
   3235,
   3245,
   3255,
   3263,
   3272,
   3280,
   3290,
   3298,
   3307,
   3315,
   3325,
   3332,
   3340,
   3347,
   3356,
   3363,
   3371,
   3378,
   3387,
   3397,
   3404,
   3414,
   3421,
   3428,
   3435,
   3442,
   3449,
   3456,
   3463,
   3471,
   3478,
   3486,
   3494,
   3503,
   3509,
   3516,
   3522,
   3530,
   3537,
   3563,
   3570,
   3579,
   3586,
   3596,
   3602,
   3609,
   3616,
   3624,
   3631,
   3641,
   3651,
   3661,
   3671,
   3681,
   3689,
   3701,
   3709,
   3718,
   3726,
   3740,
   3747,
   3754,
   3763,
   3773,
   3783,
   3793,
   3803,
   3813,
   3823,
   3831,
   3840,
   3848,
   3858,
   3866,
   3875,
   3883,
   3893,
   3900,
   3908,
   3915,
   3924,
   3931,
   3939,
   3946,
   3955,
   3965,
   3972,
   3982,
   3989,
   3996,
   4003,
   4010,
   4017,
   4024,
   4031,
   4037,
   4044,
   4050,
   4058,
   4065,
   4091,
   4098,
   4107,
   4114,
   4124,
   4130,
   4137,
   4144,
   4152,
   4159,
   4169,
   4179,
   4189,
   4199,
   4209,
   4217,
   4229,
   4237,
   4246,
   4254,
   4268,
   4275,
   4282,
   4291,
   4301,
   4311,
   4321,
   4331,
   4341,
   4351,
   4359,
   4368,
   4376,
   4386,
   4394,
   4403,
   4411,
   4421,
   4428,
   4436,
   4443,
   4452,
   4459,
   4467,
   4474,
   4483,
   4493,
   4500,
   4510,
   4517,
   4524,
   4531,
   4538,
   4545,
   4552,
   4559,
   4565,
   4572,
   4578,
   4586,
   4593,
   4619,
   4626,
   4635,
   4642,
   4652,
   4658,
   4665,
   4672,
   4680,
   4687,
   4697,
   4707,
   4717,
   4727,
   4737,
   4745,
   4757,
   4765,
   4774,
   4782,
   4796,
   4803,
   4810,
   4819,
   4829,
   4839,
   4849,
   4859,
   4869,
   4879,
   4887,
   4896,
   4904,
   4914,
   4922,
   4931,
   4939,
   4949,
   4956,
   4964,
   4971,
   4980,
   4987,
   4995,
   5002,
   5011,
   5021,
   5028,
   5038,
   5045,
   5052,
   5059,
   5066,
   5073,
   5080,
   5087,
   5093,
   5100,
   5106,
   5114,
   5121,
   5147,
   5154,
   5163,
   5170,
   5180,
   5186,
   5193,
   5200,
   5208,
   5215,
   5225,
   5235,
   5245,
   5255,
   5265,
   5273,
   5285,
   5293,
   5302,
   5310,
   5324,
   5331,
   5338,
   5347,
   5357,
   5367,
   5377,
   5387,
   5397,
   5407,
   5415,
   5424,
   5432,
   5442,
   5450,
   5459,
   5467,
   5477,
   5484,
   5492,
   5499,
   5508,
   5515,
   5523,
   5530,
   5539,
   5549,
   5556,
   5566,
   5573,
   5580,
   5587,
   5594,
   5601,
   5608,
   5615,
   5621,
   5628,
   5634,
   5642,
   5649,
   5675,
   5682,
   5691,
   5698,
   5708,
   5714,
   5721,
   5728,
   5736,
   5743,
   5753,
   5763,
   5773,
   5783,
   5793,
   5801,
   5813,
   5821,
   5830,
   5838,
   5852,
   5859,
   5866,
   5875,
   5885,
   5895,
   5905,
   5915,
   5925,
   5935,
   5943,
   5952,
   5960,
   5970,
   5978,
   5987,
   5995,
   6005,
   6012,
   6020,
   6027,
   6036,
   6043,
   6051,
   6058,
   6067,
   6077,
   6084,
   6094,
   6101,
   6108,
   6115,
   6122,
   6129,
   6136,
   6143,
   0,
   6148,
   6154,
   6156,
   6160,
   6167,
   6171,
   6178,
   6183,
   6190,
   6199,
   6204,
   6209,
   6216,
   6225,
   6230,
   6233,
   6237,
   6239,
   6243,
   6249,
   6251,
   6254,
   6257,
   6260,
   6264,
   6268,
   6271,
   6274,
   6287,
   6304,
   6322,
   6335,
   6349,
   6362,
   6378,
   6391,
   6405,
   6419,
   6432,
   6445,
   6448,
   6452,
   6456,
   6460,
   6465,
   6470,
   6474,
   6478,
   6482,
   6486,
   6490,
   6495,
   6500,
   6504,
   6508,
   6511,
   6521,
   6527,
   6531,
   6535,
   6539,
   6542,
   6545,
   6548,
   6551,
   6555,
   6560,
   6565,
   6569,
   6573,
   6578,
   6584,
   6595,
   6607,
   6613,
   6625,
   6638,
   6642,
   6647,
   6658,
   6670,
   6675,
   6687,
   6700,
   6702,
   6707,
   6712,
   6716,
   6720,
   6725,
   6731,
   6736,
   6741,
   6746,
   6751,
   6756,
   6760,
   6764,
   6768,
   6771,
   6774,
   6777,
   6780,
   6782,
   6786,
   6790,
   6793,
   6796,
   6805,
   6814,
   6824,
   6833,
   6842,
   6850,
   6860,
   6870,
   6879,
   6888,
   6891,
   6893,
   6897,
   6901,
   6905,
   6909,
   6912,
   6917,
   6922,
   6926,
   6930,
   6934,
   6938,
   6942,
   6945,
   6950,
   6955,
   6959,
   6963,
   6971,
   6975,
   6978,
   6983,
   6988,
   6993,
   6997,
   7001,
   7011,
   7013,
   7015,
   7018,
   7021,
   7024,
   7028,
   7031,
   7036,
   7041,
   7045,
   7049,
   7054,
   7058,
   7062,
   7065,
   7068,
   7074,
   7085,
   7097,
   7103,
   7115,
   7128,
   7132,
   7137,
   7147,
   7158,
   7163,
   7174,
   7186,
   7188,
   7192,
   7196,
   7200,
   7204,
   7209,
   7215,
   7220,
   7225,
   7230,
   7235,
   7240,
   7244,
   7248,
   7252,
   7255,
   7259,
   7263,
   7266,
   7269,
   7272,
   7280,
   7288,
   7295,
   7302,
   7309,
   7317,
   7320,
   7323,
   7326,
   7331,
   7337,
   7342,
   7347,
   7352,
   7357,
   7362,
   7367,
   7372,
   7376,
   7380,
   7384,
   7388,
   7392,
   0,
   7397,
   7403,
   7405,
   7410,
   7421,
   7430,
   7435,
   7445,
   7452,
   7457,
   7464,
   0,
   7471,
   7477,
   7482,
   7492,
   7507,
   7522,
   7537,
   7542,
   7547,
   7552,
   7560,
   7575,
   0,
   7583,
   7586,
   7589,
   7592,
   7595,
   7598,
   7601,
   7604,
   7607,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   7609,
   7612,
   7615,
   7617,
   7620,
   7623,
   7626,
   7629,
   7631,
   7633,
   7638,
   7640,
   7642,
   7647,
   7654,
   7662,
   7667,
   7673,
   7678,
   7684,
   7689,
   7693,
   7695,
   7697,
   7699,
   0,
   7701,
   0,
   0,
   7703,
   0,
   0,
   7706,
   7714,
   7722,
   7731,
   7739,
   7748,
   7755,
   7762,
   7770,
   7780,
   7787,
   7794,
   7796,
   7798,
   7802,
   7804,
   7806,
   0,
   0,
   7808,
   0,
   0,
   7811,
   0,
   0,
   7814,
   7817,
   7820,
   7822,
   0,
   7824,
   7826,
   7831,
   7837,
   7844,
   7851,
   7859,
   7866,
   7875,
   7882,
   7887,
   7895,
   7903,
   7916,
   7929,
   7936,
   7946,
   7954,
   7962,
   7971,
   7985,
   7999,
   8011,
   8026,
   8039,
   8052,
   8065,
   8081,
   8096,
   8110,
   8124,
   8141,
   8157,
   8172,
   8185,
   8201,
   8215,
   8229,
   8237,
   8248,
   8257,
   8266,
   8275,
   8282,
   8292,
   8300,
   8308,
   8315,
   8322,
   8332,
   8342,
   8350,
   8361,
   8372,
   8382,
   8393,
   8405,
   8416,
   8428,
   8441,
   8455,
   8468,
   8475,
   8483,
   8491,
   8499,
   8502,
   8506,
   8510,
   8514,
   8517,
   8520,
   8525,
   8529,
   8533,
   8538,
   8542,
   8546,
   8550,
   8554,
   8559,
   8564,
   8569,
   8574,
   8578,
   8582,
   8588,
   8594,
   8600,
   8606,
   8612,
   8619,
   8625,
   8631,
   8638,
   8644,
   8650,
   8656,
   8662,
   8668,
   8675,
   8681,
   8687,
   8693,
   8700,
   8707,
   8714,
   8721,
   8727,
   8733,
   8739,
   8746,
   8753,
   8760,
   8766,
   8772,
   8778,
   8785,
   8792,
   8799,
   8812,
   8818,
   8824,
   8830,
   8837,
   8843,
   8849,
   8855,
   8861,
   8867,
   8873,
   8879,
   8885,
   8892,
   8898,
   8904,
   8910,
   8917,
   8924,
   8931,
   8938,
   8945,
   8951,
   8957,
   8963,
   8970,
   8977,
   8984,
   8990,
   8996,
   9002,
   9009,
   9016,
   9023,
   9036,
   9039,
   9042,
   9047,
   9051,
   9055,
   9060,
   9064,
   9068,
   9072,
   9076,
   9081,
   9086,
   9091,
   9096,
   9100,
   9104,
   9110,
   9116,
   9119,
   9122,
   9125,
   9127,
   9131,
   9135,
   9139,
   9143,
   9147,
   9150,
   9155,
   9159,
   9163,
   9166,
   9170,
   9173,
   9176,
   9179,
   9182,
   9185,
   9188,
   9191,
   9195,
   9198,
   9202,
   9205,
   9209,
   9213,
   9217,
   9220,
   0,
   0,
   9222,
   9224,
   0,
   0,
   0,
   0,
   0,
   9229,
   9232,
   9235,
   9238,
   9241,
   9244,
   9251,
   9258,
   9265,
   9280,
   9287,
   9294,
   9308,
   9322,
   9328,
   9340,
   9352,
   9358,
   9364,
   9371,
   9378,
   9384,
   9390,
   9396,
   9402,
   9408,
   9414,
   9418,
   9424,
   9436,
   9448,
   9451,
   9454,
   9461,
   9468,
   9475,
   9490,
   9497,
   9504,
   9518,
   9532,
   9544,
   9556,
   9562,
   9569,
   9575,
   9582,
   9588,
   9594,
   9600,
   9606,
   9612,
   9618,
   9622,
   9628,
   9640,
   9652,
   9655,
   9658,
   9661,
   9663,
   9666,
   9669,
   9672,
   9674,
   9677,
   9681,
   9685,
   9688,
   9692,
   9695,
   9698,
   9701,
   9704,
   9707,
   9710,
   9713,
   9716,
   9719,
   9723,
   9727,
   9731,
   9735,
   9737,
   9739,
   9743,
   9750,
   9752,
   9756,
   9758,
   9760,
   9764,
   9771,
   9773,
   9783,
   9788,
   9793,
   9798,
   9803,
   9813,
   9824,
   9829,
   9834,
   9839,
   9841,
   9843,
   9845,
   9847,
   9849,
   9851,
   9853,
   9855,
   9857,
   9859,
   9861,
   0,
   9863,
   9865,
   9867,
   9869,
   9871,
   9873,
   9875,
   9877,
   9879,
   9884,
   9890,
   9896,
   9904,
   9913,
   9918,
   9925,
   9933,
   9939,
   9946,
   9953,
   9962,
   9972,
   9978,
   9986,
   9995,
   10004,
   10015,
   10027,
   10033,
   10041,
   10050,
   10053,
   10056,
   10059,
   10064,
   10069,
   10074,
   10081,
   10086,
   10092,
   10102,
   10104,
   10107,
   10110,
   10113,
   10116,
   10119,
   10123,
   10127,
   10131,
   10135,
   10139,
   10142,
   10146,
   10150,
   10154,
   10158,
   10163,
   10166,
   10170,
   10174,
   10178,
   10182,
   10187,
   10196,
   10218,
   10221,
   10224,
   10227,
   10230,
   10233,
   10236,
   10240,
   10243,
   10247,
   10255,
   10257,
   10260,
   10263,
   10266,
   10269,
   10273,
   10277,
   10281,
   10284,
   10287,
   10291,
   10295,
   10299,
   10303,
   10306,
   10310,
   10314,
   10318,
   10322,
   10330,
   0,
   10352,
   10354,
   10356,
   10359,
   10361,
   10365,
   10370,
   10374,
   10377,
   10380,
   10382,
   10385,
   10388,
   10390,
   10393,
   10405,
   10412,
   10419,
   10426,
   10433,
   10472,
   10491,
   10498,
   10505,
   10517,
   10523,
   10530,
   10537,
   10544,
   10551,
   10558,
   10564,
   10580,
   10622,
   10629,
   10636,
   10643,
   10655,
   10658,
   10661,
   10664,
   10667,
   10670,
   10674,
   10679,
   10683,
   10685,
   10687,
   10690,
   10693,
   10695,
   10697,
   10700,
   10703,
   10706,
   10709,
   10713,
   10716,
   10718,
   10720,
   10722,
   10725,
   10728,
   10731,
   10734,
   10737,
   10740,
   10743,
   10746,
   10749,
   10752,
   10755,
   0,
   0,
   0,
   10757,
   10760,
   10763,
   10766,
   10769,
   10772,
   10775,
   10778,
   10781,
   10784,
   10787,
   10793,
   10799,
   10805,
   10812,
   10819,
   10830,
   10837,
   10843,
   10851,
   10858,
   10865,
   10874,
   10880,
   10888,
   10895,
   10902,
   10911,
   10923,
   10948,
   10954,
   10960,
   10966,
   10973,
   10980,
   10991,
   10998,
   11004,
   11012,
   11019,
   11026,
   11035,
   11041,
   11049,
   11056,
   11063,
   11072,
   11084,
   11109,
   11115,
   11121,
   11127,
   11133,
   11139,
   11142,
   11144,
   11146,
   11148,
   11150,
   11152,
   11155,
   11157,
   11159,
   11161,
   11163,
   11165,
   11167,
   11169,
   11171,
   11173,
   11175,
   11179,
   11181,
   11183,
   11187,
   11191,
   11193,
   11196,
   11201,
   11204,
   11207,
   11209,
   11211,
   11213,
   11215,
   11217,
   11219,
   11221,
   11223,
   11225,
   11227,
   11229,
   11233,
   11238,
   11244,
   11247,
   11251,
   11254,
   0,
   0,
   0,
   0,
   0,
   0,
   11258,
   11262,
   11266,
   11270,
   11274,
   11278,
   11282,
   11286,
   11290,
   11294,
   11298,
   11302,
   11308,
   11310,
   11312,
   11314,
   11316,
   11318,
   11321,
   11323,
   11325,
   11327,
   11331,
   11335,
   11339,
   11343,
   11347,
   11352,
   11355,
   11358,
   11361,
   11364,
   11367,
   11372,
   11377,
   11382,
   11387,
   11391,
   11395,
   11400,
   11405,
   11410,
   11415,
   11419,
   11423,
   11427,
   11431,
   11434,
   11437,
   11442,
   11447,
   11452,
   11457,
   11460,
   11463,
   11468,
   11473,
   11478,
   11483,
   11486,
   11489,
   11494,
   11499,
   11504,
   11509,
   11512,
   11515,
   11520,
   11525,
   11530,
   11535,
   11539,
   11543,
   11549,
   11555,
   11561,
   11567,
   11571,
   11575,
   11581,
   11587,
   11593,
   11599,
   11603,
   11607,
   11613,
   11619,
   11625,
   11631,
   11634,
   11637,
   11642,
   11647,
   11652,
   11657,
   11660,
   11663,
   11668,
   11673,
   11678,
   11683,
   11688,
   11693,
   11698,
   11703,
   11708,
   11713,
   11718,
   11723,
   11730,
   11737,
   11744,
   11751,
   11758,
   11765,
   11767,
   11774,
   11782,
   11789,
   11798,
   11805,
   11813,
   11820,
   11829,
   11836,
   11844,
   11851,
   11860,
   11867,
   11875,
   11882,
   11891,
   11900,
   11910,
   11919,
   11930,
   11939,
   11949,
   11958,
   11969,
   11978,
   11988,
   11997,
   12008,
   12017,
   12027,
   12036,
   12047,
   12053,
   12061,
   12070,
   12078,
   12088,
   12096,
   12105,
   12113,
   12123,
   12131,
   12140,
   12148,
   12158,
   12166,
   12175,
   12183,
   12193,
   12202,
   12212,
   12221,
   12232,
   12241,
   12251,
   12260,
   12271,
   12280,
   12290,
   12299,
   12310,
   12319,
   12329,
   12338,
   12349,
   12358,
   12368,
   12377,
   12388,
   12397,
   12407,
   12416,
   12427,
   12436,
   12446,
   12455,
   12466,
   12475,
   12485,
   12494,
   12505,
   12514,
   12524,
   12533,
   12544,
   12553,
   12563,
   12572,
   12583,
   12592,
   12602,
   12611,
   12622,
   12631,
   12641,
   12650,
   12661,
   12668,
   12679,
   12688,
   12698,
   12707,
   12718,
   12727,
   12737,
   12746,
   12757,
   12766,
   12776,
   12785,
   12796,
   12805,
   12815,
   12824,
   12835,
   12844,
   12854,
   12863,
   12874,
   12883,
   12893,
   12902,
   12913,
   12922,
   12932,
   12941,
   12952,
   12961,
   12971,
   12980,
   12991,
   13002,
   13011,
   13021,
   13030,
   13041,
   13050,
   13060,
   13069,
   13080,
   13089,
   13099,
   13108,
   13119,
   13128,
   13138,
   13147,
   13158,
   13167,
   13176,
   13185,
   13194,
   13205,
   13220,
   13231,
   13246,
   13254,
   13262,
   13270,
   13278,
   13286,
   13290,
   13294,
   13298,
   13302,
   13314,
   13327,
   13341,
   13355,
   13369,
   13383,
   13388,
   13393,
   13398,
   13403,
   13409,
   13415,
   13421,
   13427,
   13433,
   13439,
   13445,
   13451,
   13456,
   13461,
   13466,
   13471,
   13476,
   13481,
   13486,
   13491,
   13498,
   13505,
   13512,
   13519,
   13526,
   0,
   13533,
   13535,
   13540,
   13545,
   13547,
   13551,
   13556,
   13561,
   13564,
   0,
   13568,
   13573,
   13575,
   13581,
   13586,
   13595,
   13601,
   13608,
   13611,
   13614,
   13618,
   13622,
   13626,
   13632,
   13637,
   13641,
   13645,
   13650,
   13654,
   13658,
   13664,
   13669,
   13673,
   13677,
   13682,
   0,
   0,
   13686,
   13688,
   13699,
   13706,
   13713,
   13722,
   13732,
   13737,
   13739,
   13741,
   13744,
   13748,
   0,
   0,
   13750,
   13752,
   0,
   0,
   13756,
   13759,
   13762,
   13765,
   13769,
   0,
   0,
   13773,
   13775,
   0,
   0,
   13779,
   13781,
   13783,
   13788,
   13792,
   13796,
   13801,
   0,
   13803,
   13805,
   13816,
   13824,
   13835,
   13844,
   13853,
   13869,
   13882,
   13898,
   13912,
   13926,
   13937,
   13945,
   13956,
   13965,
   13974,
   13984,
   13996,
   14006,
   14019,
   14030,
   14041,
   14055,
   14066,
   14074,
   14085,
   14094,
   14103,
   14112,
   14124,
   14134,
   14144,
   14149,
   14154,
   14159,
   14164,
   14175,
   14186,
   14197,
   14208,
   14212,
   14218,
   14224,
   14230,
   14236,
   14242,
   14248,
   14254,
   14260,
   14266,
   14272,
   14278,
   14284,
   14288,
   14294,
   14300,
   14306,
   14312,
   14319,
   14324,
   14329,
   14334,
   14339,
   14346,
   14353,
   14360,
   14367,
   14369,
   14376,
   14383,
   14390,
   14397,
   14403,
   14409,
   14415,
   14421,
   14427,
   14433,
   14439,
   14445,
   14451,
   14456,
   14461,
   14464,
   14472,
   14480,
   14488,
   14496,
   14504,
   14512,
   14517,
   14520,
   14522,
   14524,
   14526,
   14528,
   14530,
   14532,
   14535,
   14537,
   14544,
   14549,
   14554,
   14559,
   14564,
   14577,
   14590,
   14604,
   14616,
   14633,
   14648,
   14663,
   14678,
   14694,
   14696,
   14700,
   14703,
   14711,
   14717,
   14723,
   14729,
   14735,
   14739,
   14742,
   14750,
   14756,
   14762,
   14768,
   14774,
   14784,
   14787,
   14791,
   14794,
   14802,
   14808,
   14814,
   14820,
   14826,
   14831,
   14835,
   14844,
   14851,
   14858,
   14865,
   14872,
   14877,
   14881,
   14890,
   14897,
   14904,
   14911,
   14918,
   14922,
   14925,
   14933,
   14939,
   14945,
   14951,
   14957,
   14961,
   14964,
   14972,
   14978,
   14984,
   14990,
   14996,
   14999,
   15007,
   15013,
   15019,
   15025,
   15031,
   15034,
   15041,
   15046,
   15051,
   15056,
   15061,
   15072,
   15082,
   15092,
   15102,
   15112,
   15120,
   15128,
   15136,
   15144,
   15152,
   15160,
   15165,
   15168,
   15170,
   15176,
   15183,
   15190,
   15197,
   15204,
   15212,
   15218,
   15226,
   15233,
   15240,
   15244,
   15248,
   15252,
   15257,
   15262,
   15267,
   15272,
   15277,
   15282,
   15287,
   15292,
   15297,
   15301,
   15305,
   15309,
   15314,
   15320,
   15324,
   15330,
   15334,
   15338,
   15340,
   15344,
   15348,
   15352,
   15355,
   15357,
   15361,
   15365,
   15368,
   15373,
   15378,
   15383,
   15386,
   15391,
   15396,
   15401,
   15404,
   15409,
   15413,
   15419,
   15423,
   15427,
   15433,
   15437,
   15441,
   15445,
   15449,
   15453,
   15456,
   15460,
   15465,
   15468,
   15474,
   15480,
   15486,
   15492,
   15497,
   15505,
   15513,
   15522,
   15527,
   15534,
   15536,
   15538,
   15546,
   15548,
   0,
   0,
   0,
   15554,
   15556,
   15561,
   15565,
   15569,
   15573,
   15577,
   15582,
   15587,
   15592,
   15597,
   15601,
   15605,
   15611,
   15615,
   15619,
   15621,
   15625,
   15629,
   15631,
   15634,
   15638,
   15641,
   15646,
   15651,
   15654,
   15659,
   15664,
   15667,
   15671,
   15677,
   15681,
   15685,
   15693,
   15701,
   15704,
   15711,
   15715,
   15720,
   15726,
   15734,
   15738,
   15743,
   15748,
   15753,
   15760,
   15762,
   15766,
   15770,
   15776,
   15778,
   15782,
   15785,
   15787,
   15791,
   15794,
   15798,
   15800,
   15802,
   15806,
   15810,
   15814,
   15820,
   15823,
   15826,
   15829,
   15831,
   15835,
   15839,
   15842,
   15845,
   15848,
   15853,
   15858,
   15863,
   15868,
   15873,
   15882,
   15891,
   15900,
   15909,
   15916,
   15923,
   15930,
   15937,
   15944,
   15951,
   15958,
   15965,
   15971,
   15977,
   15983,
   15989,
   15995,
   16001,
   16007,
   16013,
   16019,
   16025,
   16031,
   16037,
   16045,
   16053,
   16061,
   16069,
   16077,
   16085,
   16090,
   16133,
   16176,
   16196,
   16201,
   16203,
   16206,
   16210,
   16215,
   16217,
   16220,
   16223,
   16227,
   16229,
   16231,
   16234,
   16238,
   16243,
   16246,
   16252,
   16258,
   16263,
   16268,
   16274,
   16279,
   16285,
   16290,
   16296,
   16301,
   16308,
   16314,
   16320,
   16325,
   16332,
   16338,
   16344,
   16349,
   16356,
   16362,
   16368,
   16373,
   16380,
   16386,
   16390,
   16394,
   16400,
   16403,
   16409,
   16415,
   16432,
   16448,
   16452,
   16459,
   16465,
   16472,
   16476,
   16486,
   16490,
   16501,
   16513,
   16518,
   16523,
   16531,
   16539,
   16544,
   16552,
   16557,
   16565,
   16573,
   16584,
   16589,
   16597,
   16605,
   16616,
   16627,
   16633,
   16642,
   16647,
   16655,
   16660,
   16669,
   0,
   16681,
   16689,
   16697,
   0,
   0,
   0,
   16705,
   16712,
   16716,
   16722,
   16725,
   16728,
   16732,
   16738,
   16742,
   16746,
   16750,
   16754,
   16758,
   16762,
   16765,
   16770,
   16774,
   16779,
   16783,
   16788,
   16793,
   0,
   0,
   16797,
   16804,
   16811,
   16813,
   0,
   0,
   0,
   0,
   16815,
   16818,
   0,
   0,
   0,
   0,
   16821,
   16825,
   16829,
   0,
   0,
   0,
   16831,
   16833,
   0,
   16835,
   16846,
   16862,
   16873,
   16885,
   16899,
   16911,
   16916,
   16921,
   16923,
   16930,
   16937,
   16940,
   16943,
   16947,
   16951,
   16955,
   16959,
   16964,
   16969,
   16976,
   16983,
   16988,
   16990,
   16993,
   16995,
   16998,
   17000,
   17002,
   17005,
   17009,
   17013,
   17015,
   17023,
   17032,
   17039,
   17042,
   17046,
   17054,
   17062,
   17067,
   17075,
   17086,
   17097,
   17111,
   17125,
   17130,
   17141,
   17145,
   17149,
   0,
   17154,
   17157,
   17163,
   17176,
   17184,
   17201,
   17217,
   17224,
   17230,
   17234,
   17236,
   17239,
   17245,
   17258,
   17275,
   17291,
   17298,
   17304,
   17308,
   17310,
   17313,
   17319,
   17332,
   17349,
   17365,
   17372,
   17378,
   17383,
};

static const nir_algebraic_table nir_opt_algebraic_table = {
   .transforms = nir_opt_algebraic_transforms,
   .transform_offsets = nir_opt_algebraic_transform_offsets,
   .pass_op_table = nir_opt_algebraic_pass_op_table,
   .values = nir_opt_algebraic_values,
   .expression_cond = nir_opt_algebraic_expression_cond,
   .variable_cond = nir_opt_algebraic_variable_cond,
};

bool
nir_opt_algebraic(nir_shader *shader)
{
   bool progress = false;
   bool condition_flags[122];
   const nir_shader_compiler_options *options = shader->options;
   const shader_info *info = &shader->info;
   (void) options;
   (void) info;

   /* This is not a great place for this, but it seems to be the best place
    * for it. Check that at most one kind of lowering is requested for
    * bitfield extract and bitfield insert. Otherwise the lowering can fight
    * with each other and optimizations.
    */
   assert((int)options->lower_bitfield_extract +
          (int)options->lower_bitfield_extract_to_shifts <= 1);
   assert((int)options->lower_bitfield_insert +
          (int)options->lower_bitfield_insert_to_shifts +
          (int)options->lower_bitfield_insert_to_bitfield_select <= 1);


   STATIC_ASSERT(5977 == ARRAY_SIZE(nir_opt_algebraic_values));
   condition_flags[0] = true;
   condition_flags[1] = !options->lower_bitops;
   condition_flags[2] = options->lower_bitops;
   condition_flags[3] = !options->lower_bitops && (options->lower_int64_options & (nir_lower_imul64 | nir_lower_shift64)) == nir_lower_imul64;
   condition_flags[4] = options->lower_mul_2x32_64;
   condition_flags[5] = !nir_is_float_control_signed_zero_inf_nan_preserve(info->float_controls_execution_mode, 16);
   condition_flags[6] = !nir_is_float_control_signed_zero_inf_nan_preserve(info->float_controls_execution_mode, 32);
   condition_flags[7] = !options->lower_iadd_sat;
   condition_flags[8] = !options->lower_uadd_sat;
   condition_flags[9] = options->has_fmulz && !nir_is_float_control_signed_zero_inf_nan_preserve(info->float_controls_execution_mode, 32);
   condition_flags[10] = !options->has_sdot_4x8;
   condition_flags[11] = !options->has_udot_4x8;
   condition_flags[12] = !options->has_sudot_4x8;
   condition_flags[13] = !options->has_dot_2x16;
   condition_flags[14] = options->lower_flrp16;
   condition_flags[15] = !options->lower_flrp16;
   condition_flags[16] = options->lower_flrp32;
   condition_flags[17] = !options->lower_flrp32;
   condition_flags[18] = options->lower_flrp64;
   condition_flags[19] = !options->lower_flrp64;
   condition_flags[20] = options->lower_ftrunc;
   condition_flags[21] = options->lower_ftrunc || (options->lower_doubles_options & nir_lower_dtrunc);
   condition_flags[22] = options->lower_ffloor;
   condition_flags[23] = (options->lower_ffloor || (options->lower_doubles_options & nir_lower_dfloor)) && !(options->lower_doubles_options & nir_lower_dfract);
   condition_flags[24] = !options->lower_ffloor;
   condition_flags[25] = !options->lower_ffloor && !(options->lower_doubles_options & nir_lower_dfloor);
   condition_flags[26] = options->lower_ffract;
   condition_flags[27] = options->lower_ffract || (options->lower_doubles_options & nir_lower_dfract);
   condition_flags[28] = options->lower_fceil;
   condition_flags[29] = options->lower_ffma16;
   condition_flags[30] = options->lower_ffma32;
   condition_flags[31] = options->lower_ffma64;
   condition_flags[32] = options->fuse_ffma16;
   condition_flags[33] = options->fuse_ffma32;
   condition_flags[34] = options->fuse_ffma64;
   condition_flags[35] = options->lower_fdph;
   condition_flags[36] = !options->lower_fdph;
   condition_flags[37] = options->lower_fdot;
   condition_flags[38] = !options->lower_fsat;
   condition_flags[39] = !options->lower_iabs;
   condition_flags[40] = options->lower_fsat;
   condition_flags[41] = !options->lower_fsat && !nir_is_float_control_signed_zero_inf_nan_preserve(info->float_controls_execution_mode, 32);
   condition_flags[42] = !options->lower_fsign;
   condition_flags[43] = options->lower_umax;
   condition_flags[44] = options->lower_umin;
   condition_flags[45] = !options->lower_umax;
   condition_flags[46] = !options->lower_umin;
   condition_flags[47] = options->lower_scmp;
   condition_flags[48] = options->lower_vector_cmp;
   condition_flags[49] = !options->lower_rotate;
   condition_flags[50] = options->lower_rotate;
   condition_flags[51] = options->lower_fpow;
   condition_flags[52] = !options->lower_fpow;
   condition_flags[53] = options->lower_fdiv;
   condition_flags[54] = options->lower_fsqrt;
   condition_flags[55] = !options->lower_fsqrt;
   condition_flags[56] = options->lower_sincos;
   condition_flags[57] = !(options->lower_doubles_options & nir_lower_fp64_full_software);
   condition_flags[58] = !options->lower_extract_byte;
   condition_flags[59] = !options->lower_extract_word;
   condition_flags[60] = options->has_pack_32_4x8;
   condition_flags[61] = options->lower_pack_64_2x32_split;
   condition_flags[62] = options->lower_pack_32_2x16_split;
   condition_flags[63] = options->lower_unpack_64_2x32_split;
   condition_flags[64] = options->lower_unpack_32_2x16_split;
   condition_flags[65] = options->has_find_msb_rev;
   condition_flags[66] = !options->lower_find_msb_to_reverse;
   condition_flags[67] = !options->lower_find_lsb;
   condition_flags[68] = options->lower_fmod;
   condition_flags[69] = options->lower_uadd_carry;
   condition_flags[70] = options->lower_usub_borrow;
   condition_flags[71] = options->lower_bitfield_insert;
   condition_flags[72] = options->lower_hadd;
   condition_flags[73] = options->lower_hadd64 || (options->lower_int64_options & nir_lower_iadd64) != 0;
   condition_flags[74] = options->lower_mul_32x16;
   condition_flags[75] = options->lower_uadd_sat || (options->lower_int64_options & nir_lower_iadd64) != 0;
   condition_flags[76] = options->lower_uadd_sat;
   condition_flags[77] = options->lower_usub_sat;
   condition_flags[78] = (options->lower_int64_options & nir_lower_usub_sat64) != 0;
   condition_flags[79] = (options->lower_int64_options & nir_lower_iadd_sat64) != 0;
   condition_flags[80] = (options->lower_int64_options & nir_lower_minmax64) != 0;
   condition_flags[81] = (options->lower_int64_options & nir_lower_icmp64) != 0;
   condition_flags[82] = options->lower_bitfield_insert_to_shifts;
   condition_flags[83] = options->lower_bitfield_insert_to_bitfield_select;
   condition_flags[84] = options->lower_bitfield_extract;
   condition_flags[85] = options->lower_bitfield_insert_to_bitfield_select || options->lower_bitfield_insert;
   condition_flags[86] = options->lower_bitfield_extract_to_shifts;
   condition_flags[87] = options->lower_ifind_msb;
   condition_flags[88] = options->lower_find_msb_to_reverse;
   condition_flags[89] = options->lower_uclz;
   condition_flags[90] = options->lower_find_lsb;
   condition_flags[91] = options->lower_extract_byte;
   condition_flags[92] = options->lower_extract_word;
   condition_flags[93] = options->lower_pack_unorm_2x16;
   condition_flags[94] = options->lower_pack_unorm_4x8;
   condition_flags[95] = options->lower_pack_snorm_2x16;
   condition_flags[96] = options->lower_pack_snorm_4x8;
   condition_flags[97] = options->lower_unpack_unorm_2x16;
   condition_flags[98] = options->lower_unpack_unorm_4x8;
   condition_flags[99] = options->lower_unpack_snorm_2x16;
   condition_flags[100] = options->lower_unpack_snorm_4x8;
   condition_flags[101] = options->lower_pack_split;
   condition_flags[102] = options->lower_isign;
   condition_flags[103] = !options->lower_isign;
   condition_flags[104] = options->lower_fsign;
   condition_flags[105] = !options->has_imul24;
   condition_flags[106] = !options->has_umul24;
   condition_flags[107] = !options->has_umad24;
   condition_flags[108] = options->has_imul24;
   condition_flags[109] = options->has_umad24;
   condition_flags[110] = options->has_umul24;
   condition_flags[111] = !options->lower_uadd_sat && !(options->lower_int64_options & nir_lower_iadd64);
   condition_flags[112] = !options->lower_usub_sat;
   condition_flags[113] = !options->lower_usub_sat && !(options->lower_int64_options & nir_lower_usub_sat64);
   condition_flags[114] = options->lower_iadd_sat;
   condition_flags[115] = options->support_8bit_alu;
   condition_flags[116] = options->support_16bit_alu;
   condition_flags[117] = options->lower_ldexp;
   condition_flags[118] = !options->lower_bitfield_reverse;
   condition_flags[119] = info->stage == MESA_SHADER_COMPUTE && info->cs.derivative_group == DERIVATIVE_GROUP_NONE;
   condition_flags[120] = options->lower_fisnormal;
   condition_flags[121] = !options->vectorize_vec2_16bit;

   nir_foreach_function(function, shader) {
      if (function->impl) {
         progress |= nir_algebraic_impl(function->impl, condition_flags,
                                        &nir_opt_algebraic_table);
      }
   }

   return progress;
}


#include "nir.h"
#include "nir_builder.h"
#include "nir_search.h"
#include "nir_search_helpers.h"

/* What follows is NIR algebraic transform code for the following 15
 * transforms:
 *    ('~fmul(is_used_once)', ('fmul(is_used_once)', 'a(is_not_const)', '#b'), 'c(is_not_const)') => ('fmul', ('fmul', 'a', 'c'), 'b')
 *    ('imul(is_used_once)', ('imul(is_used_once)', 'a(is_not_const)', '#b'), 'c(is_not_const)') => ('imul', ('imul', 'a', 'c'), 'b')
 *    ('~fadd(is_used_once)', ('fadd(is_used_once)', 'a(is_not_const)', '#b'), 'c(is_not_const)') => ('fadd', ('fadd', 'a', 'c'), 'b')
 *    ('iadd(is_used_once)', ('iadd(is_used_once)', 'a(is_not_const)', '#b'), 'c(is_not_const)') => ('iadd', ('iadd', 'a', 'c'), 'b')
 *    ('~fadd', ('fmul', 'a', 'b'), ('fmul', 'a', 'c')) => ('fmul', 'a', ('fadd', 'b', 'c'))
 *    ('iadd', ('imul', 'a', 'b'), ('imul', 'a', 'c')) => ('imul', 'a', ('iadd', 'b', 'c'))
 *    ('~fadd', ('fneg', 'a'), 'a') => 0.0
 *    ('iadd', ('ineg', 'a'), 'a') => 0
 *    ('iadd', ('ineg', 'a'), ('iadd', 'a', 'b')) => b
 *    ('iadd', 'a', ('iadd', ('ineg', 'a'), 'b')) => b
 *    ('~fadd', ('fneg', 'a'), ('fadd', 'a', 'b')) => b
 *    ('~fadd', 'a', ('fadd', ('fneg', 'a'), 'b')) => b
 *    ('~flrp', ('fadd(is_used_once)', 'a', -1.0), ('fadd(is_used_once)', 'a', 1.0), 'd') => ('fadd', ('flrp', -1.0, 1.0, 'd'), 'a')
 *    ('~flrp', ('fadd(is_used_once)', 'a', 1.0), ('fadd(is_used_once)', 'a', -1.0), 'd') => ('fadd', ('flrp', 1.0, -1.0, 'd'), 'a')
 *    ('~flrp', ('fadd(is_used_once)', 'a', '#b'), ('fadd(is_used_once)', 'a', '#c'), 'd') => ('fadd', ('fmul', 'd', ('fadd', 'c', ('fneg', 'b'))), ('fadd', 'a', 'b'))
 */


static const nir_search_value_union nir_opt_algebraic_before_ffma_values[] = {
   /* ('~fmul(is_used_once)', ('fmul(is_used_once)', 'a(is_not_const)', '#b'), 'c(is_not_const)') => ('fmul', ('fmul', 'a', 'c'), 'b') */
   { .variable = {
      { nir_search_value_variable, -3 },
      0, /* a */
      false,
      nir_type_invalid,
      0,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      1, /* b */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 0, 1 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      2, /* c */
      false,
      nir_type_invalid,
      0,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      true,
      false,
      false,
      nir_op_fmul,
      0, 2,
      { 2, 3 },
      0,
   } },

   { .variable = {
      { nir_search_value_variable, -3 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 5, 6 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 2,
      { 7, 8 },
      -1,
   } },

   /* ('imul(is_used_once)', ('imul(is_used_once)', 'a(is_not_const)', '#b'), 'c(is_not_const)') => ('imul', ('imul', 'a', 'c'), 'b') */
   /* search2068_0_0 -> 0 in the cache */
   /* search2068_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imul,
      1, 1,
      { 0, 1 },
      0,
   } },
   /* search2068_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imul,
      0, 2,
      { 10, 3 },
      0,
   } },

   /* replace2068_0_0 -> 5 in the cache */
   /* replace2068_0_1 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imul,
      1, 1,
      { 5, 6 },
      -1,
   } },
   /* replace2068_1 -> 8 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imul,
      0, 2,
      { 12, 8 },
      -1,
   } },

   /* ('~fadd(is_used_once)', ('fadd(is_used_once)', 'a(is_not_const)', '#b'), 'c(is_not_const)') => ('fadd', ('fadd', 'a', 'c'), 'b') */
   /* search2069_0_0 -> 0 in the cache */
   /* search2069_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 0, 1 },
      0,
   } },
   /* search2069_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 14, 3 },
      0,
   } },

   /* replace2069_0_0 -> 5 in the cache */
   /* replace2069_0_1 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 5, 6 },
      -1,
   } },
   /* replace2069_1 -> 8 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 16, 8 },
      -1,
   } },

   /* ('iadd(is_used_once)', ('iadd(is_used_once)', 'a(is_not_const)', '#b'), 'c(is_not_const)') => ('iadd', ('iadd', 'a', 'c'), 'b') */
   /* search2070_0_0 -> 0 in the cache */
   /* search2070_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 0, 1 },
      0,
   } },
   /* search2070_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 18, 3 },
      0,
   } },

   /* replace2070_0_0 -> 5 in the cache */
   /* replace2070_0_1 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 5, 6 },
      -1,
   } },
   /* replace2070_1 -> 8 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 20, 8 },
      -1,
   } },

   /* ('~fadd', ('fmul', 'a', 'b'), ('fmul', 'a', 'c')) => ('fmul', 'a', ('fadd', 'b', 'c')) */
   /* search2071_0_0 -> 5 in the cache */
   /* search2071_0_1 -> 8 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 5, 8 },
      -1,
   } },
   /* search2071_1_0 -> 5 in the cache */
   /* search2071_1_1 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmul,
      2, 1,
      { 5, 6 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 22, 23 },
      -1,
   } },

   /* replace2071_0 -> 5 in the cache */
   /* replace2071_1_0 -> 8 in the cache */
   /* replace2071_1_1 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 8, 6 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 2,
      { 5, 25 },
      -1,
   } },

   /* ('iadd', ('imul', 'a', 'b'), ('imul', 'a', 'c')) => ('imul', 'a', ('iadd', 'b', 'c')) */
   /* search2072_0_0 -> 5 in the cache */
   /* search2072_0_1 -> 8 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imul,
      1, 1,
      { 5, 8 },
      -1,
   } },
   /* search2072_1_0 -> 5 in the cache */
   /* search2072_1_1 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imul,
      2, 1,
      { 5, 6 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 3,
      { 27, 28 },
      -1,
   } },

   /* replace2072_0 -> 5 in the cache */
   /* replace2072_1_0 -> 8 in the cache */
   /* replace2072_1_1 -> 6 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 8, 6 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_imul,
      0, 2,
      { 5, 30 },
      -1,
   } },

   /* ('~fadd', ('fneg', 'a'), 'a') => 0.0 */
   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 32 },
      -1,
   } },
   /* search2073_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 33, 32 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0x0 /* 0.0 */ },
   } },

   /* ('iadd', ('ineg', 'a'), 'a') => 0 */
   /* search2074_0_0 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 32 },
      -1,
   } },
   /* search2074_1 -> 32 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 36, 32 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_int, { 0x0 /* 0 */ },
   } },

   /* ('iadd', ('ineg', 'a'), ('iadd', 'a', 'b')) => b */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 39 },
      -1,
   } },
   /* search2075_1_0 -> 39 in the cache */
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 39, 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 40, 42 },
      -1,
   } },

   /* replace2075 -> 41 in the cache */

   /* ('iadd', 'a', ('iadd', ('ineg', 'a'), 'b')) => b */
   /* search2076_0 -> 39 in the cache */
   /* search2076_1_0_0 -> 39 in the cache */
   /* search2076_1_0 -> 40 in the cache */
   /* search2076_1_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 40, 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 39, 44 },
      -1,
   } },

   /* replace2076 -> 41 in the cache */

   /* ('~fadd', ('fneg', 'a'), ('fadd', 'a', 'b')) => b */
   /* search2077_0_0 -> 39 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 39 },
      -1,
   } },
   /* search2077_1_0 -> 39 in the cache */
   /* search2077_1_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 39, 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 46, 47 },
      -1,
   } },

   /* replace2077 -> 41 in the cache */

   /* ('~fadd', 'a', ('fadd', ('fneg', 'a'), 'b')) => b */
   /* search2078_0 -> 39 in the cache */
   /* search2078_1_0_0 -> 39 in the cache */
   /* search2078_1_0 -> 46 in the cache */
   /* search2078_1_1 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 46, 41 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 39, 49 },
      -1,
   } },

   /* replace2078 -> 41 in the cache */

   /* ('~flrp', ('fadd(is_used_once)', 'a', -1.0), ('fadd(is_used_once)', 'a', 1.0), 'd') => ('fadd', ('flrp', -1.0, 1.0, 'd'), 'a') */
   /* search2079_0_0 -> 39 in the cache */
   { .constant = {
      { nir_search_value_constant, -2 },
      nir_type_float, { 0xbff0000000000000 /* -1.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 39, 51 },
      0,
   } },
   /* search2079_1_0 -> 39 in the cache */
   { .constant = {
      { nir_search_value_constant, -2 },
      nir_type_float, { 0x3ff0000000000000 /* 1.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 39, 53 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* d */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 2,
      { 52, 54, 55 },
      -1,
   } },

   /* replace2079_0_0 -> 51 in the cache */
   /* replace2079_0_1 -> 53 in the cache */
   /* replace2079_0_2 -> 55 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 51, 53, 55 },
      -1,
   } },
   /* replace2079_1 -> 39 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 57, 39 },
      -1,
   } },

   /* ('~flrp', ('fadd(is_used_once)', 'a', 1.0), ('fadd(is_used_once)', 'a', -1.0), 'd') => ('fadd', ('flrp', 1.0, -1.0, 'd'), 'a') */
   /* search2080_0_0 -> 39 in the cache */
   /* search2080_0_1 -> 53 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 39, 53 },
      0,
   } },
   /* search2080_1_0 -> 39 in the cache */
   /* search2080_1_1 -> 51 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 39, 51 },
      0,
   } },
   /* search2080_2 -> 55 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 2,
      { 59, 60, 55 },
      -1,
   } },

   /* replace2080_0_0 -> 53 in the cache */
   /* replace2080_0_1 -> 51 in the cache */
   /* replace2080_0_2 -> 55 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 53, 51, 55 },
      -1,
   } },
   /* replace2080_1 -> 39 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 62, 39 },
      -1,
   } },

   /* ('~flrp', ('fadd(is_used_once)', 'a', '#b'), ('fadd(is_used_once)', 'a', '#c'), 'd') => ('fadd', ('fmul', 'd', ('fadd', 'c', ('fneg', 'b'))), ('fadd', 'a', 'b')) */
   { .variable = {
      { nir_search_value_variable, -4 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -4 },
      1, /* b */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 64, 65 },
      0,
   } },
   /* search2081_1_0 -> 64 in the cache */
   { .variable = {
      { nir_search_value_variable, -4 },
      2, /* c */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 64, 67 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, -4 },
      3, /* d */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 2,
      { 66, 68, 69 },
      -1,
   } },

   /* replace2081_0_0 -> 69 in the cache */
   { .variable = {
      { nir_search_value_variable, -4 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -4 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 72 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      2, 1,
      { 71, 73 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 2,
      { 69, 74 },
      -1,
   } },
   /* replace2081_1_0 -> 64 in the cache */
   /* replace2081_1_1 -> 72 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      3, 1,
      { 64, 72 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 4,
      { 75, 76 },
      -1,
   } },

};

static const nir_search_expression_cond nir_opt_algebraic_before_ffma_expression_cond[] = {
   (is_used_once),
};

static const nir_search_variable_cond nir_opt_algebraic_before_ffma_variable_cond[] = {
   (is_not_const),
};

static const struct transform nir_opt_algebraic_before_ffma_transforms[] = {
   { ~0, ~0, ~0 }, /* Sentinel */

   { 15, 17, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 35, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 15, 17, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 35, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 24, 26, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 35, 0 },
   { 48, 41, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 15, 17, 0 },
   { 34, 35, 0 },
   { 48, 41, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4, 9, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 19, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 37, 38, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 19, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 37, 38, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 29, 31, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 37, 38, 0 },
   { 43, 41, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 19, 21, 0 },
   { 37, 38, 0 },
   { 43, 41, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 11, 13, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 11, 13, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 56, 58, 0 },
   { 61, 63, 0 },
   { 70, 77, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 50, 41, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 15, 17, 0 },
   { 50, 41, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 50, 41, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 15, 17, 0 },
   { 50, 41, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 35, 0 },
   { 48, 41, 0 },
   { 50, 41, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 15, 17, 0 },
   { 34, 35, 0 },
   { 48, 41, 0 },
   { 50, 41, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 45, 41, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 19, 21, 0 },
   { 45, 41, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 45, 41, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 19, 21, 0 },
   { 45, 41, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 37, 38, 0 },
   { 43, 41, 0 },
   { 45, 41, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 19, 21, 0 },
   { 37, 38, 0 },
   { 43, 41, 0 },
   { 45, 41, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

};

static const struct per_op_table nir_opt_algebraic_before_ffma_pass_op_table[nir_num_search_ops] = {
   [nir_op_fmul] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         2,
         3,
         19,
         3,
         3,
         20,
         19,
         20,
         19,
      },
   },
   [nir_op_imul] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         4,
         5,
         28,
         5,
         5,
         29,
         28,
         29,
         28,
      },
   },
   [nir_op_fadd] = {
      .filter = (const uint16_t []) {
         0,
         1,
         2,
         2,
         0,
         0,
         3,
         4,
         0,
         0,
         5,
         0,
         3,
         6,
         4,
         7,
         3,
         6,
         6,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         4,
         4,
         6,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 8,
      .table = (const uint16_t []) {
      
         6,
         7,
         6,
         6,
         12,
         13,
         31,
         32,
         7,
         7,
         7,
         7,
         14,
         15,
         33,
         34,
         6,
         7,
         16,
         6,
         12,
         13,
         31,
         32,
         6,
         7,
         6,
         6,
         12,
         17,
         31,
         32,
         12,
         14,
         12,
         12,
         12,
         18,
         32,
         32,
         13,
         15,
         13,
         17,
         18,
         13,
         35,
         36,
         31,
         33,
         31,
         31,
         32,
         35,
         31,
         32,
         32,
         34,
         32,
         32,
         32,
         36,
         32,
         32,
      },
   },
   [nir_op_iadd] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         2,
         2,
         0,
         0,
         3,
         4,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         6,
         4,
         7,
         3,
         6,
         6,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         4,
         4,
         6,
         6,
      },
      
      .num_filtered_states = 8,
      .table = (const uint16_t []) {
      
         8,
         9,
         8,
         8,
         21,
         22,
         37,
         38,
         9,
         9,
         9,
         9,
         23,
         24,
         39,
         40,
         8,
         9,
         25,
         8,
         21,
         22,
         37,
         38,
         8,
         9,
         8,
         8,
         21,
         26,
         37,
         38,
         21,
         23,
         21,
         21,
         21,
         27,
         38,
         38,
         22,
         24,
         22,
         26,
         27,
         22,
         41,
         42,
         37,
         39,
         37,
         37,
         38,
         41,
         37,
         38,
         38,
         40,
         38,
         38,
         38,
         42,
         38,
         38,
      },
   },
   [nir_op_fneg] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         10,
      },
   },
   [nir_op_ineg] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         11,
      },
   },
   [nir_op_flrp] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         0,
         0,
         0,
         0,
         0,
         30,
         30,
      },
   },
};

/* Mapping from state index to offset in transforms (0 being no transforms) */
static const uint16_t nir_opt_algebraic_before_ffma_transform_offsets[] = {
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   1,
   3,
   5,
   7,
   9,
   11,
   14,
   18,
   20,
   22,
   24,
   26,
   28,
   30,
   32,
   35,
   39,
   41,
   43,
   47,
   49,
   52,
   54,
   57,
   61,
   66,
   68,
   71,
   73,
   76,
   80,
};

static const nir_algebraic_table nir_opt_algebraic_before_ffma_table = {
   .transforms = nir_opt_algebraic_before_ffma_transforms,
   .transform_offsets = nir_opt_algebraic_before_ffma_transform_offsets,
   .pass_op_table = nir_opt_algebraic_before_ffma_pass_op_table,
   .values = nir_opt_algebraic_before_ffma_values,
   .expression_cond = nir_opt_algebraic_before_ffma_expression_cond,
   .variable_cond = nir_opt_algebraic_before_ffma_variable_cond,
};

bool
nir_opt_algebraic_before_ffma(nir_shader *shader)
{
   bool progress = false;
   bool condition_flags[122];
   const nir_shader_compiler_options *options = shader->options;
   const shader_info *info = &shader->info;
   (void) options;
   (void) info;

   /* This is not a great place for this, but it seems to be the best place
    * for it. Check that at most one kind of lowering is requested for
    * bitfield extract and bitfield insert. Otherwise the lowering can fight
    * with each other and optimizations.
    */
   assert((int)options->lower_bitfield_extract +
          (int)options->lower_bitfield_extract_to_shifts <= 1);
   assert((int)options->lower_bitfield_insert +
          (int)options->lower_bitfield_insert_to_shifts +
          (int)options->lower_bitfield_insert_to_bitfield_select <= 1);


   STATIC_ASSERT(78 == ARRAY_SIZE(nir_opt_algebraic_before_ffma_values));
   condition_flags[0] = true;
   condition_flags[1] = !options->lower_bitops;
   condition_flags[2] = options->lower_bitops;
   condition_flags[3] = !options->lower_bitops && (options->lower_int64_options & (nir_lower_imul64 | nir_lower_shift64)) == nir_lower_imul64;
   condition_flags[4] = options->lower_mul_2x32_64;
   condition_flags[5] = !nir_is_float_control_signed_zero_inf_nan_preserve(info->float_controls_execution_mode, 16);
   condition_flags[6] = !nir_is_float_control_signed_zero_inf_nan_preserve(info->float_controls_execution_mode, 32);
   condition_flags[7] = !options->lower_iadd_sat;
   condition_flags[8] = !options->lower_uadd_sat;
   condition_flags[9] = options->has_fmulz && !nir_is_float_control_signed_zero_inf_nan_preserve(info->float_controls_execution_mode, 32);
   condition_flags[10] = !options->has_sdot_4x8;
   condition_flags[11] = !options->has_udot_4x8;
   condition_flags[12] = !options->has_sudot_4x8;
   condition_flags[13] = !options->has_dot_2x16;
   condition_flags[14] = options->lower_flrp16;
   condition_flags[15] = !options->lower_flrp16;
   condition_flags[16] = options->lower_flrp32;
   condition_flags[17] = !options->lower_flrp32;
   condition_flags[18] = options->lower_flrp64;
   condition_flags[19] = !options->lower_flrp64;
   condition_flags[20] = options->lower_ftrunc;
   condition_flags[21] = options->lower_ftrunc || (options->lower_doubles_options & nir_lower_dtrunc);
   condition_flags[22] = options->lower_ffloor;
   condition_flags[23] = (options->lower_ffloor || (options->lower_doubles_options & nir_lower_dfloor)) && !(options->lower_doubles_options & nir_lower_dfract);
   condition_flags[24] = !options->lower_ffloor;
   condition_flags[25] = !options->lower_ffloor && !(options->lower_doubles_options & nir_lower_dfloor);
   condition_flags[26] = options->lower_ffract;
   condition_flags[27] = options->lower_ffract || (options->lower_doubles_options & nir_lower_dfract);
   condition_flags[28] = options->lower_fceil;
   condition_flags[29] = options->lower_ffma16;
   condition_flags[30] = options->lower_ffma32;
   condition_flags[31] = options->lower_ffma64;
   condition_flags[32] = options->fuse_ffma16;
   condition_flags[33] = options->fuse_ffma32;
   condition_flags[34] = options->fuse_ffma64;
   condition_flags[35] = options->lower_fdph;
   condition_flags[36] = !options->lower_fdph;
   condition_flags[37] = options->lower_fdot;
   condition_flags[38] = !options->lower_fsat;
   condition_flags[39] = !options->lower_iabs;
   condition_flags[40] = options->lower_fsat;
   condition_flags[41] = !options->lower_fsat && !nir_is_float_control_signed_zero_inf_nan_preserve(info->float_controls_execution_mode, 32);
   condition_flags[42] = !options->lower_fsign;
   condition_flags[43] = options->lower_umax;
   condition_flags[44] = options->lower_umin;
   condition_flags[45] = !options->lower_umax;
   condition_flags[46] = !options->lower_umin;
   condition_flags[47] = options->lower_scmp;
   condition_flags[48] = options->lower_vector_cmp;
   condition_flags[49] = !options->lower_rotate;
   condition_flags[50] = options->lower_rotate;
   condition_flags[51] = options->lower_fpow;
   condition_flags[52] = !options->lower_fpow;
   condition_flags[53] = options->lower_fdiv;
   condition_flags[54] = options->lower_fsqrt;
   condition_flags[55] = !options->lower_fsqrt;
   condition_flags[56] = options->lower_sincos;
   condition_flags[57] = !(options->lower_doubles_options & nir_lower_fp64_full_software);
   condition_flags[58] = !options->lower_extract_byte;
   condition_flags[59] = !options->lower_extract_word;
   condition_flags[60] = options->has_pack_32_4x8;
   condition_flags[61] = options->lower_pack_64_2x32_split;
   condition_flags[62] = options->lower_pack_32_2x16_split;
   condition_flags[63] = options->lower_unpack_64_2x32_split;
   condition_flags[64] = options->lower_unpack_32_2x16_split;
   condition_flags[65] = options->has_find_msb_rev;
   condition_flags[66] = !options->lower_find_msb_to_reverse;
   condition_flags[67] = !options->lower_find_lsb;
   condition_flags[68] = options->lower_fmod;
   condition_flags[69] = options->lower_uadd_carry;
   condition_flags[70] = options->lower_usub_borrow;
   condition_flags[71] = options->lower_bitfield_insert;
   condition_flags[72] = options->lower_hadd;
   condition_flags[73] = options->lower_hadd64 || (options->lower_int64_options & nir_lower_iadd64) != 0;
   condition_flags[74] = options->lower_mul_32x16;
   condition_flags[75] = options->lower_uadd_sat || (options->lower_int64_options & nir_lower_iadd64) != 0;
   condition_flags[76] = options->lower_uadd_sat;
   condition_flags[77] = options->lower_usub_sat;
   condition_flags[78] = (options->lower_int64_options & nir_lower_usub_sat64) != 0;
   condition_flags[79] = (options->lower_int64_options & nir_lower_iadd_sat64) != 0;
   condition_flags[80] = (options->lower_int64_options & nir_lower_minmax64) != 0;
   condition_flags[81] = (options->lower_int64_options & nir_lower_icmp64) != 0;
   condition_flags[82] = options->lower_bitfield_insert_to_shifts;
   condition_flags[83] = options->lower_bitfield_insert_to_bitfield_select;
   condition_flags[84] = options->lower_bitfield_extract;
   condition_flags[85] = options->lower_bitfield_insert_to_bitfield_select || options->lower_bitfield_insert;
   condition_flags[86] = options->lower_bitfield_extract_to_shifts;
   condition_flags[87] = options->lower_ifind_msb;
   condition_flags[88] = options->lower_find_msb_to_reverse;
   condition_flags[89] = options->lower_uclz;
   condition_flags[90] = options->lower_find_lsb;
   condition_flags[91] = options->lower_extract_byte;
   condition_flags[92] = options->lower_extract_word;
   condition_flags[93] = options->lower_pack_unorm_2x16;
   condition_flags[94] = options->lower_pack_unorm_4x8;
   condition_flags[95] = options->lower_pack_snorm_2x16;
   condition_flags[96] = options->lower_pack_snorm_4x8;
   condition_flags[97] = options->lower_unpack_unorm_2x16;
   condition_flags[98] = options->lower_unpack_unorm_4x8;
   condition_flags[99] = options->lower_unpack_snorm_2x16;
   condition_flags[100] = options->lower_unpack_snorm_4x8;
   condition_flags[101] = options->lower_pack_split;
   condition_flags[102] = options->lower_isign;
   condition_flags[103] = !options->lower_isign;
   condition_flags[104] = options->lower_fsign;
   condition_flags[105] = !options->has_imul24;
   condition_flags[106] = !options->has_umul24;
   condition_flags[107] = !options->has_umad24;
   condition_flags[108] = options->has_imul24;
   condition_flags[109] = options->has_umad24;
   condition_flags[110] = options->has_umul24;
   condition_flags[111] = !options->lower_uadd_sat && !(options->lower_int64_options & nir_lower_iadd64);
   condition_flags[112] = !options->lower_usub_sat;
   condition_flags[113] = !options->lower_usub_sat && !(options->lower_int64_options & nir_lower_usub_sat64);
   condition_flags[114] = options->lower_iadd_sat;
   condition_flags[115] = options->support_8bit_alu;
   condition_flags[116] = options->support_16bit_alu;
   condition_flags[117] = options->lower_ldexp;
   condition_flags[118] = !options->lower_bitfield_reverse;
   condition_flags[119] = info->stage == MESA_SHADER_COMPUTE && info->cs.derivative_group == DERIVATIVE_GROUP_NONE;
   condition_flags[120] = options->lower_fisnormal;
   condition_flags[121] = !options->vectorize_vec2_16bit;

   nir_foreach_function(function, shader) {
      if (function->impl) {
         progress |= nir_algebraic_impl(function->impl, condition_flags,
                                        &nir_opt_algebraic_before_ffma_table);
      }
   }

   return progress;
}


#include "nir.h"
#include "nir_builder.h"
#include "nir_search.h"
#include "nir_search_helpers.h"

/* What follows is NIR algebraic transform code for the following 211
 * transforms:
 *    ('flt', ('fadd(is_used_once)', 'a', 'b'), 0.0) => ('flt', 'a', ('fneg', 'b'))
 *    ('flt', ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', 'b')), 0.0) => ('flt', ('fneg', 'a'), 'b')
 *    ('flt', 0.0, ('fadd(is_used_once)', 'a', 'b')) => ('flt', ('fneg', 'a'), 'b')
 *    ('flt', 0.0, ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', 'b'))) => ('flt', 'a', ('fneg', 'b'))
 *    ('~fge', ('fadd(is_used_once)', 'a', 'b'), 0.0) => ('fge', 'a', ('fneg', 'b'))
 *    ('~fge', ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', 'b')), 0.0) => ('fge', ('fneg', 'a'), 'b')
 *    ('~fge', 0.0, ('fadd(is_used_once)', 'a', 'b')) => ('fge', ('fneg', 'a'), 'b')
 *    ('~fge', 0.0, ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', 'b'))) => ('fge', 'a', ('fneg', 'b'))
 *    ('~feq', ('fadd(is_used_once)', 'a', 'b'), 0.0) => ('feq', 'a', ('fneg', 'b'))
 *    ('~fneu', ('fadd(is_used_once)', 'a', 'b'), 0.0) => ('fneu', 'a', ('fneg', 'b'))
 *    ('fge', ('fadd(is_used_once)', 'a(is_finite)', 'b'), 0.0) => ('fge', 'a', ('fneg', 'b'))
 *    ('fge', ('fneg(is_used_once)', ('fadd(is_used_once)', 'a(is_finite)', 'b')), 0.0) => ('fge', ('fneg', 'a'), 'b')
 *    ('fge', 0.0, ('fadd(is_used_once)', 'a(is_finite)', 'b')) => ('fge', ('fneg', 'a'), 'b')
 *    ('fge', 0.0, ('fneg(is_used_once)', ('fadd(is_used_once)', 'a(is_finite)', 'b'))) => ('fge', 'a', ('fneg', 'b'))
 *    ('feq', ('fadd(is_used_once)', 'a(is_finite)', 'b'), 0.0) => ('feq', 'a', ('fneg', 'b'))
 *    ('fneu', ('fadd(is_used_once)', 'a(is_finite)', 'b'), 0.0) => ('fneu', 'a', ('fneg', 'b'))
 *    ('iand', ('fneu', 'a', 'b'), ('iand', ('feq', 'a', 'a'), ('feq', 'b', 'b'))) => ('ior', ('!flt', 'a', 'b'), ('!flt', 'b', 'a'))
 *    ('iand', ('fneu', 'a', 0.0), ('feq', 'a', 'a')) => ('!flt', 0.0, ('fabs', 'a'))
 *    ('ior', ('feq', 'a', 'b'), ('ior', ('fneu', 'a', 'a'), ('fneu', 'b', 'b'))) => ('inot', ('ior', ('!flt', 'a', 'b'), ('!flt', 'b', 'a')))
 *    ('ior', ('feq', 'a', 0.0), ('fneu', 'a', 'a')) => ('inot', ('!flt', 0.0, ('fabs', 'a')))
 *    ('fneg', ('fneg', 'a')) => a
 *    ('~fadd@16', ('fmul(is_only_used_by_fadd)', 'a', 'b'), 'c') => ('ffma', 'a', 'b', 'c')
 *    ('~fadd@16', ('fneg(is_only_used_by_fadd)', ('fmul(is_only_used_by_fadd)', 'a', 'b')), 'c') => ('ffma', ('fneg', 'a'), 'b', 'c')
 *    ('~fadd@16', ('fabs(is_only_used_by_fadd)', ('fmul(is_only_used_by_fadd)', 'a', 'b')), 'c') => ('ffma', ('fabs', 'a'), ('fabs', 'b'), 'c')
 *    ('~fadd@16', ('fneg(is_only_used_by_fadd)', ('fabs', ('fmul(is_only_used_by_fadd)', 'a', 'b'))), 'c') => ('ffma', ('fneg', ('fabs', 'a')), ('fabs', 'b'), 'c')
 *    ('~fadd@32', ('fmul(is_only_used_by_fadd)', 'a', 'b'), 'c') => ('ffma', 'a', 'b', 'c')
 *    ('~fadd@32', ('fneg(is_only_used_by_fadd)', ('fmul(is_only_used_by_fadd)', 'a', 'b')), 'c') => ('ffma', ('fneg', 'a'), 'b', 'c')
 *    ('~fadd@32', ('fabs(is_only_used_by_fadd)', ('fmul(is_only_used_by_fadd)', 'a', 'b')), 'c') => ('ffma', ('fabs', 'a'), ('fabs', 'b'), 'c')
 *    ('~fadd@32', ('fneg(is_only_used_by_fadd)', ('fabs', ('fmul(is_only_used_by_fadd)', 'a', 'b'))), 'c') => ('ffma', ('fneg', ('fabs', 'a')), ('fabs', 'b'), 'c')
 *    ('~fadd@32', ('fmulz(is_only_used_by_fadd)', 'a', 'b'), 'c') => ('ffmaz', 'a', 'b', 'c')
 *    ('~fadd@32', ('fneg(is_only_used_by_fadd)', ('fmulz(is_only_used_by_fadd)', 'a', 'b')), 'c') => ('ffmaz', ('fneg', 'a'), 'b', 'c')
 *    ('~fadd@32', ('fabs(is_only_used_by_fadd)', ('fmulz(is_only_used_by_fadd)', 'a', 'b')), 'c') => ('ffmaz', ('fabs', 'a'), ('fabs', 'b'), 'c')
 *    ('~fadd@32', ('fneg(is_only_used_by_fadd)', ('fabs', ('fmulz(is_only_used_by_fadd)', 'a', 'b'))), 'c') => ('ffmaz', ('fneg', ('fabs', 'a')), ('fabs', 'b'), 'c')
 *    ('~fadd@64', ('fmul(is_only_used_by_fadd)', 'a', 'b'), 'c') => ('ffma', 'a', 'b', 'c')
 *    ('~fadd@64', ('fneg(is_only_used_by_fadd)', ('fmul(is_only_used_by_fadd)', 'a', 'b')), 'c') => ('ffma', ('fneg', 'a'), 'b', 'c')
 *    ('~fadd@64', ('fabs(is_only_used_by_fadd)', ('fmul(is_only_used_by_fadd)', 'a', 'b')), 'c') => ('ffma', ('fabs', 'a'), ('fabs', 'b'), 'c')
 *    ('~fadd@64', ('fneg(is_only_used_by_fadd)', ('fabs', ('fmul(is_only_used_by_fadd)', 'a', 'b'))), 'c') => ('ffma', ('fneg', ('fabs', 'a')), ('fabs', 'b'), 'c')
 *    ('fadd@8', 'a', ('fneg', 'b')) => ('fsub', 'a', 'b')
 *    ('fadd@16', 'a', ('fneg', 'b')) => ('fsub', 'a', 'b')
 *    ('fadd@32', 'a', ('fneg', 'b')) => ('fsub', 'a', 'b')
 *    ('fadd@64', 'a', ('fneg', 'b')) => ('fsub', 'a', 'b')
 *    ('fneg', 'a') => ('fmul', 'a', -1.0)
 *    ('iadd', 'a', ('ineg', 'b')) => ('isub', 'a', 'b')
 *    ('ineg', 'a') => ('isub', 0, 'a')
 *    ('iabs', 'a') => ('imax', 'a', ('ineg', 'a'))
 *    ('iadd', ('iadd(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), 'c(is_not_const)') => ('iadd3', 'a', 'b', 'c')
 *    ('iadd', ('isub(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), 'c(is_not_const)') => ('iadd3', 'a', ('ineg', 'b'), 'c')
 *    ('isub', ('isub(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), 'c(is_not_const)') => ('iadd3', 'a', ('ineg', 'b'), ('ineg', 'c'))
 *    ('vec2(is_only_used_as_float)', ('fneg@16', 'a'), 'b') => ('fmul', ('vec2', 'a', 'b'), ('vec2', -1.0, 1.0))
 *    ('vec2(is_only_used_as_float)', 'a', ('fneg@16', 'b')) => ('fmul', ('vec2', 'a', 'b'), ('vec2', 1.0, -1.0))
 *    ('flt', '#b(is_gt_0_and_lt_1)', ('fsat(is_used_once)', 'a')) => ('flt', 'b', 'a')
 *    ('fge', ('fsat(is_used_once)', 'a'), '#b(is_gt_0_and_lt_1)') => ('fge', 'a', 'b')
 *    ('feq', ('fsat(is_used_once)', 'a'), '#b(is_gt_0_and_lt_1)') => ('feq', 'a', 'b')
 *    ('fneu', ('fsat(is_used_once)', 'a'), '#b(is_gt_0_and_lt_1)') => ('fneu', 'a', 'b')
 *    ('fge', ('fsat(is_used_once)', 'a'), 1.0) => ('fge', 'a', 1.0)
 *    ('~fge', ('fmin(is_used_once)', ('fadd(is_used_once)', 'a', 'b'), ('fadd', 'c', 'd')), 0.0) => ('iand', ('fge', 'a', ('fneg', 'b')), ('fge', 'c', ('fneg', 'd')))
 *    ('flt', ('fneg', 'a'), ('fneg', 'b')) => ('flt', 'b', 'a')
 *    ('fge', ('fneg', 'a'), ('fneg', 'b')) => ('fge', 'b', 'a')
 *    ('feq', ('fneg', 'a'), ('fneg', 'b')) => ('feq', 'b', 'a')
 *    ('fneu', ('fneg', 'a'), ('fneg', 'b')) => ('fneu', 'b', 'a')
 *    ('flt', ('fneg', 'a'), -1.0) => ('flt', 1.0, 'a')
 *    ('flt', -1.0, ('fneg', 'a')) => ('flt', 'a', 1.0)
 *    ('fge', ('fneg', 'a'), -1.0) => ('fge', 1.0, 'a')
 *    ('fge', -1.0, ('fneg', 'a')) => ('fge', 'a', 1.0)
 *    ('fneu', ('fneg', 'a'), -1.0) => ('fneu', 1.0, 'a')
 *    ('feq', -1.0, ('fneg', 'a')) => ('feq', 'a', 1.0)
 *    ('ior', 'a', 'a') => a
 *    ('iand', 'a', 'a') => a
 *    ('~fadd', ('fneg(is_used_once)', ('fsat(is_used_once)', 'a(is_not_fmul)')), 1.0) => ('fsat', ('fadd', 1.0, ('fneg', 'a')))
 *    ('fdot2', 'a', 'b') => ('fdot2_replicated', 'a', 'b')
 *    ('fdot3', 'a', 'b') => ('fdot3_replicated', 'a', 'b')
 *    ('fdot4', 'a', 'b') => ('fdot4_replicated', 'a', 'b')
 *    ('fdph', 'a', 'b') => ('fdph_replicated', 'a', 'b')
 *    ('~flrp', ('fadd(is_used_once)', 'a', 'b'), ('fadd(is_used_once)', 'a', 'c'), 'd') => ('fadd', ('flrp', 'b', 'c', 'd'), 'a')
 *    ('fround_even', 'a') => ('bcsel', ('feq', ('ffract', 'a'), 0.5), ('fadd', ('ffloor', ('fadd', 'a', 0.5)), 1.0), ('ffloor', ('fadd', 'a', 0.5)))
 *    ('~ffma@32', 'a', 2.0, -1.0) => ('flrp', -1.0, 1.0, 'a')
 *    ('~ffma@32', 'a', -2.0, -1.0) => ('flrp', -1.0, 1.0, ('fneg', 'a'))
 *    ('~ffma@32', 'a', -2.0, 1.0) => ('flrp', 1.0, -1.0, 'a')
 *    ('~ffma@32', 'a', 2.0, 1.0) => ('flrp', 1.0, -1.0, ('fneg', 'a'))
 *    ('~fadd@32', ('fmul(is_used_once)', 2.0, 'a'), -1.0) => ('flrp', -1.0, 1.0, 'a')
 *    ('~fadd@32', ('fmul(is_used_once)', -2.0, 'a'), -1.0) => ('flrp', -1.0, 1.0, ('fneg', 'a'))
 *    ('~fadd@32', ('fmul(is_used_once)', -2.0, 'a'), 1.0) => ('flrp', 1.0, -1.0, 'a')
 *    ('~fadd@32', ('fmul(is_used_once)', 2.0, 'a'), 1.0) => ('flrp', 1.0, -1.0, ('fneg', 'a'))
 *    ('~ffma@32', ('fadd', 'b', ('fneg', 'a')), 'a', 'a') => ('flrp', 'a', 'b', 'a')
 *    ('~ffma@32', 'a', 2.0, ('fneg', ('fmul', 'a', 'a'))) => ('flrp', 'a', 1.0, 'a')
 *    ('~ffma@32', 'a', 2.0, ('fmul', ('fneg', 'a'), 'a')) => ('flrp', 'a', 1.0, 'a')
 *    ('~ffma@32', 'a', ('fneg', 'a'), ('fmul', 2.0, 'a')) => ('flrp', 'a', 1.0, 'a')
 *    ('~fmul@32', 'a', ('fadd', 2.0, ('fneg', 'a'))) => ('flrp', 'a', 1.0, 'a')
 *    ('fmin', ('fadd(is_used_once)', '#c', 'a'), ('fadd(is_used_once)', '#c', 'b')) => ('fadd', 'c', ('fmin', 'a', 'b'))
 *    ('fmax', ('fadd(is_used_once)', '#c', 'a'), ('fadd(is_used_once)', '#c', 'b')) => ('fadd', 'c', ('fmax', 'a', 'b'))
 *    ('bcsel', ('feq', ('fsqrt', 'a(is_not_negative)'), 0.0), 3.4028234663852886e+38, ('frsq', 'a')) => ('fmin', ('frsq', 'a'), 3.4028234663852886e+38)
 *    ('~fadd', ('ffma(is_used_once)', 'a', 'b', ('ffma', 'c', 'd', ('fmul(is_used_once)', 'e(is_not_const_and_not_fsign)', 'f(is_not_const_and_not_fsign)'))), 'g(is_not_const)') => ('ffma', 'a', 'b', ('ffma', 'c', 'd', ('ffma', 'e', 'f', 'g')))
 *    ('~fadd', ('ffma(is_used_once)', 'a', 'b', ('fmul(is_used_once)', 'c(is_not_const_and_not_fsign)', 'd(is_not_const_and_not_fsign)')), 'e(is_not_const)') => ('ffma', 'a', 'b', ('ffma', 'c', 'd', 'e'))
 *    ('~fadd', ('fneg', ('ffma(is_used_once)', 'a', 'b', ('ffma', 'c', 'd', ('fmul(is_used_once)', 'e(is_not_const_and_not_fsign)', 'f(is_not_const_and_not_fsign)')))), 'g(is_not_const)') => ('ffma', ('fneg', 'a'), 'b', ('ffma', ('fneg', 'c'), 'd', ('ffma', ('fneg', 'e'), 'f', 'g')))
 *    ('~fadd', ('ffmaz(is_used_once)', 'a', 'b', ('ffmaz', 'c', 'd', ('fmulz(is_used_once)', 'e(is_not_const_and_not_fsign)', 'f(is_not_const_and_not_fsign)'))), 'g(is_not_const)') => ('ffmaz', 'a', 'b', ('ffmaz', 'c', 'd', ('ffmaz', 'e', 'f', 'g')))
 *    ('~fadd', ('ffmaz(is_used_once)', 'a', 'b', ('fmulz(is_used_once)', 'c(is_not_const_and_not_fsign)', 'd(is_not_const_and_not_fsign)')), 'e(is_not_const)') => ('ffmaz', 'a', 'b', ('ffmaz', 'c', 'd', 'e'))
 *    ('~fadd', ('fneg', ('ffmaz(is_used_once)', 'a', 'b', ('ffmaz', 'c', 'd', ('fmulz(is_used_once)', 'e(is_not_const_and_not_fsign)', 'f(is_not_const_and_not_fsign)')))), 'g(is_not_const)') => ('ffmaz', ('fneg', 'a'), 'b', ('ffmaz', ('fneg', 'c'), 'd', ('ffmaz', ('fneg', 'e'), 'f', 'g')))
 *    ('ubfe', 'a', 'b', 0) => 0
 *    ('ibfe', 'a', 'b', 0) => 0
 *    ('ubfe', 'a', '#b', '#c') => ('iand', ('ushr', 4294967295, ('ineg', 'c')), ('ushr', 'a', 'b'))
 *    ('ibfe', 'a', '#b', '#c') => ('ishr', ('ishl', 'a', ('ineg', ('iadd', 'b', 'c'))), ('ineg', 'c'))
 *    ('ishl', 'a', 0) => a
 *    ('ishl', 'a', -32) => a
 *    ('ishr', 'a', 0) => a
 *    ('ishr', 'a', -32) => a
 *    ('ushr', 'a', 0) => a
 *    ('extract_i8', ('extract_i8', 'a', 'b'), 0) => ('extract_i8', 'a', 'b')
 *    ('extract_i8', ('extract_u8', 'a', 'b'), 0) => ('extract_i8', 'a', 'b')
 *    ('extract_u8', ('extract_i8', 'a', 'b'), 0) => ('extract_u8', 'a', 'b')
 *    ('extract_u8', ('extract_u8', 'a', 'b'), 0) => ('extract_u8', 'a', 'b')
 *    ('u2u16', ('u2u8', 'a@16')) => ('extract_u8', 'a', 0)
 *    ('u2u16', ('i2i8', 'a@16')) => ('extract_u8', 'a', 0)
 *    ('i2i16', ('u2u8', 'a@16')) => ('extract_i8', 'a', 0)
 *    ('i2i16', ('i2i8', 'a@16')) => ('extract_i8', 'a', 0)
 *    ('u2u32', ('u2u8', 'a@32')) => ('extract_u8', 'a', 0)
 *    ('u2u32', ('i2i8', 'a@32')) => ('extract_u8', 'a', 0)
 *    ('u2u32', ('u2u16', 'a@32')) => ('extract_u16', 'a', 0)
 *    ('u2u32', ('i2i16', 'a@32')) => ('extract_u16', 'a', 0)
 *    ('i2i32', ('u2u8', 'a@32')) => ('extract_i8', 'a', 0)
 *    ('i2i32', ('i2i8', 'a@32')) => ('extract_i8', 'a', 0)
 *    ('i2i32', ('u2u16', 'a@32')) => ('extract_i16', 'a', 0)
 *    ('i2i32', ('i2i16', 'a@32')) => ('extract_i16', 'a', 0)
 *    ('ishl', ('extract_u8', 'a@32', 0), 8) => ('insert_u8', 'a', 1)
 *    ('ishl', ('extract_u8', 'a@32', 0), 16) => ('insert_u8', 'a', 2)
 *    ('ishl', ('extract_u8', 'a@32', 0), 24) => ('insert_u8', 'a', 3)
 *    ('iand', ('ishl', 'a@32', 8), 65280) => ('insert_u8', 'a', 1)
 *    ('iand', ('ishl', 'a@32', 16), 16711680) => ('insert_u8', 'a', 2)
 *    ('iand', ('ishl', 'a@32', 24), 4278190080) => ('insert_u8', 'a', 3)
 *    ('ishl', 'a@32', 24) => ('insert_u8', 'a', 3)
 *    ('ishl', 'a@32', 16) => ('insert_u16', 'a', 1)
 *    ('insert_u8', ('extract_u8', 'a', 0), 'b') => ('insert_u8', 'a', 'b')
 *    ('insert_u16', ('extract_u16', 'a', 0), 'b') => ('insert_u16', 'a', 'b')
 *    ('iand', ('ine(is_used_once)', 'a@8', 0), ('ine', 'b@8', 0)) => ('ine', ('umin', 'a', 'b'), 0)
 *    ('ior', ('ieq(is_used_once)', 'a@8', 0), ('ieq', 'b@8', 0)) => ('ieq', ('umin', 'a', 'b'), 0)
 *    ('iand', ('ine(is_used_once)', 'a@16', 0), ('ine', 'b@16', 0)) => ('ine', ('umin', 'a', 'b'), 0)
 *    ('ior', ('ieq(is_used_once)', 'a@16', 0), ('ieq', 'b@16', 0)) => ('ieq', ('umin', 'a', 'b'), 0)
 *    ('iand', ('ine(is_used_once)', 'a@32', 0), ('ine', 'b@32', 0)) => ('ine', ('umin', 'a', 'b'), 0)
 *    ('ior', ('ieq(is_used_once)', 'a@32', 0), ('ieq', 'b@32', 0)) => ('ieq', ('umin', 'a', 'b'), 0)
 *    ('iand', ('ine(is_used_once)', 'a@64', 0), ('ine', 'b@64', 0)) => ('ine', ('umin', 'a', 'b'), 0)
 *    ('ior', ('ieq(is_used_once)', 'a@64', 0), ('ieq', 'b@64', 0)) => ('ieq', ('umin', 'a', 'b'), 0)
 *    ('~fadd@16', 1.0, ('fmul(is_used_once)', 'c', ('fadd', 'b', -1.0))) => ('fadd', ('fadd', 1.0, ('fneg', 'c')), ('fmul', 'b', 'c'))
 *    ('bcsel', 'a', 0, ('b2f16', ('inot', 'b@bool'))) => ('b2f16', ('inot', ('ior', 'a', 'b')))
 *    ('~fadd@32', 1.0, ('fmul(is_used_once)', 'c', ('fadd', 'b', -1.0))) => ('fadd', ('fadd', 1.0, ('fneg', 'c')), ('fmul', 'b', 'c'))
 *    ('bcsel', 'a', 0, ('b2f32', ('inot', 'b@bool'))) => ('b2f32', ('inot', ('ior', 'a', 'b')))
 *    ('~fadd@64', 1.0, ('fmul(is_used_once)', 'c', ('fadd', 'b', -1.0))) => ('fadd', ('fadd', 1.0, ('fneg', 'c')), ('fmul', 'b', 'c'))
 *    ('bcsel', 'a', 0, ('b2f64', ('inot', 'b@bool'))) => ('b2f64', ('inot', ('ior', 'a', 'b')))
 *    ('bcsel', 'a', ('fadd(is_used_once)', 'b', 'c'), ('fadd', 'b', 'd')) => ('fadd', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('fadd', 'b', 'c'), ('fadd(is_used_once)', 'b', 'd')) => ('fadd', 'b', ('bcsel', 'a', 'c', 'd'))
 *    ('bcsel', 'a', ('ffma(is_used_once)', 'b', 'c', 'd'), ('ffma', 'b', 'c', 'e')) => ('ffma', 'b', 'c', ('bcsel', 'a', 'd', 'e'))
 *    ('bcsel', 'a', ('ffma', 'b', 'c', 'd'), ('ffma(is_used_once)', 'b', 'c', 'e')) => ('ffma', 'b', 'c', ('bcsel', 'a', 'd', 'e'))
 *    ('bcsel', 'a', ('ffma(is_used_once)', 'b', 'c', 'd'), ('ffma', 'b', 'e', 'd')) => ('ffma', 'b', ('bcsel', 'a', 'c', 'e'), 'd')
 *    ('bcsel', 'a', ('ffma', 'b', 'c', 'd'), ('ffma(is_used_once)', 'b', 'e', 'd')) => ('ffma', 'b', ('bcsel', 'a', 'c', 'e'), 'd')
 *    ('bcsel', 'a', ('ffmaz(is_used_once)', 'b', 'c', 'd'), ('ffmaz', 'b', 'c', 'e')) => ('ffmaz', 'b', 'c', ('bcsel', 'a', 'd', 'e'))
 *    ('bcsel', 'a', ('ffmaz', 'b', 'c', 'd'), ('ffmaz(is_used_once)', 'b', 'c', 'e')) => ('ffmaz', 'b', 'c', ('bcsel', 'a', 'd', 'e'))
 *    ('bcsel', 'a', ('ffmaz(is_used_once)', 'b', 'c', 'd'), ('ffmaz', 'b', 'e', 'd')) => ('ffmaz', 'b', ('bcsel', 'a', 'c', 'e'), 'd')
 *    ('bcsel', 'a', ('ffmaz', 'b', 'c', 'd'), ('ffmaz(is_used_once)', 'b', 'e', 'd')) => ('ffmaz', 'b', ('bcsel', 'a', 'c', 'e'), 'd')
 *    ('~f2f32', ('fabs', ('f2fmp', 'a'))) => ('fabs', 'a')
 *    ('~f2f32', ('fceil', ('f2fmp', 'a'))) => ('fceil', 'a')
 *    ('~f2f32', ('fcos', ('f2fmp', 'a'))) => ('fcos', 'a')
 *    ('~f2f32', ('fddx', ('f2fmp', 'a'))) => ('fddx', 'a')
 *    ('~f2f32', ('fddx_coarse', ('f2fmp', 'a'))) => ('fddx_coarse', 'a')
 *    ('~f2f32', ('fddx_fine', ('f2fmp', 'a'))) => ('fddx_fine', 'a')
 *    ('~f2f32', ('fddy', ('f2fmp', 'a'))) => ('fddy', 'a')
 *    ('~f2f32', ('fddy_coarse', ('f2fmp', 'a'))) => ('fddy_coarse', 'a')
 *    ('~f2f32', ('fddy_fine', ('f2fmp', 'a'))) => ('fddy_fine', 'a')
 *    ('~f2f32', ('fexp2', ('f2fmp', 'a'))) => ('fexp2', 'a')
 *    ('~f2f32', ('ffloor', ('f2fmp', 'a'))) => ('ffloor', 'a')
 *    ('~f2f32', ('ffract', ('f2fmp', 'a'))) => ('ffract', 'a')
 *    ('~f2f32', ('flog2', ('f2fmp', 'a'))) => ('flog2', 'a')
 *    ('~f2f32', ('fneg', ('f2fmp', 'a'))) => ('fneg', 'a')
 *    ('~f2f32', ('frcp', ('f2fmp', 'a'))) => ('frcp', 'a')
 *    ('~f2f32', ('fround_even', ('f2fmp', 'a'))) => ('fround_even', 'a')
 *    ('~f2f32', ('frsq', ('f2fmp', 'a'))) => ('frsq', 'a')
 *    ('~f2f32', ('fsat', ('f2fmp', 'a'))) => ('fsat', 'a')
 *    ('~f2f32', ('fsign', ('f2fmp', 'a'))) => ('fsign', 'a')
 *    ('~f2f32', ('fsin', ('f2fmp', 'a'))) => ('fsin', 'a')
 *    ('~f2f32', ('fsqrt', ('f2fmp', 'a'))) => ('fsqrt', 'a')
 *    ('~f2f32', ('fadd', ('f2fmp', 'a'), ('f2fmp', 'b'))) => ('fadd', 'a', 'b')
 *    ('~f2f32', ('fdiv', ('f2fmp', 'a'), ('f2fmp', 'b'))) => ('fdiv', 'a', 'b')
 *    ('~f2f32', ('fmax', ('f2fmp', 'a'), ('f2fmp', 'b'))) => ('fmax', 'a', 'b')
 *    ('~f2f32', ('fmin', ('f2fmp', 'a'), ('f2fmp', 'b'))) => ('fmin', 'a', 'b')
 *    ('~f2f32', ('fmod', ('f2fmp', 'a'), ('f2fmp', 'b'))) => ('fmod', 'a', 'b')
 *    ('~f2f32', ('fmul', ('f2fmp', 'a'), ('f2fmp', 'b'))) => ('fmul', 'a', 'b')
 *    ('~f2f32', ('fpow', ('f2fmp', 'a'), ('f2fmp', 'b'))) => ('fpow', 'a', 'b')
 *    ('~f2f32', ('frem', ('f2fmp', 'a'), ('f2fmp', 'b'))) => ('frem', 'a', 'b')
 *    ('~f2f32', ('ffma', ('f2fmp', 'a'), ('f2fmp', 'b'), ('f2fmp', 'c'))) => ('ffma', 'a', 'b', 'c')
 *    ('~f2f32', ('flrp', ('f2fmp', 'a'), ('f2fmp', 'b'), ('f2fmp', 'c'))) => ('flrp', 'a', 'b', 'c')
 *    ('~feq', ('f2fmp', 'a'), ('f2fmp', 'b')) => ('feq', 'a', 'b')
 *    ('~fge', ('f2fmp', 'a'), ('f2fmp', 'b')) => ('fge', 'a', 'b')
 *    ('~flt', ('f2fmp', 'a'), ('f2fmp', 'b')) => ('flt', 'a', 'b')
 *    ('~fneu', ('f2fmp', 'a'), ('f2fmp', 'b')) => ('fneu', 'a', 'b')
 *    ('f2fmp', 'a') => ('f2f16', 'a')
 *    ('f2imp', 'a') => ('f2i16', 'a')
 *    ('f2ump', 'a') => ('f2u16', 'a')
 *    ('i2imp', 'a') => ('i2i16', 'a')
 *    ('i2fmp', 'a') => ('i2f16', 'a')
 *    ('i2imp', 'a') => ('u2u16', 'a')
 *    ('u2fmp', 'a') => ('u2f16', 'a')
 *    ('fisfinite', 'a') => ('flt', ('fabs', 'a'), inf)
 *    ('fcsel', ('slt', 0, 'a'), 'b', 'c') => ('fcsel_gt', 'a', 'b', 'c')
 *    ('fcsel', ('slt', 'a', 0), 'b', 'c') => ('fcsel_gt', ('fneg', 'a'), 'b', 'c')
 *    ('fcsel', ('sge', 'a', 0), 'b', 'c') => ('fcsel_ge', 'a', 'b', 'c')
 *    ('fcsel', ('sge', 0, 'a'), 'b', 'c') => ('fcsel_ge', ('fneg', 'a'), 'b', 'c')
 *    ('bcsel', ('ilt', 0, 'a@32'), 'b@32', 'c@32') => ('i32csel_gt', 'a', 'b', 'c')
 *    ('bcsel', ('ilt', 'a@32', 0), 'b@32', 'c@32') => ('i32csel_ge', 'a', 'c', 'b')
 *    ('bcsel', ('ige', 'a@32', 0), 'b@32', 'c@32') => ('i32csel_ge', 'a', 'b', 'c')
 *    ('bcsel', ('ige', 0, 'a@32'), 'b@32', 'c@32') => ('i32csel_gt', 'a', 'c', 'b')
 *    ('bcsel', ('flt', 0, 'a@32'), 'b@32', 'c@32') => ('fcsel_gt', 'a', 'b', 'c')
 *    ('bcsel', ('flt', 'a@32', 0), 'b@32', 'c@32') => ('fcsel_gt', ('fneg', 'a'), 'b', 'c')
 *    ('bcsel', ('fge', 'a@32', 0), 'b@32', 'c@32') => ('fcsel_ge', 'a', 'b', 'c')
 *    ('bcsel', ('fge', 0, 'a@32'), 'b@32', 'c@32') => ('fcsel_ge', ('fneg', 'a'), 'b', 'c')
 */


static const nir_search_value_union nir_opt_algebraic_late_values[] = {
   /* ('flt', ('fadd(is_used_once)', 'a', 'b'), 0.0) => ('flt', 'a', ('fneg', 'b')) */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 0, 1 },
      0,
   } },
   { .constant = {
      { nir_search_value_constant, -2 },
      nir_type_float, { 0x0 /* 0.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 2, 3 },
      -1,
   } },

   /* replace2082_0 -> 0 in the cache */
   /* replace2082_1_0 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 1 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 0, 5 },
      -1,
   } },

   /* ('flt', ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', 'b')), 0.0) => ('flt', ('fneg', 'a'), 'b') */
   /* search2083_0_0_0 -> 0 in the cache */
   /* search2083_0_0_1 -> 1 in the cache */
   /* search2083_0_0 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 2 },
      0,
   } },
   /* search2083_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 7, 3 },
      -1,
   } },

   /* replace2083_0_0 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 0 },
      -1,
   } },
   /* replace2083_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 9, 1 },
      -1,
   } },

   /* ('flt', 0.0, ('fadd(is_used_once)', 'a', 'b')) => ('flt', ('fneg', 'a'), 'b') */
   /* search2084_0 -> 3 in the cache */
   /* search2084_1_0 -> 0 in the cache */
   /* search2084_1_1 -> 1 in the cache */
   /* search2084_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 3, 2 },
      -1,
   } },

   /* replace2084_0_0 -> 0 in the cache */
   /* replace2084_0 -> 9 in the cache */
   /* replace2084_1 -> 1 in the cache */
   /* replace2084 -> 10 in the cache */

   /* ('flt', 0.0, ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', 'b'))) => ('flt', 'a', ('fneg', 'b')) */
   /* search2085_0 -> 3 in the cache */
   /* search2085_1_0_0 -> 0 in the cache */
   /* search2085_1_0_1 -> 1 in the cache */
   /* search2085_1_0 -> 2 in the cache */
   /* search2085_1 -> 7 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 1,
      { 3, 7 },
      -1,
   } },

   /* replace2085_0 -> 0 in the cache */
   /* replace2085_1_0 -> 1 in the cache */
   /* replace2085_1 -> 5 in the cache */
   /* replace2085 -> 6 in the cache */

   /* ('~fge', ('fadd(is_used_once)', 'a', 'b'), 0.0) => ('fge', 'a', ('fneg', 'b')) */
   /* search2086_0_0 -> 0 in the cache */
   /* search2086_0_1 -> 1 in the cache */
   /* search2086_0 -> 2 in the cache */
   /* search2086_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 2, 3 },
      -1,
   } },

   /* replace2086_0 -> 0 in the cache */
   /* replace2086_1_0 -> 1 in the cache */
   /* replace2086_1 -> 5 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 0, 5 },
      -1,
   } },

   /* ('~fge', ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', 'b')), 0.0) => ('fge', ('fneg', 'a'), 'b') */
   /* search2087_0_0_0 -> 0 in the cache */
   /* search2087_0_0_1 -> 1 in the cache */
   /* search2087_0_0 -> 2 in the cache */
   /* search2087_0 -> 7 in the cache */
   /* search2087_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 7, 3 },
      -1,
   } },

   /* replace2087_0_0 -> 0 in the cache */
   /* replace2087_0 -> 9 in the cache */
   /* replace2087_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 9, 1 },
      -1,
   } },

   /* ('~fge', 0.0, ('fadd(is_used_once)', 'a', 'b')) => ('fge', ('fneg', 'a'), 'b') */
   /* search2088_0 -> 3 in the cache */
   /* search2088_1_0 -> 0 in the cache */
   /* search2088_1_1 -> 1 in the cache */
   /* search2088_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 3, 2 },
      -1,
   } },

   /* replace2088_0_0 -> 0 in the cache */
   /* replace2088_0 -> 9 in the cache */
   /* replace2088_1 -> 1 in the cache */
   /* replace2088 -> 16 in the cache */

   /* ('~fge', 0.0, ('fneg(is_used_once)', ('fadd(is_used_once)', 'a', 'b'))) => ('fge', 'a', ('fneg', 'b')) */
   /* search2089_0 -> 3 in the cache */
   /* search2089_1_0_0 -> 0 in the cache */
   /* search2089_1_0_1 -> 1 in the cache */
   /* search2089_1_0 -> 2 in the cache */
   /* search2089_1 -> 7 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 3, 7 },
      -1,
   } },

   /* replace2089_0 -> 0 in the cache */
   /* replace2089_1_0 -> 1 in the cache */
   /* replace2089_1 -> 5 in the cache */
   /* replace2089 -> 14 in the cache */

   /* ('~feq', ('fadd(is_used_once)', 'a', 'b'), 0.0) => ('feq', 'a', ('fneg', 'b')) */
   /* search2090_0_0 -> 0 in the cache */
   /* search2090_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 0, 1 },
      0,
   } },
   /* search2090_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_feq,
      0, 2,
      { 19, 3 },
      -1,
   } },

   /* replace2090_0 -> 0 in the cache */
   /* replace2090_1_0 -> 1 in the cache */
   /* replace2090_1 -> 5 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 0, 5 },
      -1,
   } },

   /* ('~fneu', ('fadd(is_used_once)', 'a', 'b'), 0.0) => ('fneu', 'a', ('fneg', 'b')) */
   /* search2091_0_0 -> 0 in the cache */
   /* search2091_0_1 -> 1 in the cache */
   /* search2091_0 -> 19 in the cache */
   /* search2091_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_fneu,
      0, 2,
      { 19, 3 },
      -1,
   } },

   /* replace2091_0 -> 0 in the cache */
   /* replace2091_1_0 -> 1 in the cache */
   /* replace2091_1 -> 5 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 0, 5 },
      -1,
   } },

   /* ('fge', ('fadd(is_used_once)', 'a(is_finite)', 'b'), 0.0) => ('fge', 'a', ('fneg', 'b')) */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      0,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search2092_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 24, 1 },
      0,
   } },
   /* search2092_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 25, 3 },
      -1,
   } },

   /* replace2092_0 -> 0 in the cache */
   /* replace2092_1_0 -> 1 in the cache */
   /* replace2092_1 -> 5 in the cache */
   /* replace2092 -> 14 in the cache */

   /* ('fge', ('fneg(is_used_once)', ('fadd(is_used_once)', 'a(is_finite)', 'b')), 0.0) => ('fge', ('fneg', 'a'), 'b') */
   /* search2093_0_0_0 -> 24 in the cache */
   /* search2093_0_0_1 -> 1 in the cache */
   /* search2093_0_0 -> 25 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 25 },
      0,
   } },
   /* search2093_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 27, 3 },
      -1,
   } },

   /* replace2093_0_0 -> 0 in the cache */
   /* replace2093_0 -> 9 in the cache */
   /* replace2093_1 -> 1 in the cache */
   /* replace2093 -> 16 in the cache */

   /* ('fge', 0.0, ('fadd(is_used_once)', 'a(is_finite)', 'b')) => ('fge', ('fneg', 'a'), 'b') */
   /* search2094_0 -> 3 in the cache */
   /* search2094_1_0 -> 24 in the cache */
   /* search2094_1_1 -> 1 in the cache */
   /* search2094_1 -> 25 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 3, 25 },
      -1,
   } },

   /* replace2094_0_0 -> 0 in the cache */
   /* replace2094_0 -> 9 in the cache */
   /* replace2094_1 -> 1 in the cache */
   /* replace2094 -> 16 in the cache */

   /* ('fge', 0.0, ('fneg(is_used_once)', ('fadd(is_used_once)', 'a(is_finite)', 'b'))) => ('fge', 'a', ('fneg', 'b')) */
   /* search2095_0 -> 3 in the cache */
   /* search2095_1_0_0 -> 24 in the cache */
   /* search2095_1_0_1 -> 1 in the cache */
   /* search2095_1_0 -> 25 in the cache */
   /* search2095_1 -> 27 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 1,
      { 3, 27 },
      -1,
   } },

   /* replace2095_0 -> 0 in the cache */
   /* replace2095_1_0 -> 1 in the cache */
   /* replace2095_1 -> 5 in the cache */
   /* replace2095 -> 14 in the cache */

   /* ('feq', ('fadd(is_used_once)', 'a(is_finite)', 'b'), 0.0) => ('feq', 'a', ('fneg', 'b')) */
   /* search2096_0_0 -> 24 in the cache */
   /* search2096_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 24, 1 },
      0,
   } },
   /* search2096_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 2,
      { 31, 3 },
      -1,
   } },

   /* replace2096_0 -> 0 in the cache */
   /* replace2096_1_0 -> 1 in the cache */
   /* replace2096_1 -> 5 in the cache */
   /* replace2096 -> 21 in the cache */

   /* ('fneu', ('fadd(is_used_once)', 'a(is_finite)', 'b'), 0.0) => ('fneu', 'a', ('fneg', 'b')) */
   /* search2097_0_0 -> 24 in the cache */
   /* search2097_0_1 -> 1 in the cache */
   /* search2097_0 -> 31 in the cache */
   /* search2097_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 2,
      { 31, 3 },
      -1,
   } },

   /* replace2097_0 -> 0 in the cache */
   /* replace2097_1_0 -> 1 in the cache */
   /* replace2097_1 -> 5 in the cache */
   /* replace2097 -> 23 in the cache */

   /* ('iand', ('fneu', 'a', 'b'), ('iand', ('feq', 'a', 'a'), ('feq', 'b', 'b'))) => ('ior', ('!flt', 'a', 'b'), ('!flt', 'b', 'a')) */
   /* search2098_0_0 -> 0 in the cache */
   /* search2098_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      1, 1,
      { 0, 1 },
      -1,
   } },
   /* search2098_1_0_0 -> 0 in the cache */
   /* search2098_1_0_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      -1, 0,
      { 0, 0 },
      -1,
   } },
   /* search2098_1_1_0 -> 1 in the cache */
   /* search2098_1_1_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      -1, 0,
      { 1, 1 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      2, 1,
      { 35, 36 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 34, 37 },
      -1,
   } },

   /* replace2098_0_0 -> 0 in the cache */
   /* replace2098_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      nir_op_flt,
      -1, 0,
      { 0, 1 },
      -1,
   } },
   /* replace2098_1_0 -> 1 in the cache */
   /* replace2098_1_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      nir_op_flt,
      -1, 0,
      { 1, 0 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 39, 40 },
      -1,
   } },

   /* ('iand', ('fneu', 'a', 0.0), ('feq', 'a', 'a')) => ('!flt', 0.0, ('fabs', 'a')) */
   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0x0 /* 0.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      1, 1,
      { 42, 43 },
      -1,
   } },
   /* search2099_1_0 -> 42 in the cache */
   /* search2099_1_1 -> 42 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      -1, 0,
      { 42, 42 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 2,
      { 44, 45 },
      -1,
   } },

   /* replace2099_0 -> 43 in the cache */
   /* replace2099_1_0 -> 42 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 42 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      true,
      false,
      nir_op_flt,
      -1, 0,
      { 43, 47 },
      -1,
   } },

   /* ('ior', ('feq', 'a', 'b'), ('ior', ('fneu', 'a', 'a'), ('fneu', 'b', 'b'))) => ('inot', ('ior', ('!flt', 'a', 'b'), ('!flt', 'b', 'a'))) */
   /* search2100_0_0 -> 0 in the cache */
   /* search2100_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      1, 1,
      { 0, 1 },
      -1,
   } },
   /* search2100_1_0_0 -> 0 in the cache */
   /* search2100_1_0_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      -1, 0,
      { 0, 0 },
      -1,
   } },
   /* search2100_1_1_0 -> 1 in the cache */
   /* search2100_1_1_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      -1, 0,
      { 1, 1 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      2, 1,
      { 50, 51 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 49, 52 },
      -1,
   } },

   /* replace2100_0_0_0 -> 0 in the cache */
   /* replace2100_0_0_1 -> 1 in the cache */
   /* replace2100_0_0 -> 39 in the cache */
   /* replace2100_0_1_0 -> 1 in the cache */
   /* replace2100_0_1_1 -> 0 in the cache */
   /* replace2100_0_1 -> 40 in the cache */
   /* replace2100_0 -> 41 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 1,
      { 41 },
      -1,
   } },

   /* ('ior', ('feq', 'a', 0.0), ('fneu', 'a', 'a')) => ('inot', ('!flt', 0.0, ('fabs', 'a'))) */
   /* search2101_0_0 -> 42 in the cache */
   /* search2101_0_1 -> 43 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      1, 1,
      { 42, 43 },
      -1,
   } },
   /* search2101_1_0 -> 42 in the cache */
   /* search2101_1_1 -> 42 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      -1, 0,
      { 42, 42 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 2,
      { 55, 56 },
      -1,
   } },

   /* replace2101_0_0 -> 43 in the cache */
   /* replace2101_0_1_0 -> 42 in the cache */
   /* replace2101_0_1 -> 47 in the cache */
   /* replace2101_0 -> 48 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 48 },
      -1,
   } },

   /* ('fneg', ('fneg', 'a')) => a */
   /* search2102_0_0 -> 42 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 42 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 59 },
      -1,
   } },

   /* replace2102 -> 42 in the cache */

   /* ('~fadd@16', ('fmul(is_only_used_by_fadd)', 'a', 'b'), 'c') => ('ffma', 'a', 'b', 'c') */
   { .variable = {
      { nir_search_value_variable, 16 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 16 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 61, 62 },
      1,
   } },
   { .variable = {
      { nir_search_value_variable, 16 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 63, 64 },
      -1,
   } },

   /* replace2103_0 -> 61 in the cache */
   /* replace2103_1 -> 62 in the cache */
   /* replace2103_2 -> 64 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 61, 62, 64 },
      -1,
   } },

   /* ('~fadd@16', ('fneg(is_only_used_by_fadd)', ('fmul(is_only_used_by_fadd)', 'a', 'b')), 'c') => ('ffma', ('fneg', 'a'), 'b', 'c') */
   /* search2104_0_0_0 -> 61 in the cache */
   /* search2104_0_0_1 -> 62 in the cache */
   /* search2104_0_0 -> 63 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 63 },
      1,
   } },
   /* search2104_1 -> 64 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 67, 64 },
      -1,
   } },

   /* replace2104_0_0 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 61 },
      -1,
   } },
   /* replace2104_1 -> 62 in the cache */
   /* replace2104_2 -> 64 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 69, 62, 64 },
      -1,
   } },

   /* ('~fadd@16', ('fabs(is_only_used_by_fadd)', ('fmul(is_only_used_by_fadd)', 'a', 'b')), 'c') => ('ffma', ('fabs', 'a'), ('fabs', 'b'), 'c') */
   /* search2105_0_0_0 -> 61 in the cache */
   /* search2105_0_0_1 -> 62 in the cache */
   /* search2105_0_0 -> 63 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 1,
      { 63 },
      1,
   } },
   /* search2105_1 -> 64 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 71, 64 },
      -1,
   } },

   /* replace2105_0_0 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 61 },
      -1,
   } },
   /* replace2105_1_0 -> 62 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 62 },
      -1,
   } },
   /* replace2105_2 -> 64 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 73, 74, 64 },
      -1,
   } },

   /* ('~fadd@16', ('fneg(is_only_used_by_fadd)', ('fabs', ('fmul(is_only_used_by_fadd)', 'a', 'b'))), 'c') => ('ffma', ('fneg', ('fabs', 'a')), ('fabs', 'b'), 'c') */
   /* search2106_0_0_0_0 -> 61 in the cache */
   /* search2106_0_0_0_1 -> 62 in the cache */
   /* search2106_0_0_0 -> 63 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 1,
      { 63 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 76 },
      1,
   } },
   /* search2106_1 -> 64 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 77, 64 },
      -1,
   } },

   /* replace2106_0_0_0 -> 61 in the cache */
   /* replace2106_0_0 -> 73 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 73 },
      -1,
   } },
   /* replace2106_1_0 -> 62 in the cache */
   /* replace2106_1 -> 74 in the cache */
   /* replace2106_2 -> 64 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 79, 74, 64 },
      -1,
   } },

   /* ('~fadd@32', ('fmul(is_only_used_by_fadd)', 'a', 'b'), 'c') => ('ffma', 'a', 'b', 'c') */
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 81, 82 },
      1,
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 83, 84 },
      -1,
   } },

   /* replace2107_0 -> 81 in the cache */
   /* replace2107_1 -> 82 in the cache */
   /* replace2107_2 -> 84 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 81, 82, 84 },
      -1,
   } },

   /* ('~fadd@32', ('fneg(is_only_used_by_fadd)', ('fmul(is_only_used_by_fadd)', 'a', 'b')), 'c') => ('ffma', ('fneg', 'a'), 'b', 'c') */
   /* search2108_0_0_0 -> 81 in the cache */
   /* search2108_0_0_1 -> 82 in the cache */
   /* search2108_0_0 -> 83 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 83 },
      1,
   } },
   /* search2108_1 -> 84 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 87, 84 },
      -1,
   } },

   /* replace2108_0_0 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 81 },
      -1,
   } },
   /* replace2108_1 -> 82 in the cache */
   /* replace2108_2 -> 84 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 89, 82, 84 },
      -1,
   } },

   /* ('~fadd@32', ('fabs(is_only_used_by_fadd)', ('fmul(is_only_used_by_fadd)', 'a', 'b')), 'c') => ('ffma', ('fabs', 'a'), ('fabs', 'b'), 'c') */
   /* search2109_0_0_0 -> 81 in the cache */
   /* search2109_0_0_1 -> 82 in the cache */
   /* search2109_0_0 -> 83 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 1,
      { 83 },
      1,
   } },
   /* search2109_1 -> 84 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 91, 84 },
      -1,
   } },

   /* replace2109_0_0 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 81 },
      -1,
   } },
   /* replace2109_1_0 -> 82 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 82 },
      -1,
   } },
   /* replace2109_2 -> 84 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 93, 94, 84 },
      -1,
   } },

   /* ('~fadd@32', ('fneg(is_only_used_by_fadd)', ('fabs', ('fmul(is_only_used_by_fadd)', 'a', 'b'))), 'c') => ('ffma', ('fneg', ('fabs', 'a')), ('fabs', 'b'), 'c') */
   /* search2110_0_0_0_0 -> 81 in the cache */
   /* search2110_0_0_0_1 -> 82 in the cache */
   /* search2110_0_0_0 -> 83 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 1,
      { 83 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 96 },
      1,
   } },
   /* search2110_1 -> 84 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 97, 84 },
      -1,
   } },

   /* replace2110_0_0_0 -> 81 in the cache */
   /* replace2110_0_0 -> 93 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 93 },
      -1,
   } },
   /* replace2110_1_0 -> 82 in the cache */
   /* replace2110_1 -> 94 in the cache */
   /* replace2110_2 -> 84 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 99, 94, 84 },
      -1,
   } },

   /* ('~fadd@32', ('fmulz(is_only_used_by_fadd)', 'a', 'b'), 'c') => ('ffmaz', 'a', 'b', 'c') */
   /* search2111_0_0 -> 81 in the cache */
   /* search2111_0_1 -> 82 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      1, 1,
      { 81, 82 },
      1,
   } },
   /* search2111_1 -> 84 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 101, 84 },
      -1,
   } },

   /* replace2111_0 -> 81 in the cache */
   /* replace2111_1 -> 82 in the cache */
   /* replace2111_2 -> 84 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 1,
      { 81, 82, 84 },
      -1,
   } },

   /* ('~fadd@32', ('fneg(is_only_used_by_fadd)', ('fmulz(is_only_used_by_fadd)', 'a', 'b')), 'c') => ('ffmaz', ('fneg', 'a'), 'b', 'c') */
   /* search2112_0_0_0 -> 81 in the cache */
   /* search2112_0_0_1 -> 82 in the cache */
   /* search2112_0_0 -> 101 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 101 },
      1,
   } },
   /* search2112_1 -> 84 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 104, 84 },
      -1,
   } },

   /* replace2112_0_0 -> 81 in the cache */
   /* replace2112_0 -> 89 in the cache */
   /* replace2112_1 -> 82 in the cache */
   /* replace2112_2 -> 84 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 1,
      { 89, 82, 84 },
      -1,
   } },

   /* ('~fadd@32', ('fabs(is_only_used_by_fadd)', ('fmulz(is_only_used_by_fadd)', 'a', 'b')), 'c') => ('ffmaz', ('fabs', 'a'), ('fabs', 'b'), 'c') */
   /* search2113_0_0_0 -> 81 in the cache */
   /* search2113_0_0_1 -> 82 in the cache */
   /* search2113_0_0 -> 101 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 1,
      { 101 },
      1,
   } },
   /* search2113_1 -> 84 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 107, 84 },
      -1,
   } },

   /* replace2113_0_0 -> 81 in the cache */
   /* replace2113_0 -> 93 in the cache */
   /* replace2113_1_0 -> 82 in the cache */
   /* replace2113_1 -> 94 in the cache */
   /* replace2113_2 -> 84 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 1,
      { 93, 94, 84 },
      -1,
   } },

   /* ('~fadd@32', ('fneg(is_only_used_by_fadd)', ('fabs', ('fmulz(is_only_used_by_fadd)', 'a', 'b'))), 'c') => ('ffmaz', ('fneg', ('fabs', 'a')), ('fabs', 'b'), 'c') */
   /* search2114_0_0_0_0 -> 81 in the cache */
   /* search2114_0_0_0_1 -> 82 in the cache */
   /* search2114_0_0_0 -> 101 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 1,
      { 101 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 110 },
      1,
   } },
   /* search2114_1 -> 84 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 111, 84 },
      -1,
   } },

   /* replace2114_0_0_0 -> 81 in the cache */
   /* replace2114_0_0 -> 93 in the cache */
   /* replace2114_0 -> 99 in the cache */
   /* replace2114_1_0 -> 82 in the cache */
   /* replace2114_1 -> 94 in the cache */
   /* replace2114_2 -> 84 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 1,
      { 99, 94, 84 },
      -1,
   } },

   /* ('~fadd@64', ('fmul(is_only_used_by_fadd)', 'a', 'b'), 'c') => ('ffma', 'a', 'b', 'c') */
   { .variable = {
      { nir_search_value_variable, 64 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 64 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 114, 115 },
      1,
   } },
   { .variable = {
      { nir_search_value_variable, 64 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 116, 117 },
      -1,
   } },

   /* replace2115_0 -> 114 in the cache */
   /* replace2115_1 -> 115 in the cache */
   /* replace2115_2 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 114, 115, 117 },
      -1,
   } },

   /* ('~fadd@64', ('fneg(is_only_used_by_fadd)', ('fmul(is_only_used_by_fadd)', 'a', 'b')), 'c') => ('ffma', ('fneg', 'a'), 'b', 'c') */
   /* search2116_0_0_0 -> 114 in the cache */
   /* search2116_0_0_1 -> 115 in the cache */
   /* search2116_0_0 -> 116 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 116 },
      1,
   } },
   /* search2116_1 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 120, 117 },
      -1,
   } },

   /* replace2116_0_0 -> 114 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 114 },
      -1,
   } },
   /* replace2116_1 -> 115 in the cache */
   /* replace2116_2 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 122, 115, 117 },
      -1,
   } },

   /* ('~fadd@64', ('fabs(is_only_used_by_fadd)', ('fmul(is_only_used_by_fadd)', 'a', 'b')), 'c') => ('ffma', ('fabs', 'a'), ('fabs', 'b'), 'c') */
   /* search2117_0_0_0 -> 114 in the cache */
   /* search2117_0_0_1 -> 115 in the cache */
   /* search2117_0_0 -> 116 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 1,
      { 116 },
      1,
   } },
   /* search2117_1 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 124, 117 },
      -1,
   } },

   /* replace2117_0_0 -> 114 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 114 },
      -1,
   } },
   /* replace2117_1_0 -> 115 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 115 },
      -1,
   } },
   /* replace2117_2 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 126, 127, 117 },
      -1,
   } },

   /* ('~fadd@64', ('fneg(is_only_used_by_fadd)', ('fabs', ('fmul(is_only_used_by_fadd)', 'a', 'b'))), 'c') => ('ffma', ('fneg', ('fabs', 'a')), ('fabs', 'b'), 'c') */
   /* search2118_0_0_0_0 -> 114 in the cache */
   /* search2118_0_0_0_1 -> 115 in the cache */
   /* search2118_0_0_0 -> 116 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 1,
      { 116 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 129 },
      1,
   } },
   /* search2118_1 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 130, 117 },
      -1,
   } },

   /* replace2118_0_0_0 -> 114 in the cache */
   /* replace2118_0_0 -> 126 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 126 },
      -1,
   } },
   /* replace2118_1_0 -> 115 in the cache */
   /* replace2118_1 -> 127 in the cache */
   /* replace2118_2 -> 117 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 132, 127, 117 },
      -1,
   } },

   /* ('fadd@8', 'a', ('fneg', 'b')) => ('fsub', 'a', 'b') */
   { .variable = {
      { nir_search_value_variable, 8 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 8 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 135 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 134, 136 },
      -1,
   } },

   /* replace2119_0 -> 134 in the cache */
   /* replace2119_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 0,
      { 134, 135 },
      -1,
   } },

   /* ('fadd@16', 'a', ('fneg', 'b')) => ('fsub', 'a', 'b') */
   /* search2120_0 -> 61 in the cache */
   /* search2120_1_0 -> 62 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 62 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 61, 139 },
      -1,
   } },

   /* replace2120_0 -> 61 in the cache */
   /* replace2120_1 -> 62 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 0,
      { 61, 62 },
      -1,
   } },

   /* ('fadd@32', 'a', ('fneg', 'b')) => ('fsub', 'a', 'b') */
   /* search2121_0 -> 81 in the cache */
   /* search2121_1_0 -> 82 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 82 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 81, 142 },
      -1,
   } },

   /* replace2121_0 -> 81 in the cache */
   /* replace2121_1 -> 82 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 0,
      { 81, 82 },
      -1,
   } },

   /* ('fadd@64', 'a', ('fneg', 'b')) => ('fsub', 'a', 'b') */
   /* search2122_0 -> 114 in the cache */
   /* search2122_1_0 -> 115 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 115 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 114, 145 },
      -1,
   } },

   /* replace2122_0 -> 114 in the cache */
   /* replace2122_1 -> 115 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fsub,
      -1, 0,
      { 114, 115 },
      -1,
   } },

   /* ('fneg', 'a') => ('fmul', 'a', -1.0) */
   /* search2123_0 -> 42 in the cache */
   /* search2123 -> 59 in the cache */

   /* replace2123_0 -> 42 in the cache */
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0xbff0000000000000 /* -1.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 42, 148 },
      -1,
   } },

   /* ('iadd', 'a', ('ineg', 'b')) => ('isub', 'a', 'b') */
   /* search2124_0 -> 0 in the cache */
   /* search2124_1_0 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 1 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 0, 150 },
      -1,
   } },

   /* replace2124_0 -> 0 in the cache */
   /* replace2124_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 0, 1 },
      -1,
   } },

   /* ('ineg', 'a') => ('isub', 0, 'a') */
   /* search2125_0 -> 42 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 42 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_int, { 0x0 /* 0 */ },
   } },
   /* replace2125_1 -> 42 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 154, 42 },
      -1,
   } },

   /* ('iabs', 'a') => ('imax', 'a', ('ineg', 'a')) */
   /* search2126_0 -> 42 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_iabs,
      -1, 0,
      { 42 },
      -1,
   } },

   /* replace2126_0 -> 42 in the cache */
   /* replace2126_1_0 -> 42 in the cache */
   /* replace2126_1 -> 153 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_imax,
      0, 1,
      { 42, 153 },
      -1,
   } },

   /* ('iadd', ('iadd(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), 'c(is_not_const)') => ('iadd3', 'a', 'b', 'c') */
   { .variable = {
      { nir_search_value_variable, -3 },
      0, /* a */
      false,
      nir_type_invalid,
      1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      1, /* b */
      false,
      nir_type_invalid,
      1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      1, 1,
      { 158, 159 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      2, /* c */
      false,
      nir_type_invalid,
      1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 2,
      { 160, 161 },
      -1,
   } },

   { .variable = {
      { nir_search_value_variable, -3 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd3,
      0, 1,
      { 163, 164, 165 },
      -1,
   } },

   /* ('iadd', ('isub(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), 'c(is_not_const)') => ('iadd3', 'a', ('ineg', 'b'), 'c') */
   /* search2128_0_0 -> 158 in the cache */
   /* search2128_0_1 -> 159 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 158, 159 },
      0,
   } },
   /* search2128_1 -> 161 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 167, 161 },
      -1,
   } },

   /* replace2128_0 -> 163 in the cache */
   /* replace2128_1_0 -> 164 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 164 },
      -1,
   } },
   /* replace2128_2 -> 165 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd3,
      0, 1,
      { 163, 169, 165 },
      -1,
   } },

   /* ('isub', ('isub(is_used_once)', 'a(is_not_const)', 'b(is_not_const)'), 'c(is_not_const)') => ('iadd3', 'a', ('ineg', 'b'), ('ineg', 'c')) */
   /* search2129_0_0 -> 158 in the cache */
   /* search2129_0_1 -> 159 in the cache */
   /* search2129_0 -> 167 in the cache */
   /* search2129_1 -> 161 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_isub,
      -1, 0,
      { 167, 161 },
      -1,
   } },

   /* replace2129_0 -> 163 in the cache */
   /* replace2129_1_0 -> 164 in the cache */
   /* replace2129_1 -> 169 in the cache */
   /* replace2129_2_0 -> 165 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 165 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_iadd3,
      0, 1,
      { 163, 169, 172 },
      -1,
   } },

   /* ('vec2(is_only_used_as_float)', ('fneg@16', 'a'), 'b') => ('fmul', ('vec2', 'a', 'b'), ('vec2', -1.0, 1.0)) */
   /* search2130_0_0 -> 61 in the cache */
   /* search2130_0 -> 69 in the cache */
   /* search2130_1 -> 62 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_vec2,
      -1, 0,
      { 69, 62 },
      2,
   } },

   /* replace2130_0_0 -> 61 in the cache */
   /* replace2130_0_1 -> 62 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_vec2,
      -1, 0,
      { 61, 62 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 16 },
      nir_type_float, { 0xbff0000000000000 /* -1.0 */ },
   } },
   { .constant = {
      { nir_search_value_constant, 16 },
      nir_type_float, { 0x3ff0000000000000 /* 1.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_vec2,
      -1, 0,
      { 176, 177 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 175, 178 },
      -1,
   } },

   /* ('vec2(is_only_used_as_float)', 'a', ('fneg@16', 'b')) => ('fmul', ('vec2', 'a', 'b'), ('vec2', 1.0, -1.0)) */
   /* search2131_0 -> 61 in the cache */
   /* search2131_1_0 -> 62 in the cache */
   /* search2131_1 -> 139 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_vec2,
      -1, 0,
      { 61, 139 },
      2,
   } },

   /* replace2131_0_0 -> 61 in the cache */
   /* replace2131_0_1 -> 62 in the cache */
   /* replace2131_0 -> 175 in the cache */
   /* replace2131_1_0 -> 177 in the cache */
   /* replace2131_1_1 -> 176 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_vec2,
      -1, 0,
      { 177, 176 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 175, 181 },
      -1,
   } },

   /* ('flt', '#b(is_gt_0_and_lt_1)', ('fsat(is_used_once)', 'a')) => ('flt', 'b', 'a') */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* b */
      true,
      nir_type_invalid,
      2,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 184 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 183, 185 },
      -1,
   } },

   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* replace2132_1 -> 184 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 187, 184 },
      -1,
   } },

   /* ('fge', ('fsat(is_used_once)', 'a'), '#b(is_gt_0_and_lt_1)') => ('fge', 'a', 'b') */
   /* search2133_0_0 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 0 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      true,
      nir_type_invalid,
      2,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 189, 190 },
      -1,
   } },

   /* replace2133_0 -> 0 in the cache */
   /* replace2133_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 0, 1 },
      -1,
   } },

   /* ('feq', ('fsat(is_used_once)', 'a'), '#b(is_gt_0_and_lt_1)') => ('feq', 'a', 'b') */
   /* search2134_0_0 -> 0 in the cache */
   /* search2134_0 -> 189 in the cache */
   /* search2134_1 -> 190 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 189, 190 },
      -1,
   } },

   /* replace2134_0 -> 0 in the cache */
   /* replace2134_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 0, 1 },
      -1,
   } },

   /* ('fneu', ('fsat(is_used_once)', 'a'), '#b(is_gt_0_and_lt_1)') => ('fneu', 'a', 'b') */
   /* search2135_0_0 -> 0 in the cache */
   /* search2135_0 -> 189 in the cache */
   /* search2135_1 -> 190 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 189, 190 },
      -1,
   } },

   /* replace2135_0 -> 0 in the cache */
   /* replace2135_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 0, 1 },
      -1,
   } },

   /* ('fge', ('fsat(is_used_once)', 'a'), 1.0) => ('fge', 'a', 1.0) */
   /* search2136_0_0 -> 42 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 42 },
      0,
   } },
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0x3ff0000000000000 /* 1.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 197, 198 },
      -1,
   } },

   /* replace2136_0 -> 42 in the cache */
   /* replace2136_1 -> 198 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 42, 198 },
      -1,
   } },

   /* ('~fge', ('fmin(is_used_once)', ('fadd(is_used_once)', 'a', 'b'), ('fadd', 'c', 'd')), 0.0) => ('iand', ('fge', 'a', ('fneg', 'b')), ('fge', 'c', ('fneg', 'd'))) */
   { .variable = {
      { nir_search_value_variable, -4 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -4 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 201, 202 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, -4 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -4 },
      3, /* d */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      2, 1,
      { 204, 205 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 3,
      { 203, 206 },
      0,
   } },
   { .constant = {
      { nir_search_value_constant, -4 },
      nir_type_float, { 0x0 /* 0.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_fge,
      -1, 3,
      { 207, 208 },
      -1,
   } },

   /* replace2137_0_0 -> 201 in the cache */
   /* replace2137_0_1_0 -> 202 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 202 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 201, 210 },
      -1,
   } },
   /* replace2137_1_0 -> 204 in the cache */
   /* replace2137_1_1_0 -> 205 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 205 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 204, 212 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 211, 213 },
      -1,
   } },

   /* ('flt', ('fneg', 'a'), ('fneg', 'b')) => ('flt', 'b', 'a') */
   /* search2138_0_0 -> 0 in the cache */
   /* search2138_0 -> 9 in the cache */
   /* search2138_1_0 -> 1 in the cache */
   /* search2138_1 -> 5 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 9, 5 },
      -1,
   } },

   /* replace2138_0 -> 1 in the cache */
   /* replace2138_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 1, 0 },
      -1,
   } },

   /* ('fge', ('fneg', 'a'), ('fneg', 'b')) => ('fge', 'b', 'a') */
   /* search2139_0_0 -> 0 in the cache */
   /* search2139_0 -> 9 in the cache */
   /* search2139_1_0 -> 1 in the cache */
   /* search2139_1 -> 5 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 9, 5 },
      -1,
   } },

   /* replace2139_0 -> 1 in the cache */
   /* replace2139_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 1, 0 },
      -1,
   } },

   /* ('feq', ('fneg', 'a'), ('fneg', 'b')) => ('feq', 'b', 'a') */
   /* search2140_0_0 -> 0 in the cache */
   /* search2140_0 -> 9 in the cache */
   /* search2140_1_0 -> 1 in the cache */
   /* search2140_1 -> 5 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 9, 5 },
      -1,
   } },

   /* replace2140_0 -> 1 in the cache */
   /* replace2140_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 1, 0 },
      -1,
   } },

   /* ('fneu', ('fneg', 'a'), ('fneg', 'b')) => ('fneu', 'b', 'a') */
   /* search2141_0_0 -> 0 in the cache */
   /* search2141_0 -> 9 in the cache */
   /* search2141_1_0 -> 1 in the cache */
   /* search2141_1 -> 5 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 9, 5 },
      -1,
   } },

   /* replace2141_0 -> 1 in the cache */
   /* replace2141_1 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 1, 0 },
      -1,
   } },

   /* ('flt', ('fneg', 'a'), -1.0) => ('flt', 1.0, 'a') */
   /* search2142_0_0 -> 42 in the cache */
   /* search2142_0 -> 59 in the cache */
   /* search2142_1 -> 148 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 59, 148 },
      -1,
   } },

   /* replace2142_0 -> 198 in the cache */
   /* replace2142_1 -> 42 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 198, 42 },
      -1,
   } },

   /* ('flt', -1.0, ('fneg', 'a')) => ('flt', 'a', 1.0) */
   /* search2143_0 -> 148 in the cache */
   /* search2143_1_0 -> 42 in the cache */
   /* search2143_1 -> 59 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 148, 59 },
      -1,
   } },

   /* replace2143_0 -> 42 in the cache */
   /* replace2143_1 -> 198 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 42, 198 },
      -1,
   } },

   /* ('fge', ('fneg', 'a'), -1.0) => ('fge', 1.0, 'a') */
   /* search2144_0_0 -> 42 in the cache */
   /* search2144_0 -> 59 in the cache */
   /* search2144_1 -> 148 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 59, 148 },
      -1,
   } },

   /* replace2144_0 -> 198 in the cache */
   /* replace2144_1 -> 42 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 198, 42 },
      -1,
   } },

   /* ('fge', -1.0, ('fneg', 'a')) => ('fge', 'a', 1.0) */
   /* search2145_0 -> 148 in the cache */
   /* search2145_1_0 -> 42 in the cache */
   /* search2145_1 -> 59 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 148, 59 },
      -1,
   } },

   /* replace2145_0 -> 42 in the cache */
   /* replace2145_1 -> 198 in the cache */
   /* replace2145 -> 200 in the cache */

   /* ('fneu', ('fneg', 'a'), -1.0) => ('fneu', 1.0, 'a') */
   /* search2146_0_0 -> 42 in the cache */
   /* search2146_0 -> 59 in the cache */
   /* search2146_1 -> 148 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 59, 148 },
      -1,
   } },

   /* replace2146_0 -> 198 in the cache */
   /* replace2146_1 -> 42 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 198, 42 },
      -1,
   } },

   /* ('feq', -1.0, ('fneg', 'a')) => ('feq', 'a', 1.0) */
   /* search2147_0 -> 148 in the cache */
   /* search2147_1_0 -> 42 in the cache */
   /* search2147_1 -> 59 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 148, 59 },
      -1,
   } },

   /* replace2147_0 -> 42 in the cache */
   /* replace2147_1 -> 198 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 42, 198 },
      -1,
   } },

   /* ('ior', 'a', 'a') => a */
   /* search2148_0 -> 42 in the cache */
   /* search2148_1 -> 42 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ior,
      -1, 0,
      { 42, 42 },
      -1,
   } },

   /* replace2148 -> 42 in the cache */

   /* ('iand', 'a', 'a') => a */
   /* search2149_0 -> 42 in the cache */
   /* search2149_1 -> 42 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_iand,
      -1, 0,
      { 42, 42 },
      -1,
   } },

   /* replace2149 -> 42 in the cache */

   /* ('~fadd', ('fneg(is_used_once)', ('fsat(is_used_once)', 'a(is_not_fmul)')), 1.0) => ('fsat', ('fadd', 1.0, ('fneg', 'a'))) */
   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* a */
      false,
      nir_type_invalid,
      3,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 236 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 237 },
      0,
   } },
   /* search2150_1 -> 198 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 238, 198 },
      -1,
   } },

   /* replace2150_0_0 -> 198 in the cache */
   /* replace2150_0_1_0 -> 42 in the cache */
   /* replace2150_0_1 -> 59 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 198, 59 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 1,
      { 240 },
      -1,
   } },

   /* ('fdot2', 'a', 'b') => ('fdot2_replicated', 'a', 'b') */
   /* search2151_0 -> 0 in the cache */
   /* search2151_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot2,
      0, 1,
      { 0, 1 },
      -1,
   } },

   /* replace2151_0 -> 0 in the cache */
   /* replace2151_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot2_replicated,
      0, 1,
      { 0, 1 },
      -1,
   } },

   /* ('fdot3', 'a', 'b') => ('fdot3_replicated', 'a', 'b') */
   /* search2152_0 -> 0 in the cache */
   /* search2152_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot3,
      0, 1,
      { 0, 1 },
      -1,
   } },

   /* replace2152_0 -> 0 in the cache */
   /* replace2152_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot3_replicated,
      0, 1,
      { 0, 1 },
      -1,
   } },

   /* ('fdot4', 'a', 'b') => ('fdot4_replicated', 'a', 'b') */
   /* search2153_0 -> 0 in the cache */
   /* search2153_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot4,
      0, 1,
      { 0, 1 },
      -1,
   } },

   /* replace2153_0 -> 0 in the cache */
   /* replace2153_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot4_replicated,
      0, 1,
      { 0, 1 },
      -1,
   } },

   /* ('fdph', 'a', 'b') => ('fdph_replicated', 'a', 'b') */
   /* search2154_0 -> 0 in the cache */
   /* search2154_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdph,
      -1, 0,
      { 0, 1 },
      -1,
   } },

   /* replace2154_0 -> 0 in the cache */
   /* replace2154_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdph_replicated,
      -1, 0,
      { 0, 1 },
      -1,
   } },

   /* ('~flrp', ('fadd(is_used_once)', 'a', 'b'), ('fadd(is_used_once)', 'a', 'c'), 'd') => ('fadd', ('flrp', 'b', 'c', 'd'), 'a') */
   /* search2155_0_0 -> 201 in the cache */
   /* search2155_0_1 -> 202 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 201, 202 },
      0,
   } },
   /* search2155_1_0 -> 201 in the cache */
   /* search2155_1_1 -> 204 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 201, 204 },
      0,
   } },
   /* search2155_2 -> 205 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      true,
      false,
      false,
      nir_op_flrp,
      -1, 2,
      { 250, 251, 205 },
      -1,
   } },

   /* replace2155_0_0 -> 202 in the cache */
   /* replace2155_0_1 -> 204 in the cache */
   /* replace2155_0_2 -> 205 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 202, 204, 205 },
      -1,
   } },
   /* replace2155_1 -> 201 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 253, 201 },
      -1,
   } },

   /* ('fround_even', 'a') => ('bcsel', ('feq', ('ffract', 'a'), 0.5), ('fadd', ('ffloor', ('fadd', 'a', 0.5)), 1.0), ('ffloor', ('fadd', 'a', 0.5))) */
   /* search2156_0 -> 42 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fround_even,
      -1, 0,
      { 42 },
      -1,
   } },

   /* replace2156_0_0_0 -> 42 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 0,
      { 42 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0x3fe0000000000000 /* 0.5 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 256, 257 },
      -1,
   } },
   /* replace2156_1_0_0_0 -> 42 in the cache */
   /* replace2156_1_0_0_1 -> 257 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      2, 1,
      { 42, 257 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffloor,
      -1, 1,
      { 259 },
      -1,
   } },
   /* replace2156_1_1 -> 198 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 2,
      { 260, 198 },
      -1,
   } },
   /* replace2156_2_0_0 -> 42 in the cache */
   /* replace2156_2_0_1 -> 257 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fadd,
      3, 1,
      { 42, 257 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ffloor,
      -1, 1,
      { 262 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 4,
      { 258, 261, 263 },
      -1,
   } },

   /* ('~ffma@32', 'a', 2.0, -1.0) => ('flrp', -1.0, 1.0, 'a') */
   /* search2157_0 -> 81 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_float, { 0x4000000000000000 /* 2.0 */ },
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_float, { 0xbff0000000000000 /* -1.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 81, 265, 266 },
      -1,
   } },

   /* replace2157_0 -> 266 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_float, { 0x3ff0000000000000 /* 1.0 */ },
   } },
   /* replace2157_2 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 266, 268, 81 },
      -1,
   } },

   /* ('~ffma@32', 'a', -2.0, -1.0) => ('flrp', -1.0, 1.0, ('fneg', 'a')) */
   /* search2158_0 -> 81 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_float, { 0xc000000000000000 /* -2.0 */ },
   } },
   /* search2158_2 -> 266 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 81, 270, 266 },
      -1,
   } },

   /* replace2158_0 -> 266 in the cache */
   /* replace2158_1 -> 268 in the cache */
   /* replace2158_2_0 -> 81 in the cache */
   /* replace2158_2 -> 89 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 266, 268, 89 },
      -1,
   } },

   /* ('~ffma@32', 'a', -2.0, 1.0) => ('flrp', 1.0, -1.0, 'a') */
   /* search2159_0 -> 81 in the cache */
   /* search2159_1 -> 270 in the cache */
   /* search2159_2 -> 268 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 81, 270, 268 },
      -1,
   } },

   /* replace2159_0 -> 268 in the cache */
   /* replace2159_1 -> 266 in the cache */
   /* replace2159_2 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 268, 266, 81 },
      -1,
   } },

   /* ('~ffma@32', 'a', 2.0, 1.0) => ('flrp', 1.0, -1.0, ('fneg', 'a')) */
   /* search2160_0 -> 81 in the cache */
   /* search2160_1 -> 265 in the cache */
   /* search2160_2 -> 268 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 81, 265, 268 },
      -1,
   } },

   /* replace2160_0 -> 268 in the cache */
   /* replace2160_1 -> 266 in the cache */
   /* replace2160_2_0 -> 81 in the cache */
   /* replace2160_2 -> 89 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 268, 266, 89 },
      -1,
   } },

   /* ('~fadd@32', ('fmul(is_used_once)', 2.0, 'a'), -1.0) => ('flrp', -1.0, 1.0, 'a') */
   /* search2161_0_0 -> 265 in the cache */
   /* search2161_0_1 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 265, 81 },
      0,
   } },
   /* search2161_1 -> 266 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 277, 266 },
      -1,
   } },

   /* replace2161_0 -> 266 in the cache */
   /* replace2161_1 -> 268 in the cache */
   /* replace2161_2 -> 81 in the cache */
   /* replace2161 -> 269 in the cache */

   /* ('~fadd@32', ('fmul(is_used_once)', -2.0, 'a'), -1.0) => ('flrp', -1.0, 1.0, ('fneg', 'a')) */
   /* search2162_0_0 -> 270 in the cache */
   /* search2162_0_1 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 270, 81 },
      0,
   } },
   /* search2162_1 -> 266 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 279, 266 },
      -1,
   } },

   /* replace2162_0 -> 266 in the cache */
   /* replace2162_1 -> 268 in the cache */
   /* replace2162_2_0 -> 81 in the cache */
   /* replace2162_2 -> 89 in the cache */
   /* replace2162 -> 272 in the cache */

   /* ('~fadd@32', ('fmul(is_used_once)', -2.0, 'a'), 1.0) => ('flrp', 1.0, -1.0, 'a') */
   /* search2163_0_0 -> 270 in the cache */
   /* search2163_0_1 -> 81 in the cache */
   /* search2163_0 -> 279 in the cache */
   /* search2163_1 -> 268 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 279, 268 },
      -1,
   } },

   /* replace2163_0 -> 268 in the cache */
   /* replace2163_1 -> 266 in the cache */
   /* replace2163_2 -> 81 in the cache */
   /* replace2163 -> 274 in the cache */

   /* ('~fadd@32', ('fmul(is_used_once)', 2.0, 'a'), 1.0) => ('flrp', 1.0, -1.0, ('fneg', 'a')) */
   /* search2164_0_0 -> 265 in the cache */
   /* search2164_0_1 -> 81 in the cache */
   /* search2164_0 -> 277 in the cache */
   /* search2164_1 -> 268 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 277, 268 },
      -1,
   } },

   /* replace2164_0 -> 268 in the cache */
   /* replace2164_1 -> 266 in the cache */
   /* replace2164_2_0 -> 81 in the cache */
   /* replace2164_2 -> 89 in the cache */
   /* replace2164 -> 276 in the cache */

   /* ('~ffma@32', ('fadd', 'b', ('fneg', 'a')), 'a', 'a') => ('flrp', 'a', 'b', 'a') */
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 284 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 283, 285 },
      -1,
   } },
   /* search2165_1 -> 284 in the cache */
   /* search2165_2 -> 284 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 286, 284, 284 },
      -1,
   } },

   /* replace2165_0 -> 284 in the cache */
   /* replace2165_1 -> 283 in the cache */
   /* replace2165_2 -> 284 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 284, 283, 284 },
      -1,
   } },

   /* ('~ffma@32', 'a', 2.0, ('fneg', ('fmul', 'a', 'a'))) => ('flrp', 'a', 1.0, 'a') */
   /* search2166_0 -> 81 in the cache */
   /* search2166_1 -> 265 in the cache */
   /* search2166_2_0_0 -> 81 in the cache */
   /* search2166_2_0_1 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      -1, 0,
      { 81, 81 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 289 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 81, 265, 290 },
      -1,
   } },

   /* replace2166_0 -> 81 in the cache */
   /* replace2166_1 -> 268 in the cache */
   /* replace2166_2 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 81, 268, 81 },
      -1,
   } },

   /* ('~ffma@32', 'a', 2.0, ('fmul', ('fneg', 'a'), 'a')) => ('flrp', 'a', 1.0, 'a') */
   /* search2167_0 -> 81 in the cache */
   /* search2167_1 -> 265 in the cache */
   /* search2167_2_0_0 -> 81 in the cache */
   /* search2167_2_0 -> 89 in the cache */
   /* search2167_2_1 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 89, 81 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 81, 265, 293 },
      -1,
   } },

   /* replace2167_0 -> 81 in the cache */
   /* replace2167_1 -> 268 in the cache */
   /* replace2167_2 -> 81 in the cache */
   /* replace2167 -> 292 in the cache */

   /* ('~ffma@32', 'a', ('fneg', 'a'), ('fmul', 2.0, 'a')) => ('flrp', 'a', 1.0, 'a') */
   /* search2168_0 -> 81 in the cache */
   /* search2168_1_0 -> 81 in the cache */
   /* search2168_1 -> 89 in the cache */
   /* search2168_2_0 -> 265 in the cache */
   /* search2168_2_1 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 1,
      { 265, 81 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 81, 89, 295 },
      -1,
   } },

   /* replace2168_0 -> 81 in the cache */
   /* replace2168_1 -> 268 in the cache */
   /* replace2168_2 -> 81 in the cache */
   /* replace2168 -> 292 in the cache */

   /* ('~fmul@32', 'a', ('fadd', 2.0, ('fneg', 'a'))) => ('flrp', 'a', 1.0, 'a') */
   /* search2169_0 -> 81 in the cache */
   /* search2169_1_0 -> 265 in the cache */
   /* search2169_1_1_0 -> 81 in the cache */
   /* search2169_1_1 -> 89 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 265, 89 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fmul,
      0, 2,
      { 81, 297 },
      -1,
   } },

   /* replace2169_0 -> 81 in the cache */
   /* replace2169_1 -> 268 in the cache */
   /* replace2169_2 -> 81 in the cache */
   /* replace2169 -> 292 in the cache */

   /* ('fmin', ('fadd(is_used_once)', '#c', 'a'), ('fadd(is_used_once)', '#c', 'b')) => ('fadd', 'c', ('fmin', 'a', 'b')) */
   { .variable = {
      { nir_search_value_variable, -3 },
      0, /* c */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      1, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 299, 300 },
      0,
   } },
   /* search2170_1_0 -> 299 in the cache */
   { .variable = {
      { nir_search_value_variable, -3 },
      2, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      2, 1,
      { 299, 302 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 3,
      { 301, 303 },
      -1,
   } },

   { .variable = {
      { nir_search_value_variable, -3 },
      0, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* replace2170_1_0 -> 300 in the cache */
   /* replace2170_1_1 -> 302 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmin,
      1, 1,
      { 300, 302 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 305, 306 },
      -1,
   } },

   /* ('fmax', ('fadd(is_used_once)', '#c', 'a'), ('fadd(is_used_once)', '#c', 'b')) => ('fadd', 'c', ('fmax', 'a', 'b')) */
   /* search2171_0_0 -> 299 in the cache */
   /* search2171_0_1 -> 300 in the cache */
   /* search2171_0 -> 301 in the cache */
   /* search2171_1_0 -> 299 in the cache */
   /* search2171_1_1 -> 302 in the cache */
   /* search2171_1 -> 303 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 3,
      { 301, 303 },
      -1,
   } },

   /* replace2171_0 -> 305 in the cache */
   /* replace2171_1_0 -> 300 in the cache */
   /* replace2171_1_1 -> 302 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fmax,
      1, 1,
      { 300, 302 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 2,
      { 305, 309 },
      -1,
   } },

   /* ('bcsel', ('feq', ('fsqrt', 'a(is_not_negative)'), 0.0), 3.4028234663852886e+38, ('frsq', 'a')) => ('fmin', ('frsq', 'a'), 3.4028234663852886e+38) */
   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* a */
      false,
      nir_type_invalid,
      4,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsqrt,
      -1, 0,
      { 311 },
      -1,
   } },
   /* search2172_0_1 -> 43 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 312, 43 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0x47efffffe0000000 /* 3.4028234663852886e+38 */ },
   } },
   /* search2172_2_0 -> 42 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_frsq,
      -1, 0,
      { 42 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 1,
      { 313, 314, 315 },
      -1,
   } },

   /* replace2172_0_0 -> 42 in the cache */
   /* replace2172_0 -> 315 in the cache */
   /* replace2172_1 -> 314 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 315, 314 },
      -1,
   } },

   /* ('~fadd', ('ffma(is_used_once)', 'a', 'b', ('ffma', 'c', 'd', ('fmul(is_used_once)', 'e(is_not_const_and_not_fsign)', 'f(is_not_const_and_not_fsign)'))), 'g(is_not_const)') => ('ffma', 'a', 'b', ('ffma', 'c', 'd', ('ffma', 'e', 'f', 'g'))) */
   { .variable = {
      { nir_search_value_variable, -7 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -7 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -7 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -7 },
      3, /* d */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -7 },
      4, /* e */
      false,
      nir_type_invalid,
      5,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -7 },
      5, /* f */
      false,
      nir_type_invalid,
      5,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -7 },
      false,
      false,
      false,
      nir_op_fmul,
      3, 1,
      { 322, 323 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -7 },
      false,
      false,
      false,
      nir_op_ffma,
      2, 2,
      { 320, 321, 324 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -7 },
      false,
      false,
      false,
      nir_op_ffma,
      1, 3,
      { 318, 319, 325 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, -7 },
      6, /* g */
      false,
      nir_type_invalid,
      1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -7 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 4,
      { 326, 327 },
      -1,
   } },

   /* replace2173_0 -> 318 in the cache */
   /* replace2173_1 -> 319 in the cache */
   /* replace2173_2_0 -> 320 in the cache */
   /* replace2173_2_1 -> 321 in the cache */
   { .variable = {
      { nir_search_value_variable, -7 },
      4, /* e */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -7 },
      5, /* f */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -7 },
      6, /* g */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -7 },
      false,
      false,
      false,
      nir_op_ffma,
      2, 1,
      { 329, 330, 331 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -7 },
      false,
      false,
      false,
      nir_op_ffma,
      1, 2,
      { 320, 321, 332 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -7 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 3,
      { 318, 319, 333 },
      -1,
   } },

   /* ('~fadd', ('ffma(is_used_once)', 'a', 'b', ('fmul(is_used_once)', 'c(is_not_const_and_not_fsign)', 'd(is_not_const_and_not_fsign)')), 'e(is_not_const)') => ('ffma', 'a', 'b', ('ffma', 'c', 'd', 'e')) */
   { .variable = {
      { nir_search_value_variable, -5 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -5 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -5 },
      2, /* c */
      false,
      nir_type_invalid,
      5,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -5 },
      3, /* d */
      false,
      nir_type_invalid,
      5,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_fmul,
      2, 1,
      { 337, 338 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_ffma,
      1, 2,
      { 335, 336, 339 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, -5 },
      4, /* e */
      false,
      nir_type_invalid,
      1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 340, 341 },
      -1,
   } },

   /* replace2174_0 -> 335 in the cache */
   /* replace2174_1 -> 336 in the cache */
   { .variable = {
      { nir_search_value_variable, -5 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -5 },
      3, /* d */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, -5 },
      4, /* e */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_ffma,
      1, 1,
      { 343, 344, 345 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 2,
      { 335, 336, 346 },
      -1,
   } },

   /* ('~fadd', ('fneg', ('ffma(is_used_once)', 'a', 'b', ('ffma', 'c', 'd', ('fmul(is_used_once)', 'e(is_not_const_and_not_fsign)', 'f(is_not_const_and_not_fsign)')))), 'g(is_not_const)') => ('ffma', ('fneg', 'a'), 'b', ('ffma', ('fneg', 'c'), 'd', ('ffma', ('fneg', 'e'), 'f', 'g'))) */
   /* search2175_0_0_0 -> 318 in the cache */
   /* search2175_0_0_1 -> 319 in the cache */
   /* search2175_0_0_2_0 -> 320 in the cache */
   /* search2175_0_0_2_1 -> 321 in the cache */
   /* search2175_0_0_2_2_0 -> 322 in the cache */
   /* search2175_0_0_2_2_1 -> 323 in the cache */
   /* search2175_0_0_2_2 -> 324 in the cache */
   /* search2175_0_0_2 -> 325 in the cache */
   /* search2175_0_0 -> 326 in the cache */
   { .expression = {
      { nir_search_value_expression, -7 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 3,
      { 326 },
      -1,
   } },
   /* search2175_1 -> 327 in the cache */
   { .expression = {
      { nir_search_value_expression, -7 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 4,
      { 348, 327 },
      -1,
   } },

   /* replace2175_0_0 -> 318 in the cache */
   { .expression = {
      { nir_search_value_expression, -7 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 318 },
      -1,
   } },
   /* replace2175_1 -> 319 in the cache */
   /* replace2175_2_0_0 -> 320 in the cache */
   { .expression = {
      { nir_search_value_expression, -7 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 320 },
      -1,
   } },
   /* replace2175_2_1 -> 321 in the cache */
   /* replace2175_2_2_0_0 -> 329 in the cache */
   { .expression = {
      { nir_search_value_expression, -7 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 329 },
      -1,
   } },
   /* replace2175_2_2_1 -> 330 in the cache */
   /* replace2175_2_2_2 -> 331 in the cache */
   { .expression = {
      { nir_search_value_expression, -7 },
      false,
      false,
      false,
      nir_op_ffma,
      2, 1,
      { 352, 330, 331 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -7 },
      false,
      false,
      false,
      nir_op_ffma,
      1, 2,
      { 351, 321, 353 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -7 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 3,
      { 350, 319, 354 },
      -1,
   } },

   /* ('~fadd', ('ffmaz(is_used_once)', 'a', 'b', ('ffmaz', 'c', 'd', ('fmulz(is_used_once)', 'e(is_not_const_and_not_fsign)', 'f(is_not_const_and_not_fsign)'))), 'g(is_not_const)') => ('ffmaz', 'a', 'b', ('ffmaz', 'c', 'd', ('ffmaz', 'e', 'f', 'g'))) */
   /* search2176_0_0 -> 81 in the cache */
   /* search2176_0_1 -> 82 in the cache */
   /* search2176_0_2_0 -> 84 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      3, /* d */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      4, /* e */
      false,
      nir_type_invalid,
      5,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      5, /* f */
      false,
      nir_type_invalid,
      5,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      3, 1,
      { 357, 358 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      2, 2,
      { 84, 356, 359 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      1, 3,
      { 81, 82, 360 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      6, /* g */
      false,
      nir_type_invalid,
      1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 4,
      { 361, 362 },
      -1,
   } },

   /* replace2176_0 -> 81 in the cache */
   /* replace2176_1 -> 82 in the cache */
   /* replace2176_2_0 -> 84 in the cache */
   /* replace2176_2_1 -> 356 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      4, /* e */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      5, /* f */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      6, /* g */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      2, 1,
      { 364, 365, 366 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      1, 2,
      { 84, 356, 367 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 3,
      { 81, 82, 368 },
      -1,
   } },

   /* ('~fadd', ('ffmaz(is_used_once)', 'a', 'b', ('fmulz(is_used_once)', 'c(is_not_const_and_not_fsign)', 'd(is_not_const_and_not_fsign)')), 'e(is_not_const)') => ('ffmaz', 'a', 'b', ('ffmaz', 'c', 'd', 'e')) */
   /* search2177_0_0 -> 81 in the cache */
   /* search2177_0_1 -> 82 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      2, /* c */
      false,
      nir_type_invalid,
      5,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      3, /* d */
      false,
      nir_type_invalid,
      5,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmulz,
      2, 1,
      { 370, 371 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      1, 2,
      { 81, 82, 372 },
      0,
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      4, /* e */
      false,
      nir_type_invalid,
      1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 373, 374 },
      -1,
   } },

   /* replace2177_0 -> 81 in the cache */
   /* replace2177_1 -> 82 in the cache */
   /* replace2177_2_0 -> 84 in the cache */
   /* replace2177_2_1 -> 356 in the cache */
   /* replace2177_2_2 -> 364 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      1, 1,
      { 84, 356, 364 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 2,
      { 81, 82, 376 },
      -1,
   } },

   /* ('~fadd', ('fneg', ('ffmaz(is_used_once)', 'a', 'b', ('ffmaz', 'c', 'd', ('fmulz(is_used_once)', 'e(is_not_const_and_not_fsign)', 'f(is_not_const_and_not_fsign)')))), 'g(is_not_const)') => ('ffmaz', ('fneg', 'a'), 'b', ('ffmaz', ('fneg', 'c'), 'd', ('ffmaz', ('fneg', 'e'), 'f', 'g'))) */
   /* search2178_0_0_0 -> 81 in the cache */
   /* search2178_0_0_1 -> 82 in the cache */
   /* search2178_0_0_2_0 -> 84 in the cache */
   /* search2178_0_0_2_1 -> 356 in the cache */
   /* search2178_0_0_2_2_0 -> 357 in the cache */
   /* search2178_0_0_2_2_1 -> 358 in the cache */
   /* search2178_0_0_2_2 -> 359 in the cache */
   /* search2178_0_0_2 -> 360 in the cache */
   /* search2178_0_0 -> 361 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 3,
      { 361 },
      -1,
   } },
   /* search2178_1 -> 362 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 4,
      { 378, 362 },
      -1,
   } },

   /* replace2178_0_0 -> 81 in the cache */
   /* replace2178_0 -> 89 in the cache */
   /* replace2178_1 -> 82 in the cache */
   /* replace2178_2_0_0 -> 84 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 84 },
      -1,
   } },
   /* replace2178_2_1 -> 356 in the cache */
   /* replace2178_2_2_0_0 -> 364 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 364 },
      -1,
   } },
   /* replace2178_2_2_1 -> 365 in the cache */
   /* replace2178_2_2_2 -> 366 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      2, 1,
      { 381, 365, 366 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      1, 2,
      { 380, 356, 382 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 3,
      { 89, 82, 383 },
      -1,
   } },

   /* ('ubfe', 'a', 'b', 0) => 0 */
   /* search2179_0 -> 81 in the cache */
   /* search2179_1 -> 82 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x0 /* 0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ubfe,
      -1, 0,
      { 81, 82, 385 },
      -1,
   } },

   /* replace2179 -> 385 in the cache */

   /* ('ibfe', 'a', 'b', 0) => 0 */
   /* search2180_0 -> 81 in the cache */
   /* search2180_1 -> 82 in the cache */
   /* search2180_2 -> 385 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ibfe,
      -1, 0,
      { 81, 82, 385 },
      -1,
   } },

   /* replace2180 -> 385 in the cache */

   /* ('ubfe', 'a', '#b', '#c') => ('iand', ('ushr', 4294967295, ('ineg', 'c')), ('ushr', 'a', 'b')) */
   /* search2181_0 -> 81 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      1, /* b */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .variable = {
      { nir_search_value_variable, 32 },
      2, /* c */
      true,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ubfe,
      -1, 0,
      { 81, 388, 389 },
      -1,
   } },

   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xffffffff /* 4294967295 */ },
   } },
   /* replace2181_0_1_0 -> 84 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 0,
      { 84 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 391, 392 },
      -1,
   } },
   /* replace2181_1_0 -> 81 in the cache */
   /* replace2181_1_1 -> 82 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 81, 82 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 393, 394 },
      -1,
   } },

   /* ('ibfe', 'a', '#b', '#c') => ('ishr', ('ishl', 'a', ('ineg', ('iadd', 'b', 'c'))), ('ineg', 'c')) */
   /* search2182_0 -> 81 in the cache */
   /* search2182_1 -> 388 in the cache */
   /* search2182_2 -> 389 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ibfe,
      -1, 0,
      { 81, 388, 389 },
      -1,
   } },

   /* replace2182_0_0 -> 81 in the cache */
   /* replace2182_0_1_0_0 -> 82 in the cache */
   /* replace2182_0_1_0_1 -> 84 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iadd,
      0, 1,
      { 82, 84 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ineg,
      -1, 1,
      { 397 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 1,
      { 81, 398 },
      -1,
   } },
   /* replace2182_1_0 -> 84 in the cache */
   /* replace2182_1 -> 392 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 1,
      { 399, 392 },
      -1,
   } },

   /* ('ishl', 'a', 0) => a */
   /* search2183_0 -> 42 in the cache */
   /* search2183_1 -> 385 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 42, 385 },
      -1,
   } },

   /* replace2183 -> 42 in the cache */

   /* ('ishl', 'a', -32) => a */
   /* search2184_0 -> 42 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { -0x20 /* -32 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 42, 402 },
      -1,
   } },

   /* replace2184 -> 42 in the cache */

   /* ('ishr', 'a', 0) => a */
   /* search2185_0 -> 42 in the cache */
   /* search2185_1 -> 385 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 42, 385 },
      -1,
   } },

   /* replace2185 -> 42 in the cache */

   /* ('ishr', 'a', -32) => a */
   /* search2186_0 -> 42 in the cache */
   /* search2186_1 -> 402 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ishr,
      -1, 0,
      { 42, 402 },
      -1,
   } },

   /* replace2186 -> 42 in the cache */

   /* ('ushr', 'a', 0) => a */
   /* search2187_0 -> 42 in the cache */
   /* search2187_1 -> 385 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_ushr,
      -1, 0,
      { 42, 385 },
      -1,
   } },

   /* replace2187 -> 42 in the cache */

   /* ('extract_i8', ('extract_i8', 'a', 'b'), 0) => ('extract_i8', 'a', 'b') */
   /* search2188_0_0 -> 0 in the cache */
   /* search2188_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 0, 1 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, -2 },
      nir_type_int, { 0x0 /* 0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 407, 408 },
      -1,
   } },

   /* replace2188_0 -> 0 in the cache */
   /* replace2188_1 -> 1 in the cache */
   /* replace2188 -> 407 in the cache */

   /* ('extract_i8', ('extract_u8', 'a', 'b'), 0) => ('extract_i8', 'a', 'b') */
   /* search2189_0_0 -> 0 in the cache */
   /* search2189_0_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 0, 1 },
      -1,
   } },
   /* search2189_1 -> 408 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 410, 408 },
      -1,
   } },

   /* replace2189_0 -> 0 in the cache */
   /* replace2189_1 -> 1 in the cache */
   /* replace2189 -> 407 in the cache */

   /* ('extract_u8', ('extract_i8', 'a', 'b'), 0) => ('extract_u8', 'a', 'b') */
   /* search2190_0_0 -> 0 in the cache */
   /* search2190_0_1 -> 1 in the cache */
   /* search2190_0 -> 407 in the cache */
   /* search2190_1 -> 408 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 407, 408 },
      -1,
   } },

   /* replace2190_0 -> 0 in the cache */
   /* replace2190_1 -> 1 in the cache */
   /* replace2190 -> 410 in the cache */

   /* ('extract_u8', ('extract_u8', 'a', 'b'), 0) => ('extract_u8', 'a', 'b') */
   /* search2191_0_0 -> 0 in the cache */
   /* search2191_0_1 -> 1 in the cache */
   /* search2191_0 -> 410 in the cache */
   /* search2191_1 -> 408 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 410, 408 },
      -1,
   } },

   /* replace2191_0 -> 0 in the cache */
   /* replace2191_1 -> 1 in the cache */
   /* replace2191 -> 410 in the cache */

   /* ('u2u16', ('u2u8', 'a@16')) => ('extract_u8', 'a', 0) */
   /* search2192_0_0 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 61 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 414 },
      -1,
   } },

   /* replace2192_0 -> 61 in the cache */
   { .constant = {
      { nir_search_value_constant, 16 },
      nir_type_int, { 0x0 /* 0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 61, 416 },
      -1,
   } },

   /* ('u2u16', ('i2i8', 'a@16')) => ('extract_u8', 'a', 0) */
   /* search2193_0_0 -> 61 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 61 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 418 },
      -1,
   } },

   /* replace2193_0 -> 61 in the cache */
   /* replace2193_1 -> 416 in the cache */
   /* replace2193 -> 417 in the cache */

   /* ('i2i16', ('u2u8', 'a@16')) => ('extract_i8', 'a', 0) */
   /* search2194_0_0 -> 61 in the cache */
   /* search2194_0 -> 414 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 414 },
      -1,
   } },

   /* replace2194_0 -> 61 in the cache */
   /* replace2194_1 -> 416 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 61, 416 },
      -1,
   } },

   /* ('i2i16', ('i2i8', 'a@16')) => ('extract_i8', 'a', 0) */
   /* search2195_0_0 -> 61 in the cache */
   /* search2195_0 -> 418 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 418 },
      -1,
   } },

   /* replace2195_0 -> 61 in the cache */
   /* replace2195_1 -> 416 in the cache */
   /* replace2195 -> 421 in the cache */

   /* ('u2u32', ('u2u8', 'a@32')) => ('extract_u8', 'a', 0) */
   /* search2196_0_0 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_u2u8,
      -1, 0,
      { 81 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 423 },
      -1,
   } },

   /* replace2196_0 -> 81 in the cache */
   /* replace2196_1 -> 385 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 81, 385 },
      -1,
   } },

   /* ('u2u32', ('i2i8', 'a@32')) => ('extract_u8', 'a', 0) */
   /* search2197_0_0 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_i2i8,
      -1, 0,
      { 81 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 426 },
      -1,
   } },

   /* replace2197_0 -> 81 in the cache */
   /* replace2197_1 -> 385 in the cache */
   /* replace2197 -> 425 in the cache */

   /* ('u2u32', ('u2u16', 'a@32')) => ('extract_u16', 'a', 0) */
   /* search2198_0_0 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2u16,
      -1, 0,
      { 81 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 428 },
      -1,
   } },

   /* replace2198_0 -> 81 in the cache */
   /* replace2198_1 -> 385 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 0,
      { 81, 385 },
      -1,
   } },

   /* ('u2u32', ('i2i16', 'a@32')) => ('extract_u16', 'a', 0) */
   /* search2199_0_0 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2i16,
      -1, 0,
      { 81 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_u2u32,
      -1, 0,
      { 431 },
      -1,
   } },

   /* replace2199_0 -> 81 in the cache */
   /* replace2199_1 -> 385 in the cache */
   /* replace2199 -> 430 in the cache */

   /* ('i2i32', ('u2u8', 'a@32')) => ('extract_i8', 'a', 0) */
   /* search2200_0_0 -> 81 in the cache */
   /* search2200_0 -> 423 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 423 },
      -1,
   } },

   /* replace2200_0 -> 81 in the cache */
   /* replace2200_1 -> 385 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i8,
      -1, 0,
      { 81, 385 },
      -1,
   } },

   /* ('i2i32', ('i2i8', 'a@32')) => ('extract_i8', 'a', 0) */
   /* search2201_0_0 -> 81 in the cache */
   /* search2201_0 -> 426 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 426 },
      -1,
   } },

   /* replace2201_0 -> 81 in the cache */
   /* replace2201_1 -> 385 in the cache */
   /* replace2201 -> 434 in the cache */

   /* ('i2i32', ('u2u16', 'a@32')) => ('extract_i16', 'a', 0) */
   /* search2202_0_0 -> 81 in the cache */
   /* search2202_0 -> 428 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 428 },
      -1,
   } },

   /* replace2202_0 -> 81 in the cache */
   /* replace2202_1 -> 385 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_extract_i16,
      -1, 0,
      { 81, 385 },
      -1,
   } },

   /* ('i2i32', ('i2i16', 'a@32')) => ('extract_i16', 'a', 0) */
   /* search2203_0_0 -> 81 in the cache */
   /* search2203_0 -> 431 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i2i32,
      -1, 0,
      { 431 },
      -1,
   } },

   /* replace2203_0 -> 81 in the cache */
   /* replace2203_1 -> 385 in the cache */
   /* replace2203 -> 437 in the cache */

   /* ('ishl', ('extract_u8', 'a@32', 0), 8) => ('insert_u8', 'a', 1) */
   /* search2204_0_0 -> 81 in the cache */
   /* search2204_0_1 -> 385 in the cache */
   /* search2204_0 -> 425 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x8 /* 8 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 425, 439 },
      -1,
   } },

   /* replace2204_0 -> 81 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x1 /* 1 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_insert_u8,
      -1, 0,
      { 81, 441 },
      -1,
   } },

   /* ('ishl', ('extract_u8', 'a@32', 0), 16) => ('insert_u8', 'a', 2) */
   /* search2205_0_0 -> 81 in the cache */
   /* search2205_0_1 -> 385 in the cache */
   /* search2205_0 -> 425 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x10 /* 16 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 425, 443 },
      -1,
   } },

   /* replace2205_0 -> 81 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x2 /* 2 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_insert_u8,
      -1, 0,
      { 81, 445 },
      -1,
   } },

   /* ('ishl', ('extract_u8', 'a@32', 0), 24) => ('insert_u8', 'a', 3) */
   /* search2206_0_0 -> 81 in the cache */
   /* search2206_0_1 -> 385 in the cache */
   /* search2206_0 -> 425 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x18 /* 24 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 425, 447 },
      -1,
   } },

   /* replace2206_0 -> 81 in the cache */
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0x3 /* 3 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_insert_u8,
      -1, 0,
      { 81, 449 },
      -1,
   } },

   /* ('iand', ('ishl', 'a@32', 8), 65280) => ('insert_u8', 'a', 1) */
   /* search2207_0_0 -> 81 in the cache */
   /* search2207_0_1 -> 439 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 81, 439 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xff00 /* 65280 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 451, 452 },
      -1,
   } },

   /* replace2207_0 -> 81 in the cache */
   /* replace2207_1 -> 441 in the cache */
   /* replace2207 -> 442 in the cache */

   /* ('iand', ('ishl', 'a@32', 16), 16711680) => ('insert_u8', 'a', 2) */
   /* search2208_0_0 -> 81 in the cache */
   /* search2208_0_1 -> 443 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 81, 443 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xff0000 /* 16711680 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 454, 455 },
      -1,
   } },

   /* replace2208_0 -> 81 in the cache */
   /* replace2208_1 -> 445 in the cache */
   /* replace2208 -> 446 in the cache */

   /* ('iand', ('ishl', 'a@32', 24), 4278190080) => ('insert_u8', 'a', 3) */
   /* search2209_0_0 -> 81 in the cache */
   /* search2209_0_1 -> 447 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ishl,
      -1, 0,
      { 81, 447 },
      -1,
   } },
   { .constant = {
      { nir_search_value_constant, 32 },
      nir_type_int, { 0xff000000 /* 4278190080 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_iand,
      0, 1,
      { 457, 458 },
      -1,
   } },

   /* replace2209_0 -> 81 in the cache */
   /* replace2209_1 -> 449 in the cache */
   /* replace2209 -> 450 in the cache */

   /* ('ishl', 'a@32', 24) => ('insert_u8', 'a', 3) */
   /* search2210_0 -> 81 in the cache */
   /* search2210_1 -> 447 in the cache */
   /* search2210 -> 457 in the cache */

   /* replace2210_0 -> 81 in the cache */
   /* replace2210_1 -> 449 in the cache */
   /* replace2210 -> 450 in the cache */

   /* ('ishl', 'a@32', 16) => ('insert_u16', 'a', 1) */
   /* search2211_0 -> 81 in the cache */
   /* search2211_1 -> 443 in the cache */
   /* search2211 -> 454 in the cache */

   /* replace2211_0 -> 81 in the cache */
   /* replace2211_1 -> 441 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_insert_u16,
      -1, 0,
      { 81, 441 },
      -1,
   } },

   /* ('insert_u8', ('extract_u8', 'a', 0), 'b') => ('insert_u8', 'a', 'b') */
   /* search2212_0_0 -> 0 in the cache */
   /* search2212_0_1 -> 408 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_u8,
      -1, 0,
      { 0, 408 },
      -1,
   } },
   /* search2212_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_insert_u8,
      -1, 0,
      { 461, 1 },
      -1,
   } },

   /* replace2212_0 -> 0 in the cache */
   /* replace2212_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_insert_u8,
      -1, 0,
      { 0, 1 },
      -1,
   } },

   /* ('insert_u16', ('extract_u16', 'a', 0), 'b') => ('insert_u16', 'a', 'b') */
   /* search2213_0_0 -> 0 in the cache */
   /* search2213_0_1 -> 408 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_extract_u16,
      -1, 0,
      { 0, 408 },
      -1,
   } },
   /* search2213_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_insert_u16,
      -1, 0,
      { 464, 1 },
      -1,
   } },

   /* replace2213_0 -> 0 in the cache */
   /* replace2213_1 -> 1 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_insert_u16,
      -1, 0,
      { 0, 1 },
      -1,
   } },

   /* ('iand', ('ine(is_used_once)', 'a@8', 0), ('ine', 'b@8', 0)) => ('ine', ('umin', 'a', 'b'), 0) */
   /* search2214_0_0 -> 134 in the cache */
   { .constant = {
      { nir_search_value_constant, 8 },
      nir_type_int, { 0x0 /* 0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 134, 467 },
      0,
   } },
   /* search2214_1_0 -> 135 in the cache */
   /* search2214_1_1 -> 467 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 135, 467 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 468, 469 },
      -1,
   } },

   /* replace2214_0_0 -> 134 in the cache */
   /* replace2214_0_1 -> 135 in the cache */
   { .expression = {
      { nir_search_value_expression, 8 },
      false,
      false,
      false,
      nir_op_umin,
      1, 1,
      { 134, 135 },
      -1,
   } },
   /* replace2214_1 -> 467 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 471, 467 },
      -1,
   } },

   /* ('ior', ('ieq(is_used_once)', 'a@8', 0), ('ieq', 'b@8', 0)) => ('ieq', ('umin', 'a', 'b'), 0) */
   /* search2215_0_0 -> 134 in the cache */
   /* search2215_0_1 -> 467 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 134, 467 },
      0,
   } },
   /* search2215_1_0 -> 135 in the cache */
   /* search2215_1_1 -> 467 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 135, 467 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 473, 474 },
      -1,
   } },

   /* replace2215_0_0 -> 134 in the cache */
   /* replace2215_0_1 -> 135 in the cache */
   /* replace2215_0 -> 471 in the cache */
   /* replace2215_1 -> 467 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 471, 467 },
      -1,
   } },

   /* ('iand', ('ine(is_used_once)', 'a@16', 0), ('ine', 'b@16', 0)) => ('ine', ('umin', 'a', 'b'), 0) */
   /* search2216_0_0 -> 61 in the cache */
   /* search2216_0_1 -> 416 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 61, 416 },
      0,
   } },
   /* search2216_1_0 -> 62 in the cache */
   /* search2216_1_1 -> 416 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 62, 416 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 477, 478 },
      -1,
   } },

   /* replace2216_0_0 -> 61 in the cache */
   /* replace2216_0_1 -> 62 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_umin,
      1, 1,
      { 61, 62 },
      -1,
   } },
   /* replace2216_1 -> 416 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 480, 416 },
      -1,
   } },

   /* ('ior', ('ieq(is_used_once)', 'a@16', 0), ('ieq', 'b@16', 0)) => ('ieq', ('umin', 'a', 'b'), 0) */
   /* search2217_0_0 -> 61 in the cache */
   /* search2217_0_1 -> 416 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 61, 416 },
      0,
   } },
   /* search2217_1_0 -> 62 in the cache */
   /* search2217_1_1 -> 416 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 62, 416 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 482, 483 },
      -1,
   } },

   /* replace2217_0_0 -> 61 in the cache */
   /* replace2217_0_1 -> 62 in the cache */
   /* replace2217_0 -> 480 in the cache */
   /* replace2217_1 -> 416 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 480, 416 },
      -1,
   } },

   /* ('iand', ('ine(is_used_once)', 'a@32', 0), ('ine', 'b@32', 0)) => ('ine', ('umin', 'a', 'b'), 0) */
   /* search2218_0_0 -> 81 in the cache */
   /* search2218_0_1 -> 385 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 81, 385 },
      0,
   } },
   /* search2218_1_0 -> 82 in the cache */
   /* search2218_1_1 -> 385 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 82, 385 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 486, 487 },
      -1,
   } },

   /* replace2218_0_0 -> 81 in the cache */
   /* replace2218_0_1 -> 82 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_umin,
      1, 1,
      { 81, 82 },
      -1,
   } },
   /* replace2218_1 -> 385 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 489, 385 },
      -1,
   } },

   /* ('ior', ('ieq(is_used_once)', 'a@32', 0), ('ieq', 'b@32', 0)) => ('ieq', ('umin', 'a', 'b'), 0) */
   /* search2219_0_0 -> 81 in the cache */
   /* search2219_0_1 -> 385 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 81, 385 },
      0,
   } },
   /* search2219_1_0 -> 82 in the cache */
   /* search2219_1_1 -> 385 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 82, 385 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 491, 492 },
      -1,
   } },

   /* replace2219_0_0 -> 81 in the cache */
   /* replace2219_0_1 -> 82 in the cache */
   /* replace2219_0 -> 489 in the cache */
   /* replace2219_1 -> 385 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 489, 385 },
      -1,
   } },

   /* ('iand', ('ine(is_used_once)', 'a@64', 0), ('ine', 'b@64', 0)) => ('ine', ('umin', 'a', 'b'), 0) */
   /* search2220_0_0 -> 114 in the cache */
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_int, { 0x0 /* 0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      1, 1,
      { 114, 495 },
      0,
   } },
   /* search2220_1_0 -> 115 in the cache */
   /* search2220_1_1 -> 495 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      2, 1,
      { 115, 495 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_iand,
      0, 3,
      { 496, 497 },
      -1,
   } },

   /* replace2220_0_0 -> 114 in the cache */
   /* replace2220_0_1 -> 115 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_umin,
      1, 1,
      { 114, 115 },
      -1,
   } },
   /* replace2220_1 -> 495 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ine,
      0, 2,
      { 499, 495 },
      -1,
   } },

   /* ('ior', ('ieq(is_used_once)', 'a@64', 0), ('ieq', 'b@64', 0)) => ('ieq', ('umin', 'a', 'b'), 0) */
   /* search2221_0_0 -> 114 in the cache */
   /* search2221_0_1 -> 495 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      1, 1,
      { 114, 495 },
      0,
   } },
   /* search2221_1_0 -> 115 in the cache */
   /* search2221_1_1 -> 495 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      2, 1,
      { 115, 495 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 3,
      { 501, 502 },
      -1,
   } },

   /* replace2221_0_0 -> 114 in the cache */
   /* replace2221_0_1 -> 115 in the cache */
   /* replace2221_0 -> 499 in the cache */
   /* replace2221_1 -> 495 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ieq,
      0, 2,
      { 499, 495 },
      -1,
   } },

   /* ('~fadd@16', 1.0, ('fmul(is_used_once)', 'c', ('fadd', 'b', -1.0))) => ('fadd', ('fadd', 1.0, ('fneg', 'c')), ('fmul', 'b', 'c')) */
   /* search2222_0 -> 177 in the cache */
   { .variable = {
      { nir_search_value_variable, 16 },
      0, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search2222_1_1_0 -> 62 in the cache */
   /* search2222_1_1_1 -> 176 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fadd,
      2, 1,
      { 62, 176 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 2,
      { 505, 506 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 177, 507 },
      -1,
   } },

   /* replace2222_0_0 -> 177 in the cache */
   /* replace2222_0_1_0 -> 505 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 505 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 177, 509 },
      -1,
   } },
   /* replace2222_1_0 -> 62 in the cache */
   /* replace2222_1_1 -> 505 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      2, 1,
      { 62, 505 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 510, 511 },
      -1,
   } },

   /* ('bcsel', 'a', 0, ('b2f16', ('inot', 'b@bool'))) => ('b2f16', ('inot', ('ior', 'a', 'b'))) */
   { .variable = {
      { nir_search_value_variable, 1 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search2223_1 -> 416 in the cache */
   { .variable = {
      { nir_search_value_variable, 1 },
      1, /* b */
      false,
      nir_type_bool,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 0,
      { 514 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_b2f16,
      -1, 0,
      { 515 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 513, 416, 516 },
      -1,
   } },

   /* replace2223_0_0_0 -> 513 in the cache */
   { .variable = {
      { nir_search_value_variable, 1 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ior,
      0, 1,
      { 513, 518 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_inot,
      -1, 1,
      { 519 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_b2f16,
      -1, 1,
      { 520 },
      -1,
   } },

   /* ('~fadd@32', 1.0, ('fmul(is_used_once)', 'c', ('fadd', 'b', -1.0))) => ('fadd', ('fadd', 1.0, ('fneg', 'c')), ('fmul', 'b', 'c')) */
   /* search2224_0 -> 268 in the cache */
   { .variable = {
      { nir_search_value_variable, 32 },
      0, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search2224_1_1_0 -> 82 in the cache */
   /* search2224_1_1_1 -> 266 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      2, 1,
      { 82, 266 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 2,
      { 522, 523 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 268, 524 },
      -1,
   } },

   /* replace2224_0_0 -> 268 in the cache */
   /* replace2224_0_1_0 -> 522 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 522 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 268, 526 },
      -1,
   } },
   /* replace2224_1_0 -> 82 in the cache */
   /* replace2224_1_1 -> 522 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      2, 1,
      { 82, 522 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 527, 528 },
      -1,
   } },

   /* ('bcsel', 'a', 0, ('b2f32', ('inot', 'b@bool'))) => ('b2f32', ('inot', ('ior', 'a', 'b'))) */
   /* search2225_0 -> 513 in the cache */
   /* search2225_1 -> 385 in the cache */
   /* search2225_2_0_0 -> 514 in the cache */
   /* search2225_2_0 -> 515 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_b2f32,
      -1, 0,
      { 515 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 513, 385, 530 },
      -1,
   } },

   /* replace2225_0_0_0 -> 513 in the cache */
   /* replace2225_0_0_1 -> 518 in the cache */
   /* replace2225_0_0 -> 519 in the cache */
   /* replace2225_0 -> 520 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_b2f32,
      -1, 1,
      { 520 },
      -1,
   } },

   /* ('~fadd@64', 1.0, ('fmul(is_used_once)', 'c', ('fadd', 'b', -1.0))) => ('fadd', ('fadd', 1.0, ('fneg', 'c')), ('fmul', 'b', 'c')) */
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_float, { 0x3ff0000000000000 /* 1.0 */ },
   } },
   { .variable = {
      { nir_search_value_variable, 64 },
      0, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   /* search2226_1_1_0 -> 115 in the cache */
   { .constant = {
      { nir_search_value_constant, 64 },
      nir_type_float, { 0xbff0000000000000 /* -1.0 */ },
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fadd,
      2, 1,
      { 115, 535 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmul,
      1, 2,
      { 534, 536 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 533, 537 },
      -1,
   } },

   /* replace2226_0_0 -> 533 in the cache */
   /* replace2226_0_1_0 -> 534 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 534 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 533, 539 },
      -1,
   } },
   /* replace2226_1_0 -> 115 in the cache */
   /* replace2226_1_1 -> 534 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fmul,
      2, 1,
      { 115, 534 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 3,
      { 540, 541 },
      -1,
   } },

   /* ('bcsel', 'a', 0, ('b2f64', ('inot', 'b@bool'))) => ('b2f64', ('inot', ('ior', 'a', 'b'))) */
   /* search2227_0 -> 513 in the cache */
   /* search2227_1 -> 495 in the cache */
   /* search2227_2_0_0 -> 514 in the cache */
   /* search2227_2_0 -> 515 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_b2f64,
      -1, 0,
      { 515 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 513, 495, 543 },
      -1,
   } },

   /* replace2227_0_0_0 -> 513 in the cache */
   /* replace2227_0_0_1 -> 518 in the cache */
   /* replace2227_0_0 -> 519 in the cache */
   /* replace2227_0 -> 520 in the cache */
   { .expression = {
      { nir_search_value_expression, 64 },
      false,
      false,
      false,
      nir_op_b2f64,
      -1, 1,
      { 520 },
      -1,
   } },

   /* ('bcsel', 'a', ('fadd(is_used_once)', 'b', 'c'), ('fadd', 'b', 'd')) => ('fadd', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search2228_0 -> 513 in the cache */
   /* search2228_1_0 -> 202 in the cache */
   /* search2228_1_1 -> 204 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 202, 204 },
      0,
   } },
   /* search2228_2_0 -> 202 in the cache */
   /* search2228_2_1 -> 205 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 202, 205 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 513, 546, 547 },
      -1,
   } },

   /* replace2228_0 -> 202 in the cache */
   /* replace2228_1_0 -> 513 in the cache */
   /* replace2228_1_1 -> 204 in the cache */
   /* replace2228_1_2 -> 205 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 513, 204, 205 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 202, 549 },
      -1,
   } },

   /* ('bcsel', 'a', ('fadd', 'b', 'c'), ('fadd(is_used_once)', 'b', 'd')) => ('fadd', 'b', ('bcsel', 'a', 'c', 'd')) */
   /* search2229_0 -> 513 in the cache */
   /* search2229_1_0 -> 202 in the cache */
   /* search2229_1_1 -> 204 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 202, 204 },
      -1,
   } },
   /* search2229_2_0 -> 202 in the cache */
   /* search2229_2_1 -> 205 in the cache */
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_fadd,
      1, 1,
      { 202, 205 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -4 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 513, 551, 552 },
      -1,
   } },

   /* replace2229_0 -> 202 in the cache */
   /* replace2229_1_0 -> 513 in the cache */
   /* replace2229_1_1 -> 204 in the cache */
   /* replace2229_1_2 -> 205 in the cache */
   /* replace2229_1 -> 549 in the cache */
   /* replace2229 -> 550 in the cache */

   /* ('bcsel', 'a', ('ffma(is_used_once)', 'b', 'c', 'd'), ('ffma', 'b', 'c', 'e')) => ('ffma', 'b', 'c', ('bcsel', 'a', 'd', 'e')) */
   /* search2230_0 -> 513 in the cache */
   /* search2230_1_0 -> 336 in the cache */
   /* search2230_1_1 -> 343 in the cache */
   /* search2230_1_2 -> 344 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 336, 343, 344 },
      0,
   } },
   /* search2230_2_0 -> 336 in the cache */
   /* search2230_2_1 -> 343 in the cache */
   /* search2230_2_2 -> 345 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_ffma,
      1, 1,
      { 336, 343, 345 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 513, 554, 555 },
      -1,
   } },

   /* replace2230_0 -> 336 in the cache */
   /* replace2230_1 -> 343 in the cache */
   /* replace2230_2_0 -> 513 in the cache */
   /* replace2230_2_1 -> 344 in the cache */
   /* replace2230_2_2 -> 345 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 513, 344, 345 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 336, 343, 557 },
      -1,
   } },

   /* ('bcsel', 'a', ('ffma', 'b', 'c', 'd'), ('ffma(is_used_once)', 'b', 'c', 'e')) => ('ffma', 'b', 'c', ('bcsel', 'a', 'd', 'e')) */
   /* search2231_0 -> 513 in the cache */
   /* search2231_1_0 -> 336 in the cache */
   /* search2231_1_1 -> 343 in the cache */
   /* search2231_1_2 -> 344 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 336, 343, 344 },
      -1,
   } },
   /* search2231_2_0 -> 336 in the cache */
   /* search2231_2_1 -> 343 in the cache */
   /* search2231_2_2 -> 345 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_ffma,
      1, 1,
      { 336, 343, 345 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 513, 559, 560 },
      -1,
   } },

   /* replace2231_0 -> 336 in the cache */
   /* replace2231_1 -> 343 in the cache */
   /* replace2231_2_0 -> 513 in the cache */
   /* replace2231_2_1 -> 344 in the cache */
   /* replace2231_2_2 -> 345 in the cache */
   /* replace2231_2 -> 557 in the cache */
   /* replace2231 -> 558 in the cache */

   /* ('bcsel', 'a', ('ffma(is_used_once)', 'b', 'c', 'd'), ('ffma', 'b', 'e', 'd')) => ('ffma', 'b', ('bcsel', 'a', 'c', 'e'), 'd') */
   /* search2232_0 -> 513 in the cache */
   /* search2232_1_0 -> 336 in the cache */
   /* search2232_1_1 -> 343 in the cache */
   /* search2232_1_2 -> 344 in the cache */
   /* search2232_1 -> 554 in the cache */
   /* search2232_2_0 -> 336 in the cache */
   /* search2232_2_1 -> 345 in the cache */
   /* search2232_2_2 -> 344 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_ffma,
      1, 1,
      { 336, 345, 344 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 513, 554, 562 },
      -1,
   } },

   /* replace2232_0 -> 336 in the cache */
   /* replace2232_1_0 -> 513 in the cache */
   /* replace2232_1_1 -> 343 in the cache */
   /* replace2232_1_2 -> 345 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 513, 343, 345 },
      -1,
   } },
   /* replace2232_2 -> 344 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 336, 564, 344 },
      -1,
   } },

   /* ('bcsel', 'a', ('ffma', 'b', 'c', 'd'), ('ffma(is_used_once)', 'b', 'e', 'd')) => ('ffma', 'b', ('bcsel', 'a', 'c', 'e'), 'd') */
   /* search2233_0 -> 513 in the cache */
   /* search2233_1_0 -> 336 in the cache */
   /* search2233_1_1 -> 343 in the cache */
   /* search2233_1_2 -> 344 in the cache */
   /* search2233_1 -> 559 in the cache */
   /* search2233_2_0 -> 336 in the cache */
   /* search2233_2_1 -> 345 in the cache */
   /* search2233_2_2 -> 344 in the cache */
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_ffma,
      1, 1,
      { 336, 345, 344 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -5 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 513, 559, 566 },
      -1,
   } },

   /* replace2233_0 -> 336 in the cache */
   /* replace2233_1_0 -> 513 in the cache */
   /* replace2233_1_1 -> 343 in the cache */
   /* replace2233_1_2 -> 345 in the cache */
   /* replace2233_1 -> 564 in the cache */
   /* replace2233_2 -> 344 in the cache */
   /* replace2233 -> 565 in the cache */

   /* ('bcsel', 'a', ('ffmaz(is_used_once)', 'b', 'c', 'd'), ('ffmaz', 'b', 'c', 'e')) => ('ffmaz', 'b', 'c', ('bcsel', 'a', 'd', 'e')) */
   /* search2234_0 -> 513 in the cache */
   /* search2234_1_0 -> 82 in the cache */
   /* search2234_1_1 -> 84 in the cache */
   /* search2234_1_2 -> 356 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 1,
      { 82, 84, 356 },
      0,
   } },
   /* search2234_2_0 -> 82 in the cache */
   /* search2234_2_1 -> 84 in the cache */
   /* search2234_2_2 -> 364 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      1, 1,
      { 82, 84, 364 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 513, 568, 569 },
      -1,
   } },

   /* replace2234_0 -> 82 in the cache */
   /* replace2234_1 -> 84 in the cache */
   /* replace2234_2_0 -> 513 in the cache */
   /* replace2234_2_1 -> 356 in the cache */
   /* replace2234_2_2 -> 364 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 513, 356, 364 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 1,
      { 82, 84, 571 },
      -1,
   } },

   /* ('bcsel', 'a', ('ffmaz', 'b', 'c', 'd'), ('ffmaz(is_used_once)', 'b', 'c', 'e')) => ('ffmaz', 'b', 'c', ('bcsel', 'a', 'd', 'e')) */
   /* search2235_0 -> 513 in the cache */
   /* search2235_1_0 -> 82 in the cache */
   /* search2235_1_1 -> 84 in the cache */
   /* search2235_1_2 -> 356 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 1,
      { 82, 84, 356 },
      -1,
   } },
   /* search2235_2_0 -> 82 in the cache */
   /* search2235_2_1 -> 84 in the cache */
   /* search2235_2_2 -> 364 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      1, 1,
      { 82, 84, 364 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 513, 573, 574 },
      -1,
   } },

   /* replace2235_0 -> 82 in the cache */
   /* replace2235_1 -> 84 in the cache */
   /* replace2235_2_0 -> 513 in the cache */
   /* replace2235_2_1 -> 356 in the cache */
   /* replace2235_2_2 -> 364 in the cache */
   /* replace2235_2 -> 571 in the cache */
   /* replace2235 -> 572 in the cache */

   /* ('bcsel', 'a', ('ffmaz(is_used_once)', 'b', 'c', 'd'), ('ffmaz', 'b', 'e', 'd')) => ('ffmaz', 'b', ('bcsel', 'a', 'c', 'e'), 'd') */
   /* search2236_0 -> 513 in the cache */
   /* search2236_1_0 -> 82 in the cache */
   /* search2236_1_1 -> 84 in the cache */
   /* search2236_1_2 -> 356 in the cache */
   /* search2236_1 -> 568 in the cache */
   /* search2236_2_0 -> 82 in the cache */
   /* search2236_2_1 -> 364 in the cache */
   /* search2236_2_2 -> 356 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      1, 1,
      { 82, 364, 356 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 513, 568, 576 },
      -1,
   } },

   /* replace2236_0 -> 82 in the cache */
   /* replace2236_1_0 -> 513 in the cache */
   /* replace2236_1_1 -> 84 in the cache */
   /* replace2236_1_2 -> 364 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 513, 84, 364 },
      -1,
   } },
   /* replace2236_2 -> 356 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      0, 1,
      { 82, 578, 356 },
      -1,
   } },

   /* ('bcsel', 'a', ('ffmaz', 'b', 'c', 'd'), ('ffmaz(is_used_once)', 'b', 'e', 'd')) => ('ffmaz', 'b', ('bcsel', 'a', 'c', 'e'), 'd') */
   /* search2237_0 -> 513 in the cache */
   /* search2237_1_0 -> 82 in the cache */
   /* search2237_1_1 -> 84 in the cache */
   /* search2237_1_2 -> 356 in the cache */
   /* search2237_1 -> 573 in the cache */
   /* search2237_2_0 -> 82 in the cache */
   /* search2237_2_1 -> 364 in the cache */
   /* search2237_2_2 -> 356 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffmaz,
      1, 1,
      { 82, 364, 356 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 2,
      { 513, 573, 580 },
      -1,
   } },

   /* replace2237_0 -> 82 in the cache */
   /* replace2237_1_0 -> 513 in the cache */
   /* replace2237_1_1 -> 84 in the cache */
   /* replace2237_1_2 -> 364 in the cache */
   /* replace2237_1 -> 578 in the cache */
   /* replace2237_2 -> 356 in the cache */
   /* replace2237 -> 579 in the cache */

   /* ('~f2f32', ('fabs', ('f2fmp', 'a'))) => ('fabs', 'a') */
   /* search2238_0_0_0 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2fmp,
      -1, 0,
      { 81 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 582 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 583 },
      -1,
   } },

   /* replace2238_0 -> 81 in the cache */
   /* replace2238 -> 93 in the cache */

   /* ('~f2f32', ('fceil', ('f2fmp', 'a'))) => ('fceil', 'a') */
   /* search2239_0_0_0 -> 81 in the cache */
   /* search2239_0_0 -> 582 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fceil,
      -1, 0,
      { 582 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 585 },
      -1,
   } },

   /* replace2239_0 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fceil,
      -1, 0,
      { 81 },
      -1,
   } },

   /* ('~f2f32', ('fcos', ('f2fmp', 'a'))) => ('fcos', 'a') */
   /* search2240_0_0_0 -> 81 in the cache */
   /* search2240_0_0 -> 582 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fcos,
      -1, 0,
      { 582 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 588 },
      -1,
   } },

   /* replace2240_0 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fcos,
      -1, 0,
      { 81 },
      -1,
   } },

   /* ('~f2f32', ('fddx', ('f2fmp', 'a'))) => ('fddx', 'a') */
   /* search2241_0_0_0 -> 81 in the cache */
   /* search2241_0_0 -> 582 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fddx,
      -1, 0,
      { 582 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 591 },
      -1,
   } },

   /* replace2241_0 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fddx,
      -1, 0,
      { 81 },
      -1,
   } },

   /* ('~f2f32', ('fddx_coarse', ('f2fmp', 'a'))) => ('fddx_coarse', 'a') */
   /* search2242_0_0_0 -> 81 in the cache */
   /* search2242_0_0 -> 582 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fddx_coarse,
      -1, 0,
      { 582 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 594 },
      -1,
   } },

   /* replace2242_0 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fddx_coarse,
      -1, 0,
      { 81 },
      -1,
   } },

   /* ('~f2f32', ('fddx_fine', ('f2fmp', 'a'))) => ('fddx_fine', 'a') */
   /* search2243_0_0_0 -> 81 in the cache */
   /* search2243_0_0 -> 582 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fddx_fine,
      -1, 0,
      { 582 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 597 },
      -1,
   } },

   /* replace2243_0 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fddx_fine,
      -1, 0,
      { 81 },
      -1,
   } },

   /* ('~f2f32', ('fddy', ('f2fmp', 'a'))) => ('fddy', 'a') */
   /* search2244_0_0_0 -> 81 in the cache */
   /* search2244_0_0 -> 582 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fddy,
      -1, 0,
      { 582 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 600 },
      -1,
   } },

   /* replace2244_0 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fddy,
      -1, 0,
      { 81 },
      -1,
   } },

   /* ('~f2f32', ('fddy_coarse', ('f2fmp', 'a'))) => ('fddy_coarse', 'a') */
   /* search2245_0_0_0 -> 81 in the cache */
   /* search2245_0_0 -> 582 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fddy_coarse,
      -1, 0,
      { 582 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 603 },
      -1,
   } },

   /* replace2245_0 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fddy_coarse,
      -1, 0,
      { 81 },
      -1,
   } },

   /* ('~f2f32', ('fddy_fine', ('f2fmp', 'a'))) => ('fddy_fine', 'a') */
   /* search2246_0_0_0 -> 81 in the cache */
   /* search2246_0_0 -> 582 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fddy_fine,
      -1, 0,
      { 582 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 606 },
      -1,
   } },

   /* replace2246_0 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fddy_fine,
      -1, 0,
      { 81 },
      -1,
   } },

   /* ('~f2f32', ('fexp2', ('f2fmp', 'a'))) => ('fexp2', 'a') */
   /* search2247_0_0_0 -> 81 in the cache */
   /* search2247_0_0 -> 582 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fexp2,
      -1, 0,
      { 582 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 609 },
      -1,
   } },

   /* replace2247_0 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fexp2,
      -1, 0,
      { 81 },
      -1,
   } },

   /* ('~f2f32', ('ffloor', ('f2fmp', 'a'))) => ('ffloor', 'a') */
   /* search2248_0_0_0 -> 81 in the cache */
   /* search2248_0_0 -> 582 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ffloor,
      -1, 0,
      { 582 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 612 },
      -1,
   } },

   /* replace2248_0 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffloor,
      -1, 0,
      { 81 },
      -1,
   } },

   /* ('~f2f32', ('ffract', ('f2fmp', 'a'))) => ('ffract', 'a') */
   /* search2249_0_0_0 -> 81 in the cache */
   /* search2249_0_0 -> 582 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 0,
      { 582 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 615 },
      -1,
   } },

   /* replace2249_0 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_ffract,
      -1, 0,
      { 81 },
      -1,
   } },

   /* ('~f2f32', ('flog2', ('f2fmp', 'a'))) => ('flog2', 'a') */
   /* search2250_0_0_0 -> 81 in the cache */
   /* search2250_0_0 -> 582 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_flog2,
      -1, 0,
      { 582 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 618 },
      -1,
   } },

   /* replace2250_0 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_flog2,
      -1, 0,
      { 81 },
      -1,
   } },

   /* ('~f2f32', ('fneg', ('f2fmp', 'a'))) => ('fneg', 'a') */
   /* search2251_0_0_0 -> 81 in the cache */
   /* search2251_0_0 -> 582 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 582 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 621 },
      -1,
   } },

   /* replace2251_0 -> 81 in the cache */
   /* replace2251 -> 89 in the cache */

   /* ('~f2f32', ('frcp', ('f2fmp', 'a'))) => ('frcp', 'a') */
   /* search2252_0_0_0 -> 81 in the cache */
   /* search2252_0_0 -> 582 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_frcp,
      -1, 0,
      { 582 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 623 },
      -1,
   } },

   /* replace2252_0 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_frcp,
      -1, 0,
      { 81 },
      -1,
   } },

   /* ('~f2f32', ('fround_even', ('f2fmp', 'a'))) => ('fround_even', 'a') */
   /* search2253_0_0_0 -> 81 in the cache */
   /* search2253_0_0 -> 582 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fround_even,
      -1, 0,
      { 582 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 626 },
      -1,
   } },

   /* replace2253_0 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fround_even,
      -1, 0,
      { 81 },
      -1,
   } },

   /* ('~f2f32', ('frsq', ('f2fmp', 'a'))) => ('frsq', 'a') */
   /* search2254_0_0_0 -> 81 in the cache */
   /* search2254_0_0 -> 582 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_frsq,
      -1, 0,
      { 582 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 629 },
      -1,
   } },

   /* replace2254_0 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_frsq,
      -1, 0,
      { 81 },
      -1,
   } },

   /* ('~f2f32', ('fsat', ('f2fmp', 'a'))) => ('fsat', 'a') */
   /* search2255_0_0_0 -> 81 in the cache */
   /* search2255_0_0 -> 582 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 582 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 632 },
      -1,
   } },

   /* replace2255_0 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fsat,
      -1, 0,
      { 81 },
      -1,
   } },

   /* ('~f2f32', ('fsign', ('f2fmp', 'a'))) => ('fsign', 'a') */
   /* search2256_0_0_0 -> 81 in the cache */
   /* search2256_0_0 -> 582 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fsign,
      -1, 0,
      { 582 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 635 },
      -1,
   } },

   /* replace2256_0 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fsign,
      -1, 0,
      { 81 },
      -1,
   } },

   /* ('~f2f32', ('fsin', ('f2fmp', 'a'))) => ('fsin', 'a') */
   /* search2257_0_0_0 -> 81 in the cache */
   /* search2257_0_0 -> 582 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fsin,
      -1, 0,
      { 582 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 638 },
      -1,
   } },

   /* replace2257_0 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fsin,
      -1, 0,
      { 81 },
      -1,
   } },

   /* ('~f2f32', ('fsqrt', ('f2fmp', 'a'))) => ('fsqrt', 'a') */
   /* search2258_0_0_0 -> 81 in the cache */
   /* search2258_0_0 -> 582 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fsqrt,
      -1, 0,
      { 582 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 641 },
      -1,
   } },

   /* replace2258_0 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fsqrt,
      -1, 0,
      { 81 },
      -1,
   } },

   /* ('~f2f32', ('fadd', ('f2fmp', 'a'), ('f2fmp', 'b'))) => ('fadd', 'a', 'b') */
   /* search2259_0_0_0 -> 81 in the cache */
   /* search2259_0_0 -> 582 in the cache */
   /* search2259_0_1_0 -> 82 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2fmp,
      -1, 0,
      { 82 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 582, 644 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 1,
      { 645 },
      -1,
   } },

   /* replace2259_0 -> 81 in the cache */
   /* replace2259_1 -> 82 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 81, 82 },
      -1,
   } },

   /* ('~f2f32', ('fdiv', ('f2fmp', 'a'), ('f2fmp', 'b'))) => ('fdiv', 'a', 'b') */
   /* search2260_0_0_0 -> 81 in the cache */
   /* search2260_0_0 -> 582 in the cache */
   /* search2260_0_1_0 -> 82 in the cache */
   /* search2260_0_1 -> 644 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fdiv,
      -1, 0,
      { 582, 644 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 648 },
      -1,
   } },

   /* replace2260_0 -> 81 in the cache */
   /* replace2260_1 -> 82 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fdiv,
      -1, 0,
      { 81, 82 },
      -1,
   } },

   /* ('~f2f32', ('fmax', ('f2fmp', 'a'), ('f2fmp', 'b'))) => ('fmax', 'a', 'b') */
   /* search2261_0_0_0 -> 81 in the cache */
   /* search2261_0_0 -> 582 in the cache */
   /* search2261_0_1_0 -> 82 in the cache */
   /* search2261_0_1 -> 644 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 582, 644 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 1,
      { 651 },
      -1,
   } },

   /* replace2261_0 -> 81 in the cache */
   /* replace2261_1 -> 82 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 81, 82 },
      -1,
   } },

   /* ('~f2f32', ('fmin', ('f2fmp', 'a'), ('f2fmp', 'b'))) => ('fmin', 'a', 'b') */
   /* search2262_0_0_0 -> 81 in the cache */
   /* search2262_0_0 -> 582 in the cache */
   /* search2262_0_1_0 -> 82 in the cache */
   /* search2262_0_1 -> 644 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 582, 644 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 1,
      { 654 },
      -1,
   } },

   /* replace2262_0 -> 81 in the cache */
   /* replace2262_1 -> 82 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 81, 82 },
      -1,
   } },

   /* ('~f2f32', ('fmod', ('f2fmp', 'a'), ('f2fmp', 'b'))) => ('fmod', 'a', 'b') */
   /* search2263_0_0_0 -> 81 in the cache */
   /* search2263_0_0 -> 582 in the cache */
   /* search2263_0_1_0 -> 82 in the cache */
   /* search2263_0_1 -> 644 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmod,
      -1, 0,
      { 582, 644 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 657 },
      -1,
   } },

   /* replace2263_0 -> 81 in the cache */
   /* replace2263_1 -> 82 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmod,
      -1, 0,
      { 81, 82 },
      -1,
   } },

   /* ('~f2f32', ('fmul', ('f2fmp', 'a'), ('f2fmp', 'b'))) => ('fmul', 'a', 'b') */
   /* search2264_0_0_0 -> 81 in the cache */
   /* search2264_0_0 -> 582 in the cache */
   /* search2264_0_1_0 -> 82 in the cache */
   /* search2264_0_1 -> 644 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 582, 644 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 1,
      { 660 },
      -1,
   } },

   /* replace2264_0 -> 81 in the cache */
   /* replace2264_1 -> 82 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 81, 82 },
      -1,
   } },

   /* ('~f2f32', ('fpow', ('f2fmp', 'a'), ('f2fmp', 'b'))) => ('fpow', 'a', 'b') */
   /* search2265_0_0_0 -> 81 in the cache */
   /* search2265_0_0 -> 582 in the cache */
   /* search2265_0_1_0 -> 82 in the cache */
   /* search2265_0_1 -> 644 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 582, 644 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 663 },
      -1,
   } },

   /* replace2265_0 -> 81 in the cache */
   /* replace2265_1 -> 82 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fpow,
      -1, 0,
      { 81, 82 },
      -1,
   } },

   /* ('~f2f32', ('frem', ('f2fmp', 'a'), ('f2fmp', 'b'))) => ('frem', 'a', 'b') */
   /* search2266_0_0_0 -> 81 in the cache */
   /* search2266_0_0 -> 582 in the cache */
   /* search2266_0_1_0 -> 82 in the cache */
   /* search2266_0_1 -> 644 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_frem,
      -1, 0,
      { 582, 644 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 666 },
      -1,
   } },

   /* replace2266_0 -> 81 in the cache */
   /* replace2266_1 -> 82 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_frem,
      -1, 0,
      { 81, 82 },
      -1,
   } },

   /* ('~f2f32', ('ffma', ('f2fmp', 'a'), ('f2fmp', 'b'), ('f2fmp', 'c'))) => ('ffma', 'a', 'b', 'c') */
   /* search2267_0_0_0 -> 81 in the cache */
   /* search2267_0_0 -> 582 in the cache */
   /* search2267_0_1_0 -> 82 in the cache */
   /* search2267_0_1 -> 644 in the cache */
   /* search2267_0_2_0 -> 84 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2fmp,
      -1, 0,
      { 84 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 582, 644, 669 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 1,
      { 670 },
      -1,
   } },

   /* replace2267_0 -> 81 in the cache */
   /* replace2267_1 -> 82 in the cache */
   /* replace2267_2 -> 84 in the cache */
   /* replace2267 -> 86 in the cache */

   /* ('~f2f32', ('flrp', ('f2fmp', 'a'), ('f2fmp', 'b'), ('f2fmp', 'c'))) => ('flrp', 'a', 'b', 'c') */
   /* search2268_0_0_0 -> 81 in the cache */
   /* search2268_0_0 -> 582 in the cache */
   /* search2268_0_1_0 -> 82 in the cache */
   /* search2268_0_1 -> 644 in the cache */
   /* search2268_0_2_0 -> 84 in the cache */
   /* search2268_0_2 -> 669 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 582, 644, 669 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, 32 },
      true,
      false,
      false,
      nir_op_f2f32,
      -1, 0,
      { 672 },
      -1,
   } },

   /* replace2268_0 -> 81 in the cache */
   /* replace2268_1 -> 82 in the cache */
   /* replace2268_2 -> 84 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 81, 82, 84 },
      -1,
   } },

   /* ('~feq', ('f2fmp', 'a'), ('f2fmp', 'b')) => ('feq', 'a', 'b') */
   /* search2269_0_0 -> 81 in the cache */
   /* search2269_0 -> 582 in the cache */
   /* search2269_1_0 -> 82 in the cache */
   /* search2269_1 -> 644 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 582, 644 },
      -1,
   } },

   /* replace2269_0 -> 81 in the cache */
   /* replace2269_1 -> 82 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_feq,
      0, 1,
      { 81, 82 },
      -1,
   } },

   /* ('~fge', ('f2fmp', 'a'), ('f2fmp', 'b')) => ('fge', 'a', 'b') */
   /* search2270_0_0 -> 81 in the cache */
   /* search2270_0 -> 582 in the cache */
   /* search2270_1_0 -> 82 in the cache */
   /* search2270_1 -> 644 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 582, 644 },
      -1,
   } },

   /* replace2270_0 -> 81 in the cache */
   /* replace2270_1 -> 82 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 81, 82 },
      -1,
   } },

   /* ('~flt', ('f2fmp', 'a'), ('f2fmp', 'b')) => ('flt', 'a', 'b') */
   /* search2271_0_0 -> 81 in the cache */
   /* search2271_0 -> 582 in the cache */
   /* search2271_1_0 -> 82 in the cache */
   /* search2271_1 -> 644 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 582, 644 },
      -1,
   } },

   /* replace2271_0 -> 81 in the cache */
   /* replace2271_1 -> 82 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 81, 82 },
      -1,
   } },

   /* ('~fneu', ('f2fmp', 'a'), ('f2fmp', 'b')) => ('fneu', 'a', 'b') */
   /* search2272_0_0 -> 81 in the cache */
   /* search2272_0 -> 582 in the cache */
   /* search2272_1_0 -> 82 in the cache */
   /* search2272_1 -> 644 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      true,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 582, 644 },
      -1,
   } },

   /* replace2272_0 -> 81 in the cache */
   /* replace2272_1 -> 82 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fneu,
      0, 1,
      { 81, 82 },
      -1,
   } },

   /* ('f2fmp', 'a') => ('f2f16', 'a') */
   /* search2273_0 -> 81 in the cache */
   /* search2273 -> 582 in the cache */

   /* replace2273_0 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2f16,
      -1, 0,
      { 81 },
      -1,
   } },

   /* ('f2imp', 'a') => ('f2i16', 'a') */
   /* search2274_0 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2imp,
      -1, 0,
      { 81 },
      -1,
   } },

   /* replace2274_0 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2i16,
      -1, 0,
      { 81 },
      -1,
   } },

   /* ('f2ump', 'a') => ('f2u16', 'a') */
   /* search2275_0 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2ump,
      -1, 0,
      { 81 },
      -1,
   } },

   /* replace2275_0 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_f2u16,
      -1, 0,
      { 81 },
      -1,
   } },

   /* ('i2imp', 'a') => ('i2i16', 'a') */
   /* search2276_0 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2imp,
      -1, 0,
      { 81 },
      -1,
   } },

   /* replace2276_0 -> 81 in the cache */
   /* replace2276 -> 431 in the cache */

   /* ('i2fmp', 'a') => ('i2f16', 'a') */
   /* search2277_0 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2fmp,
      -1, 0,
      { 81 },
      -1,
   } },

   /* replace2277_0 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_i2f16,
      -1, 0,
      { 81 },
      -1,
   } },

   /* ('i2imp', 'a') => ('u2u16', 'a') */
   /* search2278_0 -> 81 in the cache */
   /* search2278 -> 688 in the cache */

   /* replace2278_0 -> 81 in the cache */
   /* replace2278 -> 428 in the cache */

   /* ('u2fmp', 'a') => ('u2f16', 'a') */
   /* search2279_0 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2fmp,
      -1, 0,
      { 81 },
      -1,
   } },

   /* replace2279_0 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 16 },
      false,
      false,
      false,
      nir_op_u2f16,
      -1, 0,
      { 81 },
      -1,
   } },

   /* ('fisfinite', 'a') => ('flt', ('fabs', 'a'), inf) */
   /* search2280_0 -> 42 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fisfinite,
      -1, 0,
      { 42 },
      -1,
   } },

   /* replace2280_0_0 -> 42 in the cache */
   /* replace2280_0 -> 47 in the cache */
   { .constant = {
      { nir_search_value_constant, -1 },
      nir_type_float, { 0x7ff0000000000000 /* inf */ },
   } },
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 47, 694 },
      -1,
   } },

   /* ('fcsel', ('slt', 0, 'a'), 'b', 'c') => ('fcsel_gt', 'a', 'b', 'c') */
   /* search2281_0_0 -> 385 in the cache */
   /* search2281_0_1 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_slt,
      -1, 0,
      { 385, 81 },
      -1,
   } },
   /* search2281_1 -> 82 in the cache */
   /* search2281_2 -> 84 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fcsel,
      -1, 0,
      { 696, 82, 84 },
      -1,
   } },

   /* replace2281_0 -> 81 in the cache */
   /* replace2281_1 -> 82 in the cache */
   /* replace2281_2 -> 84 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fcsel_gt,
      -1, 0,
      { 81, 82, 84 },
      -1,
   } },

   /* ('fcsel', ('slt', 'a', 0), 'b', 'c') => ('fcsel_gt', ('fneg', 'a'), 'b', 'c') */
   /* search2282_0_0 -> 81 in the cache */
   /* search2282_0_1 -> 385 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_slt,
      -1, 0,
      { 81, 385 },
      -1,
   } },
   /* search2282_1 -> 82 in the cache */
   /* search2282_2 -> 84 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fcsel,
      -1, 0,
      { 699, 82, 84 },
      -1,
   } },

   /* replace2282_0_0 -> 81 in the cache */
   /* replace2282_0 -> 89 in the cache */
   /* replace2282_1 -> 82 in the cache */
   /* replace2282_2 -> 84 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fcsel_gt,
      -1, 0,
      { 89, 82, 84 },
      -1,
   } },

   /* ('fcsel', ('sge', 'a', 0), 'b', 'c') => ('fcsel_ge', 'a', 'b', 'c') */
   /* search2283_0_0 -> 81 in the cache */
   /* search2283_0_1 -> 385 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sge,
      -1, 0,
      { 81, 385 },
      -1,
   } },
   /* search2283_1 -> 82 in the cache */
   /* search2283_2 -> 84 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fcsel,
      -1, 0,
      { 702, 82, 84 },
      -1,
   } },

   /* replace2283_0 -> 81 in the cache */
   /* replace2283_1 -> 82 in the cache */
   /* replace2283_2 -> 84 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fcsel_ge,
      -1, 0,
      { 81, 82, 84 },
      -1,
   } },

   /* ('fcsel', ('sge', 0, 'a'), 'b', 'c') => ('fcsel_ge', ('fneg', 'a'), 'b', 'c') */
   /* search2284_0_0 -> 385 in the cache */
   /* search2284_0_1 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_sge,
      -1, 0,
      { 385, 81 },
      -1,
   } },
   /* search2284_1 -> 82 in the cache */
   /* search2284_2 -> 84 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fcsel,
      -1, 0,
      { 705, 82, 84 },
      -1,
   } },

   /* replace2284_0_0 -> 81 in the cache */
   /* replace2284_0 -> 89 in the cache */
   /* replace2284_1 -> 82 in the cache */
   /* replace2284_2 -> 84 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_fcsel_ge,
      -1, 0,
      { 89, 82, 84 },
      -1,
   } },

   /* ('bcsel', ('ilt', 0, 'a@32'), 'b@32', 'c@32') => ('i32csel_gt', 'a', 'b', 'c') */
   /* search2285_0_0 -> 385 in the cache */
   /* search2285_0_1 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 385, 81 },
      -1,
   } },
   /* search2285_1 -> 82 in the cache */
   /* search2285_2 -> 84 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 708, 82, 84 },
      -1,
   } },

   /* replace2285_0 -> 81 in the cache */
   /* replace2285_1 -> 82 in the cache */
   /* replace2285_2 -> 84 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i32csel_gt,
      -1, 0,
      { 81, 82, 84 },
      -1,
   } },

   /* ('bcsel', ('ilt', 'a@32', 0), 'b@32', 'c@32') => ('i32csel_ge', 'a', 'c', 'b') */
   /* search2286_0_0 -> 81 in the cache */
   /* search2286_0_1 -> 385 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ilt,
      -1, 0,
      { 81, 385 },
      -1,
   } },
   /* search2286_1 -> 82 in the cache */
   /* search2286_2 -> 84 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 711, 82, 84 },
      -1,
   } },

   /* replace2286_0 -> 81 in the cache */
   /* replace2286_1 -> 84 in the cache */
   /* replace2286_2 -> 82 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i32csel_ge,
      -1, 0,
      { 81, 84, 82 },
      -1,
   } },

   /* ('bcsel', ('ige', 'a@32', 0), 'b@32', 'c@32') => ('i32csel_ge', 'a', 'b', 'c') */
   /* search2287_0_0 -> 81 in the cache */
   /* search2287_0_1 -> 385 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 81, 385 },
      -1,
   } },
   /* search2287_1 -> 82 in the cache */
   /* search2287_2 -> 84 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 714, 82, 84 },
      -1,
   } },

   /* replace2287_0 -> 81 in the cache */
   /* replace2287_1 -> 82 in the cache */
   /* replace2287_2 -> 84 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i32csel_ge,
      -1, 0,
      { 81, 82, 84 },
      -1,
   } },

   /* ('bcsel', ('ige', 0, 'a@32'), 'b@32', 'c@32') => ('i32csel_gt', 'a', 'c', 'b') */
   /* search2288_0_0 -> 385 in the cache */
   /* search2288_0_1 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_ige,
      -1, 0,
      { 385, 81 },
      -1,
   } },
   /* search2288_1 -> 82 in the cache */
   /* search2288_2 -> 84 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 717, 82, 84 },
      -1,
   } },

   /* replace2288_0 -> 81 in the cache */
   /* replace2288_1 -> 84 in the cache */
   /* replace2288_2 -> 82 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_i32csel_gt,
      -1, 0,
      { 81, 84, 82 },
      -1,
   } },

   /* ('bcsel', ('flt', 0, 'a@32'), 'b@32', 'c@32') => ('fcsel_gt', 'a', 'b', 'c') */
   /* search2289_0_0 -> 385 in the cache */
   /* search2289_0_1 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 385, 81 },
      -1,
   } },
   /* search2289_1 -> 82 in the cache */
   /* search2289_2 -> 84 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 720, 82, 84 },
      -1,
   } },

   /* replace2289_0 -> 81 in the cache */
   /* replace2289_1 -> 82 in the cache */
   /* replace2289_2 -> 84 in the cache */
   /* replace2289 -> 698 in the cache */

   /* ('bcsel', ('flt', 'a@32', 0), 'b@32', 'c@32') => ('fcsel_gt', ('fneg', 'a'), 'b', 'c') */
   /* search2290_0_0 -> 81 in the cache */
   /* search2290_0_1 -> 385 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_flt,
      -1, 0,
      { 81, 385 },
      -1,
   } },
   /* search2290_1 -> 82 in the cache */
   /* search2290_2 -> 84 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 722, 82, 84 },
      -1,
   } },

   /* replace2290_0_0 -> 81 in the cache */
   /* replace2290_0 -> 89 in the cache */
   /* replace2290_1 -> 82 in the cache */
   /* replace2290_2 -> 84 in the cache */
   /* replace2290 -> 701 in the cache */

   /* ('bcsel', ('fge', 'a@32', 0), 'b@32', 'c@32') => ('fcsel_ge', 'a', 'b', 'c') */
   /* search2291_0_0 -> 81 in the cache */
   /* search2291_0_1 -> 385 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 81, 385 },
      -1,
   } },
   /* search2291_1 -> 82 in the cache */
   /* search2291_2 -> 84 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 724, 82, 84 },
      -1,
   } },

   /* replace2291_0 -> 81 in the cache */
   /* replace2291_1 -> 82 in the cache */
   /* replace2291_2 -> 84 in the cache */
   /* replace2291 -> 704 in the cache */

   /* ('bcsel', ('fge', 0, 'a@32'), 'b@32', 'c@32') => ('fcsel_ge', ('fneg', 'a'), 'b', 'c') */
   /* search2292_0_0 -> 385 in the cache */
   /* search2292_0_1 -> 81 in the cache */
   { .expression = {
      { nir_search_value_expression, 1 },
      false,
      false,
      false,
      nir_op_fge,
      -1, 0,
      { 385, 81 },
      -1,
   } },
   /* search2292_1 -> 82 in the cache */
   /* search2292_2 -> 84 in the cache */
   { .expression = {
      { nir_search_value_expression, 32 },
      false,
      false,
      false,
      nir_op_bcsel,
      -1, 0,
      { 726, 82, 84 },
      -1,
   } },

   /* replace2292_0_0 -> 81 in the cache */
   /* replace2292_0 -> 89 in the cache */
   /* replace2292_1 -> 82 in the cache */
   /* replace2292_2 -> 84 in the cache */
   /* replace2292 -> 707 in the cache */

};

static const nir_search_expression_cond nir_opt_algebraic_late_expression_cond[] = {
   (is_used_once),
   (is_only_used_by_fadd),
   (is_only_used_as_float),
};

static const nir_search_variable_cond nir_opt_algebraic_late_variable_cond[] = {
   (is_finite),
   (is_not_const),
   (is_gt_0_and_lt_1),
   (is_not_fmul),
   (is_not_negative),
   (is_not_const_and_not_fsign),
};

static const struct transform nir_opt_algebraic_late_transforms[] = {
   { ~0, ~0, ~0 }, /* Sentinel */

   { 59, 149, 124 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 235, 42, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 234, 42, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 153, 155, 126 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 156, 157, 127 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 242, 243, 130 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 244, 245, 130 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 246, 247, 130 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 248, 249, 130 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 255, 264, 131 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 267, 269, 17 },
   { 271, 272, 17 },
   { 273, 274, 17 },
   { 275, 276, 17 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 386, 385, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 386, 385, 0 },
   { 390, 395, 133 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 387, 385, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 387, 385, 0 },
   { 396, 400, 133 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 401, 42, 0 },
   { 403, 42, 0 },
   { 457, 450, 134 },
   { 454, 460, 135 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 404, 42, 0 },
   { 405, 42, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 406, 42, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 582, 683, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 684, 685, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 686, 687, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 688, 431, 0 },
   { 688, 428, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 689, 690, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 691, 692, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 693, 695, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 548, 550, 0 },
   { 553, 550, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 556, 558, 0 },
   { 561, 558, 0 },
   { 563, 565, 0 },
   { 567, 565, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 570, 572, 0 },
   { 575, 572, 0 },
   { 577, 579, 0 },
   { 581, 579, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 723, 701, 136 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 548, 550, 0 },
   { 553, 550, 0 },
   { 723, 701, 136 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 556, 558, 0 },
   { 561, 558, 0 },
   { 563, 565, 0 },
   { 567, 565, 0 },
   { 723, 701, 136 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 570, 572, 0 },
   { 575, 572, 0 },
   { 577, 579, 0 },
   { 581, 579, 0 },
   { 723, 701, 136 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 721, 698, 136 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 548, 550, 0 },
   { 553, 550, 0 },
   { 721, 698, 136 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 556, 558, 0 },
   { 561, 558, 0 },
   { 563, 565, 0 },
   { 567, 565, 0 },
   { 721, 698, 136 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 570, 572, 0 },
   { 575, 572, 0 },
   { 577, 579, 0 },
   { 581, 579, 0 },
   { 721, 698, 136 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 721, 698, 136 },
   { 723, 701, 136 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 548, 550, 0 },
   { 553, 550, 0 },
   { 721, 698, 136 },
   { 723, 701, 136 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 556, 558, 0 },
   { 561, 558, 0 },
   { 563, 565, 0 },
   { 567, 565, 0 },
   { 721, 698, 136 },
   { 723, 701, 136 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 570, 572, 0 },
   { 575, 572, 0 },
   { 577, 579, 0 },
   { 581, 579, 0 },
   { 721, 698, 136 },
   { 723, 701, 136 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 725, 704, 136 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 548, 550, 0 },
   { 553, 550, 0 },
   { 725, 704, 136 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 556, 558, 0 },
   { 561, 558, 0 },
   { 563, 565, 0 },
   { 567, 565, 0 },
   { 725, 704, 136 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 570, 572, 0 },
   { 575, 572, 0 },
   { 577, 579, 0 },
   { 581, 579, 0 },
   { 725, 704, 136 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 727, 707, 136 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 548, 550, 0 },
   { 553, 550, 0 },
   { 727, 707, 136 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 556, 558, 0 },
   { 561, 558, 0 },
   { 563, 565, 0 },
   { 567, 565, 0 },
   { 727, 707, 136 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 570, 572, 0 },
   { 575, 572, 0 },
   { 577, 579, 0 },
   { 581, 579, 0 },
   { 727, 707, 136 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 725, 704, 136 },
   { 727, 707, 136 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 548, 550, 0 },
   { 553, 550, 0 },
   { 725, 704, 136 },
   { 727, 707, 136 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 556, 558, 0 },
   { 561, 558, 0 },
   { 563, 565, 0 },
   { 567, 565, 0 },
   { 725, 704, 136 },
   { 727, 707, 136 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 570, 572, 0 },
   { 575, 572, 0 },
   { 577, 579, 0 },
   { 581, 579, 0 },
   { 725, 704, 136 },
   { 727, 707, 136 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 712, 713, 136 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 548, 550, 0 },
   { 553, 550, 0 },
   { 712, 713, 136 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 556, 558, 0 },
   { 561, 558, 0 },
   { 563, 565, 0 },
   { 567, 565, 0 },
   { 712, 713, 136 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 570, 572, 0 },
   { 575, 572, 0 },
   { 577, 579, 0 },
   { 581, 579, 0 },
   { 712, 713, 136 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 709, 710, 136 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 548, 550, 0 },
   { 553, 550, 0 },
   { 709, 710, 136 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 556, 558, 0 },
   { 561, 558, 0 },
   { 563, 565, 0 },
   { 567, 565, 0 },
   { 709, 710, 136 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 570, 572, 0 },
   { 575, 572, 0 },
   { 577, 579, 0 },
   { 581, 579, 0 },
   { 709, 710, 136 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 709, 710, 136 },
   { 712, 713, 136 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 548, 550, 0 },
   { 553, 550, 0 },
   { 709, 710, 136 },
   { 712, 713, 136 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 556, 558, 0 },
   { 561, 558, 0 },
   { 563, 565, 0 },
   { 567, 565, 0 },
   { 709, 710, 136 },
   { 712, 713, 136 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 570, 572, 0 },
   { 575, 572, 0 },
   { 577, 579, 0 },
   { 581, 579, 0 },
   { 709, 710, 136 },
   { 712, 713, 136 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 715, 716, 136 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 548, 550, 0 },
   { 553, 550, 0 },
   { 715, 716, 136 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 556, 558, 0 },
   { 561, 558, 0 },
   { 563, 565, 0 },
   { 567, 565, 0 },
   { 715, 716, 136 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 570, 572, 0 },
   { 575, 572, 0 },
   { 577, 579, 0 },
   { 581, 579, 0 },
   { 715, 716, 136 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 718, 719, 136 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 548, 550, 0 },
   { 553, 550, 0 },
   { 718, 719, 136 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 556, 558, 0 },
   { 561, 558, 0 },
   { 563, 565, 0 },
   { 567, 565, 0 },
   { 718, 719, 136 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 570, 572, 0 },
   { 575, 572, 0 },
   { 577, 579, 0 },
   { 581, 579, 0 },
   { 718, 719, 136 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 715, 716, 136 },
   { 718, 719, 136 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 548, 550, 0 },
   { 553, 550, 0 },
   { 715, 716, 136 },
   { 718, 719, 136 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 556, 558, 0 },
   { 561, 558, 0 },
   { 563, 565, 0 },
   { 567, 565, 0 },
   { 715, 716, 136 },
   { 718, 719, 136 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 570, 572, 0 },
   { 575, 572, 0 },
   { 577, 579, 0 },
   { 581, 579, 0 },
   { 715, 716, 136 },
   { 718, 719, 136 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 11, 10, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 225, 226, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 186, 188, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4, 6, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 223, 224, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 215, 216, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 679, 680, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 59, 149, 124 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 60, 42, 0 },
   { 59, 149, 124 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 59, 149, 124 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 59, 149, 124 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 59, 149, 124 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 59, 149, 124 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 17, 16, 0 },
   { 29, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 229, 200, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 13, 14, 0 },
   { 26, 14, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 227, 228, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 217, 218, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 191, 192, 0 },
   { 199, 200, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 677, 678, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 20, 21, 0 },
   { 32, 21, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 232, 233, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 193, 194, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 219, 220, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 675, 676, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 22, 23, 0 },
   { 33, 23, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 230, 231, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 195, 196, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 221, 222, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 681, 682, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 304, 307, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 252, 254, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 308, 310, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 137, 138, 122 },
   { 140, 141, 122 },
   { 143, 144, 122 },
   { 146, 147, 123 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 65, 66, 32 },
   { 85, 86, 33 },
   { 118, 119, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 102, 103, 33 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 137, 138, 122 },
   { 140, 141, 122 },
   { 143, 144, 122 },
   { 146, 147, 123 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 65, 66, 32 },
   { 85, 86, 33 },
   { 118, 119, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 65, 66, 32 },
   { 85, 86, 33 },
   { 118, 119, 34 },
   { 278, 269, 17 },
   { 280, 272, 17 },
   { 281, 274, 17 },
   { 282, 276, 17 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 102, 103, 33 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 65, 66, 32 },
   { 85, 86, 33 },
   { 118, 119, 34 },
   { 137, 138, 122 },
   { 140, 141, 122 },
   { 143, 144, 122 },
   { 146, 147, 123 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 102, 103, 33 },
   { 137, 138, 122 },
   { 140, 141, 122 },
   { 143, 144, 122 },
   { 146, 147, 123 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 65, 66, 32 },
   { 85, 86, 33 },
   { 102, 103, 33 },
   { 118, 119, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 180, 182, 129 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 174, 179, 129 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 174, 179, 129 },
   { 180, 182, 129 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 296, 292, 17 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 235, 42, 0 },
   { 453, 442, 134 },
   { 456, 446, 134 },
   { 459, 450, 134 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 235, 42, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 46, 48, 0 },
   { 235, 42, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 235, 42, 0 },
   { 470, 472, 0 },
   { 479, 481, 0 },
   { 488, 490, 0 },
   { 498, 500, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 57, 58, 0 },
   { 234, 42, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 234, 42, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 234, 42, 0 },
   { 475, 476, 0 },
   { 484, 485, 0 },
   { 493, 494, 0 },
   { 503, 504, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 162, 166, 128 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 151, 152, 125 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 168, 170, 128 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 151, 152, 125 },
   { 162, 166, 128 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 162, 166, 128 },
   { 168, 170, 128 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 151, 152, 125 },
   { 168, 170, 128 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 171, 173, 128 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 409, 407, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 411, 407, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 412, 410, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 413, 410, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 401, 42, 0 },
   { 403, 42, 0 },
   { 440, 442, 134 },
   { 444, 446, 134 },
   { 448, 450, 134 },
   { 457, 450, 134 },
   { 454, 460, 135 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 462, 463, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 415, 417, 58 },
   { 424, 425, 58 },
   { 429, 430, 59 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 419, 417, 58 },
   { 427, 425, 58 },
   { 432, 430, 59 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 420, 421, 58 },
   { 433, 434, 58 },
   { 436, 437, 59 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 422, 421, 58 },
   { 435, 434, 58 },
   { 438, 437, 59 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 465, 466, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 255, 264, 131 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 700, 701, 136 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 697, 698, 136 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 697, 698, 136 },
   { 700, 701, 136 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 703, 704, 136 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 706, 707, 136 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 703, 704, 136 },
   { 706, 707, 136 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 12, 6, 0 },
   { 225, 226, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 8, 10, 0 },
   { 223, 224, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 18, 14, 0 },
   { 30, 14, 0 },
   { 229, 200, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 15, 16, 0 },
   { 28, 16, 0 },
   { 227, 228, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 209, 214, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 68, 70, 32 },
   { 88, 90, 33 },
   { 121, 123, 34 },
   { 137, 138, 122 },
   { 140, 141, 122 },
   { 143, 144, 122 },
   { 146, 147, 123 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 105, 106, 33 },
   { 137, 138, 122 },
   { 140, 141, 122 },
   { 143, 144, 122 },
   { 146, 147, 123 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 342, 347, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 72, 75, 32 },
   { 92, 95, 33 },
   { 125, 128, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 108, 109, 33 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 375, 377, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 68, 70, 32 },
   { 88, 90, 33 },
   { 121, 123, 34 },
   { 137, 138, 122 },
   { 140, 141, 122 },
   { 143, 144, 122 },
   { 146, 147, 123 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 105, 106, 33 },
   { 137, 138, 122 },
   { 140, 141, 122 },
   { 143, 144, 122 },
   { 146, 147, 123 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 137, 138, 122 },
   { 140, 141, 122 },
   { 143, 144, 122 },
   { 146, 147, 123 },
   { 239, 241, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 65, 66, 32 },
   { 85, 86, 33 },
   { 118, 119, 34 },
   { 508, 512, 14 },
   { 525, 529, 16 },
   { 538, 542, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 65, 66, 32 },
   { 85, 86, 33 },
   { 118, 119, 34 },
   { 278, 269, 17 },
   { 280, 272, 17 },
   { 281, 274, 17 },
   { 282, 276, 17 },
   { 508, 512, 14 },
   { 525, 529, 16 },
   { 538, 542, 18 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 342, 347, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 72, 75, 32 },
   { 92, 95, 33 },
   { 125, 128, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 108, 109, 33 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 375, 377, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 137, 138, 122 },
   { 140, 141, 122 },
   { 143, 144, 122 },
   { 146, 147, 123 },
   { 342, 347, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 72, 75, 32 },
   { 92, 95, 33 },
   { 125, 128, 34 },
   { 137, 138, 122 },
   { 140, 141, 122 },
   { 143, 144, 122 },
   { 146, 147, 123 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 108, 109, 33 },
   { 137, 138, 122 },
   { 140, 141, 122 },
   { 143, 144, 122 },
   { 146, 147, 123 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 137, 138, 122 },
   { 140, 141, 122 },
   { 143, 144, 122 },
   { 146, 147, 123 },
   { 375, 377, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 65, 66, 32 },
   { 68, 70, 32 },
   { 85, 86, 33 },
   { 88, 90, 33 },
   { 118, 119, 34 },
   { 121, 123, 34 },
   { 137, 138, 122 },
   { 140, 141, 122 },
   { 143, 144, 122 },
   { 146, 147, 123 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 65, 66, 32 },
   { 85, 86, 33 },
   { 105, 106, 33 },
   { 118, 119, 34 },
   { 137, 138, 122 },
   { 140, 141, 122 },
   { 143, 144, 122 },
   { 146, 147, 123 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 65, 66, 32 },
   { 85, 86, 33 },
   { 118, 119, 34 },
   { 342, 347, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 65, 66, 32 },
   { 72, 75, 32 },
   { 85, 86, 33 },
   { 92, 95, 33 },
   { 118, 119, 34 },
   { 125, 128, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 65, 66, 32 },
   { 85, 86, 33 },
   { 108, 109, 33 },
   { 118, 119, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 65, 66, 32 },
   { 85, 86, 33 },
   { 118, 119, 34 },
   { 375, 377, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 68, 70, 32 },
   { 88, 90, 33 },
   { 102, 103, 33 },
   { 121, 123, 34 },
   { 137, 138, 122 },
   { 140, 141, 122 },
   { 143, 144, 122 },
   { 146, 147, 123 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 102, 103, 33 },
   { 105, 106, 33 },
   { 137, 138, 122 },
   { 140, 141, 122 },
   { 143, 144, 122 },
   { 146, 147, 123 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 102, 103, 33 },
   { 342, 347, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 72, 75, 32 },
   { 92, 95, 33 },
   { 102, 103, 33 },
   { 125, 128, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 102, 103, 33 },
   { 108, 109, 33 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 102, 103, 33 },
   { 375, 377, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 68, 70, 32 },
   { 88, 90, 33 },
   { 105, 106, 33 },
   { 121, 123, 34 },
   { 137, 138, 122 },
   { 140, 141, 122 },
   { 143, 144, 122 },
   { 146, 147, 123 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 68, 70, 32 },
   { 88, 90, 33 },
   { 121, 123, 34 },
   { 137, 138, 122 },
   { 140, 141, 122 },
   { 143, 144, 122 },
   { 146, 147, 123 },
   { 342, 347, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 68, 70, 32 },
   { 72, 75, 32 },
   { 88, 90, 33 },
   { 92, 95, 33 },
   { 121, 123, 34 },
   { 125, 128, 34 },
   { 137, 138, 122 },
   { 140, 141, 122 },
   { 143, 144, 122 },
   { 146, 147, 123 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 68, 70, 32 },
   { 88, 90, 33 },
   { 108, 109, 33 },
   { 121, 123, 34 },
   { 137, 138, 122 },
   { 140, 141, 122 },
   { 143, 144, 122 },
   { 146, 147, 123 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 68, 70, 32 },
   { 88, 90, 33 },
   { 121, 123, 34 },
   { 137, 138, 122 },
   { 140, 141, 122 },
   { 143, 144, 122 },
   { 146, 147, 123 },
   { 375, 377, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 105, 106, 33 },
   { 137, 138, 122 },
   { 140, 141, 122 },
   { 143, 144, 122 },
   { 146, 147, 123 },
   { 342, 347, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 72, 75, 32 },
   { 92, 95, 33 },
   { 105, 106, 33 },
   { 125, 128, 34 },
   { 137, 138, 122 },
   { 140, 141, 122 },
   { 143, 144, 122 },
   { 146, 147, 123 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 105, 106, 33 },
   { 108, 109, 33 },
   { 137, 138, 122 },
   { 140, 141, 122 },
   { 143, 144, 122 },
   { 146, 147, 123 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 105, 106, 33 },
   { 137, 138, 122 },
   { 140, 141, 122 },
   { 143, 144, 122 },
   { 146, 147, 123 },
   { 375, 377, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 72, 75, 32 },
   { 92, 95, 33 },
   { 125, 128, 34 },
   { 342, 347, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 108, 109, 33 },
   { 342, 347, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 342, 347, 132 },
   { 375, 377, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 72, 75, 32 },
   { 92, 95, 33 },
   { 108, 109, 33 },
   { 125, 128, 34 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 72, 75, 32 },
   { 92, 95, 33 },
   { 125, 128, 34 },
   { 375, 377, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 108, 109, 33 },
   { 375, 377, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 291, 292, 17 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 294, 292, 17 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 287, 288, 17 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 287, 288, 17 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 287, 288, 17 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 294, 292, 17 },
   { 296, 292, 17 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 267, 269, 17 },
   { 271, 272, 17 },
   { 273, 274, 17 },
   { 275, 276, 17 },
   { 287, 288, 17 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 287, 288, 17 },
   { 291, 292, 17 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 287, 288, 17 },
   { 294, 292, 17 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 287, 288, 17 },
   { 296, 292, 17 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 622, 89, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 655, 656, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 673, 674, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 661, 662, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 652, 653, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 646, 647, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 671, 86, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 584, 93, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 633, 634, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 627, 628, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 642, 643, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 630, 631, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 586, 587, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 589, 590, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 592, 593, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 595, 596, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 598, 599, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 601, 602, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 604, 605, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 607, 608, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 610, 611, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 613, 614, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 616, 617, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 619, 620, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 624, 625, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 636, 637, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 639, 640, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 649, 650, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 658, 659, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 664, 665, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 667, 668, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 517, 521, 0 },
   { 531, 532, 0 },
   { 544, 545, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 517, 521, 0 },
   { 531, 532, 0 },
   { 544, 545, 0 },
   { 723, 701, 136 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 517, 521, 0 },
   { 531, 532, 0 },
   { 544, 545, 0 },
   { 721, 698, 136 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 517, 521, 0 },
   { 531, 532, 0 },
   { 544, 545, 0 },
   { 721, 698, 136 },
   { 723, 701, 136 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 517, 521, 0 },
   { 531, 532, 0 },
   { 544, 545, 0 },
   { 725, 704, 136 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 517, 521, 0 },
   { 531, 532, 0 },
   { 544, 545, 0 },
   { 727, 707, 136 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 517, 521, 0 },
   { 531, 532, 0 },
   { 544, 545, 0 },
   { 725, 704, 136 },
   { 727, 707, 136 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 517, 521, 0 },
   { 531, 532, 0 },
   { 544, 545, 0 },
   { 712, 713, 136 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 517, 521, 0 },
   { 531, 532, 0 },
   { 544, 545, 0 },
   { 709, 710, 136 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 517, 521, 0 },
   { 531, 532, 0 },
   { 544, 545, 0 },
   { 709, 710, 136 },
   { 712, 713, 136 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 517, 521, 0 },
   { 531, 532, 0 },
   { 544, 545, 0 },
   { 715, 716, 136 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 517, 521, 0 },
   { 531, 532, 0 },
   { 544, 545, 0 },
   { 718, 719, 136 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 517, 521, 0 },
   { 531, 532, 0 },
   { 544, 545, 0 },
   { 715, 716, 136 },
   { 718, 719, 136 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 316, 317, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 298, 292, 17 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 298, 292, 17 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 298, 292, 17 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 38, 41, 0 },
   { 235, 42, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 53, 54, 0 },
   { 234, 42, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 59, 149, 124 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 59, 149, 124 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 328, 334, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 78, 80, 32 },
   { 98, 100, 33 },
   { 131, 133, 34 },
   { 137, 138, 122 },
   { 140, 141, 122 },
   { 143, 144, 122 },
   { 146, 147, 123 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 112, 113, 33 },
   { 137, 138, 122 },
   { 140, 141, 122 },
   { 143, 144, 122 },
   { 146, 147, 123 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 363, 369, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 328, 334, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 78, 80, 32 },
   { 98, 100, 33 },
   { 131, 133, 34 },
   { 137, 138, 122 },
   { 140, 141, 122 },
   { 143, 144, 122 },
   { 146, 147, 123 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 112, 113, 33 },
   { 137, 138, 122 },
   { 140, 141, 122 },
   { 143, 144, 122 },
   { 146, 147, 123 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 363, 369, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 137, 138, 122 },
   { 140, 141, 122 },
   { 143, 144, 122 },
   { 146, 147, 123 },
   { 328, 334, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 137, 138, 122 },
   { 140, 141, 122 },
   { 143, 144, 122 },
   { 146, 147, 123 },
   { 363, 369, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 65, 66, 32 },
   { 85, 86, 33 },
   { 118, 119, 34 },
   { 328, 334, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 65, 66, 32 },
   { 78, 80, 32 },
   { 85, 86, 33 },
   { 98, 100, 33 },
   { 118, 119, 34 },
   { 131, 133, 34 },
   { 137, 138, 122 },
   { 140, 141, 122 },
   { 143, 144, 122 },
   { 146, 147, 123 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 65, 66, 32 },
   { 85, 86, 33 },
   { 112, 113, 33 },
   { 118, 119, 34 },
   { 137, 138, 122 },
   { 140, 141, 122 },
   { 143, 144, 122 },
   { 146, 147, 123 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 65, 66, 32 },
   { 85, 86, 33 },
   { 118, 119, 34 },
   { 363, 369, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 102, 103, 33 },
   { 328, 334, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 78, 80, 32 },
   { 98, 100, 33 },
   { 102, 103, 33 },
   { 131, 133, 34 },
   { 137, 138, 122 },
   { 140, 141, 122 },
   { 143, 144, 122 },
   { 146, 147, 123 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 102, 103, 33 },
   { 112, 113, 33 },
   { 137, 138, 122 },
   { 140, 141, 122 },
   { 143, 144, 122 },
   { 146, 147, 123 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 102, 103, 33 },
   { 363, 369, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 68, 70, 32 },
   { 88, 90, 33 },
   { 121, 123, 34 },
   { 137, 138, 122 },
   { 140, 141, 122 },
   { 143, 144, 122 },
   { 146, 147, 123 },
   { 328, 334, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 68, 70, 32 },
   { 78, 80, 32 },
   { 88, 90, 33 },
   { 98, 100, 33 },
   { 121, 123, 34 },
   { 131, 133, 34 },
   { 137, 138, 122 },
   { 140, 141, 122 },
   { 143, 144, 122 },
   { 146, 147, 123 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 68, 70, 32 },
   { 88, 90, 33 },
   { 112, 113, 33 },
   { 121, 123, 34 },
   { 137, 138, 122 },
   { 140, 141, 122 },
   { 143, 144, 122 },
   { 146, 147, 123 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 68, 70, 32 },
   { 88, 90, 33 },
   { 121, 123, 34 },
   { 137, 138, 122 },
   { 140, 141, 122 },
   { 143, 144, 122 },
   { 146, 147, 123 },
   { 363, 369, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 105, 106, 33 },
   { 137, 138, 122 },
   { 140, 141, 122 },
   { 143, 144, 122 },
   { 146, 147, 123 },
   { 328, 334, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 78, 80, 32 },
   { 98, 100, 33 },
   { 105, 106, 33 },
   { 131, 133, 34 },
   { 137, 138, 122 },
   { 140, 141, 122 },
   { 143, 144, 122 },
   { 146, 147, 123 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 105, 106, 33 },
   { 112, 113, 33 },
   { 137, 138, 122 },
   { 140, 141, 122 },
   { 143, 144, 122 },
   { 146, 147, 123 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 105, 106, 33 },
   { 137, 138, 122 },
   { 140, 141, 122 },
   { 143, 144, 122 },
   { 146, 147, 123 },
   { 363, 369, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 328, 334, 132 },
   { 342, 347, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 78, 80, 32 },
   { 98, 100, 33 },
   { 131, 133, 34 },
   { 137, 138, 122 },
   { 140, 141, 122 },
   { 143, 144, 122 },
   { 146, 147, 123 },
   { 342, 347, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 112, 113, 33 },
   { 137, 138, 122 },
   { 140, 141, 122 },
   { 143, 144, 122 },
   { 146, 147, 123 },
   { 342, 347, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 342, 347, 132 },
   { 363, 369, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 72, 75, 32 },
   { 92, 95, 33 },
   { 125, 128, 34 },
   { 328, 334, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 72, 75, 32 },
   { 78, 80, 32 },
   { 92, 95, 33 },
   { 98, 100, 33 },
   { 125, 128, 34 },
   { 131, 133, 34 },
   { 137, 138, 122 },
   { 140, 141, 122 },
   { 143, 144, 122 },
   { 146, 147, 123 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 72, 75, 32 },
   { 92, 95, 33 },
   { 112, 113, 33 },
   { 125, 128, 34 },
   { 137, 138, 122 },
   { 140, 141, 122 },
   { 143, 144, 122 },
   { 146, 147, 123 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 72, 75, 32 },
   { 92, 95, 33 },
   { 125, 128, 34 },
   { 363, 369, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 108, 109, 33 },
   { 328, 334, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 78, 80, 32 },
   { 98, 100, 33 },
   { 108, 109, 33 },
   { 131, 133, 34 },
   { 137, 138, 122 },
   { 140, 141, 122 },
   { 143, 144, 122 },
   { 146, 147, 123 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 108, 109, 33 },
   { 112, 113, 33 },
   { 137, 138, 122 },
   { 140, 141, 122 },
   { 143, 144, 122 },
   { 146, 147, 123 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 108, 109, 33 },
   { 363, 369, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 328, 334, 132 },
   { 375, 377, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 78, 80, 32 },
   { 98, 100, 33 },
   { 131, 133, 34 },
   { 137, 138, 122 },
   { 140, 141, 122 },
   { 143, 144, 122 },
   { 146, 147, 123 },
   { 375, 377, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 112, 113, 33 },
   { 137, 138, 122 },
   { 140, 141, 122 },
   { 143, 144, 122 },
   { 146, 147, 123 },
   { 375, 377, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 363, 369, 132 },
   { 375, 377, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 78, 80, 32 },
   { 98, 100, 33 },
   { 131, 133, 34 },
   { 137, 138, 122 },
   { 140, 141, 122 },
   { 143, 144, 122 },
   { 146, 147, 123 },
   { 328, 334, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 112, 113, 33 },
   { 137, 138, 122 },
   { 140, 141, 122 },
   { 143, 144, 122 },
   { 146, 147, 123 },
   { 328, 334, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 328, 334, 132 },
   { 363, 369, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 78, 80, 32 },
   { 98, 100, 33 },
   { 112, 113, 33 },
   { 131, 133, 34 },
   { 137, 138, 122 },
   { 140, 141, 122 },
   { 143, 144, 122 },
   { 146, 147, 123 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 78, 80, 32 },
   { 98, 100, 33 },
   { 131, 133, 34 },
   { 137, 138, 122 },
   { 140, 141, 122 },
   { 143, 144, 122 },
   { 146, 147, 123 },
   { 363, 369, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 112, 113, 33 },
   { 137, 138, 122 },
   { 140, 141, 122 },
   { 143, 144, 122 },
   { 146, 147, 123 },
   { 363, 369, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 59, 149, 124 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 59, 149, 124 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 137, 138, 122 },
   { 140, 141, 122 },
   { 143, 144, 122 },
   { 146, 147, 123 },
   { 349, 355, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 137, 138, 122 },
   { 140, 141, 122 },
   { 143, 144, 122 },
   { 146, 147, 123 },
   { 379, 384, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 137, 138, 122 },
   { 140, 141, 122 },
   { 143, 144, 122 },
   { 146, 147, 123 },
   { 349, 355, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 137, 138, 122 },
   { 140, 141, 122 },
   { 143, 144, 122 },
   { 146, 147, 123 },
   { 379, 384, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 65, 66, 32 },
   { 85, 86, 33 },
   { 118, 119, 34 },
   { 137, 138, 122 },
   { 140, 141, 122 },
   { 143, 144, 122 },
   { 146, 147, 123 },
   { 349, 355, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 65, 66, 32 },
   { 85, 86, 33 },
   { 118, 119, 34 },
   { 137, 138, 122 },
   { 140, 141, 122 },
   { 143, 144, 122 },
   { 146, 147, 123 },
   { 379, 384, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 102, 103, 33 },
   { 137, 138, 122 },
   { 140, 141, 122 },
   { 143, 144, 122 },
   { 146, 147, 123 },
   { 349, 355, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 102, 103, 33 },
   { 137, 138, 122 },
   { 140, 141, 122 },
   { 143, 144, 122 },
   { 146, 147, 123 },
   { 379, 384, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 68, 70, 32 },
   { 88, 90, 33 },
   { 121, 123, 34 },
   { 137, 138, 122 },
   { 140, 141, 122 },
   { 143, 144, 122 },
   { 146, 147, 123 },
   { 349, 355, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 68, 70, 32 },
   { 88, 90, 33 },
   { 121, 123, 34 },
   { 137, 138, 122 },
   { 140, 141, 122 },
   { 143, 144, 122 },
   { 146, 147, 123 },
   { 379, 384, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 105, 106, 33 },
   { 137, 138, 122 },
   { 140, 141, 122 },
   { 143, 144, 122 },
   { 146, 147, 123 },
   { 349, 355, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 105, 106, 33 },
   { 137, 138, 122 },
   { 140, 141, 122 },
   { 143, 144, 122 },
   { 146, 147, 123 },
   { 379, 384, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 137, 138, 122 },
   { 140, 141, 122 },
   { 143, 144, 122 },
   { 146, 147, 123 },
   { 342, 347, 132 },
   { 349, 355, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 137, 138, 122 },
   { 140, 141, 122 },
   { 143, 144, 122 },
   { 146, 147, 123 },
   { 342, 347, 132 },
   { 379, 384, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 72, 75, 32 },
   { 92, 95, 33 },
   { 125, 128, 34 },
   { 137, 138, 122 },
   { 140, 141, 122 },
   { 143, 144, 122 },
   { 146, 147, 123 },
   { 349, 355, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 72, 75, 32 },
   { 92, 95, 33 },
   { 125, 128, 34 },
   { 137, 138, 122 },
   { 140, 141, 122 },
   { 143, 144, 122 },
   { 146, 147, 123 },
   { 379, 384, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 108, 109, 33 },
   { 137, 138, 122 },
   { 140, 141, 122 },
   { 143, 144, 122 },
   { 146, 147, 123 },
   { 349, 355, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 108, 109, 33 },
   { 137, 138, 122 },
   { 140, 141, 122 },
   { 143, 144, 122 },
   { 146, 147, 123 },
   { 379, 384, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 137, 138, 122 },
   { 140, 141, 122 },
   { 143, 144, 122 },
   { 146, 147, 123 },
   { 349, 355, 132 },
   { 375, 377, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 137, 138, 122 },
   { 140, 141, 122 },
   { 143, 144, 122 },
   { 146, 147, 123 },
   { 375, 377, 132 },
   { 379, 384, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 137, 138, 122 },
   { 140, 141, 122 },
   { 143, 144, 122 },
   { 146, 147, 123 },
   { 328, 334, 132 },
   { 349, 355, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 137, 138, 122 },
   { 140, 141, 122 },
   { 143, 144, 122 },
   { 146, 147, 123 },
   { 328, 334, 132 },
   { 379, 384, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 78, 80, 32 },
   { 98, 100, 33 },
   { 131, 133, 34 },
   { 137, 138, 122 },
   { 140, 141, 122 },
   { 143, 144, 122 },
   { 146, 147, 123 },
   { 349, 355, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 78, 80, 32 },
   { 98, 100, 33 },
   { 131, 133, 34 },
   { 137, 138, 122 },
   { 140, 141, 122 },
   { 143, 144, 122 },
   { 146, 147, 123 },
   { 379, 384, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 112, 113, 33 },
   { 137, 138, 122 },
   { 140, 141, 122 },
   { 143, 144, 122 },
   { 146, 147, 123 },
   { 349, 355, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 112, 113, 33 },
   { 137, 138, 122 },
   { 140, 141, 122 },
   { 143, 144, 122 },
   { 146, 147, 123 },
   { 379, 384, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 137, 138, 122 },
   { 140, 141, 122 },
   { 143, 144, 122 },
   { 146, 147, 123 },
   { 349, 355, 132 },
   { 363, 369, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 137, 138, 122 },
   { 140, 141, 122 },
   { 143, 144, 122 },
   { 146, 147, 123 },
   { 363, 369, 132 },
   { 379, 384, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 137, 138, 122 },
   { 140, 141, 122 },
   { 143, 144, 122 },
   { 146, 147, 123 },
   { 349, 355, 132 },
   { 379, 384, 132 },
   { ~0, ~0, ~0 }, /* Sentinel */

};

static const struct per_op_table nir_opt_algebraic_late_pass_op_table[nir_num_search_ops] = {
   [nir_op_flt] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         2,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         3,
         3,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
      },
      
      .num_filtered_states = 7,
      .table = (const uint16_t []) {
      
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         3,
         4,
         121,
         122,
         123,
         3,
         241,
         0,
         124,
         0,
         0,
         0,
         0,
         0,
         0,
         125,
         0,
         126,
         0,
         0,
         126,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         127,
         0,
         0,
         242,
         0,
         126,
         0,
         0,
         126,
      },
   },
   [nir_op_fadd] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         4,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         7,
         8,
         9,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         3,
         11,
         4,
         10,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         13,
         14,
         0,
         15,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         16,
         0,
         12,
         0,
         12,
         16,
         12,
         0,
         0,
         12,
         12,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         11,
         10,
         0,
         0,
         17,
         18,
         19,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         20,
         21,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 22,
      .table = (const uint16_t []) {
      
         5,
         6,
         165,
         166,
         166,
         167,
         5,
         246,
         247,
         165,
         166,
         166,
         248,
         249,
         250,
         251,
         356,
         357,
         358,
         359,
         406,
         407,
         6,
         6,
         168,
         169,
         170,
         171,
         6,
         252,
         253,
         254,
         255,
         256,
         257,
         258,
         259,
         260,
         360,
         361,
         362,
         363,
         408,
         409,
         165,
         168,
         165,
         172,
         172,
         173,
         165,
         246,
         247,
         165,
         172,
         172,
         261,
         262,
         263,
         264,
         364,
         357,
         358,
         365,
         406,
         407,
         166,
         169,
         172,
         166,
         166,
         174,
         166,
         265,
         266,
         172,
         166,
         166,
         267,
         268,
         269,
         270,
         366,
         367,
         368,
         369,
         410,
         411,
         166,
         170,
         172,
         166,
         166,
         174,
         166,
         265,
         266,
         172,
         166,
         166,
         267,
         268,
         269,
         270,
         366,
         367,
         368,
         369,
         410,
         411,
         167,
         171,
         173,
         174,
         174,
         167,
         167,
         271,
         272,
         173,
         174,
         174,
         273,
         274,
         275,
         276,
         370,
         371,
         372,
         373,
         412,
         413,
         5,
         6,
         165,
         166,
         166,
         167,
         175,
         246,
         247,
         165,
         166,
         166,
         248,
         249,
         250,
         251,
         356,
         357,
         358,
         359,
         406,
         407,
         246,
         252,
         246,
         265,
         265,
         271,
         246,
         246,
         277,
         246,
         265,
         265,
         278,
         279,
         280,
         281,
         374,
         375,
         376,
         377,
         414,
         415,
         247,
         253,
         247,
         266,
         266,
         272,
         247,
         277,
         247,
         247,
         266,
         266,
         282,
         283,
         284,
         285,
         378,
         379,
         380,
         381,
         416,
         417,
         165,
         254,
         165,
         172,
         172,
         173,
         165,
         246,
         247,
         165,
         172,
         172,
         261,
         262,
         263,
         264,
         364,
         357,
         358,
         365,
         406,
         407,
         166,
         255,
         172,
         166,
         166,
         174,
         166,
         265,
         266,
         172,
         166,
         166,
         267,
         268,
         269,
         270,
         366,
         367,
         368,
         369,
         410,
         411,
         166,
         256,
         172,
         166,
         166,
         174,
         166,
         265,
         266,
         172,
         166,
         166,
         267,
         268,
         269,
         270,
         366,
         367,
         368,
         369,
         410,
         411,
         248,
         257,
         261,
         267,
         267,
         273,
         248,
         278,
         282,
         261,
         267,
         267,
         248,
         286,
         287,
         288,
         382,
         383,
         384,
         385,
         418,
         419,
         249,
         258,
         262,
         268,
         268,
         274,
         249,
         279,
         283,
         262,
         268,
         268,
         286,
         249,
         289,
         290,
         386,
         387,
         388,
         389,
         420,
         421,
         250,
         259,
         263,
         269,
         269,
         275,
         250,
         280,
         284,
         263,
         269,
         269,
         287,
         289,
         250,
         291,
         390,
         391,
         392,
         393,
         422,
         423,
         251,
         260,
         264,
         270,
         270,
         276,
         251,
         281,
         285,
         264,
         270,
         270,
         288,
         290,
         291,
         251,
         394,
         395,
         396,
         397,
         424,
         425,
         356,
         360,
         364,
         366,
         366,
         370,
         356,
         374,
         378,
         364,
         366,
         366,
         382,
         386,
         390,
         394,
         356,
         398,
         399,
         400,
         426,
         427,
         357,
         361,
         357,
         367,
         367,
         371,
         357,
         375,
         379,
         357,
         367,
         367,
         383,
         387,
         391,
         395,
         398,
         357,
         401,
         402,
         428,
         429,
         358,
         362,
         358,
         368,
         368,
         372,
         358,
         376,
         380,
         358,
         368,
         368,
         384,
         388,
         392,
         396,
         399,
         401,
         358,
         403,
         430,
         431,
         359,
         363,
         365,
         369,
         369,
         373,
         359,
         377,
         381,
         365,
         369,
         369,
         385,
         389,
         393,
         397,
         400,
         402,
         403,
         359,
         432,
         433,
         406,
         408,
         406,
         410,
         410,
         412,
         406,
         414,
         416,
         406,
         410,
         410,
         418,
         420,
         422,
         424,
         426,
         428,
         430,
         432,
         406,
         434,
         407,
         409,
         407,
         411,
         411,
         413,
         407,
         415,
         417,
         407,
         411,
         411,
         419,
         421,
         423,
         425,
         427,
         429,
         431,
         433,
         434,
         407,
      },
   },
   [nir_op_fneg] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         4,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         9,
         0,
         0,
         0,
         0,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         0,
         0,
         2,
         2,
         10,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         2,
         2,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
      },
      
      .num_filtered_states = 11,
      .table = (const uint16_t []) {
      
         7,
         128,
         129,
         130,
         131,
         132,
         133,
         353,
         354,
         404,
         405,
      },
   },
   [nir_op_fge] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         2,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         3,
         3,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
      },
      
      .num_filtered_states = 8,
      .table = (const uint16_t []) {
      
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         10,
         134,
         135,
         9,
         9,
         243,
         9,
         0,
         136,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         137,
         0,
         138,
         0,
         0,
         138,
         0,
         0,
         139,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         140,
         0,
         0,
         0,
         244,
         0,
         138,
         0,
         0,
         138,
         0,
         0,
         245,
         0,
         0,
         0,
         0,
         0,
         0,
      },
   },
   [nir_op_feq] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         2,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         3,
         3,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
      },
      
      .num_filtered_states = 7,
      .table = (const uint16_t []) {
      
         11,
         12,
         11,
         11,
         11,
         11,
         11,
         12,
         12,
         141,
         142,
         143,
         144,
         12,
         11,
         141,
         11,
         11,
         11,
         11,
         11,
         11,
         142,
         11,
         145,
         11,
         11,
         11,
         11,
         143,
         11,
         11,
         11,
         11,
         11,
         11,
         144,
         11,
         11,
         11,
         11,
         11,
         11,
         12,
         11,
         11,
         11,
         11,
         146,
      },
   },
   [nir_op_fneu] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         2,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         3,
         3,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
      },
      
      .num_filtered_states = 6,
      .table = (const uint16_t []) {
      
         13,
         14,
         13,
         13,
         13,
         13,
         14,
         14,
         147,
         148,
         149,
         14,
         13,
         147,
         13,
         13,
         13,
         13,
         13,
         148,
         13,
         150,
         13,
         13,
         13,
         149,
         13,
         13,
         13,
         13,
         13,
         14,
         13,
         13,
         13,
         151,
      },
   },
   [nir_op_iand] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         3,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         2,
         2,
         4,
         4,
         4,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 8,
      .table = (const uint16_t []) {
      
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         182,
         15,
         15,
         15,
         15,
         183,
         15,
         184,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         351,
         15,
         15,
         184,
         15,
         15,
         15,
         15,
         351,
         15,
         182,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         15,
         185,
         15,
         15,
         15,
         15,
         351,
         351,
         15,
         15,
         15,
      },
   },
   [nir_op_ior] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         2,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         2,
         2,
         1,
         1,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 6,
      .table = (const uint16_t []) {
      
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         16,
         352,
         16,
         16,
         16,
         186,
         16,
         352,
         16,
         16,
         186,
         187,
         16,
         16,
         16,
         16,
         16,
         16,
         188,
         16,
         16,
         352,
         352,
         16,
         16,
         16,
      },
   },
   [nir_op_fmul] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         2,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         3,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         2,
         5,
         5,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         0,
         0,
         5,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 6,
      .table = (const uint16_t []) {
      
         17,
         18,
         157,
         158,
         17,
         348,
         18,
         18,
         159,
         160,
         18,
         349,
         157,
         159,
         157,
         161,
         157,
         348,
         158,
         160,
         161,
         158,
         158,
         350,
         17,
         18,
         157,
         158,
         162,
         348,
         348,
         349,
         348,
         350,
         348,
         348,
      },
   },
   [nir_op_fabs] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         0,
         189,
         190,
         191,
      },
   },
   [nir_op_fmulz] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         19,
      },
   },
   [nir_op_iadd] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         2,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         20,
         193,
         194,
         195,
         193,
         193,
         196,
         197,
         194,
         196,
         194,
         198,
         195,
         197,
         198,
         195,
      },
   },
   [nir_op_ineg] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         21,
      },
   },
   [nir_op_iabs] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         22,
      },
   },
   [nir_op_isub] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         23,
         23,
         199,
         199,
      },
   },
   [nir_op_vec2] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         176,
         177,
         178,
      },
   },
   [nir_op_fsat] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         24,
         212,
      },
   },
   [nir_op_fmin] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         1,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         2,
         2,
         2,
         2,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         2,
         2,
         2,
         2,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         1,
         1,
         2,
         2,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         0,
         0,
         0,
         0,
         0,
         152,
         152,
         0,
         0,
         152,
         153,
         0,
         0,
         0,
         0,
         154,
      },
   },
   [nir_op_fdot2] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         25,
      },
   },
   [nir_op_fdot3] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         26,
      },
   },
   [nir_op_fdot4] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         27,
      },
   },
   [nir_op_fdph] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         28,
      },
   },
   [nir_op_flrp] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         155,
         155,
         155,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         156,
      },
   },
   [nir_op_fround_even] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         29,
         213,
      },
   },
   [nir_op_ffma] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         4,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         6,
         2,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         7,
         4,
         8,
         7,
         3,
         0,
         0,
         9,
         0,
         0,
         9,
         0,
         0,
         0,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         0,
         0,
         0,
         0,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         9,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         9,
         9,
         0,
         0,
         0,
         0,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         10,
         0,
         10,
         0,
         10,
         0,
         0,
         10,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         4,
         7,
         0,
         0,
         2,
         2,
         0,
         0,
         9,
         9,
         0,
         0,
         9,
         9,
         0,
         9,
         9,
         0,
         9,
         9,
         0,
         0,
         9,
         9,
         0,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         0,
         9,
         9,
         0,
         0,
         9,
         9,
         0,
         0,
         9,
         9,
         0,
         0,
         9,
         9,
         0,
         9,
         9,
         0,
         9,
         9,
         9,
         2,
         2,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
      },
      
      .num_filtered_states = 11,
      .table = (const uint16_t []) {
      
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         30,
         31,
         30,
         179,
         179,
         30,
         293,
         294,
         294,
         30,
         292,
         30,
         30,
         30,
         179,
         180,
         30,
         30,
         179,
         180,
         30,
         292,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         30,
         30,
         30,
         179,
         180,
         30,
         30,
         179,
         180,
         30,
         292,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         295,
         295,
         295,
         296,
         296,
         295,
         295,
         296,
         296,
         295,
         297,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         30,
         31,
         30,
         179,
         179,
         30,
         293,
         294,
         294,
         30,
         292,
         30,
         31,
         30,
         179,
         179,
         30,
         293,
         294,
         294,
         30,
         292,
         30,
         31,
         30,
         179,
         180,
         30,
         293,
         294,
         298,
         30,
         292,
         30,
         31,
         30,
         179,
         179,
         30,
         293,
         294,
         294,
         30,
         292,
         30,
         31,
         30,
         179,
         179,
         30,
         293,
         294,
         294,
         30,
         292,
         30,
         31,
         30,
         179,
         179,
         30,
         293,
         294,
         294,
         30,
         292,
         30,
         31,
         30,
         179,
         180,
         30,
         293,
         294,
         298,
         30,
         292,
         30,
         31,
         30,
         179,
         179,
         30,
         293,
         294,
         294,
         30,
         292,
         30,
         31,
         30,
         179,
         179,
         30,
         293,
         294,
         294,
         30,
         292,
         295,
         299,
         295,
         296,
         296,
         295,
         300,
         301,
         301,
         295,
         297,
         30,
         31,
         30,
         179,
         179,
         30,
         293,
         294,
         294,
         30,
         292,
         30,
         30,
         30,
         179,
         180,
         30,
         30,
         179,
         180,
         30,
         292,
         30,
         31,
         30,
         179,
         180,
         30,
         293,
         294,
         298,
         30,
         292,
         30,
         30,
         30,
         179,
         180,
         30,
         30,
         179,
         180,
         30,
         292,
         30,
         30,
         30,
         179,
         180,
         30,
         30,
         179,
         180,
         30,
         292,
         30,
         30,
         30,
         179,
         180,
         30,
         30,
         179,
         180,
         30,
         292,
         30,
         30,
         30,
         179,
         180,
         30,
         30,
         179,
         180,
         30,
         292,
         30,
         30,
         30,
         179,
         180,
         30,
         30,
         179,
         180,
         30,
         292,
         30,
         30,
         30,
         179,
         180,
         30,
         30,
         179,
         180,
         30,
         292,
         30,
         30,
         30,
         179,
         180,
         30,
         30,
         179,
         180,
         30,
         292,
         295,
         295,
         295,
         296,
         302,
         295,
         295,
         296,
         302,
         295,
         297,
         30,
         30,
         30,
         179,
         180,
         30,
         30,
         179,
         180,
         30,
         292,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         30,
         31,
         30,
         179,
         179,
         30,
         293,
         294,
         294,
         30,
         292,
         30,
         30,
         30,
         179,
         180,
         30,
         30,
         179,
         180,
         30,
         292,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         30,
         30,
         30,
         179,
         180,
         30,
         30,
         179,
         180,
         30,
         292,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         295,
         295,
         295,
         296,
         296,
         295,
         295,
         296,
         296,
         295,
         297,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         30,
         31,
         30,
         179,
         179,
         30,
         293,
         294,
         294,
         30,
         292,
         30,
         30,
         30,
         179,
         180,
         30,
         30,
         179,
         180,
         30,
         292,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         30,
         30,
         30,
         179,
         180,
         30,
         30,
         179,
         180,
         30,
         292,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         295,
         295,
         295,
         296,
         296,
         295,
         295,
         296,
         296,
         295,
         297,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         30,
         31,
         30,
         179,
         179,
         30,
         293,
         294,
         294,
         30,
         292,
         30,
         30,
         30,
         179,
         180,
         30,
         30,
         179,
         180,
         30,
         292,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         30,
         30,
         30,
         179,
         179,
         181,
         30,
         179,
         179,
         30,
         292,
         30,
         30,
         30,
         179,
         180,
         30,
         30,
         179,
         180,
         30,
         292,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         295,
         295,
         295,
         296,
         296,
         295,
         295,
         296,
         296,
         295,
         297,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         30,
         30,
         30,
         179,
         180,
         30,
         30,
         179,
         180,
         30,
         292,
         30,
         31,
         30,
         179,
         180,
         30,
         293,
         294,
         298,
         30,
         292,
         30,
         30,
         30,
         179,
         180,
         30,
         30,
         179,
         180,
         30,
         292,
         30,
         30,
         30,
         179,
         180,
         30,
         30,
         179,
         180,
         30,
         292,
         30,
         30,
         30,
         179,
         180,
         30,
         30,
         179,
         180,
         30,
         292,
         30,
         30,
         30,
         179,
         180,
         30,
         30,
         179,
         180,
         30,
         292,
         30,
         30,
         30,
         179,
         180,
         30,
         30,
         179,
         180,
         30,
         292,
         30,
         30,
         30,
         179,
         180,
         30,
         30,
         179,
         180,
         30,
         292,
         30,
         30,
         30,
         179,
         180,
         30,
         30,
         179,
         180,
         30,
         292,
         295,
         295,
         295,
         296,
         302,
         295,
         295,
         296,
         302,
         295,
         297,
         30,
         30,
         30,
         179,
         180,
         30,
         30,
         179,
         180,
         30,
         292,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         30,
         31,
         30,
         179,
         179,
         30,
         293,
         294,
         294,
         30,
         292,
         30,
         30,
         30,
         179,
         180,
         30,
         30,
         179,
         180,
         30,
         292,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         30,
         30,
         30,
         179,
         180,
         30,
         30,
         179,
         180,
         30,
         292,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         295,
         295,
         295,
         296,
         296,
         295,
         295,
         296,
         296,
         295,
         297,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         30,
         31,
         30,
         179,
         179,
         30,
         293,
         294,
         294,
         30,
         292,
         30,
         30,
         30,
         179,
         180,
         30,
         30,
         179,
         180,
         30,
         292,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         30,
         30,
         30,
         179,
         180,
         30,
         30,
         179,
         180,
         30,
         292,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         295,
         295,
         295,
         296,
         296,
         295,
         295,
         296,
         296,
         295,
         297,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         295,
         295,
         295,
         296,
         296,
         295,
         295,
         296,
         296,
         295,
         297,
         295,
         299,
         295,
         296,
         296,
         295,
         300,
         301,
         301,
         295,
         297,
         295,
         295,
         295,
         296,
         302,
         295,
         295,
         296,
         302,
         295,
         297,
         295,
         295,
         295,
         296,
         296,
         295,
         295,
         296,
         296,
         295,
         297,
         295,
         295,
         295,
         296,
         296,
         295,
         295,
         296,
         296,
         295,
         297,
         295,
         295,
         295,
         296,
         296,
         295,
         295,
         296,
         296,
         295,
         297,
         295,
         295,
         295,
         296,
         302,
         295,
         295,
         296,
         302,
         295,
         297,
         295,
         295,
         295,
         296,
         296,
         295,
         295,
         296,
         296,
         295,
         297,
         295,
         295,
         295,
         296,
         296,
         295,
         295,
         296,
         296,
         295,
         297,
         295,
         295,
         295,
         296,
         296,
         295,
         295,
         296,
         296,
         295,
         297,
         295,
         295,
         295,
         296,
         296,
         295,
         295,
         296,
         296,
         295,
         297,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         30,
         31,
         30,
         179,
         179,
         30,
         293,
         294,
         294,
         30,
         292,
         30,
         30,
         30,
         179,
         180,
         30,
         30,
         179,
         180,
         30,
         292,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         30,
         30,
         30,
         179,
         180,
         30,
         30,
         179,
         180,
         30,
         292,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
         295,
         295,
         295,
         296,
         296,
         295,
         295,
         296,
         296,
         295,
         297,
         30,
         30,
         30,
         179,
         179,
         30,
         30,
         179,
         179,
         30,
         292,
      },
   },
   [nir_op_fmax] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         0,
         0,
         0,
         0,
         163,
         0,
         0,
         0,
         164,
      },
   },
   [nir_op_bcsel] = {
      .filter = (const uint16_t []) {
         0,
         1,
         2,
         3,
         4,
         5,
         5,
         0,
         6,
         7,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         9,
         0,
         10,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         12,
         13,
         14,
         15,
         16,
         17,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         3,
         3,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         7,
         7,
         6,
         6,
         0,
         6,
         0,
         0,
         0,
         0,
         18,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         0,
         0,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         19,
         0,
         0,
         0,
         10,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         3,
         2,
         7,
         6,
         6,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         9,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         11,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         0,
         0,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
         5,
      },
      
      .num_filtered_states = 20,
      .table = (const uint16_t []) {
      
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         334,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         70,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         71,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         72,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         334,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         70,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         71,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         72,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         335,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         74,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         75,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         76,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         73,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         336,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         78,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         79,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         80,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         77,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         337,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         82,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         83,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         84,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         81,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         334,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         70,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         71,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         72,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         338,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         86,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         87,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         88,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         85,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         339,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         90,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         91,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         92,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         89,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         340,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         94,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         95,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         96,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         93,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         334,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         70,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         71,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         72,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         334,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         70,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         71,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         72,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         334,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         70,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         71,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         72,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         341,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         98,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         99,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         100,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         97,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         342,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         102,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         103,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         104,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         101,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         343,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         106,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         107,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         108,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         105,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         344,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         110,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         111,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         112,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         109,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         345,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         114,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         115,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         116,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         113,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         346,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         118,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         119,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         120,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         117,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         347,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         334,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         70,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         71,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         72,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         334,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         70,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         71,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         72,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
   },
   [nir_op_fsqrt] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         32,
         214,
      },
   },
   [nir_op_frsq] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         33,
         215,
      },
   },
   [nir_op_ffmaz] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         34,
         192,
         355,
         34,
         192,
         355,
         34,
         192,
         355,
         34,
         192,
         355,
         34,
         192,
         355,
         34,
         192,
         355,
         34,
         192,
         355,
         34,
         192,
         355,
         34,
         192,
         355,
      },
   },
   [nir_op_ubfe] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         35,
         0,
         36,
         0,
         35,
         0,
         36,
      },
   },
   [nir_op_ibfe] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         37,
         0,
         38,
         0,
         37,
         0,
         38,
      },
   },
   [nir_op_ishl] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         0,
         39,
         0,
         0,
         39,
         0,
         0,
         204,
         0,
      },
   },
   [nir_op_ishr] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         40,
         0,
         40,
      },
   },
   [nir_op_ushr] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         41,
         0,
         41,
      },
   },
   [nir_op_extract_i8] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         42,
         42,
         42,
         42,
         42,
         42,
         42,
         42,
         42,
         200,
         42,
         42,
         42,
         201,
         42,
         42,
      },
   },
   [nir_op_extract_u8] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         2,
         3,
         3,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 4,
      .table = (const uint16_t []) {
      
         43,
         44,
         43,
         43,
         43,
         44,
         43,
         43,
         43,
         202,
         43,
         43,
         43,
         203,
         43,
         43,
      },
   },
   [nir_search_op_u2u] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         45,
         206,
         207,
      },
   },
   [nir_search_op_i2i] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         2,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         46,
         208,
         209,
      },
   },
   [nir_op_insert_u8] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         0,
         205,
         205,
      },
   },
   [nir_op_insert_u16] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         0,
         210,
         210,
      },
   },
   [nir_op_extract_u16] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         47,
         0,
         47,
      },
   },
   [nir_op_ine] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         48,
         48,
         48,
      },
   },
   [nir_op_ieq] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         49,
         49,
         49,
      },
   },
   [nir_search_op_b2f] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         211,
      },
   },
   [nir_op_inot] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         50,
      },
   },
   [nir_search_op_f2f] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         3,
         0,
         0,
         0,
         0,
         0,
         4,
         0,
         5,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         6,
         0,
         0,
         0,
         0,
         0,
         7,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         8,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         9,
         10,
         11,
         12,
         13,
         14,
         15,
         16,
         17,
         18,
         19,
         20,
         21,
         22,
         23,
         24,
         25,
         26,
         27,
         28,
         29,
         30,
         31,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 32,
      .table = (const uint16_t []) {
      
         0,
         303,
         304,
         305,
         306,
         307,
         308,
         309,
         310,
         311,
         312,
         313,
         314,
         315,
         316,
         317,
         318,
         319,
         320,
         321,
         322,
         323,
         324,
         325,
         326,
         327,
         328,
         329,
         330,
         331,
         332,
         333,
      },
   },
   [nir_op_f2fmp] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         51,
      },
   },
   [nir_op_fceil] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         216,
      },
   },
   [nir_op_fcos] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         217,
      },
   },
   [nir_op_fddx] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         218,
      },
   },
   [nir_op_fddx_coarse] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         219,
      },
   },
   [nir_op_fddx_fine] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         220,
      },
   },
   [nir_op_fddy] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         221,
      },
   },
   [nir_op_fddy_coarse] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         222,
      },
   },
   [nir_op_fddy_fine] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         223,
      },
   },
   [nir_op_fexp2] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         224,
      },
   },
   [nir_op_ffloor] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         225,
      },
   },
   [nir_op_ffract] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         226,
      },
   },
   [nir_op_flog2] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         227,
      },
   },
   [nir_op_frcp] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         228,
      },
   },
   [nir_op_fsign] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         229,
      },
   },
   [nir_op_fsin] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         230,
      },
   },
   [nir_op_fdiv] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         0,
         0,
         231,
      },
   },
   [nir_op_fmod] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         0,
         0,
         232,
      },
   },
   [nir_op_fpow] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         0,
         0,
         233,
      },
   },
   [nir_op_frem] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         0,
         0,
         234,
      },
   },
   [nir_op_f2imp] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         52,
      },
   },
   [nir_op_f2ump] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         53,
      },
   },
   [nir_op_i2imp] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         54,
      },
   },
   [nir_op_i2fmp] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         55,
      },
   },
   [nir_op_u2fmp] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         56,
      },
   },
   [nir_op_fisfinite] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         57,
      },
   },
   [nir_op_fcsel] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         2,
         3,
         4,
         5,
         6,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 7,
      .table = (const uint16_t []) {
      
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         235,
         235,
         235,
         235,
         235,
         235,
         235,
         235,
         235,
         235,
         235,
         235,
         235,
         235,
         235,
         235,
         235,
         235,
         235,
         235,
         235,
         235,
         235,
         235,
         235,
         235,
         235,
         235,
         235,
         235,
         235,
         235,
         235,
         235,
         235,
         235,
         235,
         235,
         235,
         235,
         235,
         235,
         235,
         235,
         235,
         235,
         235,
         235,
         235,
         236,
         236,
         236,
         236,
         236,
         236,
         236,
         236,
         236,
         236,
         236,
         236,
         236,
         236,
         236,
         236,
         236,
         236,
         236,
         236,
         236,
         236,
         236,
         236,
         236,
         236,
         236,
         236,
         236,
         236,
         236,
         236,
         236,
         236,
         236,
         236,
         236,
         236,
         236,
         236,
         236,
         236,
         236,
         236,
         236,
         236,
         236,
         236,
         236,
         237,
         237,
         237,
         237,
         237,
         237,
         237,
         237,
         237,
         237,
         237,
         237,
         237,
         237,
         237,
         237,
         237,
         237,
         237,
         237,
         237,
         237,
         237,
         237,
         237,
         237,
         237,
         237,
         237,
         237,
         237,
         237,
         237,
         237,
         237,
         237,
         237,
         237,
         237,
         237,
         237,
         237,
         237,
         237,
         237,
         237,
         237,
         237,
         237,
         238,
         238,
         238,
         238,
         238,
         238,
         238,
         238,
         238,
         238,
         238,
         238,
         238,
         238,
         238,
         238,
         238,
         238,
         238,
         238,
         238,
         238,
         238,
         238,
         238,
         238,
         238,
         238,
         238,
         238,
         238,
         238,
         238,
         238,
         238,
         238,
         238,
         238,
         238,
         238,
         238,
         238,
         238,
         238,
         238,
         238,
         238,
         238,
         238,
         239,
         239,
         239,
         239,
         239,
         239,
         239,
         239,
         239,
         239,
         239,
         239,
         239,
         239,
         239,
         239,
         239,
         239,
         239,
         239,
         239,
         239,
         239,
         239,
         239,
         239,
         239,
         239,
         239,
         239,
         239,
         239,
         239,
         239,
         239,
         239,
         239,
         239,
         239,
         239,
         239,
         239,
         239,
         239,
         239,
         239,
         239,
         239,
         239,
         240,
         240,
         240,
         240,
         240,
         240,
         240,
         240,
         240,
         240,
         240,
         240,
         240,
         240,
         240,
         240,
         240,
         240,
         240,
         240,
         240,
         240,
         240,
         240,
         240,
         240,
         240,
         240,
         240,
         240,
         240,
         240,
         240,
         240,
         240,
         240,
         240,
         240,
         240,
         240,
         240,
         240,
         240,
         240,
         240,
         240,
         240,
         240,
         240,
      },
   },
   [nir_op_slt] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         58,
         59,
         60,
      },
   },
   [nir_op_sge] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         61,
         62,
         63,
      },
   },
   [nir_op_ilt] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         64,
         65,
         66,
      },
   },
   [nir_op_ige] = {
      .filter = (const uint16_t []) {
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         0,
         67,
         68,
         69,
      },
   },
};

/* Mapping from state index to offset in transforms (0 being no transforms) */
static const uint16_t nir_opt_algebraic_late_transform_offsets[] = {
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   1,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   3,
   5,
   0,
   0,
   0,
   0,
   7,
   9,
   0,
   0,
   11,
   13,
   15,
   17,
   19,
   0,
   21,
   0,
   0,
   0,
   26,
   28,
   31,
   33,
   36,
   41,
   44,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   46,
   48,
   50,
   52,
   55,
   57,
   59,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   61,
   64,
   69,
   74,
   76,
   80,
   86,
   92,
   94,
   98,
   104,
   110,
   113,
   118,
   125,
   132,
   134,
   138,
   144,
   150,
   152,
   156,
   162,
   168,
   171,
   176,
   183,
   190,
   192,
   196,
   202,
   208,
   210,
   214,
   220,
   226,
   229,
   234,
   241,
   248,
   250,
   254,
   260,
   266,
   268,
   272,
   278,
   284,
   287,
   292,
   299,
   306,
   308,
   310,
   312,
   314,
   316,
   318,
   320,
   322,
   325,
   327,
   329,
   331,
   333,
   336,
   338,
   341,
   343,
   345,
   348,
   350,
   353,
   355,
   0,
   357,
   359,
   361,
   364,
   366,
   368,
   370,
   0,
   372,
   0,
   374,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   376,
   0,
   378,
   383,
   387,
   389,
   394,
   398,
   406,
   408,
   416,
   422,
   0,
   427,
   429,
   431,
   0,
   434,
   0,
   436,
   441,
   443,
   446,
   452,
   455,
   457,
   0,
   0,
   0,
   0,
   463,
   465,
   467,
   469,
   472,
   475,
   478,
   480,
   482,
   484,
   486,
   488,
   496,
   498,
   502,
   506,
   510,
   514,
   0,
   0,
   516,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   518,
   520,
   522,
   525,
   527,
   529,
   532,
   535,
   538,
   542,
   546,
   548,
   556,
   562,
   564,
   568,
   570,
   572,
   580,
   586,
   592,
   599,
   610,
   612,
   616,
   618,
   620,
   626,
   634,
   640,
   646,
   657,
   666,
   671,
   678,
   683,
   688,
   697,
   704,
   707,
   712,
   715,
   718,
   727,
   736,
   747,
   756,
   765,
   772,
   781,
   788,
   795,
   800,
   803,
   806,
   811,
   816,
   0,
   819,
   821,
   823,
   825,
   827,
   829,
   832,
   838,
   841,
   844,
   847,
   849,
   851,
   853,
   855,
   857,
   859,
   861,
   863,
   865,
   867,
   869,
   871,
   873,
   875,
   877,
   879,
   881,
   883,
   885,
   887,
   889,
   891,
   893,
   895,
   897,
   899,
   901,
   903,
   905,
   907,
   909,
   913,
   918,
   923,
   929,
   934,
   939,
   945,
   950,
   955,
   961,
   966,
   971,
   977,
   979,
   981,
   983,
   985,
   988,
   991,
   993,
   0,
   995,
   997,
   1005,
   1011,
   1013,
   1015,
   1023,
   1029,
   1031,
   1037,
   1043,
   1048,
   1059,
   1068,
   1073,
   1076,
   1085,
   1092,
   1095,
   1104,
   1115,
   1124,
   1133,
   1140,
   1149,
   1156,
   1163,
   1166,
   1175,
   1182,
   1185,
   1190,
   1201,
   1210,
   1215,
   1218,
   1227,
   1234,
   1237,
   1240,
   1249,
   1256,
   1259,
   1268,
   1275,
   1278,
   1287,
   1296,
   1303,
   1305,
   1307,
   1313,
   1319,
   1325,
   1331,
   1340,
   1349,
   1356,
   1363,
   1372,
   1381,
   1388,
   1395,
   1402,
   1409,
   1418,
   1427,
   1434,
   1441,
   1448,
   1455,
   1462,
   1469,
   1478,
   1487,
   1494,
   1501,
   1508,
   1515,
};

static const nir_algebraic_table nir_opt_algebraic_late_table = {
   .transforms = nir_opt_algebraic_late_transforms,
   .transform_offsets = nir_opt_algebraic_late_transform_offsets,
   .pass_op_table = nir_opt_algebraic_late_pass_op_table,
   .values = nir_opt_algebraic_late_values,
   .expression_cond = nir_opt_algebraic_late_expression_cond,
   .variable_cond = nir_opt_algebraic_late_variable_cond,
};

bool
nir_opt_algebraic_late(nir_shader *shader)
{
   bool progress = false;
   bool condition_flags[137];
   const nir_shader_compiler_options *options = shader->options;
   const shader_info *info = &shader->info;
   (void) options;
   (void) info;

   /* This is not a great place for this, but it seems to be the best place
    * for it. Check that at most one kind of lowering is requested for
    * bitfield extract and bitfield insert. Otherwise the lowering can fight
    * with each other and optimizations.
    */
   assert((int)options->lower_bitfield_extract +
          (int)options->lower_bitfield_extract_to_shifts <= 1);
   assert((int)options->lower_bitfield_insert +
          (int)options->lower_bitfield_insert_to_shifts +
          (int)options->lower_bitfield_insert_to_bitfield_select <= 1);


   STATIC_ASSERT(728 == ARRAY_SIZE(nir_opt_algebraic_late_values));
   condition_flags[0] = true;
   condition_flags[1] = !options->lower_bitops;
   condition_flags[2] = options->lower_bitops;
   condition_flags[3] = !options->lower_bitops && (options->lower_int64_options & (nir_lower_imul64 | nir_lower_shift64)) == nir_lower_imul64;
   condition_flags[4] = options->lower_mul_2x32_64;
   condition_flags[5] = !nir_is_float_control_signed_zero_inf_nan_preserve(info->float_controls_execution_mode, 16);
   condition_flags[6] = !nir_is_float_control_signed_zero_inf_nan_preserve(info->float_controls_execution_mode, 32);
   condition_flags[7] = !options->lower_iadd_sat;
   condition_flags[8] = !options->lower_uadd_sat;
   condition_flags[9] = options->has_fmulz && !nir_is_float_control_signed_zero_inf_nan_preserve(info->float_controls_execution_mode, 32);
   condition_flags[10] = !options->has_sdot_4x8;
   condition_flags[11] = !options->has_udot_4x8;
   condition_flags[12] = !options->has_sudot_4x8;
   condition_flags[13] = !options->has_dot_2x16;
   condition_flags[14] = options->lower_flrp16;
   condition_flags[15] = !options->lower_flrp16;
   condition_flags[16] = options->lower_flrp32;
   condition_flags[17] = !options->lower_flrp32;
   condition_flags[18] = options->lower_flrp64;
   condition_flags[19] = !options->lower_flrp64;
   condition_flags[20] = options->lower_ftrunc;
   condition_flags[21] = options->lower_ftrunc || (options->lower_doubles_options & nir_lower_dtrunc);
   condition_flags[22] = options->lower_ffloor;
   condition_flags[23] = (options->lower_ffloor || (options->lower_doubles_options & nir_lower_dfloor)) && !(options->lower_doubles_options & nir_lower_dfract);
   condition_flags[24] = !options->lower_ffloor;
   condition_flags[25] = !options->lower_ffloor && !(options->lower_doubles_options & nir_lower_dfloor);
   condition_flags[26] = options->lower_ffract;
   condition_flags[27] = options->lower_ffract || (options->lower_doubles_options & nir_lower_dfract);
   condition_flags[28] = options->lower_fceil;
   condition_flags[29] = options->lower_ffma16;
   condition_flags[30] = options->lower_ffma32;
   condition_flags[31] = options->lower_ffma64;
   condition_flags[32] = options->fuse_ffma16;
   condition_flags[33] = options->fuse_ffma32;
   condition_flags[34] = options->fuse_ffma64;
   condition_flags[35] = options->lower_fdph;
   condition_flags[36] = !options->lower_fdph;
   condition_flags[37] = options->lower_fdot;
   condition_flags[38] = !options->lower_fsat;
   condition_flags[39] = !options->lower_iabs;
   condition_flags[40] = options->lower_fsat;
   condition_flags[41] = !options->lower_fsat && !nir_is_float_control_signed_zero_inf_nan_preserve(info->float_controls_execution_mode, 32);
   condition_flags[42] = !options->lower_fsign;
   condition_flags[43] = options->lower_umax;
   condition_flags[44] = options->lower_umin;
   condition_flags[45] = !options->lower_umax;
   condition_flags[46] = !options->lower_umin;
   condition_flags[47] = options->lower_scmp;
   condition_flags[48] = options->lower_vector_cmp;
   condition_flags[49] = !options->lower_rotate;
   condition_flags[50] = options->lower_rotate;
   condition_flags[51] = options->lower_fpow;
   condition_flags[52] = !options->lower_fpow;
   condition_flags[53] = options->lower_fdiv;
   condition_flags[54] = options->lower_fsqrt;
   condition_flags[55] = !options->lower_fsqrt;
   condition_flags[56] = options->lower_sincos;
   condition_flags[57] = !(options->lower_doubles_options & nir_lower_fp64_full_software);
   condition_flags[58] = !options->lower_extract_byte;
   condition_flags[59] = !options->lower_extract_word;
   condition_flags[60] = options->has_pack_32_4x8;
   condition_flags[61] = options->lower_pack_64_2x32_split;
   condition_flags[62] = options->lower_pack_32_2x16_split;
   condition_flags[63] = options->lower_unpack_64_2x32_split;
   condition_flags[64] = options->lower_unpack_32_2x16_split;
   condition_flags[65] = options->has_find_msb_rev;
   condition_flags[66] = !options->lower_find_msb_to_reverse;
   condition_flags[67] = !options->lower_find_lsb;
   condition_flags[68] = options->lower_fmod;
   condition_flags[69] = options->lower_uadd_carry;
   condition_flags[70] = options->lower_usub_borrow;
   condition_flags[71] = options->lower_bitfield_insert;
   condition_flags[72] = options->lower_hadd;
   condition_flags[73] = options->lower_hadd64 || (options->lower_int64_options & nir_lower_iadd64) != 0;
   condition_flags[74] = options->lower_mul_32x16;
   condition_flags[75] = options->lower_uadd_sat || (options->lower_int64_options & nir_lower_iadd64) != 0;
   condition_flags[76] = options->lower_uadd_sat;
   condition_flags[77] = options->lower_usub_sat;
   condition_flags[78] = (options->lower_int64_options & nir_lower_usub_sat64) != 0;
   condition_flags[79] = (options->lower_int64_options & nir_lower_iadd_sat64) != 0;
   condition_flags[80] = (options->lower_int64_options & nir_lower_minmax64) != 0;
   condition_flags[81] = (options->lower_int64_options & nir_lower_icmp64) != 0;
   condition_flags[82] = options->lower_bitfield_insert_to_shifts;
   condition_flags[83] = options->lower_bitfield_insert_to_bitfield_select;
   condition_flags[84] = options->lower_bitfield_extract;
   condition_flags[85] = options->lower_bitfield_insert_to_bitfield_select || options->lower_bitfield_insert;
   condition_flags[86] = options->lower_bitfield_extract_to_shifts;
   condition_flags[87] = options->lower_ifind_msb;
   condition_flags[88] = options->lower_find_msb_to_reverse;
   condition_flags[89] = options->lower_uclz;
   condition_flags[90] = options->lower_find_lsb;
   condition_flags[91] = options->lower_extract_byte;
   condition_flags[92] = options->lower_extract_word;
   condition_flags[93] = options->lower_pack_unorm_2x16;
   condition_flags[94] = options->lower_pack_unorm_4x8;
   condition_flags[95] = options->lower_pack_snorm_2x16;
   condition_flags[96] = options->lower_pack_snorm_4x8;
   condition_flags[97] = options->lower_unpack_unorm_2x16;
   condition_flags[98] = options->lower_unpack_unorm_4x8;
   condition_flags[99] = options->lower_unpack_snorm_2x16;
   condition_flags[100] = options->lower_unpack_snorm_4x8;
   condition_flags[101] = options->lower_pack_split;
   condition_flags[102] = options->lower_isign;
   condition_flags[103] = !options->lower_isign;
   condition_flags[104] = options->lower_fsign;
   condition_flags[105] = !options->has_imul24;
   condition_flags[106] = !options->has_umul24;
   condition_flags[107] = !options->has_umad24;
   condition_flags[108] = options->has_imul24;
   condition_flags[109] = options->has_umad24;
   condition_flags[110] = options->has_umul24;
   condition_flags[111] = !options->lower_uadd_sat && !(options->lower_int64_options & nir_lower_iadd64);
   condition_flags[112] = !options->lower_usub_sat;
   condition_flags[113] = !options->lower_usub_sat && !(options->lower_int64_options & nir_lower_usub_sat64);
   condition_flags[114] = options->lower_iadd_sat;
   condition_flags[115] = options->support_8bit_alu;
   condition_flags[116] = options->support_16bit_alu;
   condition_flags[117] = options->lower_ldexp;
   condition_flags[118] = !options->lower_bitfield_reverse;
   condition_flags[119] = info->stage == MESA_SHADER_COMPUTE && info->cs.derivative_group == DERIVATIVE_GROUP_NONE;
   condition_flags[120] = options->lower_fisnormal;
   condition_flags[121] = !options->vectorize_vec2_16bit;
   condition_flags[122] = options->has_fsub;
   condition_flags[123] = options->has_fsub && !(options->lower_doubles_options & nir_lower_dsub);
   condition_flags[124] = options->lower_fneg;
   condition_flags[125] = options->has_isub || options->lower_ineg;
   condition_flags[126] = options->lower_ineg;
   condition_flags[127] = options->lower_iabs;
   condition_flags[128] = options->has_iadd3;
   condition_flags[129] = options->vectorize_vec2_16bit;
   condition_flags[130] = options->fdot_replicates;
   condition_flags[131] = options->lower_fround_even;
   condition_flags[132] = (info->stage != MESA_SHADER_VERTEX && info->stage != MESA_SHADER_GEOMETRY) && !options->intel_vec4;
   condition_flags[133] = options->avoid_ternary_with_two_constants;
   condition_flags[134] = !options->lower_insert_byte;
   condition_flags[135] = !options->lower_insert_word;
   condition_flags[136] = options->has_fused_comp_and_csel;

   nir_foreach_function(function, shader) {
      if (function->impl) {
         progress |= nir_algebraic_impl(function->impl, condition_flags,
                                        &nir_opt_algebraic_late_table);
      }
   }

   return progress;
}


#include "nir.h"
#include "nir_builder.h"
#include "nir_search.h"
#include "nir_search_helpers.h"

/* What follows is NIR algebraic transform code for the following 19
 * transforms:
 *    ('fmul', ('fneg', 'a'), ('fneg', 'b')) => ('fmul', 'a', 'b')
 *    ('ffma', ('fneg', 'a'), ('fneg', 'b'), 'c') => ('ffma', 'a', 'b', 'c')
 *    ('fdot2_replicated', ('fneg', 'a'), ('fneg', 'b')) => ('fdot2_replicated', 'a', 'b')
 *    ('fdot3_replicated', ('fneg', 'a'), ('fneg', 'b')) => ('fdot3_replicated', 'a', 'b')
 *    ('fdot4_replicated', ('fneg', 'a'), ('fneg', 'b')) => ('fdot4_replicated', 'a', 'b')
 *    ('fneg', ('fneg', 'a')) => a
 *    ('fneg', ('fmul(is_used_once)', 'a', 'b')) => ('fmul', ('fneg', 'a'), 'b')
 *    ('fabs', ('fmul(is_used_once)', 'a', 'b')) => ('fmul', ('fabs', 'a'), ('fabs', 'b'))
 *    ('fneg', ('ffma(is_used_once)', 'a', 'b', 'c')) => ('ffma', ('fneg', 'a'), 'b', ('fneg', 'c'))
 *    ('fneg', ('flrp(is_used_once)', 'a', 'b', 'c')) => ('flrp', ('fneg', 'a'), ('fneg', 'b'), 'c')
 *    ('fneg', ('~fadd(is_used_once)', 'a', 'b')) => ('fadd', ('fneg', 'a'), ('fneg', 'b'))
 *    ('fneg', ('fmin(is_used_once)', 'a', 'b')) => ('fmax', ('fneg', 'a'), ('fneg', 'b'))
 *    ('fneg', ('fmax(is_used_once)', 'a', 'b')) => ('fmin', ('fneg', 'a'), ('fneg', 'b'))
 *    ('fneg', ('fdot2_replicated(is_used_once)', 'a', 'b')) => ('fdot2_replicated', ('fneg', 'a'), 'b')
 *    ('fneg', ('fdot3_replicated(is_used_once)', 'a', 'b')) => ('fdot3_replicated', ('fneg', 'a'), 'b')
 *    ('fneg', ('fdot4_replicated(is_used_once)', 'a', 'b')) => ('fdot4_replicated', ('fneg', 'a'), 'b')
 *    ('fneg', ('fdph_replicated(is_used_once)', 'a', 'b')) => ('fdph_replicated', 'a', ('fneg', 'b'))
 *    ('fneg', ('fsign(is_used_once)', 'a')) => ('fsign', ('fneg', 'a'))
 *    ('fabs', ('fsign(is_used_once)', 'a')) => ('fsign', ('fabs', 'a'))
 */


static const nir_search_value_union nir_opt_algebraic_distribute_src_mods_values[] = {
   /* ('fmul', ('fneg', 'a'), ('fneg', 'b')) => ('fmul', 'a', 'b') */
   { .variable = {
      { nir_search_value_variable, -2 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 0 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -2 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 2 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 1, 3 },
      -1,
   } },

   /* replace2293_0 -> 0 in the cache */
   /* replace2293_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 0, 2 },
      -1,
   } },

   /* ('ffma', ('fneg', 'a'), ('fneg', 'b'), 'c') => ('ffma', 'a', 'b', 'c') */
   { .variable = {
      { nir_search_value_variable, -3 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 6 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      1, /* b */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 8 },
      -1,
   } },
   { .variable = {
      { nir_search_value_variable, -3 },
      2, /* c */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 7, 9, 10 },
      -1,
   } },

   /* replace2294_0 -> 6 in the cache */
   /* replace2294_1 -> 8 in the cache */
   /* replace2294_2 -> 10 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 6, 8, 10 },
      -1,
   } },

   /* ('fdot2_replicated', ('fneg', 'a'), ('fneg', 'b')) => ('fdot2_replicated', 'a', 'b') */
   /* search2295_0_0 -> 0 in the cache */
   /* search2295_0 -> 1 in the cache */
   /* search2295_1_0 -> 2 in the cache */
   /* search2295_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot2_replicated,
      0, 1,
      { 1, 3 },
      -1,
   } },

   /* replace2295_0 -> 0 in the cache */
   /* replace2295_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot2_replicated,
      0, 1,
      { 0, 2 },
      -1,
   } },

   /* ('fdot3_replicated', ('fneg', 'a'), ('fneg', 'b')) => ('fdot3_replicated', 'a', 'b') */
   /* search2296_0_0 -> 0 in the cache */
   /* search2296_0 -> 1 in the cache */
   /* search2296_1_0 -> 2 in the cache */
   /* search2296_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot3_replicated,
      0, 1,
      { 1, 3 },
      -1,
   } },

   /* replace2296_0 -> 0 in the cache */
   /* replace2296_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot3_replicated,
      0, 1,
      { 0, 2 },
      -1,
   } },

   /* ('fdot4_replicated', ('fneg', 'a'), ('fneg', 'b')) => ('fdot4_replicated', 'a', 'b') */
   /* search2297_0_0 -> 0 in the cache */
   /* search2297_0 -> 1 in the cache */
   /* search2297_1_0 -> 2 in the cache */
   /* search2297_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot4_replicated,
      0, 1,
      { 1, 3 },
      -1,
   } },

   /* replace2297_0 -> 0 in the cache */
   /* replace2297_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot4_replicated,
      0, 1,
      { 0, 2 },
      -1,
   } },

   /* ('fneg', ('fneg', 'a')) => a */
   { .variable = {
      { nir_search_value_variable, -1 },
      0, /* a */
      false,
      nir_type_invalid,
      -1,
      {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 19 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 20 },
      -1,
   } },

   /* replace2298 -> 19 in the cache */

   /* ('fneg', ('fmul(is_used_once)', 'a', 'b')) => ('fmul', ('fneg', 'a'), 'b') */
   /* search2299_0_0 -> 0 in the cache */
   /* search2299_0_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 0, 2 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 22 },
      -1,
   } },

   /* replace2299_0_0 -> 0 in the cache */
   /* replace2299_0 -> 1 in the cache */
   /* replace2299_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 1, 2 },
      -1,
   } },

   /* ('fabs', ('fmul(is_used_once)', 'a', 'b')) => ('fmul', ('fabs', 'a'), ('fabs', 'b')) */
   /* search2300_0_0 -> 0 in the cache */
   /* search2300_0_1 -> 2 in the cache */
   /* search2300_0 -> 22 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 1,
      { 22 },
      -1,
   } },

   /* replace2300_0_0 -> 0 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 0 },
      -1,
   } },
   /* replace2300_1_0 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 2 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmul,
      0, 1,
      { 26, 27 },
      -1,
   } },

   /* ('fneg', ('ffma(is_used_once)', 'a', 'b', 'c')) => ('ffma', ('fneg', 'a'), 'b', ('fneg', 'c')) */
   /* search2301_0_0 -> 6 in the cache */
   /* search2301_0_1 -> 8 in the cache */
   /* search2301_0_2 -> 10 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 6, 8, 10 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 29 },
      -1,
   } },

   /* replace2301_0_0 -> 6 in the cache */
   /* replace2301_0 -> 7 in the cache */
   /* replace2301_1 -> 8 in the cache */
   /* replace2301_2_0 -> 10 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 10 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_ffma,
      0, 1,
      { 7, 8, 31 },
      -1,
   } },

   /* ('fneg', ('flrp(is_used_once)', 'a', 'b', 'c')) => ('flrp', ('fneg', 'a'), ('fneg', 'b'), 'c') */
   /* search2302_0_0 -> 6 in the cache */
   /* search2302_0_1 -> 8 in the cache */
   /* search2302_0_2 -> 10 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 6, 8, 10 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 33 },
      -1,
   } },

   /* replace2302_0_0 -> 6 in the cache */
   /* replace2302_0 -> 7 in the cache */
   /* replace2302_1_0 -> 8 in the cache */
   /* replace2302_1 -> 9 in the cache */
   /* replace2302_2 -> 10 in the cache */
   { .expression = {
      { nir_search_value_expression, -3 },
      false,
      false,
      false,
      nir_op_flrp,
      -1, 0,
      { 7, 9, 10 },
      -1,
   } },

   /* ('fneg', ('~fadd(is_used_once)', 'a', 'b')) => ('fadd', ('fneg', 'a'), ('fneg', 'b')) */
   /* search2303_0_0 -> 0 in the cache */
   /* search2303_0_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      true,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 0, 2 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 36 },
      -1,
   } },

   /* replace2303_0_0 -> 0 in the cache */
   /* replace2303_0 -> 1 in the cache */
   /* replace2303_1_0 -> 2 in the cache */
   /* replace2303_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fadd,
      0, 1,
      { 1, 3 },
      -1,
   } },

   /* ('fneg', ('fmin(is_used_once)', 'a', 'b')) => ('fmax', ('fneg', 'a'), ('fneg', 'b')) */
   /* search2304_0_0 -> 0 in the cache */
   /* search2304_0_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 0, 2 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 39 },
      -1,
   } },

   /* replace2304_0_0 -> 0 in the cache */
   /* replace2304_0 -> 1 in the cache */
   /* replace2304_1_0 -> 2 in the cache */
   /* replace2304_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 1, 3 },
      -1,
   } },

   /* ('fneg', ('fmax(is_used_once)', 'a', 'b')) => ('fmin', ('fneg', 'a'), ('fneg', 'b')) */
   /* search2305_0_0 -> 0 in the cache */
   /* search2305_0_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmax,
      0, 1,
      { 0, 2 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 42 },
      -1,
   } },

   /* replace2305_0_0 -> 0 in the cache */
   /* replace2305_0 -> 1 in the cache */
   /* replace2305_1_0 -> 2 in the cache */
   /* replace2305_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fmin,
      0, 1,
      { 1, 3 },
      -1,
   } },

   /* ('fneg', ('fdot2_replicated(is_used_once)', 'a', 'b')) => ('fdot2_replicated', ('fneg', 'a'), 'b') */
   /* search2306_0_0 -> 0 in the cache */
   /* search2306_0_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot2_replicated,
      0, 1,
      { 0, 2 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 45 },
      -1,
   } },

   /* replace2306_0_0 -> 0 in the cache */
   /* replace2306_0 -> 1 in the cache */
   /* replace2306_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot2_replicated,
      0, 1,
      { 1, 2 },
      -1,
   } },

   /* ('fneg', ('fdot3_replicated(is_used_once)', 'a', 'b')) => ('fdot3_replicated', ('fneg', 'a'), 'b') */
   /* search2307_0_0 -> 0 in the cache */
   /* search2307_0_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot3_replicated,
      0, 1,
      { 0, 2 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 48 },
      -1,
   } },

   /* replace2307_0_0 -> 0 in the cache */
   /* replace2307_0 -> 1 in the cache */
   /* replace2307_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot3_replicated,
      0, 1,
      { 1, 2 },
      -1,
   } },

   /* ('fneg', ('fdot4_replicated(is_used_once)', 'a', 'b')) => ('fdot4_replicated', ('fneg', 'a'), 'b') */
   /* search2308_0_0 -> 0 in the cache */
   /* search2308_0_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot4_replicated,
      0, 1,
      { 0, 2 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 1,
      { 51 },
      -1,
   } },

   /* replace2308_0_0 -> 0 in the cache */
   /* replace2308_0 -> 1 in the cache */
   /* replace2308_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdot4_replicated,
      0, 1,
      { 1, 2 },
      -1,
   } },

   /* ('fneg', ('fdph_replicated(is_used_once)', 'a', 'b')) => ('fdph_replicated', 'a', ('fneg', 'b')) */
   /* search2309_0_0 -> 0 in the cache */
   /* search2309_0_1 -> 2 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdph_replicated,
      -1, 0,
      { 0, 2 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 54 },
      -1,
   } },

   /* replace2309_0 -> 0 in the cache */
   /* replace2309_1_0 -> 2 in the cache */
   /* replace2309_1 -> 3 in the cache */
   { .expression = {
      { nir_search_value_expression, -2 },
      false,
      false,
      false,
      nir_op_fdph_replicated,
      -1, 0,
      { 0, 3 },
      -1,
   } },

   /* ('fneg', ('fsign(is_used_once)', 'a')) => ('fsign', ('fneg', 'a')) */
   /* search2310_0_0 -> 19 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsign,
      -1, 0,
      { 19 },
      0,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fneg,
      -1, 0,
      { 57 },
      -1,
   } },

   /* replace2310_0_0 -> 19 in the cache */
   /* replace2310_0 -> 20 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsign,
      -1, 0,
      { 20 },
      -1,
   } },

   /* ('fabs', ('fsign(is_used_once)', 'a')) => ('fsign', ('fabs', 'a')) */
   /* search2311_0_0 -> 19 in the cache */
   /* search2311_0 -> 57 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 57 },
      -1,
   } },

   /* replace2311_0_0 -> 19 in the cache */
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fabs,
      -1, 0,
      { 19 },
      -1,
   } },
   { .expression = {
      { nir_search_value_expression, -1 },
      false,
      false,
      false,
      nir_op_fsign,
      -1, 0,
      { 61 },
      -1,
   } },

};

static const nir_search_expression_cond nir_opt_algebraic_distribute_src_mods_expression_cond[] = {
   (is_used_once),
};


static const struct transform nir_opt_algebraic_distribute_src_mods_transforms[] = {
   { ~0, ~0, ~0 }, /* Sentinel */

   { 23, 24, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 21, 19, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 30, 32, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 46, 47, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 49, 50, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 52, 53, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 34, 35, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 37, 38, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 40, 41, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 43, 44, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 55, 56, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 58, 59, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 25, 28, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 60, 62, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 4, 5, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 11, 12, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 13, 14, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 15, 16, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

   { 17, 18, 0 },
   { ~0, ~0, ~0 }, /* Sentinel */

};

static const struct per_op_table nir_opt_algebraic_distribute_src_mods_pass_op_table[nir_num_search_ops] = {
   [nir_op_fmul] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         2,
         2,
         2,
         28,
      },
   },
   [nir_op_fneg] = {
      .filter = (const uint16_t []) {
         0,
         0,
         1,
         2,
         3,
         4,
         5,
         6,
         7,
         8,
         9,
         10,
         11,
         12,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         2,
         0,
         0,
         1,
         3,
         4,
         5,
         6,
      },
      
      .num_filtered_states = 13,
      .table = (const uint16_t []) {
      
         3,
         14,
         15,
         16,
         17,
         18,
         19,
         20,
         21,
         22,
         23,
         24,
         25,
      },
   },
   [nir_op_ffma] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         4,
         4,
         4,
         4,
         4,
         4,
         29,
         29,
      },
   },
   [nir_op_fdot2_replicated] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         5,
         5,
         5,
         30,
      },
   },
   [nir_op_fdot3_replicated] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         6,
         6,
         6,
         31,
      },
   },
   [nir_op_fdot4_replicated] = {
      .filter = (const uint16_t []) {
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 2,
      .table = (const uint16_t []) {
      
         7,
         7,
         7,
         32,
      },
   },
   [nir_op_fabs] = {
      .filter = (const uint16_t []) {
         0,
         0,
         1,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         2,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         0,
         1,
         0,
         0,
         0,
         0,
      },
      
      .num_filtered_states = 3,
      .table = (const uint16_t []) {
      
         0,
         26,
         27,
      },
   },
   [nir_op_flrp] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         8,
      },
   },
   [nir_op_fadd] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         9,
      },
   },
   [nir_op_fmin] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         10,
      },
   },
   [nir_op_fmax] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         11,
      },
   },
   [nir_op_fdph_replicated] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         12,
      },
   },
   [nir_op_fsign] = {
      .filter = NULL,
      
      .num_filtered_states = 1,
      .table = (const uint16_t []) {
      
         13,
      },
   },
};

/* Mapping from state index to offset in transforms (0 being no transforms) */
static const uint16_t nir_opt_algebraic_distribute_src_mods_transform_offsets[] = {
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   0,
   1,
   3,
   5,
   7,
   9,
   11,
   13,
   15,
   17,
   19,
   21,
   23,
   25,
   27,
   29,
   31,
   33,
   35,
   37,
};

static const nir_algebraic_table nir_opt_algebraic_distribute_src_mods_table = {
   .transforms = nir_opt_algebraic_distribute_src_mods_transforms,
   .transform_offsets = nir_opt_algebraic_distribute_src_mods_transform_offsets,
   .pass_op_table = nir_opt_algebraic_distribute_src_mods_pass_op_table,
   .values = nir_opt_algebraic_distribute_src_mods_values,
   .expression_cond = nir_opt_algebraic_distribute_src_mods_expression_cond,
   .variable_cond = NULL,
};

bool
nir_opt_algebraic_distribute_src_mods(nir_shader *shader)
{
   bool progress = false;
   bool condition_flags[137];
   const nir_shader_compiler_options *options = shader->options;
   const shader_info *info = &shader->info;
   (void) options;
   (void) info;

   /* This is not a great place for this, but it seems to be the best place
    * for it. Check that at most one kind of lowering is requested for
    * bitfield extract and bitfield insert. Otherwise the lowering can fight
    * with each other and optimizations.
    */
   assert((int)options->lower_bitfield_extract +
          (int)options->lower_bitfield_extract_to_shifts <= 1);
   assert((int)options->lower_bitfield_insert +
          (int)options->lower_bitfield_insert_to_shifts +
          (int)options->lower_bitfield_insert_to_bitfield_select <= 1);


   STATIC_ASSERT(63 == ARRAY_SIZE(nir_opt_algebraic_distribute_src_mods_values));
   condition_flags[0] = true;
   condition_flags[1] = !options->lower_bitops;
   condition_flags[2] = options->lower_bitops;
   condition_flags[3] = !options->lower_bitops && (options->lower_int64_options & (nir_lower_imul64 | nir_lower_shift64)) == nir_lower_imul64;
   condition_flags[4] = options->lower_mul_2x32_64;
   condition_flags[5] = !nir_is_float_control_signed_zero_inf_nan_preserve(info->float_controls_execution_mode, 16);
   condition_flags[6] = !nir_is_float_control_signed_zero_inf_nan_preserve(info->float_controls_execution_mode, 32);
   condition_flags[7] = !options->lower_iadd_sat;
   condition_flags[8] = !options->lower_uadd_sat;
   condition_flags[9] = options->has_fmulz && !nir_is_float_control_signed_zero_inf_nan_preserve(info->float_controls_execution_mode, 32);
   condition_flags[10] = !options->has_sdot_4x8;
   condition_flags[11] = !options->has_udot_4x8;
   condition_flags[12] = !options->has_sudot_4x8;
   condition_flags[13] = !options->has_dot_2x16;
   condition_flags[14] = options->lower_flrp16;
   condition_flags[15] = !options->lower_flrp16;
   condition_flags[16] = options->lower_flrp32;
   condition_flags[17] = !options->lower_flrp32;
   condition_flags[18] = options->lower_flrp64;
   condition_flags[19] = !options->lower_flrp64;
   condition_flags[20] = options->lower_ftrunc;
   condition_flags[21] = options->lower_ftrunc || (options->lower_doubles_options & nir_lower_dtrunc);
   condition_flags[22] = options->lower_ffloor;
   condition_flags[23] = (options->lower_ffloor || (options->lower_doubles_options & nir_lower_dfloor)) && !(options->lower_doubles_options & nir_lower_dfract);
   condition_flags[24] = !options->lower_ffloor;
   condition_flags[25] = !options->lower_ffloor && !(options->lower_doubles_options & nir_lower_dfloor);
   condition_flags[26] = options->lower_ffract;
   condition_flags[27] = options->lower_ffract || (options->lower_doubles_options & nir_lower_dfract);
   condition_flags[28] = options->lower_fceil;
   condition_flags[29] = options->lower_ffma16;
   condition_flags[30] = options->lower_ffma32;
   condition_flags[31] = options->lower_ffma64;
   condition_flags[32] = options->fuse_ffma16;
   condition_flags[33] = options->fuse_ffma32;
   condition_flags[34] = options->fuse_ffma64;
   condition_flags[35] = options->lower_fdph;
   condition_flags[36] = !options->lower_fdph;
   condition_flags[37] = options->lower_fdot;
   condition_flags[38] = !options->lower_fsat;
   condition_flags[39] = !options->lower_iabs;
   condition_flags[40] = options->lower_fsat;
   condition_flags[41] = !options->lower_fsat && !nir_is_float_control_signed_zero_inf_nan_preserve(info->float_controls_execution_mode, 32);
   condition_flags[42] = !options->lower_fsign;
   condition_flags[43] = options->lower_umax;
   condition_flags[44] = options->lower_umin;
   condition_flags[45] = !options->lower_umax;
   condition_flags[46] = !options->lower_umin;
   condition_flags[47] = options->lower_scmp;
   condition_flags[48] = options->lower_vector_cmp;
   condition_flags[49] = !options->lower_rotate;
   condition_flags[50] = options->lower_rotate;
   condition_flags[51] = options->lower_fpow;
   condition_flags[52] = !options->lower_fpow;
   condition_flags[53] = options->lower_fdiv;
   condition_flags[54] = options->lower_fsqrt;
   condition_flags[55] = !options->lower_fsqrt;
   condition_flags[56] = options->lower_sincos;
   condition_flags[57] = !(options->lower_doubles_options & nir_lower_fp64_full_software);
   condition_flags[58] = !options->lower_extract_byte;
   condition_flags[59] = !options->lower_extract_word;
   condition_flags[60] = options->has_pack_32_4x8;
   condition_flags[61] = options->lower_pack_64_2x32_split;
   condition_flags[62] = options->lower_pack_32_2x16_split;
   condition_flags[63] = options->lower_unpack_64_2x32_split;
   condition_flags[64] = options->lower_unpack_32_2x16_split;
   condition_flags[65] = options->has_find_msb_rev;
   condition_flags[66] = !options->lower_find_msb_to_reverse;
   condition_flags[67] = !options->lower_find_lsb;
   condition_flags[68] = options->lower_fmod;
   condition_flags[69] = options->lower_uadd_carry;
   condition_flags[70] = options->lower_usub_borrow;
   condition_flags[71] = options->lower_bitfield_insert;
   condition_flags[72] = options->lower_hadd;
   condition_flags[73] = options->lower_hadd64 || (options->lower_int64_options & nir_lower_iadd64) != 0;
   condition_flags[74] = options->lower_mul_32x16;
   condition_flags[75] = options->lower_uadd_sat || (options->lower_int64_options & nir_lower_iadd64) != 0;
   condition_flags[76] = options->lower_uadd_sat;
   condition_flags[77] = options->lower_usub_sat;
   condition_flags[78] = (options->lower_int64_options & nir_lower_usub_sat64) != 0;
   condition_flags[79] = (options->lower_int64_options & nir_lower_iadd_sat64) != 0;
   condition_flags[80] = (options->lower_int64_options & nir_lower_minmax64) != 0;
   condition_flags[81] = (options->lower_int64_options & nir_lower_icmp64) != 0;
   condition_flags[82] = options->lower_bitfield_insert_to_shifts;
   condition_flags[83] = options->lower_bitfield_insert_to_bitfield_select;
   condition_flags[84] = options->lower_bitfield_extract;
   condition_flags[85] = options->lower_bitfield_insert_to_bitfield_select || options->lower_bitfield_insert;
   condition_flags[86] = options->lower_bitfield_extract_to_shifts;
   condition_flags[87] = options->lower_ifind_msb;
   condition_flags[88] = options->lower_find_msb_to_reverse;
   condition_flags[89] = options->lower_uclz;
   condition_flags[90] = options->lower_find_lsb;
   condition_flags[91] = options->lower_extract_byte;
   condition_flags[92] = options->lower_extract_word;
   condition_flags[93] = options->lower_pack_unorm_2x16;
   condition_flags[94] = options->lower_pack_unorm_4x8;
   condition_flags[95] = options->lower_pack_snorm_2x16;
   condition_flags[96] = options->lower_pack_snorm_4x8;
   condition_flags[97] = options->lower_unpack_unorm_2x16;
   condition_flags[98] = options->lower_unpack_unorm_4x8;
   condition_flags[99] = options->lower_unpack_snorm_2x16;
   condition_flags[100] = options->lower_unpack_snorm_4x8;
   condition_flags[101] = options->lower_pack_split;
   condition_flags[102] = options->lower_isign;
   condition_flags[103] = !options->lower_isign;
   condition_flags[104] = options->lower_fsign;
   condition_flags[105] = !options->has_imul24;
   condition_flags[106] = !options->has_umul24;
   condition_flags[107] = !options->has_umad24;
   condition_flags[108] = options->has_imul24;
   condition_flags[109] = options->has_umad24;
   condition_flags[110] = options->has_umul24;
   condition_flags[111] = !options->lower_uadd_sat && !(options->lower_int64_options & nir_lower_iadd64);
   condition_flags[112] = !options->lower_usub_sat;
   condition_flags[113] = !options->lower_usub_sat && !(options->lower_int64_options & nir_lower_usub_sat64);
   condition_flags[114] = options->lower_iadd_sat;
   condition_flags[115] = options->support_8bit_alu;
   condition_flags[116] = options->support_16bit_alu;
   condition_flags[117] = options->lower_ldexp;
   condition_flags[118] = !options->lower_bitfield_reverse;
   condition_flags[119] = info->stage == MESA_SHADER_COMPUTE && info->cs.derivative_group == DERIVATIVE_GROUP_NONE;
   condition_flags[120] = options->lower_fisnormal;
   condition_flags[121] = !options->vectorize_vec2_16bit;
   condition_flags[122] = options->has_fsub;
   condition_flags[123] = options->has_fsub && !(options->lower_doubles_options & nir_lower_dsub);
   condition_flags[124] = options->lower_fneg;
   condition_flags[125] = options->has_isub || options->lower_ineg;
   condition_flags[126] = options->lower_ineg;
   condition_flags[127] = options->lower_iabs;
   condition_flags[128] = options->has_iadd3;
   condition_flags[129] = options->vectorize_vec2_16bit;
   condition_flags[130] = options->fdot_replicates;
   condition_flags[131] = options->lower_fround_even;
   condition_flags[132] = (info->stage != MESA_SHADER_VERTEX && info->stage != MESA_SHADER_GEOMETRY) && !options->intel_vec4;
   condition_flags[133] = options->avoid_ternary_with_two_constants;
   condition_flags[134] = !options->lower_insert_byte;
   condition_flags[135] = !options->lower_insert_word;
   condition_flags[136] = options->has_fused_comp_and_csel;

   nir_foreach_function(function, shader) {
      if (function->impl) {
         progress |= nir_algebraic_impl(function->impl, condition_flags,
                                        &nir_opt_algebraic_distribute_src_mods_table);
      }
   }

   return progress;
}

